
/****************************************************************************************************//**
 * @file     V85XX.h
 *
 * @brief    CMSIS Cortex-M0 Peripheral Access Layer Header File for
 *           V85XX from Vango.
 *
 * @version  V1.0
 * @date     5. June 2020
 *
 * @note     Generated with SVDConv V2.87e 
 *           from CMSIS SVD File 'V85XX.svd' Version 1.0,
 *******************************************************************************************************/



/** @addtogroup Vango
  * @{
  */

/** @addtogroup V85XX
  * @{
  */

#ifndef V85XX_H
#define V85XX_H

#ifdef __cplusplus
extern "C" {
#endif


/* -------------------------  Interrupt Number Definition  ------------------------ */

typedef enum {
/* -------------------  Cortex-M0 Processor Exceptions Numbers  ------------------- */
  Reset_IRQn                    = -15,              /*!<   1  Reset Vector, invoked on Power up and warm reset                 */
  NonMaskableInt_IRQn           = -14,              /*!<   2  Non maskable Interrupt, cannot be stopped or preempted           */
  HardFault_IRQn                = -13,              /*!<   3  Hard Fault, all classes of Fault                                 */
  SVCall_IRQn                   =  -5,              /*!<  11  System Service Call via SVC instruction                          */
  PendSV_IRQn                   =  -2,              /*!<  14  Pendable request for system service                              */
  SysTick_IRQn                  =  -1,              /*!<  15  System Tick Timer                                                */
/* ----------------------  V85XX Specific Interrupt Numbers  ---------------------- */
  PMU_IRQn                      =   0,              /*!<   0  PMU                                                              */
  RTC_IRQn                      =   1,              /*!<   1  RTC                                                              */
  U32K0_IRQn                    =   2,              /*!<   2  U32K0                                                            */
  U32K1_IRQn                    =   3,              /*!<   3  U32K1                                                            */
  I2C_IRQn                      =   4,              /*!<   4  I2C                                                              */
  SPI1_IRQn                     =   5,              /*!<   5  SPI1                                                             */
  UART0_IRQn                    =   6,              /*!<   6  UART0                                                            */
  UART1_IRQn                    =   7,              /*!<   7  UART1                                                            */
  UART2_IRQn                    =   8,              /*!<   8  UART2                                                            */
  UART3_IRQn                    =   9,              /*!<   9  UART3                                                            */
  UART4_IRQn                    =  10,              /*!<  10  UART4                                                            */
  UART5_IRQn                    =  11,              /*!<  11  UART5                                                            */
  ISO78160_IRQn                 =  12,              /*!<  12  ISO78160                                                         */
  ISO78161_IRQn                 =  13,              /*!<  13  ISO78161                                                         */
  TMR0_IRQn                     =  14,              /*!<  14  TMR0                                                             */
  TMR1_IRQn                     =  15,              /*!<  15  TMR1                                                             */
  TMR2_IRQn                     =  16,              /*!<  16  TMR2                                                             */
  TMR3_IRQn                     =  17,              /*!<  17  TMR3                                                             */
  PWM0_IRQn                     =  18,              /*!<  18  PWM0                                                             */
  PWM1_IRQn                     =  19,              /*!<  19  PWM1                                                             */
  PWM2_IRQn                     =  20,              /*!<  20  PWM2                                                             */
  PWM3_IRQn                     =  21,              /*!<  21  PWM3                                                             */
  DMA_IRQn                      =  22,              /*!<  22  DMA                                                              */
  FLASH_IRQn                    =  23,              /*!<  23  FLASH                                                            */
  ANA_IRQn                      =  24,              /*!<  24  ANA                                                              */
  SPI2_IRQn                     =  27               /*!<  27  SPI2                                                             */
} IRQn_Type;


/** @addtogroup Configuration_of_CMSIS
  * @{
  */


/* ================================================================================ */
/* ================      Processor and Core Peripheral Section     ================ */
/* ================================================================================ */

/* ----------------Configuration of the Cortex-M0 Processor and Core Peripherals---------------- */
#define __CM0_REV                 0x0000            /*!< Cortex-M0 Core Revision                                               */
#define __MPU_PRESENT                  0            /*!< MPU present or not                                                    */
#define __NVIC_PRIO_BITS               2            /*!< Number of Bits used for Priority Levels                               */
#define __Vendor_SysTickConfig         0            /*!< Set to 1 if different SysTick Config is used                          */
/** @} */ /* End of group Configuration_of_CMSIS */

#include "core_cm0.h"                               /*!< Cortex-M0 processor and core peripherals                              */
#include "system_V85XX.h"                           /*!< V85XX System                                                          */


/* ================================================================================ */
/* ================       Device Specific Peripheral Section       ================ */
/* ================================================================================ */


/** @addtogroup Device_Peripheral_Registers
  * @{
  */


/* -------------------  Start of section using anonymous unions  ------------------ */
#if defined(__CC_ARM)
  #pragma push
  #pragma anon_unions
#elif defined(__ICCARM__)
  #pragma language=extended
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__TMS470__)
/* anonymous unions are enabled by default */
#elif defined(__TASKING__)
  #pragma warning 586
#else
  #warning Not supported compiler type
#endif



/* ================================================================================ */
/* ================                       ANA                      ================ */
/* ================================================================================ */


/**
  * @brief The Analog controller is used to control the analog function of V85XX. All the analog related control like ADC, comparator and other analog flag detection are controlled by this module. The analog controller is placed in always-on domain, so all the analog setting will be kept under deep-sleep mode. (ANA)
  */

typedef struct {                                    /*!< ANA Structure                                                         */
  __IO uint32_t  REG0;                              /*!< Analog register 0.                                                    */
  __IO uint32_t  REG1;                              /*!< Analog register 1.                                                    */
  __IO uint32_t  REG2;                              /*!< Analog register 2.                                                    */
  __IO uint32_t  REG3;                              /*!< Analog register 3.                                                    */
  __IO uint32_t  REG4;                              /*!< Analog register 4.                                                    */
  __IO uint32_t  REG5;                              /*!< Analog register 5.                                                    */
  __IO uint32_t  REG6;                              /*!< Analog register 6.                                                    */
  __IO uint32_t  REG7;                              /*!< Analog register 7.                                                    */
  __IO uint32_t  REG8;                              /*!< Analog register 8.                                                    */
  __IO uint32_t  REG9;                              /*!< Analog register 9.                                                    */
  __IO uint32_t  REGA;                              /*!< Analog register 10.                                                   */
  __IO uint32_t  REGB;                              /*!< Analog register 11.                                                   */
  __IO uint32_t  REGC;                              /*!< Analog register 12.                                                   */
  __IO uint32_t  REGD;                              /*!< Analog register 13.                                                   */
  __IO uint32_t  REGE;                              /*!< Analog register 14.                                                   */
  __IO uint32_t  REGF;                              /*!< Analog register 15.                                                   */
  __I  uint32_t  RESERVED[4];
  __IO uint32_t  CTRL;                              /*!< Analog control register.                                              */
  __I  uint32_t  CMPOUT;                            /*!< Comparator result register.                                           */
  __I  uint32_t  RESERVED1[2];
  __IO uint32_t  INTSTS;                            /*!< Analog interrupt status register.                                     */
  __IO uint32_t  INTEN;                             /*!< Analog interrupt enable register.                                     */
  __IO uint32_t  ADCCTRL;                           /*!< ADC control register..                                                */
  __I  uint32_t  RESERVED2;
  __I  uint32_t  ADCDATA[12];                       /*!< ADC channel x data register.                                          */
  __I  uint32_t  RESERVED3[4];
  __IO uint32_t  CMPCNT1;                           /*!< Comparator 1 counter.                                                 */
  __IO uint32_t  CMPCNT2;                           /*!< Comparator 2 counter.                                                 */
  __IO uint32_t  MISC;                              /*!< Analog misc. control register.                                        */
} ANA_Type;


/* ================================================================================ */
/* ================                      CRYPT                     ================ */
/* ================================================================================ */


/**
  * @brief CRYPT accelerate the sign and verify process speed of ECC. (CRYPT)
  */

typedef struct {                                    /*!< CRYPT Structure                                                       */
  __IO uint32_t  CTRL;                              /*!< CRYPT control register.                                               */
  __IO uint32_t  PTRA;                              /*!< CRYPT pointer A.                                                      */
  __IO uint32_t  PTRB;                              /*!< CRYPT pointer B.                                                      */
  __IO uint32_t  PTRO;                              /*!< CRYPT pointer O.                                                      */
  __I  uint32_t  CARRY;                             /*!< CRYPT carry/borrow bit register.                                      */
} CRYPT_Type;


/* ================================================================================ */
/* ================                       DMA                      ================ */
/* ================================================================================ */


/**
  * @brief DMA(Direct Memory Access) (DMA)
  */

typedef struct {                                    /*!< DMA Structure                                                         */
  __IO uint32_t  IE;                                /*!< DMA interrupt enable register.                                        */
  __IO uint32_t  STS;                               /*!< DMA status register.                                                  */
  __I  uint32_t  RESERVED[2];
  __IO uint32_t  C0CTL;                             /*!< DMA channel x control register.                                       */
  __IO uint32_t  C0SRC;                             /*!< DMA source address register.                                          */
  __IO uint32_t  C0DST;                             /*!< DMA channel x destination register.                                   */
  __IO uint32_t  C0LEN;                             /*!< DMA channel x transfer length register.                               */
  __IO uint32_t  C1CTL;                             /*!< DMA channel x control register.                                       */
  __IO uint32_t  C1SRC;                             /*!< DMA source address register.                                          */
  __IO uint32_t  C1DST;                             /*!< DMA channel x destination register.                                   */
  __IO uint32_t  C1LEN;                             /*!< DMA channel x transfer length register.                               */
  __IO uint32_t  C2CTL;                             /*!< DMA channel x control register.                                       */
  __IO uint32_t  C2SRC;                             /*!< DMA source address register.                                          */
  __IO uint32_t  C2DST;                             /*!< DMA channel x destination register.                                   */
  __IO uint32_t  C2LEN;                             /*!< DMA channel x transfer length register.                               */
  __IO uint32_t  C3CTL;                             /*!< DMA channel x control register.                                       */
  __IO uint32_t  C3SRC;                             /*!< DMA source address register.                                          */
  __IO uint32_t  C3DST;                             /*!< DMA channel x destination register.                                   */
  __IO uint32_t  C3LEN;                             /*!< DMA channel x transfer length register.                               */
  __IO uint32_t  AESCTL;                            /*!< DMA AES control register.                                             */
  __I  uint32_t  RESERVED1[3];
  __IO uint32_t  AESKEY0;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY1;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY2;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY3;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY4;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY5;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY6;                           /*!< DMA AES KEY register.                                                 */
  __IO uint32_t  AESKEY7;                           /*!< DMA AES KEY register.                                                 */
} DMA_Type;


/* ================================================================================ */
/* ================                      FLASH                     ================ */
/* ================================================================================ */


/**
  * @brief FLASH Register (FLASH)
  */

typedef struct {                                    /*!< FLASH Structure                                                       */
  __I  uint32_t  RESERVED[3];
  __I  uint32_t  STS;                               /*!< Flash programming status register.                                    */
  __I  uint32_t  RESERVED1[3];
  __IO uint32_t  INT;                               /*!< FLASH Checksum interrupt status                                       */
  __IO uint32_t  CSSADDR;                           /*!< FLASH Checksum start address                                          */
  __IO uint32_t  CSEADDR;                           /*!< FLASH Checksum end address.                                           */
  __I  uint32_t  CSVALUE;                           /*!< FLASH Checksum value register                                         */
  __IO uint32_t  CSCVALUE;                          /*!< FLASH Checksum compare value register.                                */
  __IO uint32_t  PASS;                              /*!< FLASH password register                                               */
  __IO uint32_t  CTRL;                              /*!< FLASH control register.                                               */
  __IO uint32_t  PGADDR;                            /*!< FLASH program address register.                                       */
  __IO uint32_t  PGDATA;                            /*!< FLASH program word data register.                                     */
  __I  uint32_t  RESERVED2;
  __IO uint32_t  SERASE;                            /*!< FLASH sector erase control register.                                  */
  __IO uint32_t  CERASE;                            /*!< FLASH chip erase control register.                                    */
  __IO uint32_t  DSTB;                              /*!< FLASH deep standby control register.                                  */
} FLASH_Type;


/* ================================================================================ */
/* ================                      GPIOA                     ================ */
/* ================================================================================ */


/**
  * @brief The GPIO controller is used to control the GPIOs of V85XX. (GPIOA)
  */

typedef struct {                                    /*!< GPIOA Structure                                                       */
  __IO uint32_t  OEN;                               /*!< IOA output enable register                                            */
  __IO uint32_t  IE;                                /*!< IOA input enable register.                                            */
  __IO uint32_t  DAT;                               /*!< IOA data register.                                                    */
  __IO uint32_t  ATT;                               /*!< IOA attribute register.                                               */
  __IO uint32_t  WKUEN;                             /*!< IOA wake-up enable register.                                          */
  __I  uint32_t  STS;                               /*!< IOA input status register.                                            */
  __IO uint32_t  INTSTS;                            /*!< IOA interrupt status register.                                        */
  __I  uint32_t  RESERVED[3];
  __IO uint32_t  SEL;                               /*!< IOA special function select register.                                 */
  __I  uint32_t  RESERVED1[5];
  __IO uint32_t  IOANODEG;                          /*!< IOA wake-up signal will go through de-glitch circuit or not
                                                         control register.                                                     */
} GPIOA_Type;


/* ================================================================================ */
/* ================                      GPIO                      ================ */
/* ================================================================================ */


/**
  * @brief The GPIO controller is used to control the GPIOs of TARGET. (GPIO)
  */

typedef struct {                                    /*!< GPIO Structure                                                        */
  __IO uint32_t  OEN;                               /*!< IO output enable register                                             */
  __IO uint32_t  IE;                                /*!< IO input enable register                                              */
  __IO uint32_t  DAT;                               /*!< IO data register                                                      */
  __IO uint32_t  ATT;                               /*!< IO attribute register                                                 */
  __I  uint32_t  STS;                               /*!< IO input status register                                              */
} GPIO_Type;


/* ================================================================================ */
/* ================                     GPIOSEL                    ================ */
/* ================================================================================ */


/**
  * @brief The GPIO controller is used to control the GPIOs of TARGET. (GPIOSEL)
  */

typedef struct {                                    /*!< GPIOSEL Structure                                                     */
  __IO uint32_t  IOB_SEL;                           /*!< IOB special function select register.                                 */
  __I  uint32_t  RESERVED[2];
  __IO uint32_t  IOE_SEL;                           /*!< IOE special function select register.                                 */
  __I  uint32_t  RESERVED1[4];
  __IO uint32_t  IO_MISC;                           /*!< IO misc. control register.                                            */
} GPIOSEL_Type;


/* ================================================================================ */
/* ================                       I2C                      ================ */
/* ================================================================================ */


/**
  * @brief I2C-Inter Integrated Circuit (I2C)
  */

typedef struct {                                    /*!< I2C Structure                                                         */
  __IO uint32_t  DATA;                              /*!< I2C data register.                                                    */
  __IO uint32_t  ADDR;                              /*!< I2C address register.                                                 */
  __IO uint32_t  CTRL;                              /*!< I2C control/status register.                                          */
  __IO uint32_t  STS;                               /*!< I2C status register.                                                  */
  __I  uint32_t  RESERVED[2];
  __IO uint32_t  CTRL2;                             /*!< I2C interrupt enable register.                                        */
} I2C_Type;


/* ================================================================================ */
/* ================                     ISO7816                    ================ */
/* ================================================================================ */


/**
  * @brief The ISO7816 controller is an enhance UART protocol which is able to do half-duplex communication on the 2 wires bus. (ISO7816)
  */

typedef struct {                                    /*!< ISO7816 Structure                                                     */
  __I  uint32_t  RESERVED;
  __IO uint32_t  BAUDDIVL;                          /*!< ISO7816 baud-rate low byte register                                   */
  __IO uint32_t  BAUDDIVH;                          /*!< ISO7816 baud-rate high byte register                                  */
  __IO uint32_t  DATA;                              /*!< ISO7816 data register.                                                */
  __IO uint32_t  INFO;                              /*!< ISO7816 information register.                                         */
  __IO uint32_t  CFG;                               /*!< ISO7816 control register.                                             */
  __IO uint32_t  CLK;                               /*!< ISO7816 clock divider control register.                               */
} ISO7816_Type;


/* ================================================================================ */
/* ================                       LCD                      ================ */
/* ================================================================================ */


/**
  * @brief The LCD controller is used to display content on the LCD panel. (LCD)
  */

typedef struct {                                    /*!< LCD Structure                                                         */
  __IO uint32_t  FB[40];                            /*!< LCD Frame buffer x register                                           */
  __I  uint32_t  RESERVED[24];
  __IO uint32_t  CTRL;                              /*!< LCD control register.                                                 */
  __IO uint32_t  CTRL2;                             /*!< LCD control register2.                                                */
  __IO uint32_t  SEGCTRL0;                          /*!< LCD segment enable control register x                                 */
  __IO uint32_t  SEGCTRL1;                          /*!< LCD segment enable control register x                                 */
  __IO uint32_t  SEGCTRL2;                          /*!< LCD segment enable control register x                                 */
} LCD_Type;


/* ================================================================================ */
/* ================                      MISC                      ================ */
/* ================================================================================ */


/**
  * @brief The MISC controller is used to control some special function of V85XX, which will be power-off during sleep and deep-sleep mode.  (MISC)
  */

typedef struct {                                    /*!< MISC Structure                                                        */
  __IO uint32_t  SRAMINT;                           /*!< SRAM Parity Error Interrupt.                                          */
  __IO uint32_t  SRAMINIT;                          /*!< SRAM initialize register.                                             */
  __I  uint32_t  PARERR;                            /*!< SRAM Parity Error address register.                                   */
  __IO uint32_t  IREN;                              /*!< IR enable control register.                                           */
  __IO uint32_t  DUTYL;                             /*!< IR Duty low pulse control register.                                   */
  __IO uint32_t  DUTYH;                             /*!< IR Duty high pulse control register.                                  */
  __IO uint32_t  IRQLAT;                            /*!< Cortex M0 IRQ latency control register.                               */
  __I  uint32_t  RESERVED;
  __I  uint32_t  HIADDR;                            /*!< AHB invalid access address.                                           */
  __I  uint32_t  PIADDR;                            /*!< APB invalid access address.                                           */
} MISC_Type;


/* ================================================================================ */
/* ================                      MISC2                     ================ */
/* ================================================================================ */


/**
  * @brief MISC2 controller is in retention domain which will be power-off at deep-sleep mode. The setting in MISC2 controller will be reset after wake-up from deep-sleep mode, programmer should restore the setting manually after wake-up from deep-sleep mode.  (MISC2)
  */

typedef struct {                                    /*!< MISC2 Structure                                                       */
  __IO uint32_t  FLASHWC;                           /*!< Flash wait cycle register.                                            */
  __IO uint32_t  CLKSEL;                            /*!< Clock selection register.                                             */
  __IO uint32_t  CLKDIVH;                           /*!< AHB clock divider control register                                    */
  __IO uint32_t  CLKDIVP;                           /*!< APB clock divider control register                                    */
  __IO uint32_t  HCLKEN;                            /*!< AHB clock enable control register.                                    */
  __IO uint32_t  PCLKEN;                            /*!< APB clock enable control register.                                    */
} MISC2_Type;


/* ================================================================================ */
/* ================                       PMU                      ================ */
/* ================================================================================ */


/**
  * @brief Power Management Unit. (PMU)
  */

typedef struct {                                    /*!< PMU Structure                                                         */
  __IO uint32_t  DSLEEPEN;                          /*!< PMU deep sleep enable register.                                       */
  __IO uint32_t  DSLEEPPASS;                        /*!< PMU deep sleep password register.                                     */
  __IO uint32_t  CONTROL;                           /*!< PMU control register.                                                 */
  __IO uint32_t  STS;                               /*!< MU Status register.                                                   */
  __I  uint32_t  RESERVED[11];
  __I  uint32_t  VERSIONID;                         /*!< Version ID of V85XX.                                                  */
  __IO uint32_t  WDTPASS;                           /*!< Watch dog timing unlock register.                                     */
  __IO uint32_t  WDTEN;                             /*!< Watch dog timer enable register.                                      */
  __IO uint32_t  WDTCLR;                            /*!< Watch dog timer clear register.                                       */
  __I  uint32_t  RESERVED1[237];
  __IO uint32_t  RAM[64];                           /*!< PMU 32 bits Retention RAM x.                                          */
} PMU_Type;


/* ================================================================================ */
/* ================                       PWM                      ================ */
/* ================================================================================ */


/**
  * @brief Timers are 16 bits timers with PWM and capture function. (PWM)
  */

typedef struct {                                    /*!< PWM Structure                                                         */
  __IO uint32_t  CTL;                               /*!< Control register of PWM Timer.                                        */
  __I  uint32_t  TAR;                               /*!< Current count register of PWM Timer x.                                */
  __IO uint32_t  CCTL0;                             /*!< Compare/capture control register x(x=0~3) for PWM timer y(y=0~3).     */
  __IO uint32_t  CCTL1;                             /*!< Compare/capture control register x(x=0~3) for PWM timer y(y=0~3).     */
  __IO uint32_t  CCTL2;                             /*!< Compare/capture control register x(x=0~3) for PWM timer y(y=0~3).     */
  __IO uint32_t  CCR0;                              /*!< Compare data register x for PWM timer y.                              */
  __IO uint32_t  CCR1;                              /*!< Compare data register x for PWM timer y.                              */
  __IO uint32_t  CCR2;                              /*!< Compare data register x for PWM timer y.                              */
} PWM_Type;


/* ================================================================================ */
/* ================                     PWMOSEL                    ================ */
/* ================================================================================ */


/**
  * @brief PWM output selection register. (PWMOSEL)
  */

typedef struct {                                    /*!< PWMOSEL Structure                                                     */
  __IO uint32_t  O_SEL;                             /*!< PWM output selection register.                                        */
} PWMOSEL_Type;


/* ================================================================================ */
/* ================                       RTC                      ================ */
/* ================================================================================ */


/**
  * @brief The RTC controller is used to control time calculation and RTC auto calibration function. (RTC)
  */

typedef struct {                                    /*!< RTC Structure                                                         */
  __IO uint32_t  SEC;                               /*!< RTC second register                                                   */
  __IO uint32_t  MIN;                               /*!< RTC minute register                                                   */
  __IO uint32_t  HOUR;                              /*!< RTC hour register                                                     */
  __IO uint32_t  DAY;                               /*!< RTC day register                                                      */
  __IO uint32_t  WEEK;                              /*!< RTC week-day register                                                 */
  __IO uint32_t  MON;                               /*!< RTC month register                                                    */
  __IO uint32_t  YEAR;                              /*!< RTC year register                                                     */
  __I  uint32_t  RESERVED;
  __IO uint32_t  WKUSEC;                            /*!< RTC wake-up second register.                                          */
  __IO uint32_t  WKUMIN;                            /*!< RTC wake-up minute register                                           */
  __IO uint32_t  WKUHOUR;                           /*!< RTC wake-up hour register                                             */
  __IO uint32_t  WKUCNT;                            /*!< RTC wake-up counter register                                          */
  __IO uint32_t  CAL;                               /*!< RTC calibration register                                              */
  __IO uint32_t  DIV;                               /*!< RTC PLL divider register                                              */
  __IO uint32_t  CTL;                               /*!< RTC PLL divider control register                                      */
  __I  uint32_t  RESERVED1[2];
  __IO uint32_t  PWD;                               /*!< RTC password control register.                                        */
  __IO uint32_t  CE;                                /*!< RTC write enable control register.                                    */
  __I  uint32_t  LOAD;                              /*!< RTC read enable control register                                      */
  __IO uint32_t  INTSTS;                            /*!< RTC interrupt status control register                                 */
  __IO uint32_t  INTEN;                             /*!< RTC interrupt enable control register                                 */
  __IO uint32_t  PSCA;                              /*!< RTC clock pre-scaler control register.                                */
  __I  uint32_t  RESERVED2[9];
  __IO uint32_t  ACCTRL;                            /*!< RTC auto-calibration control register.                                */
  __IO uint32_t  ACTI;                              /*!< RTC auto-calibration center temperature control register.             */
  __IO uint32_t  ACF200;                            /*!< RTC auto-calibration 200*frequency control register.                  */
  __IO uint32_t  ACADCW;                            /*!< RTC auto-calibration manual ADC value control register.               */
  __IO uint32_t  ACP0;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP1;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP2;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP3;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP4;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP5;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP6;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACP7;                              /*!< RTC auto-calibration parameter x control register.                    */
  __IO uint32_t  ACK1;                              /*!< RTC auto-calibration parameter Kx control register.                   */
  __IO uint32_t  ACK2;                              /*!< RTC auto-calibration parameter Kx control register.                   */
  __IO uint32_t  ACK3;                              /*!< RTC auto-calibration parameter Kx control register.                   */
  __IO uint32_t  ACK4;                              /*!< RTC auto-calibration parameter Kx control register.                   */
  __IO uint32_t  ACK5;                              /*!< RTC auto-calibration parameter Kx control register.                   */
  __I  uint32_t  ACTEMP;                            /*!< RTC auto-calibration calculated temperature register.                 */
  __I  uint32_t  ACPPM;                             /*!< RTC auto-calibration calculated PPM register.                         */
  __I  uint32_t  WKUCNTR;                           /*!< RTC current WKUCNT counter value read-out register.                   */
  __IO uint32_t  ACKTEMP;                           /*!< RTC auto-calibration k temperature section control register.
                                                                                                                               */
} RTC_Type;


/* ================================================================================ */
/* ================                       SPI                      ================ */
/* ================================================================================ */


/**
  * @brief SPI(Serial Peripheral Interface).  (SPI)
  */

typedef struct {                                    /*!< SPI Structure                                                         */
  __IO uint32_t  CTRL;                              /*!< SPI1 Control Register.                                                */
  __IO uint32_t  TXSTS;                             /*!< SPI1 Transmit Status Register.                                        */
  __O  uint32_t  TXDAT;                             /*!< SPI1 Transmit FIFO register.                                          */
  __IO uint32_t  RXSTS;                             /*!< SPI1 Receive Status Register.                                         */
  __I  uint32_t  RXDAT;                             /*!< SPI1 Receive FIFO Register.                                           */
  __IO uint32_t  MISC;                              /*!< SPI1 Misc. Control Register.                                          */
} SPI_Type;


/* ================================================================================ */
/* ================                       TMR                      ================ */
/* ================================================================================ */


/**
  * @brief General purpose 32 bits timer, which are used to generate regulate interrupt for CM0. (TMR)
  */

typedef struct {                                    /*!< TMR Structure                                                         */
  __IO uint32_t  CTRL;                              /*!< Control register of Timer x                                           */
  __IO uint32_t  VALUE;                             /*!< Current count register of Timer x                                     */
  __IO uint32_t  RELOAD;                            /*!< Reload register of Timer x.                                           */
  __IO uint32_t  INT;                               /*!< Interrupt status register of Timer x.                                 */
} TMR_Type;


/* ================================================================================ */
/* ================                      UART                      ================ */
/* ================================================================================ */


/**
  * @brief UART(Universal Asynchronous Receiver/Transmitter).  (UART)
  */

typedef struct {                                    /*!< UART Structure                                                        */
  __IO uint32_t  DATA;                              /*!< UART data register.                                                   */
  __IO uint32_t  STATE;                             /*!< UART status register.                                                 */
  __IO uint32_t  CTRL;                              /*!< UART control register.                                                */
  __IO uint32_t  INTSTS;                            /*!< UART interrupt status register.                                       */
  __IO uint32_t  BAUDDIV;                           /*!< UART baud rate divide register.                                       */
  __IO uint32_t  CTRL2;                             /*!< UART control register 2.                                              */
} UART_Type;


/* ================================================================================ */
/* ================                      U32K                      ================ */
/* ================================================================================ */


/**
  * @brief The UART 32K controller is used to receive data via UART protocol. There are two individual UART 32K controllers in TARGET, which can select input from UART rx0 ~ rx3. UART 32K controller is designed to operate at 32K crystal frequency, so it can work under sleep or deep sleep mode. The maximum baud rate which UART 32K can support is 9600. The UART 32K controller can support 8 bits transfer without parity or 9 bits transfer with even or odd parity. One data buffer and one shift register is used for receive engine. (U32K)
  */

typedef struct {                                    /*!< U32K Structure                                                        */
  __IO uint32_t  CTRL0;                             /*!< UART 32K control register 0.                                          */
  __IO uint32_t  CTRL1;                             /*!< UART 32K x control register 1.                                        */
  __IO uint32_t  PHASE;                             /*!< UART 32K x baud rate control register.                                */
  __I  uint32_t  DATA;                              /*!< UART 32K x receive data buffer.                                       */
  __IO uint32_t  STS;                               /*!< UART 32K x interrupt status register.                                 */
} U32K_Type;


/* --------------------  End of section using anonymous unions  ------------------- */
#if defined(__CC_ARM)
  #pragma pop
#elif defined(__ICCARM__)
  /* leave anonymous unions enabled */
#elif defined(__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined(__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined(__TASKING__)
  #pragma warning restore
#else
  #warning Not supported compiler type
#endif



/* ================================================================================ */
/* ================          struct 'ANA' Position & Mask          ================ */
/* ================================================================================ */


/* ----------------------------------  ANA_REG1  ---------------------------------- */
#define ANA_REG1_RESDIV_Pos                   (4UL)                     /*!< ANA REG1: RESDIV (Bit 4)                                    */
#define ANA_REG1_RESDIV_Msk                   (0x10UL)                  /*!< ANA REG1: RESDIV (Bitfield-Mask: 0x01)                      */
#define ANA_REG1_GDE4_Pos                     (5UL)                     /*!< ANA REG1: GDE4 (Bit 5)                                      */
#define ANA_REG1_GDE4_Msk                     (0x20UL)                  /*!< ANA REG1: GDE4 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  ANA_REG2  ---------------------------------- */
#define ANA_REG2_CMP1_SEL_Pos                 (0UL)                     /*!< ANA REG2: CMP1_SEL (Bit 0)                                  */
#define ANA_REG2_CMP1_SEL_Msk                 (0x3UL)                   /*!< ANA REG2: CMP1_SEL (Bitfield-Mask: 0x03)                    */
#define ANA_REG2_CMP2_SEL_Pos                 (2UL)                     /*!< ANA REG2: CMP2_SEL (Bit 2)                                  */
#define ANA_REG2_CMP2_SEL_Msk                 (0xcUL)                   /*!< ANA REG2: CMP2_SEL (Bitfield-Mask: 0x03)                    */
#define ANA_REG2_REFSEL_CMP1_Pos              (4UL)                     /*!< ANA REG2: REFSEL_CMP1 (Bit 4)                               */
#define ANA_REG2_REFSEL_CMP1_Msk              (0x10UL)                  /*!< ANA REG2: REFSEL_CMP1 (Bitfield-Mask: 0x01)                 */
#define ANA_REG2_REFSEL_CMP2_Pos              (5UL)                     /*!< ANA REG2: REFSEL_CMP2 (Bit 5)                               */
#define ANA_REG2_REFSEL_CMP2_Msk              (0x20UL)                  /*!< ANA REG2: REFSEL_CMP2 (Bitfield-Mask: 0x01)                 */

/* ----------------------------------  ANA_REG3  ---------------------------------- */
#define ANA_REG3_ADCPDN_Pos                   (0UL)                     /*!< ANA REG3: ADCPDN (Bit 0)                                    */
#define ANA_REG3_ADCPDN_Msk                   (0x1UL)                   /*!< ANA REG3: ADCPDN (Bitfield-Mask: 0x01)                      */
#define ANA_REG3_CMP1PDN_Pos                  (1UL)                     /*!< ANA REG3: CMP1PDN (Bit 1)                                   */
#define ANA_REG3_CMP1PDN_Msk                  (0x2UL)                   /*!< ANA REG3: CMP1PDN (Bitfield-Mask: 0x01)                     */
#define ANA_REG3_CMP2PDN_Pos                  (2UL)                     /*!< ANA REG3: CMP2PDN (Bit 2)                                   */
#define ANA_REG3_CMP2PDN_Msk                  (0x4UL)                   /*!< ANA REG3: CMP2PDN (Bitfield-Mask: 0x01)                     */
#define ANA_REG3_BGPPD_Pos                    (3UL)                     /*!< ANA REG3: BGPPD (Bit 3)                                     */
#define ANA_REG3_BGPPD_Msk                    (0x8UL)                   /*!< ANA REG3: BGPPD (Bitfield-Mask: 0x01)                       */
#define ANA_REG3_RCHPD_Pos                    (4UL)                     /*!< ANA REG3: RCHPD (Bit 4)                                     */
#define ANA_REG3_RCHPD_Msk                    (0x10UL)                  /*!< ANA REG3: RCHPD (Bitfield-Mask: 0x01)                       */
#define ANA_REG3_PLLLPDN_Pos                  (5UL)                     /*!< ANA REG3: PLLLPDN (Bit 5)                                   */
#define ANA_REG3_PLLLPDN_Msk                  (0x20UL)                  /*!< ANA REG3: PLLLPDN (Bitfield-Mask: 0x01)                     */
#define ANA_REG3_PLLHPDN_Pos                  (6UL)                     /*!< ANA REG3: PLLHPDN (Bit 6)                                   */
#define ANA_REG3_PLLHPDN_Msk                  (0x40UL)                  /*!< ANA REG3: PLLHPDN (Bitfield-Mask: 0x01)                     */
#define ANA_REG3_XOHPDN_Pos                   (7UL)                     /*!< ANA REG3: XOHPDN (Bit 7)                                    */
#define ANA_REG3_XOHPDN_Msk                   (0x80UL)                  /*!< ANA REG3: XOHPDN (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  ANA_REG5  ---------------------------------- */
#define ANA_REG5_IT_CMP1_Pos                  (0UL)                     /*!< ANA REG5: IT_CMP1 (Bit 0)                                   */
#define ANA_REG5_IT_CMP1_Msk                  (0x3UL)                   /*!< ANA REG5: IT_CMP1 (Bitfield-Mask: 0x03)                     */
#define ANA_REG5_IT_CMP2_Pos                  (2UL)                     /*!< ANA REG5: IT_CMP2 (Bit 2)                                   */
#define ANA_REG5_IT_CMP2_Msk                  (0xcUL)                   /*!< ANA REG5: IT_CMP2 (Bitfield-Mask: 0x03)                     */
#define ANA_REG5_PD_AVCCDET_Pos               (6UL)                     /*!< ANA REG5: PD_AVCCDET (Bit 6)                                */
#define ANA_REG5_PD_AVCCDET_Msk               (0x40UL)                  /*!< ANA REG5: PD_AVCCDET (Bitfield-Mask: 0x01)                  */

/* ----------------------------------  ANA_REG6  ---------------------------------- */
#define ANA_REG6_LCD_BMODE_Pos                (0UL)                     /*!< ANA REG6: LCD_BMODE (Bit 0)                                 */
#define ANA_REG6_LCD_BMODE_Msk                (0x1UL)                   /*!< ANA REG6: LCD_BMODE (Bitfield-Mask: 0x01)                   */
#define ANA_REG6_VLCD_Pos                     (1UL)                     /*!< ANA REG6: VLCD (Bit 1)                                      */
#define ANA_REG6_VLCD_Msk                     (0x1eUL)                  /*!< ANA REG6: VLCD (Bitfield-Mask: 0x0f)                        */
#define ANA_REG6_BATRTCDISC_Pos               (7UL)                     /*!< ANA REG6: BATRTCDISC (Bit 7)                                */
#define ANA_REG6_BATRTCDISC_Msk               (0x80UL)                  /*!< ANA REG6: BATRTCDISC (Bitfield-Mask: 0x01)                  */

/* ----------------------------------  ANA_REG8  ---------------------------------- */
#define ANA_REG8_VDDPVDSEL_Pos                (4UL)                     /*!< ANA REG8: VDDPVDSEL (Bit 4)                                 */
#define ANA_REG8_VDDPVDSEL_Msk                (0x70UL)                  /*!< ANA REG8: VDDPVDSEL (Bitfield-Mask: 0x07)                   */
#define ANA_REG8_AVCCPD_Pos                   (7UL)                     /*!< ANA REG8: AVCCPD (Bit 7)                                    */
#define ANA_REG8_AVCCPD_Msk                   (0x80UL)                  /*!< ANA REG8: AVCCPD (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  ANA_REG9  ---------------------------------- */
#define ANA_REG9_PLLLSEL_Pos                  (0UL)                     /*!< ANA REG9: PLLLSEL (Bit 0)                                   */
#define ANA_REG9_PLLLSEL_Msk                  (0x7UL)                   /*!< ANA REG9: PLLLSEL (Bitfield-Mask: 0x07)                     */
#define ANA_REG9_PLLHSEL_Pos                  (3UL)                     /*!< ANA REG9: PLLHSEL (Bit 3)                                   */
#define ANA_REG9_PLLHSEL_Msk                  (0x78UL)                  /*!< ANA REG9: PLLHSEL (Bitfield-Mask: 0x0f)                     */
#define ANA_REG9_PD_VDDDET_Pos                (7UL)                     /*!< ANA REG9: PD_VDDDET (Bit 7)                                 */
#define ANA_REG9_PD_VDDDET_Msk                (0x80UL)                  /*!< ANA REG9: PD_VDDDET (Bitfield-Mask: 0x01)                   */

/* ----------------------------------  ANA_REGA  ---------------------------------- */
#define ANA_REGA_PD_VDCINDET_Pos              (7UL)                     /*!< ANA REGA: PD_VDCINDET (Bit 7)                               */
#define ANA_REGA_PD_VDCINDET_Msk              (0x80UL)                  /*!< ANA REGA: PD_VDCINDET (Bitfield-Mask: 0x01)                 */

/* ----------------------------------  ANA_REGB  ---------------------------------- */
#define ANA_REGB_RCLTRIM_Pos                  (0UL)                     /*!< ANA REGB: RCLTRIM (Bit 0)                                   */
#define ANA_REGB_RCLTRIM_Msk                  (0x1fUL)                  /*!< ANA REGB: RCLTRIM (Bitfield-Mask: 0x1f)                     */

/* ----------------------------------  ANA_REGC  ---------------------------------- */
#define ANA_REGC_RCHTRIM_Pos                  (0UL)                     /*!< ANA REGC: RCHTRIM (Bit 0)                                   */
#define ANA_REGC_RCHTRIM_Msk                  (0x3fUL)                  /*!< ANA REGC: RCHTRIM (Bitfield-Mask: 0x3f)                     */

/* ----------------------------------  ANA_REGD  ---------------------------------- */
#define ANA_REGD_DVCCTRIM_Pos                 (0UL)                     /*!< ANA REGD: DVCCTRIM (Bit 0)                                  */
#define ANA_REGD_DVCCTRIM_Msk                 (0x7UL)                   /*!< ANA REGD: DVCCTRIM (Bitfield-Mask: 0x07)                    */
#define ANA_REGD_AVCCTRIM_Pos                 (3UL)                     /*!< ANA REGD: AVCCTRIM (Bit 3)                                  */
#define ANA_REGD_AVCCTRIM_Msk                 (0x38UL)                  /*!< ANA REGD: AVCCTRIM (Bitfield-Mask: 0x07)                    */
#define ANA_REGD_VREFTRIM_Pos                 (6UL)                     /*!< ANA REGD: VREFTRIM (Bit 6)                                  */
#define ANA_REGD_VREFTRIM_Msk                 (0xc0UL)                  /*!< ANA REGD: VREFTRIM (Bitfield-Mask: 0x03)                    */

/* ----------------------------------  ANA_REGE  ---------------------------------- */
#define ANA_REGE_REST_Pos                     (0UL)                     /*!< ANA REGE: REST (Bit 0)                                      */
#define ANA_REGE_REST_Msk                     (0x7UL)                   /*!< ANA REGE: REST (Bitfield-Mask: 0x07)                        */
#define ANA_REGE_RESTL_Pos                    (4UL)                     /*!< ANA REGE: RESTL (Bit 4)                                     */
#define ANA_REGE_RESTL_Msk                    (0x30UL)                  /*!< ANA REGE: RESTL (Bitfield-Mask: 0x03)                       */
#define ANA_REGE_REST_D_Pos                   (6UL)                     /*!< ANA REGE: REST_D (Bit 6)                                    */
#define ANA_REGE_REST_D_Msk                   (0x40UL)                  /*!< ANA REGE: REST_D (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  ANA_REGF  ---------------------------------- */
#define ANA_REGF_AVCCO_EN_Pos                 (2UL)                     /*!< ANA REGF: AVCCO_EN (Bit 2)                                  */
#define ANA_REGF_AVCCO_EN_Msk                 (0x4UL)                   /*!< ANA REGF: AVCCO_EN (Bitfield-Mask: 0x01)                    */
#define ANA_REGF_PDN_ADT_Pos                  (3UL)                     /*!< ANA REGF: PDN_ADT (Bit 3)                                   */
#define ANA_REGF_PDN_ADT_Msk                  (0x8UL)                   /*!< ANA REGF: PDN_ADT (Bitfield-Mask: 0x01)                     */
#define ANA_REGF_SEL_ADT_Pos                  (4UL)                     /*!< ANA REGF: SEL_ADT (Bit 4)                                   */
#define ANA_REGF_SEL_ADT_Msk                  (0x10UL)                  /*!< ANA REGF: SEL_ADT (Bitfield-Mask: 0x01)                     */
#define ANA_REGF_ADTREF1_SEL_Pos              (5UL)                     /*!< ANA REGF: ADTREF1_SEL (Bit 5)                               */
#define ANA_REGF_ADTREF1_SEL_Msk              (0x20UL)                  /*!< ANA REGF: ADTREF1_SEL (Bitfield-Mask: 0x01)                 */
#define ANA_REGF_ADTREF2_SEL_Pos              (6UL)                     /*!< ANA REGF: ADTREF2_SEL (Bit 6)                               */
#define ANA_REGF_ADTREF2_SEL_Msk              (0x40UL)                  /*!< ANA REGF: ADTREF2_SEL (Bitfield-Mask: 0x01)                 */
#define ANA_REGF_ADTREF3_SEL_Pos              (7UL)                     /*!< ANA REGF: ADTREF3_SEL (Bit 7)                               */
#define ANA_REGF_ADTREF3_SEL_Msk              (0x80UL)                  /*!< ANA REGF: ADTREF3_SEL (Bitfield-Mask: 0x01)                 */

/* ----------------------------------  ANA_CTRL  ---------------------------------- */
#define ANA_CTRL_COMP1_SEL_Pos                (0UL)                     /*!< ANA CTRL: COMP1_SEL (Bit 0)                                 */
#define ANA_CTRL_COMP1_SEL_Msk                (0x3UL)                   /*!< ANA CTRL: COMP1_SEL (Bitfield-Mask: 0x03)                   */
#define ANA_CTRL_COMP2_SEL_Pos                (2UL)                     /*!< ANA CTRL: COMP2_SEL (Bit 2)                                 */
#define ANA_CTRL_COMP2_SEL_Msk                (0xcUL)                   /*!< ANA CTRL: COMP2_SEL (Bitfield-Mask: 0x03)                   */
#define ANA_CTRL_PDNS_Pos                     (6UL)                     /*!< ANA CTRL: PDNS (Bit 6)                                      */
#define ANA_CTRL_PDNS_Msk                     (0x40UL)                  /*!< ANA CTRL: PDNS (Bitfield-Mask: 0x01)                        */
#define ANA_CTRL_RCHTGT_Pos                   (8UL)                     /*!< ANA CTRL: RCHTGT (Bit 8)                                    */
#define ANA_CTRL_RCHTGT_Msk                   (0xff00UL)                /*!< ANA CTRL: RCHTGT (Bitfield-Mask: 0xff)                      */
#define ANA_CTRL_CMP1DEB_Pos                  (20UL)                    /*!< ANA CTRL: CMP1DEB (Bit 20)                                  */
#define ANA_CTRL_CMP1DEB_Msk                  (0x300000UL)              /*!< ANA CTRL: CMP1DEB (Bitfield-Mask: 0x03)                     */
#define ANA_CTRL_CMP2DEB_Pos                  (22UL)                    /*!< ANA CTRL: CMP2DEB (Bit 22)                                  */
#define ANA_CTRL_CMP2DEB_Msk                  (0xc00000UL)              /*!< ANA CTRL: CMP2DEB (Bitfield-Mask: 0x03)                     */
#define ANA_CTRL_VDCINDEB_Pos                 (24UL)                    /*!< ANA CTRL: VDCINDEB (Bit 24)                                 */
#define ANA_CTRL_VDCINDEB_Msk                 (0x3000000UL)             /*!< ANA CTRL: VDCINDEB (Bitfield-Mask: 0x03)                    */
#define ANA_CTRL_PDNS2_Pos                    (26UL)                    /*!< ANA CTRL: PDNS2 (Bit 26)                                    */
#define ANA_CTRL_PDNS2_Msk                    (0x4000000UL)             /*!< ANA CTRL: PDNS2 (Bitfield-Mask: 0x01)                       */

/* ---------------------------------  ANA_CMPOUT  --------------------------------- */
#define ANA_CMPOUT_LOCKH_Pos                  (0UL)                     /*!< ANA CMPOUT: LOCKH (Bit 0)                                   */
#define ANA_CMPOUT_LOCKH_Msk                  (0x1UL)                   /*!< ANA CMPOUT: LOCKH (Bitfield-Mask: 0x01)                     */
#define ANA_CMPOUT_LOCKL_Pos                  (1UL)                     /*!< ANA CMPOUT: LOCKL (Bit 1)                                   */
#define ANA_CMPOUT_LOCKL_Msk                  (0x2UL)                   /*!< ANA CMPOUT: LOCKL (Bitfield-Mask: 0x01)                     */
#define ANA_CMPOUT_COMP1_Pos                  (2UL)                     /*!< ANA CMPOUT: COMP1 (Bit 2)                                   */
#define ANA_CMPOUT_COMP1_Msk                  (0x4UL)                   /*!< ANA CMPOUT: COMP1 (Bitfield-Mask: 0x01)                     */
#define ANA_CMPOUT_COMP2_Pos                  (3UL)                     /*!< ANA CMPOUT: COMP2 (Bit 3)                                   */
#define ANA_CMPOUT_COMP2_Msk                  (0x8UL)                   /*!< ANA CMPOUT: COMP2 (Bitfield-Mask: 0x01)                     */
#define ANA_CMPOUT_VDDALARM_Pos               (7UL)                     /*!< ANA CMPOUT: VDDALARM (Bit 7)                                */
#define ANA_CMPOUT_VDDALARM_Msk               (0x80UL)                  /*!< ANA CMPOUT: VDDALARM (Bitfield-Mask: 0x01)                  */
#define ANA_CMPOUT_VDCINDROP_Pos              (8UL)                     /*!< ANA CMPOUT: VDCINDROP (Bit 8)                               */
#define ANA_CMPOUT_VDCINDROP_Msk              (0x100UL)                 /*!< ANA CMPOUT: VDCINDROP (Bitfield-Mask: 0x01)                 */
#define ANA_CMPOUT_AVCCLV_Pos                 (10UL)                    /*!< ANA CMPOUT: AVCCLV (Bit 10)                                 */
#define ANA_CMPOUT_AVCCLV_Msk                 (0x400UL)                 /*!< ANA CMPOUT: AVCCLV (Bitfield-Mask: 0x01)                    */
#define ANA_CMPOUT_TADCO_Pos                  (14UL)                    /*!< ANA CMPOUT: TADCO (Bit 14)                                  */
#define ANA_CMPOUT_TADCO_Msk                  (0xc000UL)                /*!< ANA CMPOUT: TADCO (Bitfield-Mask: 0x03)                     */

/* ---------------------------------  ANA_INTSTS  --------------------------------- */
#define ANA_INTSTS_INTSTS0_Pos                (0UL)                     /*!< ANA INTSTS: INTSTS0 (Bit 0)                                 */
#define ANA_INTSTS_INTSTS0_Msk                (0x1UL)                   /*!< ANA INTSTS: INTSTS0 (Bitfield-Mask: 0x01)                   */
#define ANA_INTSTS_INTSTS1_Pos                (1UL)                     /*!< ANA INTSTS: INTSTS1 (Bit 1)                                 */
#define ANA_INTSTS_INTSTS1_Msk                (0x2UL)                   /*!< ANA INTSTS: INTSTS1 (Bitfield-Mask: 0x01)                   */
#define ANA_INTSTS_INTSTS2_Pos                (2UL)                     /*!< ANA INTSTS: INTSTS2 (Bit 2)                                 */
#define ANA_INTSTS_INTSTS2_Msk                (0x4UL)                   /*!< ANA INTSTS: INTSTS2 (Bitfield-Mask: 0x01)                   */
#define ANA_INTSTS_INTSTS3_Pos                (3UL)                     /*!< ANA INTSTS: INTSTS3 (Bit 3)                                 */
#define ANA_INTSTS_INTSTS3_Msk                (0x8UL)                   /*!< ANA INTSTS: INTSTS3 (Bitfield-Mask: 0x01)                   */
#define ANA_INTSTS_INTSTS7_Pos                (7UL)                     /*!< ANA INTSTS: INTSTS7 (Bit 7)                                 */
#define ANA_INTSTS_INTSTS7_Msk                (0x80UL)                  /*!< ANA INTSTS: INTSTS7 (Bitfield-Mask: 0x01)                   */
#define ANA_INTSTS_INTSTS8_Pos                (8UL)                     /*!< ANA INTSTS: INTSTS8 (Bit 8)                                 */
#define ANA_INTSTS_INTSTS8_Msk                (0x100UL)                 /*!< ANA INTSTS: INTSTS8 (Bitfield-Mask: 0x01)                   */
#define ANA_INTSTS_INTSTS10_Pos               (10UL)                    /*!< ANA INTSTS: INTSTS10 (Bit 10)                               */
#define ANA_INTSTS_INTSTS10_Msk               (0x400UL)                 /*!< ANA INTSTS: INTSTS10 (Bitfield-Mask: 0x01)                  */
#define ANA_INTSTS_INTSTS11_Pos               (11UL)                    /*!< ANA INTSTS: INTSTS11 (Bit 11)                               */
#define ANA_INTSTS_INTSTS11_Msk               (0x800UL)                 /*!< ANA INTSTS: INTSTS11 (Bitfield-Mask: 0x01)                  */
#define ANA_INTSTS_INTSTS12_Pos               (12UL)                    /*!< ANA INTSTS: INTSTS12 (Bit 12)                               */
#define ANA_INTSTS_INTSTS12_Msk               (0x1000UL)                /*!< ANA INTSTS: INTSTS12 (Bitfield-Mask: 0x01)                  */
#define ANA_INTSTS_INTSTS13_Pos               (13UL)                    /*!< ANA INTSTS: INTSTS13 (Bit 13)                               */
#define ANA_INTSTS_INTSTS13_Msk               (0x2000UL)                /*!< ANA INTSTS: INTSTS13 (Bitfield-Mask: 0x01)                  */

/* ----------------------------------  ANA_INTEN  --------------------------------- */
#define ANA_INTEN_INTEN0_Pos                  (0UL)                     /*!< ANA INTEN: INTEN0 (Bit 0)                                   */
#define ANA_INTEN_INTEN0_Msk                  (0x1UL)                   /*!< ANA INTEN: INTEN0 (Bitfield-Mask: 0x01)                     */
#define ANA_INTEN_INTEN1_Pos                  (1UL)                     /*!< ANA INTEN: INTEN1 (Bit 1)                                   */
#define ANA_INTEN_INTEN1_Msk                  (0x2UL)                   /*!< ANA INTEN: INTEN1 (Bitfield-Mask: 0x01)                     */
#define ANA_INTEN_INTEN2_Pos                  (2UL)                     /*!< ANA INTEN: INTEN2 (Bit 2)                                   */
#define ANA_INTEN_INTEN2_Msk                  (0x4UL)                   /*!< ANA INTEN: INTEN2 (Bitfield-Mask: 0x01)                     */
#define ANA_INTEN_INTEN3_Pos                  (3UL)                     /*!< ANA INTEN: INTEN3 (Bit 3)                                   */
#define ANA_INTEN_INTEN3_Msk                  (0x8UL)                   /*!< ANA INTEN: INTEN3 (Bitfield-Mask: 0x01)                     */
#define ANA_INTEN_INTEN7_Pos                  (7UL)                     /*!< ANA INTEN: INTEN7 (Bit 7)                                   */
#define ANA_INTEN_INTEN7_Msk                  (0x80UL)                  /*!< ANA INTEN: INTEN7 (Bitfield-Mask: 0x01)                     */
#define ANA_INTEN_INTEN8_Pos                  (8UL)                     /*!< ANA INTEN: INTEN8 (Bit 8)                                   */
#define ANA_INTEN_INTEN8_Msk                  (0x100UL)                 /*!< ANA INTEN: INTEN8 (Bitfield-Mask: 0x01)                     */
#define ANA_INTEN_INTEN10_Pos                 (10UL)                    /*!< ANA INTEN: INTEN10 (Bit 10)                                 */
#define ANA_INTEN_INTEN10_Msk                 (0x400UL)                 /*!< ANA INTEN: INTEN10 (Bitfield-Mask: 0x01)                    */
#define ANA_INTEN_INTEN11_Pos                 (11UL)                    /*!< ANA INTEN: INTEN11 (Bit 11)                                 */
#define ANA_INTEN_INTEN11_Msk                 (0x800UL)                 /*!< ANA INTEN: INTEN11 (Bitfield-Mask: 0x01)                    */
#define ANA_INTEN_INTEN12_Pos                 (12UL)                    /*!< ANA INTEN: INTEN12 (Bit 12)                                 */
#define ANA_INTEN_INTEN12_Msk                 (0x1000UL)                /*!< ANA INTEN: INTEN12 (Bitfield-Mask: 0x01)                    */
#define ANA_INTEN_INTEN13_Pos                 (13UL)                    /*!< ANA INTEN: INTEN13 (Bit 13)                                 */
#define ANA_INTEN_INTEN13_Msk                 (0x2000UL)                /*!< ANA INTEN: INTEN13 (Bitfield-Mask: 0x01)                    */

/* ---------------------------------  ANA_ADCCTRL  -------------------------------- */
#define ANA_ADCCTRL_MCH_Pos                   (0UL)                     /*!< ANA ADCCTRL: MCH (Bit 0)                                    */
#define ANA_ADCCTRL_MCH_Msk                   (0xfUL)                   /*!< ANA ADCCTRL: MCH (Bitfield-Mask: 0x0f)                      */
#define ANA_ADCCTRL_ACH_Pos                   (4UL)                     /*!< ANA ADCCTRL: ACH (Bit 4)                                    */
#define ANA_ADCCTRL_ACH_Msk                   (0xf0UL)                  /*!< ANA ADCCTRL: ACH (Bitfield-Mask: 0x0f)                      */
#define ANA_ADCCTRL_CLKDIV_Pos                (8UL)                     /*!< ANA ADCCTRL: CLKDIV (Bit 8)                                 */
#define ANA_ADCCTRL_CLKDIV_Msk                (0xf00UL)                 /*!< ANA ADCCTRL: CLKDIV (Bitfield-Mask: 0x0f)                   */
#define ANA_ADCCTRL_CLKSEL_Pos                (12UL)                    /*!< ANA ADCCTRL: CLKSEL (Bit 12)                                */
#define ANA_ADCCTRL_CLKSEL_Msk                (0x1000UL)                /*!< ANA ADCCTRL: CLKSEL (Bitfield-Mask: 0x01)                   */
#define ANA_ADCCTRL_AEN_Pos                   (16UL)                    /*!< ANA ADCCTRL: AEN (Bit 16)                                   */
#define ANA_ADCCTRL_AEN_Msk                   (0x70000UL)               /*!< ANA ADCCTRL: AEN (Bitfield-Mask: 0x07)                      */
#define ANA_ADCCTRL_MMODE_Pos                 (20UL)                    /*!< ANA ADCCTRL: MMODE (Bit 20)                                 */
#define ANA_ADCCTRL_MMODE_Msk                 (0x100000UL)              /*!< ANA ADCCTRL: MMODE (Bitfield-Mask: 0x01)                    */
#define ANA_ADCCTRL_AMODE_Pos                 (21UL)                    /*!< ANA ADCCTRL: AMODE (Bit 21)                                 */
#define ANA_ADCCTRL_AMODE_Msk                 (0x200000UL)              /*!< ANA ADCCTRL: AMODE (Bitfield-Mask: 0x01)                    */
#define ANA_ADCCTRL_DSRSEL_Pos                (22UL)                    /*!< ANA ADCCTRL: DSRSEL (Bit 22)                                */
#define ANA_ADCCTRL_DSRSEL_Msk                (0xc00000UL)              /*!< ANA ADCCTRL: DSRSEL (Bitfield-Mask: 0x03)                   */
#define ANA_ADCCTRL_CICSKIP_Pos               (24UL)                    /*!< ANA ADCCTRL: CICSKIP (Bit 24)                               */
#define ANA_ADCCTRL_CICSKIP_Msk               (0x7000000UL)             /*!< ANA ADCCTRL: CICSKIP (Bitfield-Mask: 0x07)                  */
#define ANA_ADCCTRL_CICSCA_Pos                (27UL)                    /*!< ANA ADCCTRL: CICSCA (Bit 27)                                */
#define ANA_ADCCTRL_CICSCA_Msk                (0x8000000UL)             /*!< ANA ADCCTRL: CICSCA (Bitfield-Mask: 0x01)                   */
#define ANA_ADCCTRL_CICINV_Pos                (28UL)                    /*!< ANA ADCCTRL: CICINV (Bit 28)                                */
#define ANA_ADCCTRL_CICINV_Msk                (0x10000000UL)            /*!< ANA ADCCTRL: CICINV (Bitfield-Mask: 0x01)                   */
#define ANA_ADCCTRL_CICAON_Pos                (29UL)                    /*!< ANA ADCCTRL: CICAON (Bit 29)                                */
#define ANA_ADCCTRL_CICAON_Msk                (0x20000000UL)            /*!< ANA ADCCTRL: CICAON (Bitfield-Mask: 0x01)                   */
#define ANA_ADCCTRL_MTRIG_Pos                 (31UL)                    /*!< ANA ADCCTRL: MTRIG (Bit 31)                                 */
#define ANA_ADCCTRL_MTRIG_Msk                 (0x80000000UL)            /*!< ANA ADCCTRL: MTRIG (Bitfield-Mask: 0x01)                    */

/* ---------------------------------  ANA_ADCDATA  -------------------------------- */
#define ANA_ADCDATA_ADCDATAx_Pos              (0UL)                     /*!< ANA ADCDATA: ADCDATAx (Bit 0)                               */
#define ANA_ADCDATA_ADCDATAx_Msk              (0xffffUL)                /*!< ANA ADCDATA: ADCDATAx (Bitfield-Mask: 0xffff)               */

/* ---------------------------------  ANA_CMPCNT1  -------------------------------- */
#define ANA_CMPCNT1_CNT1_Pos                  (0UL)                     /*!< ANA CMPCNT1: CNT1 (Bit 0)                                   */
#define ANA_CMPCNT1_CNT1_Msk                  (0xffffffffUL)            /*!< ANA CMPCNT1: CNT1 (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  ANA_CMPCNT2  -------------------------------- */
#define ANA_CMPCNT2_CNT2_Pos                  (0UL)                     /*!< ANA CMPCNT2: CNT2 (Bit 0)                                   */
#define ANA_CMPCNT2_CNT2_Msk                  (0xffffffffUL)            /*!< ANA CMPCNT2: CNT2 (Bitfield-Mask: 0xffffffff)               */

/* ----------------------------------  ANA_MISC  ---------------------------------- */
#define ANA_MISC_TADCTH_Pos                   (4UL)                     /*!< ANA MISC: TADCTH (Bit 4)                                    */
#define ANA_MISC_TADCTH_Msk                   (0x30UL)                  /*!< ANA MISC: TADCTH (Bitfield-Mask: 0x03)                      */


/* ================================================================================ */
/* ================         struct 'CRYPT' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  CRYPT_CTRL  --------------------------------- */
#define CRYPT_CTRL_ACT_Pos                    (0UL)                     /*!< CRYPT CTRL: ACT (Bit 0)                                     */
#define CRYPT_CTRL_ACT_Msk                    (0x1UL)                   /*!< CRYPT CTRL: ACT (Bitfield-Mask: 0x01)                       */
#define CRYPT_CTRL_MODE_Pos                   (4UL)                     /*!< CRYPT CTRL: MODE (Bit 4)                                    */
#define CRYPT_CTRL_MODE_Msk                   (0x70UL)                  /*!< CRYPT CTRL: MODE (Bitfield-Mask: 0x07)                      */
#define CRYPT_CTRL_LENGTHD_Pos                (8UL)                     /*!< CRYPT CTRL: LENGTHD (Bit 8)                                 */
#define CRYPT_CTRL_LENGTHD_Msk                (0xf00UL)                 /*!< CRYPT CTRL: LENGTHD (Bitfield-Mask: 0x0f)                   */
#define CRYPT_CTRL_NOSTOP_Pos                 (15UL)                    /*!< CRYPT CTRL: NOSTOP (Bit 15)                                 */
#define CRYPT_CTRL_NOSTOP_Msk                 (0x8000UL)                /*!< CRYPT CTRL: NOSTOP (Bitfield-Mask: 0x01)                    */

/* ---------------------------------  CRYPT_PTRA  --------------------------------- */
#define CRYPT_PTRA_PTRA_Pos                   (0UL)                     /*!< CRYPT PTRA: PTRA (Bit 0)                                    */
#define CRYPT_PTRA_PTRA_Msk                   (0x7fffUL)                /*!< CRYPT PTRA: PTRA (Bitfield-Mask: 0x7fff)                    */

/* ---------------------------------  CRYPT_PTRB  --------------------------------- */
#define CRYPT_PTRB_PTRB_Pos                   (0UL)                     /*!< CRYPT PTRB: PTRB (Bit 0)                                    */
#define CRYPT_PTRB_PTRB_Msk                   (0x7fffUL)                /*!< CRYPT PTRB: PTRB (Bitfield-Mask: 0x7fff)                    */

/* ---------------------------------  CRYPT_PTRO  --------------------------------- */
#define CRYPT_PTRO_PTRO_Pos                   (0UL)                     /*!< CRYPT PTRO: PTRO (Bit 0)                                    */
#define CRYPT_PTRO_PTRO_Msk                   (0x7fffUL)                /*!< CRYPT PTRO: PTRO (Bitfield-Mask: 0x7fff)                    */

/* ---------------------------------  CRYPT_CARRY  -------------------------------- */
#define CRYPT_CARRY_CARRY_Pos                 (0UL)                     /*!< CRYPT CARRY: CARRY (Bit 0)                                  */
#define CRYPT_CARRY_CARRY_Msk                 (0x1UL)                   /*!< CRYPT CARRY: CARRY (Bitfield-Mask: 0x01)                    */


/* ================================================================================ */
/* ================          struct 'DMA' Position & Mask          ================ */
/* ================================================================================ */


/* -----------------------------------  DMA_IE  ----------------------------------- */
#define DMA_IE_C0PEIE_Pos                     (0UL)                     /*!< DMA IE: C0PEIE (Bit 0)                                      */
#define DMA_IE_C0PEIE_Msk                     (0x1UL)                   /*!< DMA IE: C0PEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C1PEIE_Pos                     (1UL)                     /*!< DMA IE: C1PEIE (Bit 1)                                      */
#define DMA_IE_C1PEIE_Msk                     (0x2UL)                   /*!< DMA IE: C1PEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C2PEIE_Pos                     (2UL)                     /*!< DMA IE: C2PEIE (Bit 2)                                      */
#define DMA_IE_C2PEIE_Msk                     (0x4UL)                   /*!< DMA IE: C2PEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C3PEIE_Pos                     (3UL)                     /*!< DMA IE: C3PEIE (Bit 3)                                      */
#define DMA_IE_C3PEIE_Msk                     (0x8UL)                   /*!< DMA IE: C3PEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C0FEIE_Pos                     (4UL)                     /*!< DMA IE: C0FEIE (Bit 4)                                      */
#define DMA_IE_C0FEIE_Msk                     (0x10UL)                  /*!< DMA IE: C0FEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C1FEIE_Pos                     (5UL)                     /*!< DMA IE: C1FEIE (Bit 5)                                      */
#define DMA_IE_C1FEIE_Msk                     (0x20UL)                  /*!< DMA IE: C1FEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C2FEIE_Pos                     (6UL)                     /*!< DMA IE: C2FEIE (Bit 6)                                      */
#define DMA_IE_C2FEIE_Msk                     (0x40UL)                  /*!< DMA IE: C2FEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C3FEIE_Pos                     (7UL)                     /*!< DMA IE: C3FEIE (Bit 7)                                      */
#define DMA_IE_C3FEIE_Msk                     (0x80UL)                  /*!< DMA IE: C3FEIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C0DAIE_Pos                     (8UL)                     /*!< DMA IE: C0DAIE (Bit 8)                                      */
#define DMA_IE_C0DAIE_Msk                     (0x100UL)                 /*!< DMA IE: C0DAIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C1DAIE_Pos                     (9UL)                     /*!< DMA IE: C1DAIE (Bit 9)                                      */
#define DMA_IE_C1DAIE_Msk                     (0x200UL)                 /*!< DMA IE: C1DAIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C2DAIE_Pos                     (10UL)                    /*!< DMA IE: C2DAIE (Bit 10)                                     */
#define DMA_IE_C2DAIE_Msk                     (0x400UL)                 /*!< DMA IE: C2DAIE (Bitfield-Mask: 0x01)                        */
#define DMA_IE_C3DAIE_Pos                     (11UL)                    /*!< DMA IE: C3DAIE (Bit 11)                                     */
#define DMA_IE_C3DAIE_Msk                     (0x800UL)                 /*!< DMA IE: C3DAIE (Bitfield-Mask: 0x01)                        */

/* -----------------------------------  DMA_STS  ---------------------------------- */
#define DMA_STS_C0BUSY_Pos                    (0UL)                     /*!< DMA STS: C0BUSY (Bit 0)                                     */
#define DMA_STS_C0BUSY_Msk                    (0x1UL)                   /*!< DMA STS: C0BUSY (Bitfield-Mask: 0x01)                       */
#define DMA_STS_C1BUSY_Pos                    (1UL)                     /*!< DMA STS: C1BUSY (Bit 1)                                     */
#define DMA_STS_C1BUSY_Msk                    (0x2UL)                   /*!< DMA STS: C1BUSY (Bitfield-Mask: 0x01)                       */
#define DMA_STS_C2BUSY_Pos                    (2UL)                     /*!< DMA STS: C2BUSY (Bit 2)                                     */
#define DMA_STS_C2BUSY_Msk                    (0x4UL)                   /*!< DMA STS: C2BUSY (Bitfield-Mask: 0x01)                       */
#define DMA_STS_C3BUSY_Pos                    (3UL)                     /*!< DMA STS: C3BUSY (Bit 3)                                     */
#define DMA_STS_C3BUSY_Msk                    (0x8UL)                   /*!< DMA STS: C3BUSY (Bitfield-Mask: 0x01)                       */
#define DMA_STS_C0PE_Pos                      (4UL)                     /*!< DMA STS: C0PE (Bit 4)                                       */
#define DMA_STS_C0PE_Msk                      (0x10UL)                  /*!< DMA STS: C0PE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C1PE_Pos                      (5UL)                     /*!< DMA STS: C1PE (Bit 5)                                       */
#define DMA_STS_C1PE_Msk                      (0x20UL)                  /*!< DMA STS: C1PE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C2PE_Pos                      (6UL)                     /*!< DMA STS: C2PE (Bit 6)                                       */
#define DMA_STS_C2PE_Msk                      (0x40UL)                  /*!< DMA STS: C2PE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C3PE_Pos                      (7UL)                     /*!< DMA STS: C3PE (Bit 7)                                       */
#define DMA_STS_C3PE_Msk                      (0x80UL)                  /*!< DMA STS: C3PE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C0FE_Pos                      (8UL)                     /*!< DMA STS: C0FE (Bit 8)                                       */
#define DMA_STS_C0FE_Msk                      (0x100UL)                 /*!< DMA STS: C0FE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C1FE_Pos                      (9UL)                     /*!< DMA STS: C1FE (Bit 9)                                       */
#define DMA_STS_C1FE_Msk                      (0x200UL)                 /*!< DMA STS: C1FE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C2FE_Pos                      (10UL)                    /*!< DMA STS: C2FE (Bit 10)                                      */
#define DMA_STS_C2FE_Msk                      (0x400UL)                 /*!< DMA STS: C2FE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C3FE_Pos                      (11UL)                    /*!< DMA STS: C3FE (Bit 11)                                      */
#define DMA_STS_C3FE_Msk                      (0x800UL)                 /*!< DMA STS: C3FE (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C0DA_Pos                      (12UL)                    /*!< DMA STS: C0DA (Bit 12)                                      */
#define DMA_STS_C0DA_Msk                      (0x1000UL)                /*!< DMA STS: C0DA (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C1DA_Pos                      (13UL)                    /*!< DMA STS: C1DA (Bit 13)                                      */
#define DMA_STS_C1DA_Msk                      (0x2000UL)                /*!< DMA STS: C1DA (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C2DA_Pos                      (14UL)                    /*!< DMA STS: C2DA (Bit 14)                                      */
#define DMA_STS_C2DA_Msk                      (0x4000UL)                /*!< DMA STS: C2DA (Bitfield-Mask: 0x01)                         */
#define DMA_STS_C3DA_Pos                      (15UL)                    /*!< DMA STS: C3DA (Bit 15)                                      */
#define DMA_STS_C3DA_Msk                      (0x8000UL)                /*!< DMA STS: C3DA (Bitfield-Mask: 0x01)                         */

/* ----------------------------------  DMA_C0CTL  --------------------------------- */
#define DMA_C0CTL_EN_Pos                      (0UL)                     /*!< DMA C0CTL: EN (Bit 0)                                       */
#define DMA_C0CTL_EN_Msk                      (0x1UL)                   /*!< DMA C0CTL: EN (Bitfield-Mask: 0x01)                         */
#define DMA_C0CTL_SIZE_Pos                    (1UL)                     /*!< DMA C0CTL: SIZE (Bit 1)                                     */
#define DMA_C0CTL_SIZE_Msk                    (0x6UL)                   /*!< DMA C0CTL: SIZE (Bitfield-Mask: 0x03)                       */
#define DMA_C0CTL_SMODE_Pos                   (3UL)                     /*!< DMA C0CTL: SMODE (Bit 3)                                    */
#define DMA_C0CTL_SMODE_Msk                   (0x18UL)                  /*!< DMA C0CTL: SMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C0CTL_DMODE_Pos                   (5UL)                     /*!< DMA C0CTL: DMODE (Bit 5)                                    */
#define DMA_C0CTL_DMODE_Msk                   (0x60UL)                  /*!< DMA C0CTL: DMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C0CTL_DMASEL_Pos                  (7UL)                     /*!< DMA C0CTL: DMASEL (Bit 7)                                   */
#define DMA_C0CTL_DMASEL_Msk                  (0xf80UL)                 /*!< DMA C0CTL: DMASEL (Bitfield-Mask: 0x1f)                     */
#define DMA_C0CTL_TMODE_Pos                   (12UL)                    /*!< DMA C0CTL: TMODE (Bit 12)                                   */
#define DMA_C0CTL_TMODE_Msk                   (0x1000UL)                /*!< DMA C0CTL: TMODE (Bitfield-Mask: 0x01)                      */
#define DMA_C0CTL_CONT_Pos                    (13UL)                    /*!< DMA C0CTL: CONT (Bit 13)                                    */
#define DMA_C0CTL_CONT_Msk                    (0x2000UL)                /*!< DMA C0CTL: CONT (Bitfield-Mask: 0x01)                       */
#define DMA_C0CTL_AESEN_Pos                   (14UL)                    /*!< DMA C0CTL: AESEN (Bit 14)                                   */
#define DMA_C0CTL_AESEN_Msk                   (0x4000UL)                /*!< DMA C0CTL: AESEN (Bitfield-Mask: 0x01)                      */
#define DMA_C0CTL_STOP_Pos                    (15UL)                    /*!< DMA C0CTL: STOP (Bit 15)                                    */
#define DMA_C0CTL_STOP_Msk                    (0x8000UL)                /*!< DMA C0CTL: STOP (Bitfield-Mask: 0x01)                       */
#define DMA_C0CTL_PLEN_Pos                    (16UL)                    /*!< DMA C0CTL: PLEN (Bit 16)                                    */
#define DMA_C0CTL_PLEN_Msk                    (0xff0000UL)              /*!< DMA C0CTL: PLEN (Bitfield-Mask: 0xff)                       */
#define DMA_C0CTL_FLEN_Pos                    (24UL)                    /*!< DMA C0CTL: FLEN (Bit 24)                                    */
#define DMA_C0CTL_FLEN_Msk                    (0xff000000UL)            /*!< DMA C0CTL: FLEN (Bitfield-Mask: 0xff)                       */

/* ----------------------------------  DMA_C0SRC  --------------------------------- */
#define DMA_C0SRC_SRC_Pos                     (0UL)                     /*!< DMA C0SRC: SRC (Bit 0)                                      */
#define DMA_C0SRC_SRC_Msk                     (0xffffffffUL)            /*!< DMA C0SRC: SRC (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C0DST  --------------------------------- */
#define DMA_C0DST_DST_Pos                     (0UL)                     /*!< DMA C0DST: DST (Bit 0)                                      */
#define DMA_C0DST_DST_Msk                     (0xffffffffUL)            /*!< DMA C0DST: DST (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C0LEN  --------------------------------- */
#define DMA_C0LEN_CPLEN_Pos                   (0UL)                     /*!< DMA C0LEN: CPLEN (Bit 0)                                    */
#define DMA_C0LEN_CPLEN_Msk                   (0xffUL)                  /*!< DMA C0LEN: CPLEN (Bitfield-Mask: 0xff)                      */
#define DMA_C0LEN_CFLEN_Pos                   (8UL)                     /*!< DMA C0LEN: CFLEN (Bit 8)                                    */
#define DMA_C0LEN_CFLEN_Msk                   (0xff00UL)                /*!< DMA C0LEN: CFLEN (Bitfield-Mask: 0xff)                      */

/* ----------------------------------  DMA_C1CTL  --------------------------------- */
#define DMA_C1CTL_EN_Pos                      (0UL)                     /*!< DMA C1CTL: EN (Bit 0)                                       */
#define DMA_C1CTL_EN_Msk                      (0x1UL)                   /*!< DMA C1CTL: EN (Bitfield-Mask: 0x01)                         */
#define DMA_C1CTL_SIZE_Pos                    (1UL)                     /*!< DMA C1CTL: SIZE (Bit 1)                                     */
#define DMA_C1CTL_SIZE_Msk                    (0x6UL)                   /*!< DMA C1CTL: SIZE (Bitfield-Mask: 0x03)                       */
#define DMA_C1CTL_SMODE_Pos                   (3UL)                     /*!< DMA C1CTL: SMODE (Bit 3)                                    */
#define DMA_C1CTL_SMODE_Msk                   (0x18UL)                  /*!< DMA C1CTL: SMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C1CTL_DMODE_Pos                   (5UL)                     /*!< DMA C1CTL: DMODE (Bit 5)                                    */
#define DMA_C1CTL_DMODE_Msk                   (0x60UL)                  /*!< DMA C1CTL: DMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C1CTL_DMASEL_Pos                  (7UL)                     /*!< DMA C1CTL: DMASEL (Bit 7)                                   */
#define DMA_C1CTL_DMASEL_Msk                  (0xf80UL)                 /*!< DMA C1CTL: DMASEL (Bitfield-Mask: 0x1f)                     */
#define DMA_C1CTL_TMODE_Pos                   (12UL)                    /*!< DMA C1CTL: TMODE (Bit 12)                                   */
#define DMA_C1CTL_TMODE_Msk                   (0x1000UL)                /*!< DMA C1CTL: TMODE (Bitfield-Mask: 0x01)                      */
#define DMA_C1CTL_CONT_Pos                    (13UL)                    /*!< DMA C1CTL: CONT (Bit 13)                                    */
#define DMA_C1CTL_CONT_Msk                    (0x2000UL)                /*!< DMA C1CTL: CONT (Bitfield-Mask: 0x01)                       */
#define DMA_C1CTL_AESEN_Pos                   (14UL)                    /*!< DMA C1CTL: AESEN (Bit 14)                                   */
#define DMA_C1CTL_AESEN_Msk                   (0x4000UL)                /*!< DMA C1CTL: AESEN (Bitfield-Mask: 0x01)                      */
#define DMA_C1CTL_STOP_Pos                    (15UL)                    /*!< DMA C1CTL: STOP (Bit 15)                                    */
#define DMA_C1CTL_STOP_Msk                    (0x8000UL)                /*!< DMA C1CTL: STOP (Bitfield-Mask: 0x01)                       */
#define DMA_C1CTL_PLEN_Pos                    (16UL)                    /*!< DMA C1CTL: PLEN (Bit 16)                                    */
#define DMA_C1CTL_PLEN_Msk                    (0xff0000UL)              /*!< DMA C1CTL: PLEN (Bitfield-Mask: 0xff)                       */
#define DMA_C1CTL_FLEN_Pos                    (24UL)                    /*!< DMA C1CTL: FLEN (Bit 24)                                    */
#define DMA_C1CTL_FLEN_Msk                    (0xff000000UL)            /*!< DMA C1CTL: FLEN (Bitfield-Mask: 0xff)                       */

/* ----------------------------------  DMA_C1SRC  --------------------------------- */
#define DMA_C1SRC_SRC_Pos                     (0UL)                     /*!< DMA C1SRC: SRC (Bit 0)                                      */
#define DMA_C1SRC_SRC_Msk                     (0xffffffffUL)            /*!< DMA C1SRC: SRC (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C1DST  --------------------------------- */
#define DMA_C1DST_DST_Pos                     (0UL)                     /*!< DMA C1DST: DST (Bit 0)                                      */
#define DMA_C1DST_DST_Msk                     (0xffffffffUL)            /*!< DMA C1DST: DST (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C1LEN  --------------------------------- */
#define DMA_C1LEN_CPLEN_Pos                   (0UL)                     /*!< DMA C1LEN: CPLEN (Bit 0)                                    */
#define DMA_C1LEN_CPLEN_Msk                   (0xffUL)                  /*!< DMA C1LEN: CPLEN (Bitfield-Mask: 0xff)                      */
#define DMA_C1LEN_CFLEN_Pos                   (8UL)                     /*!< DMA C1LEN: CFLEN (Bit 8)                                    */
#define DMA_C1LEN_CFLEN_Msk                   (0xff00UL)                /*!< DMA C1LEN: CFLEN (Bitfield-Mask: 0xff)                      */

/* ----------------------------------  DMA_C2CTL  --------------------------------- */
#define DMA_C2CTL_EN_Pos                      (0UL)                     /*!< DMA C2CTL: EN (Bit 0)                                       */
#define DMA_C2CTL_EN_Msk                      (0x1UL)                   /*!< DMA C2CTL: EN (Bitfield-Mask: 0x01)                         */
#define DMA_C2CTL_SIZE_Pos                    (1UL)                     /*!< DMA C2CTL: SIZE (Bit 1)                                     */
#define DMA_C2CTL_SIZE_Msk                    (0x6UL)                   /*!< DMA C2CTL: SIZE (Bitfield-Mask: 0x03)                       */
#define DMA_C2CTL_SMODE_Pos                   (3UL)                     /*!< DMA C2CTL: SMODE (Bit 3)                                    */
#define DMA_C2CTL_SMODE_Msk                   (0x18UL)                  /*!< DMA C2CTL: SMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C2CTL_DMODE_Pos                   (5UL)                     /*!< DMA C2CTL: DMODE (Bit 5)                                    */
#define DMA_C2CTL_DMODE_Msk                   (0x60UL)                  /*!< DMA C2CTL: DMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C2CTL_DMASEL_Pos                  (7UL)                     /*!< DMA C2CTL: DMASEL (Bit 7)                                   */
#define DMA_C2CTL_DMASEL_Msk                  (0xf80UL)                 /*!< DMA C2CTL: DMASEL (Bitfield-Mask: 0x1f)                     */
#define DMA_C2CTL_TMODE_Pos                   (12UL)                    /*!< DMA C2CTL: TMODE (Bit 12)                                   */
#define DMA_C2CTL_TMODE_Msk                   (0x1000UL)                /*!< DMA C2CTL: TMODE (Bitfield-Mask: 0x01)                      */
#define DMA_C2CTL_CONT_Pos                    (13UL)                    /*!< DMA C2CTL: CONT (Bit 13)                                    */
#define DMA_C2CTL_CONT_Msk                    (0x2000UL)                /*!< DMA C2CTL: CONT (Bitfield-Mask: 0x01)                       */
#define DMA_C2CTL_AESEN_Pos                   (14UL)                    /*!< DMA C2CTL: AESEN (Bit 14)                                   */
#define DMA_C2CTL_AESEN_Msk                   (0x4000UL)                /*!< DMA C2CTL: AESEN (Bitfield-Mask: 0x01)                      */
#define DMA_C2CTL_STOP_Pos                    (15UL)                    /*!< DMA C2CTL: STOP (Bit 15)                                    */
#define DMA_C2CTL_STOP_Msk                    (0x8000UL)                /*!< DMA C2CTL: STOP (Bitfield-Mask: 0x01)                       */
#define DMA_C2CTL_PLEN_Pos                    (16UL)                    /*!< DMA C2CTL: PLEN (Bit 16)                                    */
#define DMA_C2CTL_PLEN_Msk                    (0xff0000UL)              /*!< DMA C2CTL: PLEN (Bitfield-Mask: 0xff)                       */
#define DMA_C2CTL_FLEN_Pos                    (24UL)                    /*!< DMA C2CTL: FLEN (Bit 24)                                    */
#define DMA_C2CTL_FLEN_Msk                    (0xff000000UL)            /*!< DMA C2CTL: FLEN (Bitfield-Mask: 0xff)                       */

/* ----------------------------------  DMA_C2SRC  --------------------------------- */
#define DMA_C2SRC_SRC_Pos                     (0UL)                     /*!< DMA C2SRC: SRC (Bit 0)                                      */
#define DMA_C2SRC_SRC_Msk                     (0xffffffffUL)            /*!< DMA C2SRC: SRC (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C2DST  --------------------------------- */
#define DMA_C2DST_DST_Pos                     (0UL)                     /*!< DMA C2DST: DST (Bit 0)                                      */
#define DMA_C2DST_DST_Msk                     (0xffffffffUL)            /*!< DMA C2DST: DST (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C2LEN  --------------------------------- */
#define DMA_C2LEN_CPLEN_Pos                   (0UL)                     /*!< DMA C2LEN: CPLEN (Bit 0)                                    */
#define DMA_C2LEN_CPLEN_Msk                   (0xffUL)                  /*!< DMA C2LEN: CPLEN (Bitfield-Mask: 0xff)                      */
#define DMA_C2LEN_CFLEN_Pos                   (8UL)                     /*!< DMA C2LEN: CFLEN (Bit 8)                                    */
#define DMA_C2LEN_CFLEN_Msk                   (0xff00UL)                /*!< DMA C2LEN: CFLEN (Bitfield-Mask: 0xff)                      */

/* ----------------------------------  DMA_C3CTL  --------------------------------- */
#define DMA_C3CTL_EN_Pos                      (0UL)                     /*!< DMA C3CTL: EN (Bit 0)                                       */
#define DMA_C3CTL_EN_Msk                      (0x1UL)                   /*!< DMA C3CTL: EN (Bitfield-Mask: 0x01)                         */
#define DMA_C3CTL_SIZE_Pos                    (1UL)                     /*!< DMA C3CTL: SIZE (Bit 1)                                     */
#define DMA_C3CTL_SIZE_Msk                    (0x6UL)                   /*!< DMA C3CTL: SIZE (Bitfield-Mask: 0x03)                       */
#define DMA_C3CTL_SMODE_Pos                   (3UL)                     /*!< DMA C3CTL: SMODE (Bit 3)                                    */
#define DMA_C3CTL_SMODE_Msk                   (0x18UL)                  /*!< DMA C3CTL: SMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C3CTL_DMODE_Pos                   (5UL)                     /*!< DMA C3CTL: DMODE (Bit 5)                                    */
#define DMA_C3CTL_DMODE_Msk                   (0x60UL)                  /*!< DMA C3CTL: DMODE (Bitfield-Mask: 0x03)                      */
#define DMA_C3CTL_DMASEL_Pos                  (7UL)                     /*!< DMA C3CTL: DMASEL (Bit 7)                                   */
#define DMA_C3CTL_DMASEL_Msk                  (0xf80UL)                 /*!< DMA C3CTL: DMASEL (Bitfield-Mask: 0x1f)                     */
#define DMA_C3CTL_TMODE_Pos                   (12UL)                    /*!< DMA C3CTL: TMODE (Bit 12)                                   */
#define DMA_C3CTL_TMODE_Msk                   (0x1000UL)                /*!< DMA C3CTL: TMODE (Bitfield-Mask: 0x01)                      */
#define DMA_C3CTL_CONT_Pos                    (13UL)                    /*!< DMA C3CTL: CONT (Bit 13)                                    */
#define DMA_C3CTL_CONT_Msk                    (0x2000UL)                /*!< DMA C3CTL: CONT (Bitfield-Mask: 0x01)                       */
#define DMA_C3CTL_AESEN_Pos                   (14UL)                    /*!< DMA C3CTL: AESEN (Bit 14)                                   */
#define DMA_C3CTL_AESEN_Msk                   (0x4000UL)                /*!< DMA C3CTL: AESEN (Bitfield-Mask: 0x01)                      */
#define DMA_C3CTL_STOP_Pos                    (15UL)                    /*!< DMA C3CTL: STOP (Bit 15)                                    */
#define DMA_C3CTL_STOP_Msk                    (0x8000UL)                /*!< DMA C3CTL: STOP (Bitfield-Mask: 0x01)                       */
#define DMA_C3CTL_PLEN_Pos                    (16UL)                    /*!< DMA C3CTL: PLEN (Bit 16)                                    */
#define DMA_C3CTL_PLEN_Msk                    (0xff0000UL)              /*!< DMA C3CTL: PLEN (Bitfield-Mask: 0xff)                       */
#define DMA_C3CTL_FLEN_Pos                    (24UL)                    /*!< DMA C3CTL: FLEN (Bit 24)                                    */
#define DMA_C3CTL_FLEN_Msk                    (0xff000000UL)            /*!< DMA C3CTL: FLEN (Bitfield-Mask: 0xff)                       */

/* ----------------------------------  DMA_C3SRC  --------------------------------- */
#define DMA_C3SRC_SRC_Pos                     (0UL)                     /*!< DMA C3SRC: SRC (Bit 0)                                      */
#define DMA_C3SRC_SRC_Msk                     (0xffffffffUL)            /*!< DMA C3SRC: SRC (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C3DST  --------------------------------- */
#define DMA_C3DST_DST_Pos                     (0UL)                     /*!< DMA C3DST: DST (Bit 0)                                      */
#define DMA_C3DST_DST_Msk                     (0xffffffffUL)            /*!< DMA C3DST: DST (Bitfield-Mask: 0xffffffff)                  */

/* ----------------------------------  DMA_C3LEN  --------------------------------- */
#define DMA_C3LEN_CPLEN_Pos                   (0UL)                     /*!< DMA C3LEN: CPLEN (Bit 0)                                    */
#define DMA_C3LEN_CPLEN_Msk                   (0xffUL)                  /*!< DMA C3LEN: CPLEN (Bitfield-Mask: 0xff)                      */
#define DMA_C3LEN_CFLEN_Pos                   (8UL)                     /*!< DMA C3LEN: CFLEN (Bit 8)                                    */
#define DMA_C3LEN_CFLEN_Msk                   (0xff00UL)                /*!< DMA C3LEN: CFLEN (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  DMA_AESCTL  --------------------------------- */
#define DMA_AESCTL_ENC_Pos                    (0UL)                     /*!< DMA AESCTL: ENC (Bit 0)                                     */
#define DMA_AESCTL_ENC_Msk                    (0x1UL)                   /*!< DMA AESCTL: ENC (Bitfield-Mask: 0x01)                       */
#define DMA_AESCTL_MODE_Pos                   (2UL)                     /*!< DMA AESCTL: MODE (Bit 2)                                    */
#define DMA_AESCTL_MODE_Msk                   (0xcUL)                   /*!< DMA AESCTL: MODE (Bitfield-Mask: 0x03)                      */

/* ---------------------------------  DMA_AESKEY0  -------------------------------- */
#define DMA_AESKEY0_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY0: KEYx (Bit 0)                                   */
#define DMA_AESKEY0_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY0: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY1  -------------------------------- */
#define DMA_AESKEY1_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY1: KEYx (Bit 0)                                   */
#define DMA_AESKEY1_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY1: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY2  -------------------------------- */
#define DMA_AESKEY2_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY2: KEYx (Bit 0)                                   */
#define DMA_AESKEY2_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY2: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY3  -------------------------------- */
#define DMA_AESKEY3_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY3: KEYx (Bit 0)                                   */
#define DMA_AESKEY3_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY3: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY4  -------------------------------- */
#define DMA_AESKEY4_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY4: KEYx (Bit 0)                                   */
#define DMA_AESKEY4_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY4: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY5  -------------------------------- */
#define DMA_AESKEY5_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY5: KEYx (Bit 0)                                   */
#define DMA_AESKEY5_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY5: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY6  -------------------------------- */
#define DMA_AESKEY6_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY6: KEYx (Bit 0)                                   */
#define DMA_AESKEY6_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY6: KEYx (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  DMA_AESKEY7  -------------------------------- */
#define DMA_AESKEY7_KEYx_Pos                  (0UL)                     /*!< DMA AESKEY7: KEYx (Bit 0)                                   */
#define DMA_AESKEY7_KEYx_Msk                  (0xffffffffUL)            /*!< DMA AESKEY7: KEYx (Bitfield-Mask: 0xffffffff)               */


/* ================================================================================ */
/* ================         struct 'FLASH' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  FLASH_STS  --------------------------------- */
#define FLASH_STS_STS_Pos                     (0UL)                     /*!< FLASH STS: STS (Bit 0)                                      */
#define FLASH_STS_STS_Msk                     (0x1fUL)                  /*!< FLASH STS: STS (Bitfield-Mask: 0x1f)                        */

/* ----------------------------------  FLASH_INT  --------------------------------- */
#define FLASH_INT_CSERR_Pos                   (0UL)                     /*!< FLASH INT: CSERR (Bit 0)                                    */
#define FLASH_INT_CSERR_Msk                   (0x1UL)                   /*!< FLASH INT: CSERR (Bitfield-Mask: 0x01)                      */

/* --------------------------------  FLASH_CSSADDR  ------------------------------- */
#define FLASH_CSSADDR_CSSADDR_Pos             (0UL)                     /*!< FLASH CSSADDR: CSSADDR (Bit 0)                              */
#define FLASH_CSSADDR_CSSADDR_Msk             (0x3ffffUL)               /*!< FLASH CSSADDR: CSSADDR (Bitfield-Mask: 0x3ffff)             */

/* --------------------------------  FLASH_CSEADDR  ------------------------------- */
#define FLASH_CSEADDR_CSEADDR_Pos             (0UL)                     /*!< FLASH CSEADDR: CSEADDR (Bit 0)                              */
#define FLASH_CSEADDR_CSEADDR_Msk             (0x3ffffUL)               /*!< FLASH CSEADDR: CSEADDR (Bitfield-Mask: 0x3ffff)             */

/* --------------------------------  FLASH_CSVALUE  ------------------------------- */
#define FLASH_CSVALUE_CSVALUE_Pos             (0UL)                     /*!< FLASH CSVALUE: CSVALUE (Bit 0)                              */
#define FLASH_CSVALUE_CSVALUE_Msk             (0xffffffffUL)            /*!< FLASH CSVALUE: CSVALUE (Bitfield-Mask: 0xffffffff)          */

/* -------------------------------  FLASH_CSCVALUE  ------------------------------- */
#define FLASH_CSCVALUE_CSCVALUE_Pos           (0UL)                     /*!< FLASH CSCVALUE: CSCVALUE (Bit 0)                            */
#define FLASH_CSCVALUE_CSCVALUE_Msk           (0xffffffffUL)            /*!< FLASH CSCVALUE: CSCVALUE (Bitfield-Mask: 0xffffffff)        */

/* ---------------------------------  FLASH_PASS  --------------------------------- */
#define FLASH_PASS_UNLOCK_Pos                 (0UL)                     /*!< FLASH PASS: UNLOCK (Bit 0)                                  */
#define FLASH_PASS_UNLOCK_Msk                 (0x1UL)                   /*!< FLASH PASS: UNLOCK (Bitfield-Mask: 0x01)                    */

/* ---------------------------------  FLASH_CTRL  --------------------------------- */
#define FLASH_CTRL_CSMODE_Pos                 (0UL)                     /*!< FLASH CTRL: CSMODE (Bit 0)                                  */
#define FLASH_CTRL_CSMODE_Msk                 (0x3UL)                   /*!< FLASH CTRL: CSMODE (Bitfield-Mask: 0x03)                    */
#define FLASH_CTRL_CSINTEN_Pos                (2UL)                     /*!< FLASH CTRL: CSINTEN (Bit 2)                                 */
#define FLASH_CTRL_CSINTEN_Msk                (0x4UL)                   /*!< FLASH CTRL: CSINTEN (Bitfield-Mask: 0x01)                   */

/* --------------------------------  FLASH_PGADDR  -------------------------------- */
#define FLASH_PGADDR_PGADDR_Pos               (0UL)                     /*!< FLASH PGADDR: PGADDR (Bit 0)                                */
#define FLASH_PGADDR_PGADDR_Msk               (0x3ffffUL)               /*!< FLASH PGADDR: PGADDR (Bitfield-Mask: 0x3ffff)               */

/* --------------------------------  FLASH_PGDATA  -------------------------------- */
#define FLASH_PGDATA_PGDATA_Pos               (0UL)                     /*!< FLASH PGDATA: PGDATA (Bit 0)                                */
#define FLASH_PGDATA_PGDATA_Msk               (0xffffffffUL)            /*!< FLASH PGDATA: PGDATA (Bitfield-Mask: 0xffffffff)            */

/* --------------------------------  FLASH_SERASE  -------------------------------- */
#define FLASH_SERASE_SERASE_Pos               (0UL)                     /*!< FLASH SERASE: SERASE (Bit 0)                                */
#define FLASH_SERASE_SERASE_Msk               (0x1UL)                   /*!< FLASH SERASE: SERASE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  FLASH_CERASE  -------------------------------- */
#define FLASH_CERASE_CERASE_Pos               (0UL)                     /*!< FLASH CERASE: CERASE (Bit 0)                                */
#define FLASH_CERASE_CERASE_Msk               (0x1UL)                   /*!< FLASH CERASE: CERASE (Bitfield-Mask: 0x01)                  */

/* ---------------------------------  FLASH_DSTB  --------------------------------- */
#define FLASH_DSTB_DSTB_Pos                   (0UL)                     /*!< FLASH DSTB: DSTB (Bit 0)                                    */
#define FLASH_DSTB_DSTB_Msk                   (0x1UL)                   /*!< FLASH DSTB: DSTB (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================         struct 'GPIOA' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  GPIOA_OEN  --------------------------------- */
#define GPIOA_OEN_OEN0_Pos                    (0UL)                     /*!< GPIOA OEN: OEN0 (Bit 0)                                     */
#define GPIOA_OEN_OEN0_Msk                    (0x1UL)                   /*!< GPIOA OEN: OEN0 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN1_Pos                    (1UL)                     /*!< GPIOA OEN: OEN1 (Bit 1)                                     */
#define GPIOA_OEN_OEN1_Msk                    (0x2UL)                   /*!< GPIOA OEN: OEN1 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN2_Pos                    (2UL)                     /*!< GPIOA OEN: OEN2 (Bit 2)                                     */
#define GPIOA_OEN_OEN2_Msk                    (0x4UL)                   /*!< GPIOA OEN: OEN2 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN3_Pos                    (3UL)                     /*!< GPIOA OEN: OEN3 (Bit 3)                                     */
#define GPIOA_OEN_OEN3_Msk                    (0x8UL)                   /*!< GPIOA OEN: OEN3 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN4_Pos                    (4UL)                     /*!< GPIOA OEN: OEN4 (Bit 4)                                     */
#define GPIOA_OEN_OEN4_Msk                    (0x10UL)                  /*!< GPIOA OEN: OEN4 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN5_Pos                    (5UL)                     /*!< GPIOA OEN: OEN5 (Bit 5)                                     */
#define GPIOA_OEN_OEN5_Msk                    (0x20UL)                  /*!< GPIOA OEN: OEN5 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN6_Pos                    (6UL)                     /*!< GPIOA OEN: OEN6 (Bit 6)                                     */
#define GPIOA_OEN_OEN6_Msk                    (0x40UL)                  /*!< GPIOA OEN: OEN6 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN7_Pos                    (7UL)                     /*!< GPIOA OEN: OEN7 (Bit 7)                                     */
#define GPIOA_OEN_OEN7_Msk                    (0x80UL)                  /*!< GPIOA OEN: OEN7 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN8_Pos                    (8UL)                     /*!< GPIOA OEN: OEN8 (Bit 8)                                     */
#define GPIOA_OEN_OEN8_Msk                    (0x100UL)                 /*!< GPIOA OEN: OEN8 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN9_Pos                    (9UL)                     /*!< GPIOA OEN: OEN9 (Bit 9)                                     */
#define GPIOA_OEN_OEN9_Msk                    (0x200UL)                 /*!< GPIOA OEN: OEN9 (Bitfield-Mask: 0x01)                       */
#define GPIOA_OEN_OEN10_Pos                   (10UL)                    /*!< GPIOA OEN: OEN10 (Bit 10)                                   */
#define GPIOA_OEN_OEN10_Msk                   (0x400UL)                 /*!< GPIOA OEN: OEN10 (Bitfield-Mask: 0x01)                      */
#define GPIOA_OEN_OEN11_Pos                   (11UL)                    /*!< GPIOA OEN: OEN11 (Bit 11)                                   */
#define GPIOA_OEN_OEN11_Msk                   (0x800UL)                 /*!< GPIOA OEN: OEN11 (Bitfield-Mask: 0x01)                      */
#define GPIOA_OEN_OEN12_Pos                   (12UL)                    /*!< GPIOA OEN: OEN12 (Bit 12)                                   */
#define GPIOA_OEN_OEN12_Msk                   (0x1000UL)                /*!< GPIOA OEN: OEN12 (Bitfield-Mask: 0x01)                      */
#define GPIOA_OEN_OEN13_Pos                   (13UL)                    /*!< GPIOA OEN: OEN13 (Bit 13)                                   */
#define GPIOA_OEN_OEN13_Msk                   (0x2000UL)                /*!< GPIOA OEN: OEN13 (Bitfield-Mask: 0x01)                      */
#define GPIOA_OEN_OEN14_Pos                   (14UL)                    /*!< GPIOA OEN: OEN14 (Bit 14)                                   */
#define GPIOA_OEN_OEN14_Msk                   (0x4000UL)                /*!< GPIOA OEN: OEN14 (Bitfield-Mask: 0x01)                      */
#define GPIOA_OEN_OEN15_Pos                   (15UL)                    /*!< GPIOA OEN: OEN15 (Bit 15)                                   */
#define GPIOA_OEN_OEN15_Msk                   (0x8000UL)                /*!< GPIOA OEN: OEN15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOA_IE  ---------------------------------- */
#define GPIOA_IE_IE0_Pos                      (0UL)                     /*!< GPIOA IE: IE0 (Bit 0)                                       */
#define GPIOA_IE_IE0_Msk                      (0x1UL)                   /*!< GPIOA IE: IE0 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE1_Pos                      (1UL)                     /*!< GPIOA IE: IE1 (Bit 1)                                       */
#define GPIOA_IE_IE1_Msk                      (0x2UL)                   /*!< GPIOA IE: IE1 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE2_Pos                      (2UL)                     /*!< GPIOA IE: IE2 (Bit 2)                                       */
#define GPIOA_IE_IE2_Msk                      (0x4UL)                   /*!< GPIOA IE: IE2 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE3_Pos                      (3UL)                     /*!< GPIOA IE: IE3 (Bit 3)                                       */
#define GPIOA_IE_IE3_Msk                      (0x8UL)                   /*!< GPIOA IE: IE3 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE4_Pos                      (4UL)                     /*!< GPIOA IE: IE4 (Bit 4)                                       */
#define GPIOA_IE_IE4_Msk                      (0x10UL)                  /*!< GPIOA IE: IE4 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE5_Pos                      (5UL)                     /*!< GPIOA IE: IE5 (Bit 5)                                       */
#define GPIOA_IE_IE5_Msk                      (0x20UL)                  /*!< GPIOA IE: IE5 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE6_Pos                      (6UL)                     /*!< GPIOA IE: IE6 (Bit 6)                                       */
#define GPIOA_IE_IE6_Msk                      (0x40UL)                  /*!< GPIOA IE: IE6 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE7_Pos                      (7UL)                     /*!< GPIOA IE: IE7 (Bit 7)                                       */
#define GPIOA_IE_IE7_Msk                      (0x80UL)                  /*!< GPIOA IE: IE7 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE8_Pos                      (8UL)                     /*!< GPIOA IE: IE8 (Bit 8)                                       */
#define GPIOA_IE_IE8_Msk                      (0x100UL)                 /*!< GPIOA IE: IE8 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE9_Pos                      (9UL)                     /*!< GPIOA IE: IE9 (Bit 9)                                       */
#define GPIOA_IE_IE9_Msk                      (0x200UL)                 /*!< GPIOA IE: IE9 (Bitfield-Mask: 0x01)                         */
#define GPIOA_IE_IE10_Pos                     (10UL)                    /*!< GPIOA IE: IE10 (Bit 10)                                     */
#define GPIOA_IE_IE10_Msk                     (0x400UL)                 /*!< GPIOA IE: IE10 (Bitfield-Mask: 0x01)                        */
#define GPIOA_IE_IE11_Pos                     (11UL)                    /*!< GPIOA IE: IE11 (Bit 11)                                     */
#define GPIOA_IE_IE11_Msk                     (0x800UL)                 /*!< GPIOA IE: IE11 (Bitfield-Mask: 0x01)                        */
#define GPIOA_IE_IE12_Pos                     (12UL)                    /*!< GPIOA IE: IE12 (Bit 12)                                     */
#define GPIOA_IE_IE12_Msk                     (0x1000UL)                /*!< GPIOA IE: IE12 (Bitfield-Mask: 0x01)                        */
#define GPIOA_IE_IE13_Pos                     (13UL)                    /*!< GPIOA IE: IE13 (Bit 13)                                     */
#define GPIOA_IE_IE13_Msk                     (0x2000UL)                /*!< GPIOA IE: IE13 (Bitfield-Mask: 0x01)                        */
#define GPIOA_IE_IE14_Pos                     (14UL)                    /*!< GPIOA IE: IE14 (Bit 14)                                     */
#define GPIOA_IE_IE14_Msk                     (0x4000UL)                /*!< GPIOA IE: IE14 (Bitfield-Mask: 0x01)                        */
#define GPIOA_IE_IE15_Pos                     (15UL)                    /*!< GPIOA IE: IE15 (Bit 15)                                     */
#define GPIOA_IE_IE15_Msk                     (0x8000UL)                /*!< GPIOA IE: IE15 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  GPIOA_DAT  --------------------------------- */
#define GPIOA_DAT_DAT0_Pos                    (0UL)                     /*!< GPIOA DAT: DAT0 (Bit 0)                                     */
#define GPIOA_DAT_DAT0_Msk                    (0x1UL)                   /*!< GPIOA DAT: DAT0 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT1_Pos                    (1UL)                     /*!< GPIOA DAT: DAT1 (Bit 1)                                     */
#define GPIOA_DAT_DAT1_Msk                    (0x2UL)                   /*!< GPIOA DAT: DAT1 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT2_Pos                    (2UL)                     /*!< GPIOA DAT: DAT2 (Bit 2)                                     */
#define GPIOA_DAT_DAT2_Msk                    (0x4UL)                   /*!< GPIOA DAT: DAT2 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT3_Pos                    (3UL)                     /*!< GPIOA DAT: DAT3 (Bit 3)                                     */
#define GPIOA_DAT_DAT3_Msk                    (0x8UL)                   /*!< GPIOA DAT: DAT3 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT4_Pos                    (4UL)                     /*!< GPIOA DAT: DAT4 (Bit 4)                                     */
#define GPIOA_DAT_DAT4_Msk                    (0x10UL)                  /*!< GPIOA DAT: DAT4 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT5_Pos                    (5UL)                     /*!< GPIOA DAT: DAT5 (Bit 5)                                     */
#define GPIOA_DAT_DAT5_Msk                    (0x20UL)                  /*!< GPIOA DAT: DAT5 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT6_Pos                    (6UL)                     /*!< GPIOA DAT: DAT6 (Bit 6)                                     */
#define GPIOA_DAT_DAT6_Msk                    (0x40UL)                  /*!< GPIOA DAT: DAT6 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT7_Pos                    (7UL)                     /*!< GPIOA DAT: DAT7 (Bit 7)                                     */
#define GPIOA_DAT_DAT7_Msk                    (0x80UL)                  /*!< GPIOA DAT: DAT7 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT8_Pos                    (8UL)                     /*!< GPIOA DAT: DAT8 (Bit 8)                                     */
#define GPIOA_DAT_DAT8_Msk                    (0x100UL)                 /*!< GPIOA DAT: DAT8 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT9_Pos                    (9UL)                     /*!< GPIOA DAT: DAT9 (Bit 9)                                     */
#define GPIOA_DAT_DAT9_Msk                    (0x200UL)                 /*!< GPIOA DAT: DAT9 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DAT_DAT10_Pos                   (10UL)                    /*!< GPIOA DAT: DAT10 (Bit 10)                                   */
#define GPIOA_DAT_DAT10_Msk                   (0x400UL)                 /*!< GPIOA DAT: DAT10 (Bitfield-Mask: 0x01)                      */
#define GPIOA_DAT_DAT11_Pos                   (11UL)                    /*!< GPIOA DAT: DAT11 (Bit 11)                                   */
#define GPIOA_DAT_DAT11_Msk                   (0x800UL)                 /*!< GPIOA DAT: DAT11 (Bitfield-Mask: 0x01)                      */
#define GPIOA_DAT_DAT12_Pos                   (12UL)                    /*!< GPIOA DAT: DAT12 (Bit 12)                                   */
#define GPIOA_DAT_DAT12_Msk                   (0x1000UL)                /*!< GPIOA DAT: DAT12 (Bitfield-Mask: 0x01)                      */
#define GPIOA_DAT_DAT13_Pos                   (13UL)                    /*!< GPIOA DAT: DAT13 (Bit 13)                                   */
#define GPIOA_DAT_DAT13_Msk                   (0x2000UL)                /*!< GPIOA DAT: DAT13 (Bitfield-Mask: 0x01)                      */
#define GPIOA_DAT_DAT14_Pos                   (14UL)                    /*!< GPIOA DAT: DAT14 (Bit 14)                                   */
#define GPIOA_DAT_DAT14_Msk                   (0x4000UL)                /*!< GPIOA DAT: DAT14 (Bitfield-Mask: 0x01)                      */
#define GPIOA_DAT_DAT15_Pos                   (15UL)                    /*!< GPIOA DAT: DAT15 (Bit 15)                                   */
#define GPIOA_DAT_DAT15_Msk                   (0x8000UL)                /*!< GPIOA DAT: DAT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOA_ATT  --------------------------------- */
#define GPIOA_ATT_ATT0_Pos                    (0UL)                     /*!< GPIOA ATT: ATT0 (Bit 0)                                     */
#define GPIOA_ATT_ATT0_Msk                    (0x1UL)                   /*!< GPIOA ATT: ATT0 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT1_Pos                    (1UL)                     /*!< GPIOA ATT: ATT1 (Bit 1)                                     */
#define GPIOA_ATT_ATT1_Msk                    (0x2UL)                   /*!< GPIOA ATT: ATT1 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT2_Pos                    (2UL)                     /*!< GPIOA ATT: ATT2 (Bit 2)                                     */
#define GPIOA_ATT_ATT2_Msk                    (0x4UL)                   /*!< GPIOA ATT: ATT2 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT3_Pos                    (3UL)                     /*!< GPIOA ATT: ATT3 (Bit 3)                                     */
#define GPIOA_ATT_ATT3_Msk                    (0x8UL)                   /*!< GPIOA ATT: ATT3 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT4_Pos                    (4UL)                     /*!< GPIOA ATT: ATT4 (Bit 4)                                     */
#define GPIOA_ATT_ATT4_Msk                    (0x10UL)                  /*!< GPIOA ATT: ATT4 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT5_Pos                    (5UL)                     /*!< GPIOA ATT: ATT5 (Bit 5)                                     */
#define GPIOA_ATT_ATT5_Msk                    (0x20UL)                  /*!< GPIOA ATT: ATT5 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT6_Pos                    (6UL)                     /*!< GPIOA ATT: ATT6 (Bit 6)                                     */
#define GPIOA_ATT_ATT6_Msk                    (0x40UL)                  /*!< GPIOA ATT: ATT6 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT7_Pos                    (7UL)                     /*!< GPIOA ATT: ATT7 (Bit 7)                                     */
#define GPIOA_ATT_ATT7_Msk                    (0x80UL)                  /*!< GPIOA ATT: ATT7 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT8_Pos                    (8UL)                     /*!< GPIOA ATT: ATT8 (Bit 8)                                     */
#define GPIOA_ATT_ATT8_Msk                    (0x100UL)                 /*!< GPIOA ATT: ATT8 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT9_Pos                    (9UL)                     /*!< GPIOA ATT: ATT9 (Bit 9)                                     */
#define GPIOA_ATT_ATT9_Msk                    (0x200UL)                 /*!< GPIOA ATT: ATT9 (Bitfield-Mask: 0x01)                       */
#define GPIOA_ATT_ATT10_Pos                   (10UL)                    /*!< GPIOA ATT: ATT10 (Bit 10)                                   */
#define GPIOA_ATT_ATT10_Msk                   (0x400UL)                 /*!< GPIOA ATT: ATT10 (Bitfield-Mask: 0x01)                      */
#define GPIOA_ATT_ATT11_Pos                   (11UL)                    /*!< GPIOA ATT: ATT11 (Bit 11)                                   */
#define GPIOA_ATT_ATT11_Msk                   (0x800UL)                 /*!< GPIOA ATT: ATT11 (Bitfield-Mask: 0x01)                      */
#define GPIOA_ATT_ATT12_Pos                   (12UL)                    /*!< GPIOA ATT: ATT12 (Bit 12)                                   */
#define GPIOA_ATT_ATT12_Msk                   (0x1000UL)                /*!< GPIOA ATT: ATT12 (Bitfield-Mask: 0x01)                      */
#define GPIOA_ATT_ATT13_Pos                   (13UL)                    /*!< GPIOA ATT: ATT13 (Bit 13)                                   */
#define GPIOA_ATT_ATT13_Msk                   (0x2000UL)                /*!< GPIOA ATT: ATT13 (Bitfield-Mask: 0x01)                      */
#define GPIOA_ATT_ATT14_Pos                   (14UL)                    /*!< GPIOA ATT: ATT14 (Bit 14)                                   */
#define GPIOA_ATT_ATT14_Msk                   (0x4000UL)                /*!< GPIOA ATT: ATT14 (Bitfield-Mask: 0x01)                      */
#define GPIOA_ATT_ATT15_Pos                   (15UL)                    /*!< GPIOA ATT: ATT15 (Bit 15)                                   */
#define GPIOA_ATT_ATT15_Msk                   (0x8000UL)                /*!< GPIOA ATT: ATT15 (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  GPIOA_WKUEN  -------------------------------- */
#define GPIOA_WKUEN_WKUEN0_Pos                (0UL)                     /*!< GPIOA WKUEN: WKUEN0 (Bit 0)                                 */
#define GPIOA_WKUEN_WKUEN0_Msk                (0x3UL)                   /*!< GPIOA WKUEN: WKUEN0 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN1_Pos                (2UL)                     /*!< GPIOA WKUEN: WKUEN1 (Bit 2)                                 */
#define GPIOA_WKUEN_WKUEN1_Msk                (0xcUL)                   /*!< GPIOA WKUEN: WKUEN1 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN2_Pos                (4UL)                     /*!< GPIOA WKUEN: WKUEN2 (Bit 4)                                 */
#define GPIOA_WKUEN_WKUEN2_Msk                (0x30UL)                  /*!< GPIOA WKUEN: WKUEN2 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN3_Pos                (6UL)                     /*!< GPIOA WKUEN: WKUEN3 (Bit 6)                                 */
#define GPIOA_WKUEN_WKUEN3_Msk                (0xc0UL)                  /*!< GPIOA WKUEN: WKUEN3 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN4_Pos                (8UL)                     /*!< GPIOA WKUEN: WKUEN4 (Bit 8)                                 */
#define GPIOA_WKUEN_WKUEN4_Msk                (0x300UL)                 /*!< GPIOA WKUEN: WKUEN4 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN5_Pos                (10UL)                    /*!< GPIOA WKUEN: WKUEN5 (Bit 10)                                */
#define GPIOA_WKUEN_WKUEN5_Msk                (0xc00UL)                 /*!< GPIOA WKUEN: WKUEN5 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN6_Pos                (12UL)                    /*!< GPIOA WKUEN: WKUEN6 (Bit 12)                                */
#define GPIOA_WKUEN_WKUEN6_Msk                (0x3000UL)                /*!< GPIOA WKUEN: WKUEN6 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN7_Pos                (14UL)                    /*!< GPIOA WKUEN: WKUEN7 (Bit 14)                                */
#define GPIOA_WKUEN_WKUEN7_Msk                (0xc000UL)                /*!< GPIOA WKUEN: WKUEN7 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN8_Pos                (16UL)                    /*!< GPIOA WKUEN: WKUEN8 (Bit 16)                                */
#define GPIOA_WKUEN_WKUEN8_Msk                (0x30000UL)               /*!< GPIOA WKUEN: WKUEN8 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN9_Pos                (18UL)                    /*!< GPIOA WKUEN: WKUEN9 (Bit 18)                                */
#define GPIOA_WKUEN_WKUEN9_Msk                (0xc0000UL)               /*!< GPIOA WKUEN: WKUEN9 (Bitfield-Mask: 0x03)                   */
#define GPIOA_WKUEN_WKUEN10_Pos               (20UL)                    /*!< GPIOA WKUEN: WKUEN10 (Bit 20)                               */
#define GPIOA_WKUEN_WKUEN10_Msk               (0x300000UL)              /*!< GPIOA WKUEN: WKUEN10 (Bitfield-Mask: 0x03)                  */
#define GPIOA_WKUEN_WKUEN11_Pos               (22UL)                    /*!< GPIOA WKUEN: WKUEN11 (Bit 22)                               */
#define GPIOA_WKUEN_WKUEN11_Msk               (0xc00000UL)              /*!< GPIOA WKUEN: WKUEN11 (Bitfield-Mask: 0x03)                  */
#define GPIOA_WKUEN_WKUEN12_Pos               (24UL)                    /*!< GPIOA WKUEN: WKUEN12 (Bit 24)                               */
#define GPIOA_WKUEN_WKUEN12_Msk               (0x3000000UL)             /*!< GPIOA WKUEN: WKUEN12 (Bitfield-Mask: 0x03)                  */
#define GPIOA_WKUEN_WKUEN13_Pos               (26UL)                    /*!< GPIOA WKUEN: WKUEN13 (Bit 26)                               */
#define GPIOA_WKUEN_WKUEN13_Msk               (0xc000000UL)             /*!< GPIOA WKUEN: WKUEN13 (Bitfield-Mask: 0x03)                  */
#define GPIOA_WKUEN_WKUEN14_Pos               (28UL)                    /*!< GPIOA WKUEN: WKUEN14 (Bit 28)                               */
#define GPIOA_WKUEN_WKUEN14_Msk               (0x30000000UL)            /*!< GPIOA WKUEN: WKUEN14 (Bitfield-Mask: 0x03)                  */
#define GPIOA_WKUEN_WKUEN15_Pos               (30UL)                    /*!< GPIOA WKUEN: WKUEN15 (Bit 30)                               */
#define GPIOA_WKUEN_WKUEN15_Msk               (0xc0000000UL)            /*!< GPIOA WKUEN: WKUEN15 (Bitfield-Mask: 0x03)                  */

/* ----------------------------------  GPIOA_STS  --------------------------------- */
#define GPIOA_STS_STS0_Pos                    (0UL)                     /*!< GPIOA STS: STS0 (Bit 0)                                     */
#define GPIOA_STS_STS0_Msk                    (0x1UL)                   /*!< GPIOA STS: STS0 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS1_Pos                    (1UL)                     /*!< GPIOA STS: STS1 (Bit 1)                                     */
#define GPIOA_STS_STS1_Msk                    (0x2UL)                   /*!< GPIOA STS: STS1 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS2_Pos                    (2UL)                     /*!< GPIOA STS: STS2 (Bit 2)                                     */
#define GPIOA_STS_STS2_Msk                    (0x4UL)                   /*!< GPIOA STS: STS2 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS3_Pos                    (3UL)                     /*!< GPIOA STS: STS3 (Bit 3)                                     */
#define GPIOA_STS_STS3_Msk                    (0x8UL)                   /*!< GPIOA STS: STS3 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS4_Pos                    (4UL)                     /*!< GPIOA STS: STS4 (Bit 4)                                     */
#define GPIOA_STS_STS4_Msk                    (0x10UL)                  /*!< GPIOA STS: STS4 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS5_Pos                    (5UL)                     /*!< GPIOA STS: STS5 (Bit 5)                                     */
#define GPIOA_STS_STS5_Msk                    (0x20UL)                  /*!< GPIOA STS: STS5 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS6_Pos                    (6UL)                     /*!< GPIOA STS: STS6 (Bit 6)                                     */
#define GPIOA_STS_STS6_Msk                    (0x40UL)                  /*!< GPIOA STS: STS6 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS7_Pos                    (7UL)                     /*!< GPIOA STS: STS7 (Bit 7)                                     */
#define GPIOA_STS_STS7_Msk                    (0x80UL)                  /*!< GPIOA STS: STS7 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS8_Pos                    (8UL)                     /*!< GPIOA STS: STS8 (Bit 8)                                     */
#define GPIOA_STS_STS8_Msk                    (0x100UL)                 /*!< GPIOA STS: STS8 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS9_Pos                    (9UL)                     /*!< GPIOA STS: STS9 (Bit 9)                                     */
#define GPIOA_STS_STS9_Msk                    (0x200UL)                 /*!< GPIOA STS: STS9 (Bitfield-Mask: 0x01)                       */
#define GPIOA_STS_STS10_Pos                   (10UL)                    /*!< GPIOA STS: STS10 (Bit 10)                                   */
#define GPIOA_STS_STS10_Msk                   (0x400UL)                 /*!< GPIOA STS: STS10 (Bitfield-Mask: 0x01)                      */
#define GPIOA_STS_STS11_Pos                   (11UL)                    /*!< GPIOA STS: STS11 (Bit 11)                                   */
#define GPIOA_STS_STS11_Msk                   (0x800UL)                 /*!< GPIOA STS: STS11 (Bitfield-Mask: 0x01)                      */
#define GPIOA_STS_STS12_Pos                   (12UL)                    /*!< GPIOA STS: STS12 (Bit 12)                                   */
#define GPIOA_STS_STS12_Msk                   (0x1000UL)                /*!< GPIOA STS: STS12 (Bitfield-Mask: 0x01)                      */
#define GPIOA_STS_STS13_Pos                   (13UL)                    /*!< GPIOA STS: STS13 (Bit 13)                                   */
#define GPIOA_STS_STS13_Msk                   (0x2000UL)                /*!< GPIOA STS: STS13 (Bitfield-Mask: 0x01)                      */
#define GPIOA_STS_STS14_Pos                   (14UL)                    /*!< GPIOA STS: STS14 (Bit 14)                                   */
#define GPIOA_STS_STS14_Msk                   (0x4000UL)                /*!< GPIOA STS: STS14 (Bitfield-Mask: 0x01)                      */
#define GPIOA_STS_STS15_Pos                   (15UL)                    /*!< GPIOA STS: STS15 (Bit 15)                                   */
#define GPIOA_STS_STS15_Msk                   (0x8000UL)                /*!< GPIOA STS: STS15 (Bitfield-Mask: 0x01)                      */

/* --------------------------------  GPIOA_INTSTS  -------------------------------- */
#define GPIOA_INTSTS_INTSTS0_Pos              (0UL)                     /*!< GPIOA INTSTS: INTSTS0 (Bit 0)                               */
#define GPIOA_INTSTS_INTSTS0_Msk              (0x1UL)                   /*!< GPIOA INTSTS: INTSTS0 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS1_Pos              (1UL)                     /*!< GPIOA INTSTS: INTSTS1 (Bit 1)                               */
#define GPIOA_INTSTS_INTSTS1_Msk              (0x2UL)                   /*!< GPIOA INTSTS: INTSTS1 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS2_Pos              (2UL)                     /*!< GPIOA INTSTS: INTSTS2 (Bit 2)                               */
#define GPIOA_INTSTS_INTSTS2_Msk              (0x4UL)                   /*!< GPIOA INTSTS: INTSTS2 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS3_Pos              (3UL)                     /*!< GPIOA INTSTS: INTSTS3 (Bit 3)                               */
#define GPIOA_INTSTS_INTSTS3_Msk              (0x8UL)                   /*!< GPIOA INTSTS: INTSTS3 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS4_Pos              (4UL)                     /*!< GPIOA INTSTS: INTSTS4 (Bit 4)                               */
#define GPIOA_INTSTS_INTSTS4_Msk              (0x10UL)                  /*!< GPIOA INTSTS: INTSTS4 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS5_Pos              (5UL)                     /*!< GPIOA INTSTS: INTSTS5 (Bit 5)                               */
#define GPIOA_INTSTS_INTSTS5_Msk              (0x20UL)                  /*!< GPIOA INTSTS: INTSTS5 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS6_Pos              (6UL)                     /*!< GPIOA INTSTS: INTSTS6 (Bit 6)                               */
#define GPIOA_INTSTS_INTSTS6_Msk              (0x40UL)                  /*!< GPIOA INTSTS: INTSTS6 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS7_Pos              (7UL)                     /*!< GPIOA INTSTS: INTSTS7 (Bit 7)                               */
#define GPIOA_INTSTS_INTSTS7_Msk              (0x80UL)                  /*!< GPIOA INTSTS: INTSTS7 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS8_Pos              (8UL)                     /*!< GPIOA INTSTS: INTSTS8 (Bit 8)                               */
#define GPIOA_INTSTS_INTSTS8_Msk              (0x100UL)                 /*!< GPIOA INTSTS: INTSTS8 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS9_Pos              (9UL)                     /*!< GPIOA INTSTS: INTSTS9 (Bit 9)                               */
#define GPIOA_INTSTS_INTSTS9_Msk              (0x200UL)                 /*!< GPIOA INTSTS: INTSTS9 (Bitfield-Mask: 0x01)                 */
#define GPIOA_INTSTS_INTSTS10_Pos             (10UL)                    /*!< GPIOA INTSTS: INTSTS10 (Bit 10)                             */
#define GPIOA_INTSTS_INTSTS10_Msk             (0x400UL)                 /*!< GPIOA INTSTS: INTSTS10 (Bitfield-Mask: 0x01)                */
#define GPIOA_INTSTS_INTSTS11_Pos             (11UL)                    /*!< GPIOA INTSTS: INTSTS11 (Bit 11)                             */
#define GPIOA_INTSTS_INTSTS11_Msk             (0x800UL)                 /*!< GPIOA INTSTS: INTSTS11 (Bitfield-Mask: 0x01)                */
#define GPIOA_INTSTS_INTSTS12_Pos             (12UL)                    /*!< GPIOA INTSTS: INTSTS12 (Bit 12)                             */
#define GPIOA_INTSTS_INTSTS12_Msk             (0x1000UL)                /*!< GPIOA INTSTS: INTSTS12 (Bitfield-Mask: 0x01)                */
#define GPIOA_INTSTS_INTSTS13_Pos             (13UL)                    /*!< GPIOA INTSTS: INTSTS13 (Bit 13)                             */
#define GPIOA_INTSTS_INTSTS13_Msk             (0x2000UL)                /*!< GPIOA INTSTS: INTSTS13 (Bitfield-Mask: 0x01)                */
#define GPIOA_INTSTS_INTSTS14_Pos             (14UL)                    /*!< GPIOA INTSTS: INTSTS14 (Bit 14)                             */
#define GPIOA_INTSTS_INTSTS14_Msk             (0x4000UL)                /*!< GPIOA INTSTS: INTSTS14 (Bitfield-Mask: 0x01)                */
#define GPIOA_INTSTS_INTSTS15_Pos             (15UL)                    /*!< GPIOA INTSTS: INTSTS15 (Bit 15)                             */
#define GPIOA_INTSTS_INTSTS15_Msk             (0x8000UL)                /*!< GPIOA INTSTS: INTSTS15 (Bitfield-Mask: 0x01)                */

/* ----------------------------------  GPIOA_SEL  --------------------------------- */
#define GPIOA_SEL_IOA_SEL3_Pos                (3UL)                     /*!< GPIOA SEL: IOA_SEL3 (Bit 3)                                 */
#define GPIOA_SEL_IOA_SEL3_Msk                (0x8UL)                   /*!< GPIOA SEL: IOA_SEL3 (Bitfield-Mask: 0x01)                   */
#define GPIOA_SEL_IOA_SEL6_Pos                (6UL)                     /*!< GPIOA SEL: IOA_SEL6 (Bit 6)                                 */
#define GPIOA_SEL_IOA_SEL6_Msk                (0x40UL)                  /*!< GPIOA SEL: IOA_SEL6 (Bitfield-Mask: 0x01)                   */
#define GPIOA_SEL_IOA_SEL7_Pos                (7UL)                     /*!< GPIOA SEL: IOA_SEL7 (Bit 7)                                 */
#define GPIOA_SEL_IOA_SEL7_Msk                (0x80UL)                  /*!< GPIOA SEL: IOA_SEL7 (Bitfield-Mask: 0x01)                   */

/* -------------------------------  GPIOA_IOANODEG  ------------------------------- */
#define GPIOA_IOANODEG_IOANODEG0_Pos          (0UL)                     /*!< GPIOA IOANODEG: IOANODEG0 (Bit 0)                           */
#define GPIOA_IOANODEG_IOANODEG0_Msk          (0x1UL)                   /*!< GPIOA IOANODEG: IOANODEG0 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG1_Pos          (1UL)                     /*!< GPIOA IOANODEG: IOANODEG1 (Bit 1)                           */
#define GPIOA_IOANODEG_IOANODEG1_Msk          (0x2UL)                   /*!< GPIOA IOANODEG: IOANODEG1 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG2_Pos          (2UL)                     /*!< GPIOA IOANODEG: IOANODEG2 (Bit 2)                           */
#define GPIOA_IOANODEG_IOANODEG2_Msk          (0x4UL)                   /*!< GPIOA IOANODEG: IOANODEG2 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG3_Pos          (3UL)                     /*!< GPIOA IOANODEG: IOANODEG3 (Bit 3)                           */
#define GPIOA_IOANODEG_IOANODEG3_Msk          (0x8UL)                   /*!< GPIOA IOANODEG: IOANODEG3 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG4_Pos          (4UL)                     /*!< GPIOA IOANODEG: IOANODEG4 (Bit 4)                           */
#define GPIOA_IOANODEG_IOANODEG4_Msk          (0x10UL)                  /*!< GPIOA IOANODEG: IOANODEG4 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG5_Pos          (5UL)                     /*!< GPIOA IOANODEG: IOANODEG5 (Bit 5)                           */
#define GPIOA_IOANODEG_IOANODEG5_Msk          (0x20UL)                  /*!< GPIOA IOANODEG: IOANODEG5 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG6_Pos          (6UL)                     /*!< GPIOA IOANODEG: IOANODEG6 (Bit 6)                           */
#define GPIOA_IOANODEG_IOANODEG6_Msk          (0x40UL)                  /*!< GPIOA IOANODEG: IOANODEG6 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG7_Pos          (7UL)                     /*!< GPIOA IOANODEG: IOANODEG7 (Bit 7)                           */
#define GPIOA_IOANODEG_IOANODEG7_Msk          (0x80UL)                  /*!< GPIOA IOANODEG: IOANODEG7 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG8_Pos          (8UL)                     /*!< GPIOA IOANODEG: IOANODEG8 (Bit 8)                           */
#define GPIOA_IOANODEG_IOANODEG8_Msk          (0x100UL)                 /*!< GPIOA IOANODEG: IOANODEG8 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG9_Pos          (9UL)                     /*!< GPIOA IOANODEG: IOANODEG9 (Bit 9)                           */
#define GPIOA_IOANODEG_IOANODEG9_Msk          (0x200UL)                 /*!< GPIOA IOANODEG: IOANODEG9 (Bitfield-Mask: 0x01)             */
#define GPIOA_IOANODEG_IOANODEG10_Pos         (10UL)                    /*!< GPIOA IOANODEG: IOANODEG10 (Bit 10)                         */
#define GPIOA_IOANODEG_IOANODEG10_Msk         (0x400UL)                 /*!< GPIOA IOANODEG: IOANODEG10 (Bitfield-Mask: 0x01)            */
#define GPIOA_IOANODEG_IOANODEG11_Pos         (11UL)                    /*!< GPIOA IOANODEG: IOANODEG11 (Bit 11)                         */
#define GPIOA_IOANODEG_IOANODEG11_Msk         (0x800UL)                 /*!< GPIOA IOANODEG: IOANODEG11 (Bitfield-Mask: 0x01)            */
#define GPIOA_IOANODEG_IOANODEG12_Pos         (12UL)                    /*!< GPIOA IOANODEG: IOANODEG12 (Bit 12)                         */
#define GPIOA_IOANODEG_IOANODEG12_Msk         (0x1000UL)                /*!< GPIOA IOANODEG: IOANODEG12 (Bitfield-Mask: 0x01)            */
#define GPIOA_IOANODEG_IOANODEG13_Pos         (13UL)                    /*!< GPIOA IOANODEG: IOANODEG13 (Bit 13)                         */
#define GPIOA_IOANODEG_IOANODEG13_Msk         (0x2000UL)                /*!< GPIOA IOANODEG: IOANODEG13 (Bitfield-Mask: 0x01)            */
#define GPIOA_IOANODEG_IOANODEG14_Pos         (14UL)                    /*!< GPIOA IOANODEG: IOANODEG14 (Bit 14)                         */
#define GPIOA_IOANODEG_IOANODEG14_Msk         (0x4000UL)                /*!< GPIOA IOANODEG: IOANODEG14 (Bitfield-Mask: 0x01)            */
#define GPIOA_IOANODEG_IOANODEG15_Pos         (15UL)                    /*!< GPIOA IOANODEG: IOANODEG15 (Bit 15)                         */
#define GPIOA_IOANODEG_IOANODEG15_Msk         (0x8000UL)                /*!< GPIOA IOANODEG: IOANODEG15 (Bitfield-Mask: 0x01)            */


/* ================================================================================ */
/* ================          Group 'GPIO' Position & Mask          ================ */
/* ================================================================================ */


/* ----------------------------------  GPIO_OEN  ---------------------------------- */
#define GPIO_OEN_OEN0_Pos                     (0UL)                     /*!< GPIO OEN: OEN0 (Bit 0)                                      */
#define GPIO_OEN_OEN0_Msk                     (0x1UL)                   /*!< GPIO OEN: OEN0 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN1_Pos                     (1UL)                     /*!< GPIO OEN: OEN1 (Bit 1)                                      */
#define GPIO_OEN_OEN1_Msk                     (0x2UL)                   /*!< GPIO OEN: OEN1 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN2_Pos                     (2UL)                     /*!< GPIO OEN: OEN2 (Bit 2)                                      */
#define GPIO_OEN_OEN2_Msk                     (0x4UL)                   /*!< GPIO OEN: OEN2 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN3_Pos                     (3UL)                     /*!< GPIO OEN: OEN3 (Bit 3)                                      */
#define GPIO_OEN_OEN3_Msk                     (0x8UL)                   /*!< GPIO OEN: OEN3 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN4_Pos                     (4UL)                     /*!< GPIO OEN: OEN4 (Bit 4)                                      */
#define GPIO_OEN_OEN4_Msk                     (0x10UL)                  /*!< GPIO OEN: OEN4 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN5_Pos                     (5UL)                     /*!< GPIO OEN: OEN5 (Bit 5)                                      */
#define GPIO_OEN_OEN5_Msk                     (0x20UL)                  /*!< GPIO OEN: OEN5 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN6_Pos                     (6UL)                     /*!< GPIO OEN: OEN6 (Bit 6)                                      */
#define GPIO_OEN_OEN6_Msk                     (0x40UL)                  /*!< GPIO OEN: OEN6 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN7_Pos                     (7UL)                     /*!< GPIO OEN: OEN7 (Bit 7)                                      */
#define GPIO_OEN_OEN7_Msk                     (0x80UL)                  /*!< GPIO OEN: OEN7 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN8_Pos                     (8UL)                     /*!< GPIO OEN: OEN8 (Bit 8)                                      */
#define GPIO_OEN_OEN8_Msk                     (0x100UL)                 /*!< GPIO OEN: OEN8 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN9_Pos                     (9UL)                     /*!< GPIO OEN: OEN9 (Bit 9)                                      */
#define GPIO_OEN_OEN9_Msk                     (0x200UL)                 /*!< GPIO OEN: OEN9 (Bitfield-Mask: 0x01)                        */
#define GPIO_OEN_OEN10_Pos                    (10UL)                    /*!< GPIO OEN: OEN10 (Bit 10)                                    */
#define GPIO_OEN_OEN10_Msk                    (0x400UL)                 /*!< GPIO OEN: OEN10 (Bitfield-Mask: 0x01)                       */
#define GPIO_OEN_OEN11_Pos                    (11UL)                    /*!< GPIO OEN: OEN11 (Bit 11)                                    */
#define GPIO_OEN_OEN11_Msk                    (0x800UL)                 /*!< GPIO OEN: OEN11 (Bitfield-Mask: 0x01)                       */
#define GPIO_OEN_OEN12_Pos                    (12UL)                    /*!< GPIO OEN: OEN12 (Bit 12)                                    */
#define GPIO_OEN_OEN12_Msk                    (0x1000UL)                /*!< GPIO OEN: OEN12 (Bitfield-Mask: 0x01)                       */
#define GPIO_OEN_OEN13_Pos                    (13UL)                    /*!< GPIO OEN: OEN13 (Bit 13)                                    */
#define GPIO_OEN_OEN13_Msk                    (0x2000UL)                /*!< GPIO OEN: OEN13 (Bitfield-Mask: 0x01)                       */
#define GPIO_OEN_OEN14_Pos                    (14UL)                    /*!< GPIO OEN: OEN14 (Bit 14)                                    */
#define GPIO_OEN_OEN14_Msk                    (0x4000UL)                /*!< GPIO OEN: OEN14 (Bitfield-Mask: 0x01)                       */
#define GPIO_OEN_OEN15_Pos                    (15UL)                    /*!< GPIO OEN: OEN15 (Bit 15)                                    */
#define GPIO_OEN_OEN15_Msk                    (0x8000UL)                /*!< GPIO OEN: OEN15 (Bitfield-Mask: 0x01)                       */

/* -----------------------------------  GPIO_IE  ---------------------------------- */
#define GPIO_IE_IE0_Pos                       (0UL)                     /*!< GPIO IE: IE0 (Bit 0)                                        */
#define GPIO_IE_IE0_Msk                       (0x1UL)                   /*!< GPIO IE: IE0 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE1_Pos                       (1UL)                     /*!< GPIO IE: IE1 (Bit 1)                                        */
#define GPIO_IE_IE1_Msk                       (0x2UL)                   /*!< GPIO IE: IE1 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE2_Pos                       (2UL)                     /*!< GPIO IE: IE2 (Bit 2)                                        */
#define GPIO_IE_IE2_Msk                       (0x4UL)                   /*!< GPIO IE: IE2 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE3_Pos                       (3UL)                     /*!< GPIO IE: IE3 (Bit 3)                                        */
#define GPIO_IE_IE3_Msk                       (0x8UL)                   /*!< GPIO IE: IE3 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE4_Pos                       (4UL)                     /*!< GPIO IE: IE4 (Bit 4)                                        */
#define GPIO_IE_IE4_Msk                       (0x10UL)                  /*!< GPIO IE: IE4 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE5_Pos                       (5UL)                     /*!< GPIO IE: IE5 (Bit 5)                                        */
#define GPIO_IE_IE5_Msk                       (0x20UL)                  /*!< GPIO IE: IE5 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE6_Pos                       (6UL)                     /*!< GPIO IE: IE6 (Bit 6)                                        */
#define GPIO_IE_IE6_Msk                       (0x40UL)                  /*!< GPIO IE: IE6 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE7_Pos                       (7UL)                     /*!< GPIO IE: IE7 (Bit 7)                                        */
#define GPIO_IE_IE7_Msk                       (0x80UL)                  /*!< GPIO IE: IE7 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE8_Pos                       (8UL)                     /*!< GPIO IE: IE8 (Bit 8)                                        */
#define GPIO_IE_IE8_Msk                       (0x100UL)                 /*!< GPIO IE: IE8 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE9_Pos                       (9UL)                     /*!< GPIO IE: IE9 (Bit 9)                                        */
#define GPIO_IE_IE9_Msk                       (0x200UL)                 /*!< GPIO IE: IE9 (Bitfield-Mask: 0x01)                          */
#define GPIO_IE_IE10_Pos                      (10UL)                    /*!< GPIO IE: IE10 (Bit 10)                                      */
#define GPIO_IE_IE10_Msk                      (0x400UL)                 /*!< GPIO IE: IE10 (Bitfield-Mask: 0x01)                         */
#define GPIO_IE_IE11_Pos                      (11UL)                    /*!< GPIO IE: IE11 (Bit 11)                                      */
#define GPIO_IE_IE11_Msk                      (0x800UL)                 /*!< GPIO IE: IE11 (Bitfield-Mask: 0x01)                         */
#define GPIO_IE_IE12_Pos                      (12UL)                    /*!< GPIO IE: IE12 (Bit 12)                                      */
#define GPIO_IE_IE12_Msk                      (0x1000UL)                /*!< GPIO IE: IE12 (Bitfield-Mask: 0x01)                         */
#define GPIO_IE_IE13_Pos                      (13UL)                    /*!< GPIO IE: IE13 (Bit 13)                                      */
#define GPIO_IE_IE13_Msk                      (0x2000UL)                /*!< GPIO IE: IE13 (Bitfield-Mask: 0x01)                         */
#define GPIO_IE_IE14_Pos                      (14UL)                    /*!< GPIO IE: IE14 (Bit 14)                                      */
#define GPIO_IE_IE14_Msk                      (0x4000UL)                /*!< GPIO IE: IE14 (Bitfield-Mask: 0x01)                         */
#define GPIO_IE_IE15_Pos                      (15UL)                    /*!< GPIO IE: IE15 (Bit 15)                                      */
#define GPIO_IE_IE15_Msk                      (0x8000UL)                /*!< GPIO IE: IE15 (Bitfield-Mask: 0x01)                         */

/* ----------------------------------  GPIO_DAT  ---------------------------------- */
#define GPIO_DAT_DAT0_Pos                     (0UL)                     /*!< GPIO DAT: DAT0 (Bit 0)                                      */
#define GPIO_DAT_DAT0_Msk                     (0x1UL)                   /*!< GPIO DAT: DAT0 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT1_Pos                     (1UL)                     /*!< GPIO DAT: DAT1 (Bit 1)                                      */
#define GPIO_DAT_DAT1_Msk                     (0x2UL)                   /*!< GPIO DAT: DAT1 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT2_Pos                     (2UL)                     /*!< GPIO DAT: DAT2 (Bit 2)                                      */
#define GPIO_DAT_DAT2_Msk                     (0x4UL)                   /*!< GPIO DAT: DAT2 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT3_Pos                     (3UL)                     /*!< GPIO DAT: DAT3 (Bit 3)                                      */
#define GPIO_DAT_DAT3_Msk                     (0x8UL)                   /*!< GPIO DAT: DAT3 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT4_Pos                     (4UL)                     /*!< GPIO DAT: DAT4 (Bit 4)                                      */
#define GPIO_DAT_DAT4_Msk                     (0x10UL)                  /*!< GPIO DAT: DAT4 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT5_Pos                     (5UL)                     /*!< GPIO DAT: DAT5 (Bit 5)                                      */
#define GPIO_DAT_DAT5_Msk                     (0x20UL)                  /*!< GPIO DAT: DAT5 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT6_Pos                     (6UL)                     /*!< GPIO DAT: DAT6 (Bit 6)                                      */
#define GPIO_DAT_DAT6_Msk                     (0x40UL)                  /*!< GPIO DAT: DAT6 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT7_Pos                     (7UL)                     /*!< GPIO DAT: DAT7 (Bit 7)                                      */
#define GPIO_DAT_DAT7_Msk                     (0x80UL)                  /*!< GPIO DAT: DAT7 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT8_Pos                     (8UL)                     /*!< GPIO DAT: DAT8 (Bit 8)                                      */
#define GPIO_DAT_DAT8_Msk                     (0x100UL)                 /*!< GPIO DAT: DAT8 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT9_Pos                     (9UL)                     /*!< GPIO DAT: DAT9 (Bit 9)                                      */
#define GPIO_DAT_DAT9_Msk                     (0x200UL)                 /*!< GPIO DAT: DAT9 (Bitfield-Mask: 0x01)                        */
#define GPIO_DAT_DAT10_Pos                    (10UL)                    /*!< GPIO DAT: DAT10 (Bit 10)                                    */
#define GPIO_DAT_DAT10_Msk                    (0x400UL)                 /*!< GPIO DAT: DAT10 (Bitfield-Mask: 0x01)                       */
#define GPIO_DAT_DAT11_Pos                    (11UL)                    /*!< GPIO DAT: DAT11 (Bit 11)                                    */
#define GPIO_DAT_DAT11_Msk                    (0x800UL)                 /*!< GPIO DAT: DAT11 (Bitfield-Mask: 0x01)                       */
#define GPIO_DAT_DAT12_Pos                    (12UL)                    /*!< GPIO DAT: DAT12 (Bit 12)                                    */
#define GPIO_DAT_DAT12_Msk                    (0x1000UL)                /*!< GPIO DAT: DAT12 (Bitfield-Mask: 0x01)                       */
#define GPIO_DAT_DAT13_Pos                    (13UL)                    /*!< GPIO DAT: DAT13 (Bit 13)                                    */
#define GPIO_DAT_DAT13_Msk                    (0x2000UL)                /*!< GPIO DAT: DAT13 (Bitfield-Mask: 0x01)                       */
#define GPIO_DAT_DAT14_Pos                    (14UL)                    /*!< GPIO DAT: DAT14 (Bit 14)                                    */
#define GPIO_DAT_DAT14_Msk                    (0x4000UL)                /*!< GPIO DAT: DAT14 (Bitfield-Mask: 0x01)                       */
#define GPIO_DAT_DAT15_Pos                    (15UL)                    /*!< GPIO DAT: DAT15 (Bit 15)                                    */
#define GPIO_DAT_DAT15_Msk                    (0x8000UL)                /*!< GPIO DAT: DAT15 (Bitfield-Mask: 0x01)                       */

/* ----------------------------------  GPIO_ATT  ---------------------------------- */
#define GPIO_ATT_ATT0_Pos                     (0UL)                     /*!< GPIO ATT: ATT0 (Bit 0)                                      */
#define GPIO_ATT_ATT0_Msk                     (0x1UL)                   /*!< GPIO ATT: ATT0 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT1_Pos                     (1UL)                     /*!< GPIO ATT: ATT1 (Bit 1)                                      */
#define GPIO_ATT_ATT1_Msk                     (0x2UL)                   /*!< GPIO ATT: ATT1 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT2_Pos                     (2UL)                     /*!< GPIO ATT: ATT2 (Bit 2)                                      */
#define GPIO_ATT_ATT2_Msk                     (0x4UL)                   /*!< GPIO ATT: ATT2 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT3_Pos                     (3UL)                     /*!< GPIO ATT: ATT3 (Bit 3)                                      */
#define GPIO_ATT_ATT3_Msk                     (0x8UL)                   /*!< GPIO ATT: ATT3 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT4_Pos                     (4UL)                     /*!< GPIO ATT: ATT4 (Bit 4)                                      */
#define GPIO_ATT_ATT4_Msk                     (0x10UL)                  /*!< GPIO ATT: ATT4 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT5_Pos                     (5UL)                     /*!< GPIO ATT: ATT5 (Bit 5)                                      */
#define GPIO_ATT_ATT5_Msk                     (0x20UL)                  /*!< GPIO ATT: ATT5 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT6_Pos                     (6UL)                     /*!< GPIO ATT: ATT6 (Bit 6)                                      */
#define GPIO_ATT_ATT6_Msk                     (0x40UL)                  /*!< GPIO ATT: ATT6 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT7_Pos                     (7UL)                     /*!< GPIO ATT: ATT7 (Bit 7)                                      */
#define GPIO_ATT_ATT7_Msk                     (0x80UL)                  /*!< GPIO ATT: ATT7 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT8_Pos                     (8UL)                     /*!< GPIO ATT: ATT8 (Bit 8)                                      */
#define GPIO_ATT_ATT8_Msk                     (0x100UL)                 /*!< GPIO ATT: ATT8 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT9_Pos                     (9UL)                     /*!< GPIO ATT: ATT9 (Bit 9)                                      */
#define GPIO_ATT_ATT9_Msk                     (0x200UL)                 /*!< GPIO ATT: ATT9 (Bitfield-Mask: 0x01)                        */
#define GPIO_ATT_ATT10_Pos                    (10UL)                    /*!< GPIO ATT: ATT10 (Bit 10)                                    */
#define GPIO_ATT_ATT10_Msk                    (0x400UL)                 /*!< GPIO ATT: ATT10 (Bitfield-Mask: 0x01)                       */
#define GPIO_ATT_ATT11_Pos                    (11UL)                    /*!< GPIO ATT: ATT11 (Bit 11)                                    */
#define GPIO_ATT_ATT11_Msk                    (0x800UL)                 /*!< GPIO ATT: ATT11 (Bitfield-Mask: 0x01)                       */
#define GPIO_ATT_ATT12_Pos                    (12UL)                    /*!< GPIO ATT: ATT12 (Bit 12)                                    */
#define GPIO_ATT_ATT12_Msk                    (0x1000UL)                /*!< GPIO ATT: ATT12 (Bitfield-Mask: 0x01)                       */
#define GPIO_ATT_ATT13_Pos                    (13UL)                    /*!< GPIO ATT: ATT13 (Bit 13)                                    */
#define GPIO_ATT_ATT13_Msk                    (0x2000UL)                /*!< GPIO ATT: ATT13 (Bitfield-Mask: 0x01)                       */
#define GPIO_ATT_ATT14_Pos                    (14UL)                    /*!< GPIO ATT: ATT14 (Bit 14)                                    */
#define GPIO_ATT_ATT14_Msk                    (0x4000UL)                /*!< GPIO ATT: ATT14 (Bitfield-Mask: 0x01)                       */
#define GPIO_ATT_ATT15_Pos                    (15UL)                    /*!< GPIO ATT: ATT15 (Bit 15)                                    */
#define GPIO_ATT_ATT15_Msk                    (0x8000UL)                /*!< GPIO ATT: ATT15 (Bitfield-Mask: 0x01)                       */

/* ----------------------------------  GPIO_STS  ---------------------------------- */
#define GPIO_STS_STS0_Pos                     (0UL)                     /*!< GPIO STS: STS0 (Bit 0)                                      */
#define GPIO_STS_STS0_Msk                     (0x1UL)                   /*!< GPIO STS: STS0 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS1_Pos                     (1UL)                     /*!< GPIO STS: STS1 (Bit 1)                                      */
#define GPIO_STS_STS1_Msk                     (0x2UL)                   /*!< GPIO STS: STS1 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS2_Pos                     (2UL)                     /*!< GPIO STS: STS2 (Bit 2)                                      */
#define GPIO_STS_STS2_Msk                     (0x4UL)                   /*!< GPIO STS: STS2 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS3_Pos                     (3UL)                     /*!< GPIO STS: STS3 (Bit 3)                                      */
#define GPIO_STS_STS3_Msk                     (0x8UL)                   /*!< GPIO STS: STS3 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS4_Pos                     (4UL)                     /*!< GPIO STS: STS4 (Bit 4)                                      */
#define GPIO_STS_STS4_Msk                     (0x10UL)                  /*!< GPIO STS: STS4 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS5_Pos                     (5UL)                     /*!< GPIO STS: STS5 (Bit 5)                                      */
#define GPIO_STS_STS5_Msk                     (0x20UL)                  /*!< GPIO STS: STS5 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS6_Pos                     (6UL)                     /*!< GPIO STS: STS6 (Bit 6)                                      */
#define GPIO_STS_STS6_Msk                     (0x40UL)                  /*!< GPIO STS: STS6 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS7_Pos                     (7UL)                     /*!< GPIO STS: STS7 (Bit 7)                                      */
#define GPIO_STS_STS7_Msk                     (0x80UL)                  /*!< GPIO STS: STS7 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS8_Pos                     (8UL)                     /*!< GPIO STS: STS8 (Bit 8)                                      */
#define GPIO_STS_STS8_Msk                     (0x100UL)                 /*!< GPIO STS: STS8 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS9_Pos                     (9UL)                     /*!< GPIO STS: STS9 (Bit 9)                                      */
#define GPIO_STS_STS9_Msk                     (0x200UL)                 /*!< GPIO STS: STS9 (Bitfield-Mask: 0x01)                        */
#define GPIO_STS_STS10_Pos                    (10UL)                    /*!< GPIO STS: STS10 (Bit 10)                                    */
#define GPIO_STS_STS10_Msk                    (0x400UL)                 /*!< GPIO STS: STS10 (Bitfield-Mask: 0x01)                       */
#define GPIO_STS_STS11_Pos                    (11UL)                    /*!< GPIO STS: STS11 (Bit 11)                                    */
#define GPIO_STS_STS11_Msk                    (0x800UL)                 /*!< GPIO STS: STS11 (Bitfield-Mask: 0x01)                       */
#define GPIO_STS_STS12_Pos                    (12UL)                    /*!< GPIO STS: STS12 (Bit 12)                                    */
#define GPIO_STS_STS12_Msk                    (0x1000UL)                /*!< GPIO STS: STS12 (Bitfield-Mask: 0x01)                       */
#define GPIO_STS_STS13_Pos                    (13UL)                    /*!< GPIO STS: STS13 (Bit 13)                                    */
#define GPIO_STS_STS13_Msk                    (0x2000UL)                /*!< GPIO STS: STS13 (Bitfield-Mask: 0x01)                       */
#define GPIO_STS_STS14_Pos                    (14UL)                    /*!< GPIO STS: STS14 (Bit 14)                                    */
#define GPIO_STS_STS14_Msk                    (0x4000UL)                /*!< GPIO STS: STS14 (Bitfield-Mask: 0x01)                       */
#define GPIO_STS_STS15_Pos                    (15UL)                    /*!< GPIO STS: STS15 (Bit 15)                                    */
#define GPIO_STS_STS15_Msk                    (0x8000UL)                /*!< GPIO STS: STS15 (Bitfield-Mask: 0x01)                       */


/* ================================================================================ */
/* ================         struct 'GPIOB' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  GPIOB_OEN  --------------------------------- */
#define GPIOB_OEN_OEN0_Pos                    (0UL)                     /*!< GPIOB OEN: OEN0 (Bit 0)                                     */
#define GPIOB_OEN_OEN0_Msk                    (0x1UL)                   /*!< GPIOB OEN: OEN0 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN1_Pos                    (1UL)                     /*!< GPIOB OEN: OEN1 (Bit 1)                                     */
#define GPIOB_OEN_OEN1_Msk                    (0x2UL)                   /*!< GPIOB OEN: OEN1 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN2_Pos                    (2UL)                     /*!< GPIOB OEN: OEN2 (Bit 2)                                     */
#define GPIOB_OEN_OEN2_Msk                    (0x4UL)                   /*!< GPIOB OEN: OEN2 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN3_Pos                    (3UL)                     /*!< GPIOB OEN: OEN3 (Bit 3)                                     */
#define GPIOB_OEN_OEN3_Msk                    (0x8UL)                   /*!< GPIOB OEN: OEN3 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN4_Pos                    (4UL)                     /*!< GPIOB OEN: OEN4 (Bit 4)                                     */
#define GPIOB_OEN_OEN4_Msk                    (0x10UL)                  /*!< GPIOB OEN: OEN4 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN5_Pos                    (5UL)                     /*!< GPIOB OEN: OEN5 (Bit 5)                                     */
#define GPIOB_OEN_OEN5_Msk                    (0x20UL)                  /*!< GPIOB OEN: OEN5 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN6_Pos                    (6UL)                     /*!< GPIOB OEN: OEN6 (Bit 6)                                     */
#define GPIOB_OEN_OEN6_Msk                    (0x40UL)                  /*!< GPIOB OEN: OEN6 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN7_Pos                    (7UL)                     /*!< GPIOB OEN: OEN7 (Bit 7)                                     */
#define GPIOB_OEN_OEN7_Msk                    (0x80UL)                  /*!< GPIOB OEN: OEN7 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN8_Pos                    (8UL)                     /*!< GPIOB OEN: OEN8 (Bit 8)                                     */
#define GPIOB_OEN_OEN8_Msk                    (0x100UL)                 /*!< GPIOB OEN: OEN8 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN9_Pos                    (9UL)                     /*!< GPIOB OEN: OEN9 (Bit 9)                                     */
#define GPIOB_OEN_OEN9_Msk                    (0x200UL)                 /*!< GPIOB OEN: OEN9 (Bitfield-Mask: 0x01)                       */
#define GPIOB_OEN_OEN10_Pos                   (10UL)                    /*!< GPIOB OEN: OEN10 (Bit 10)                                   */
#define GPIOB_OEN_OEN10_Msk                   (0x400UL)                 /*!< GPIOB OEN: OEN10 (Bitfield-Mask: 0x01)                      */
#define GPIOB_OEN_OEN11_Pos                   (11UL)                    /*!< GPIOB OEN: OEN11 (Bit 11)                                   */
#define GPIOB_OEN_OEN11_Msk                   (0x800UL)                 /*!< GPIOB OEN: OEN11 (Bitfield-Mask: 0x01)                      */
#define GPIOB_OEN_OEN12_Pos                   (12UL)                    /*!< GPIOB OEN: OEN12 (Bit 12)                                   */
#define GPIOB_OEN_OEN12_Msk                   (0x1000UL)                /*!< GPIOB OEN: OEN12 (Bitfield-Mask: 0x01)                      */
#define GPIOB_OEN_OEN13_Pos                   (13UL)                    /*!< GPIOB OEN: OEN13 (Bit 13)                                   */
#define GPIOB_OEN_OEN13_Msk                   (0x2000UL)                /*!< GPIOB OEN: OEN13 (Bitfield-Mask: 0x01)                      */
#define GPIOB_OEN_OEN14_Pos                   (14UL)                    /*!< GPIOB OEN: OEN14 (Bit 14)                                   */
#define GPIOB_OEN_OEN14_Msk                   (0x4000UL)                /*!< GPIOB OEN: OEN14 (Bitfield-Mask: 0x01)                      */
#define GPIOB_OEN_OEN15_Pos                   (15UL)                    /*!< GPIOB OEN: OEN15 (Bit 15)                                   */
#define GPIOB_OEN_OEN15_Msk                   (0x8000UL)                /*!< GPIOB OEN: OEN15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOB_IE  ---------------------------------- */
#define GPIOB_IE_IE0_Pos                      (0UL)                     /*!< GPIOB IE: IE0 (Bit 0)                                       */
#define GPIOB_IE_IE0_Msk                      (0x1UL)                   /*!< GPIOB IE: IE0 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE1_Pos                      (1UL)                     /*!< GPIOB IE: IE1 (Bit 1)                                       */
#define GPIOB_IE_IE1_Msk                      (0x2UL)                   /*!< GPIOB IE: IE1 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE2_Pos                      (2UL)                     /*!< GPIOB IE: IE2 (Bit 2)                                       */
#define GPIOB_IE_IE2_Msk                      (0x4UL)                   /*!< GPIOB IE: IE2 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE3_Pos                      (3UL)                     /*!< GPIOB IE: IE3 (Bit 3)                                       */
#define GPIOB_IE_IE3_Msk                      (0x8UL)                   /*!< GPIOB IE: IE3 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE4_Pos                      (4UL)                     /*!< GPIOB IE: IE4 (Bit 4)                                       */
#define GPIOB_IE_IE4_Msk                      (0x10UL)                  /*!< GPIOB IE: IE4 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE5_Pos                      (5UL)                     /*!< GPIOB IE: IE5 (Bit 5)                                       */
#define GPIOB_IE_IE5_Msk                      (0x20UL)                  /*!< GPIOB IE: IE5 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE6_Pos                      (6UL)                     /*!< GPIOB IE: IE6 (Bit 6)                                       */
#define GPIOB_IE_IE6_Msk                      (0x40UL)                  /*!< GPIOB IE: IE6 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE7_Pos                      (7UL)                     /*!< GPIOB IE: IE7 (Bit 7)                                       */
#define GPIOB_IE_IE7_Msk                      (0x80UL)                  /*!< GPIOB IE: IE7 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE8_Pos                      (8UL)                     /*!< GPIOB IE: IE8 (Bit 8)                                       */
#define GPIOB_IE_IE8_Msk                      (0x100UL)                 /*!< GPIOB IE: IE8 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE9_Pos                      (9UL)                     /*!< GPIOB IE: IE9 (Bit 9)                                       */
#define GPIOB_IE_IE9_Msk                      (0x200UL)                 /*!< GPIOB IE: IE9 (Bitfield-Mask: 0x01)                         */
#define GPIOB_IE_IE10_Pos                     (10UL)                    /*!< GPIOB IE: IE10 (Bit 10)                                     */
#define GPIOB_IE_IE10_Msk                     (0x400UL)                 /*!< GPIOB IE: IE10 (Bitfield-Mask: 0x01)                        */
#define GPIOB_IE_IE11_Pos                     (11UL)                    /*!< GPIOB IE: IE11 (Bit 11)                                     */
#define GPIOB_IE_IE11_Msk                     (0x800UL)                 /*!< GPIOB IE: IE11 (Bitfield-Mask: 0x01)                        */
#define GPIOB_IE_IE12_Pos                     (12UL)                    /*!< GPIOB IE: IE12 (Bit 12)                                     */
#define GPIOB_IE_IE12_Msk                     (0x1000UL)                /*!< GPIOB IE: IE12 (Bitfield-Mask: 0x01)                        */
#define GPIOB_IE_IE13_Pos                     (13UL)                    /*!< GPIOB IE: IE13 (Bit 13)                                     */
#define GPIOB_IE_IE13_Msk                     (0x2000UL)                /*!< GPIOB IE: IE13 (Bitfield-Mask: 0x01)                        */
#define GPIOB_IE_IE14_Pos                     (14UL)                    /*!< GPIOB IE: IE14 (Bit 14)                                     */
#define GPIOB_IE_IE14_Msk                     (0x4000UL)                /*!< GPIOB IE: IE14 (Bitfield-Mask: 0x01)                        */
#define GPIOB_IE_IE15_Pos                     (15UL)                    /*!< GPIOB IE: IE15 (Bit 15)                                     */
#define GPIOB_IE_IE15_Msk                     (0x8000UL)                /*!< GPIOB IE: IE15 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  GPIOB_DAT  --------------------------------- */
#define GPIOB_DAT_DAT0_Pos                    (0UL)                     /*!< GPIOB DAT: DAT0 (Bit 0)                                     */
#define GPIOB_DAT_DAT0_Msk                    (0x1UL)                   /*!< GPIOB DAT: DAT0 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT1_Pos                    (1UL)                     /*!< GPIOB DAT: DAT1 (Bit 1)                                     */
#define GPIOB_DAT_DAT1_Msk                    (0x2UL)                   /*!< GPIOB DAT: DAT1 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT2_Pos                    (2UL)                     /*!< GPIOB DAT: DAT2 (Bit 2)                                     */
#define GPIOB_DAT_DAT2_Msk                    (0x4UL)                   /*!< GPIOB DAT: DAT2 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT3_Pos                    (3UL)                     /*!< GPIOB DAT: DAT3 (Bit 3)                                     */
#define GPIOB_DAT_DAT3_Msk                    (0x8UL)                   /*!< GPIOB DAT: DAT3 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT4_Pos                    (4UL)                     /*!< GPIOB DAT: DAT4 (Bit 4)                                     */
#define GPIOB_DAT_DAT4_Msk                    (0x10UL)                  /*!< GPIOB DAT: DAT4 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT5_Pos                    (5UL)                     /*!< GPIOB DAT: DAT5 (Bit 5)                                     */
#define GPIOB_DAT_DAT5_Msk                    (0x20UL)                  /*!< GPIOB DAT: DAT5 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT6_Pos                    (6UL)                     /*!< GPIOB DAT: DAT6 (Bit 6)                                     */
#define GPIOB_DAT_DAT6_Msk                    (0x40UL)                  /*!< GPIOB DAT: DAT6 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT7_Pos                    (7UL)                     /*!< GPIOB DAT: DAT7 (Bit 7)                                     */
#define GPIOB_DAT_DAT7_Msk                    (0x80UL)                  /*!< GPIOB DAT: DAT7 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT8_Pos                    (8UL)                     /*!< GPIOB DAT: DAT8 (Bit 8)                                     */
#define GPIOB_DAT_DAT8_Msk                    (0x100UL)                 /*!< GPIOB DAT: DAT8 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT9_Pos                    (9UL)                     /*!< GPIOB DAT: DAT9 (Bit 9)                                     */
#define GPIOB_DAT_DAT9_Msk                    (0x200UL)                 /*!< GPIOB DAT: DAT9 (Bitfield-Mask: 0x01)                       */
#define GPIOB_DAT_DAT10_Pos                   (10UL)                    /*!< GPIOB DAT: DAT10 (Bit 10)                                   */
#define GPIOB_DAT_DAT10_Msk                   (0x400UL)                 /*!< GPIOB DAT: DAT10 (Bitfield-Mask: 0x01)                      */
#define GPIOB_DAT_DAT11_Pos                   (11UL)                    /*!< GPIOB DAT: DAT11 (Bit 11)                                   */
#define GPIOB_DAT_DAT11_Msk                   (0x800UL)                 /*!< GPIOB DAT: DAT11 (Bitfield-Mask: 0x01)                      */
#define GPIOB_DAT_DAT12_Pos                   (12UL)                    /*!< GPIOB DAT: DAT12 (Bit 12)                                   */
#define GPIOB_DAT_DAT12_Msk                   (0x1000UL)                /*!< GPIOB DAT: DAT12 (Bitfield-Mask: 0x01)                      */
#define GPIOB_DAT_DAT13_Pos                   (13UL)                    /*!< GPIOB DAT: DAT13 (Bit 13)                                   */
#define GPIOB_DAT_DAT13_Msk                   (0x2000UL)                /*!< GPIOB DAT: DAT13 (Bitfield-Mask: 0x01)                      */
#define GPIOB_DAT_DAT14_Pos                   (14UL)                    /*!< GPIOB DAT: DAT14 (Bit 14)                                   */
#define GPIOB_DAT_DAT14_Msk                   (0x4000UL)                /*!< GPIOB DAT: DAT14 (Bitfield-Mask: 0x01)                      */
#define GPIOB_DAT_DAT15_Pos                   (15UL)                    /*!< GPIOB DAT: DAT15 (Bit 15)                                   */
#define GPIOB_DAT_DAT15_Msk                   (0x8000UL)                /*!< GPIOB DAT: DAT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOB_ATT  --------------------------------- */
#define GPIOB_ATT_ATT0_Pos                    (0UL)                     /*!< GPIOB ATT: ATT0 (Bit 0)                                     */
#define GPIOB_ATT_ATT0_Msk                    (0x1UL)                   /*!< GPIOB ATT: ATT0 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT1_Pos                    (1UL)                     /*!< GPIOB ATT: ATT1 (Bit 1)                                     */
#define GPIOB_ATT_ATT1_Msk                    (0x2UL)                   /*!< GPIOB ATT: ATT1 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT2_Pos                    (2UL)                     /*!< GPIOB ATT: ATT2 (Bit 2)                                     */
#define GPIOB_ATT_ATT2_Msk                    (0x4UL)                   /*!< GPIOB ATT: ATT2 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT3_Pos                    (3UL)                     /*!< GPIOB ATT: ATT3 (Bit 3)                                     */
#define GPIOB_ATT_ATT3_Msk                    (0x8UL)                   /*!< GPIOB ATT: ATT3 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT4_Pos                    (4UL)                     /*!< GPIOB ATT: ATT4 (Bit 4)                                     */
#define GPIOB_ATT_ATT4_Msk                    (0x10UL)                  /*!< GPIOB ATT: ATT4 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT5_Pos                    (5UL)                     /*!< GPIOB ATT: ATT5 (Bit 5)                                     */
#define GPIOB_ATT_ATT5_Msk                    (0x20UL)                  /*!< GPIOB ATT: ATT5 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT6_Pos                    (6UL)                     /*!< GPIOB ATT: ATT6 (Bit 6)                                     */
#define GPIOB_ATT_ATT6_Msk                    (0x40UL)                  /*!< GPIOB ATT: ATT6 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT7_Pos                    (7UL)                     /*!< GPIOB ATT: ATT7 (Bit 7)                                     */
#define GPIOB_ATT_ATT7_Msk                    (0x80UL)                  /*!< GPIOB ATT: ATT7 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT8_Pos                    (8UL)                     /*!< GPIOB ATT: ATT8 (Bit 8)                                     */
#define GPIOB_ATT_ATT8_Msk                    (0x100UL)                 /*!< GPIOB ATT: ATT8 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT9_Pos                    (9UL)                     /*!< GPIOB ATT: ATT9 (Bit 9)                                     */
#define GPIOB_ATT_ATT9_Msk                    (0x200UL)                 /*!< GPIOB ATT: ATT9 (Bitfield-Mask: 0x01)                       */
#define GPIOB_ATT_ATT10_Pos                   (10UL)                    /*!< GPIOB ATT: ATT10 (Bit 10)                                   */
#define GPIOB_ATT_ATT10_Msk                   (0x400UL)                 /*!< GPIOB ATT: ATT10 (Bitfield-Mask: 0x01)                      */
#define GPIOB_ATT_ATT11_Pos                   (11UL)                    /*!< GPIOB ATT: ATT11 (Bit 11)                                   */
#define GPIOB_ATT_ATT11_Msk                   (0x800UL)                 /*!< GPIOB ATT: ATT11 (Bitfield-Mask: 0x01)                      */
#define GPIOB_ATT_ATT12_Pos                   (12UL)                    /*!< GPIOB ATT: ATT12 (Bit 12)                                   */
#define GPIOB_ATT_ATT12_Msk                   (0x1000UL)                /*!< GPIOB ATT: ATT12 (Bitfield-Mask: 0x01)                      */
#define GPIOB_ATT_ATT13_Pos                   (13UL)                    /*!< GPIOB ATT: ATT13 (Bit 13)                                   */
#define GPIOB_ATT_ATT13_Msk                   (0x2000UL)                /*!< GPIOB ATT: ATT13 (Bitfield-Mask: 0x01)                      */
#define GPIOB_ATT_ATT14_Pos                   (14UL)                    /*!< GPIOB ATT: ATT14 (Bit 14)                                   */
#define GPIOB_ATT_ATT14_Msk                   (0x4000UL)                /*!< GPIOB ATT: ATT14 (Bitfield-Mask: 0x01)                      */
#define GPIOB_ATT_ATT15_Pos                   (15UL)                    /*!< GPIOB ATT: ATT15 (Bit 15)                                   */
#define GPIOB_ATT_ATT15_Msk                   (0x8000UL)                /*!< GPIOB ATT: ATT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOB_STS  --------------------------------- */
#define GPIOB_STS_STS0_Pos                    (0UL)                     /*!< GPIOB STS: STS0 (Bit 0)                                     */
#define GPIOB_STS_STS0_Msk                    (0x1UL)                   /*!< GPIOB STS: STS0 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS1_Pos                    (1UL)                     /*!< GPIOB STS: STS1 (Bit 1)                                     */
#define GPIOB_STS_STS1_Msk                    (0x2UL)                   /*!< GPIOB STS: STS1 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS2_Pos                    (2UL)                     /*!< GPIOB STS: STS2 (Bit 2)                                     */
#define GPIOB_STS_STS2_Msk                    (0x4UL)                   /*!< GPIOB STS: STS2 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS3_Pos                    (3UL)                     /*!< GPIOB STS: STS3 (Bit 3)                                     */
#define GPIOB_STS_STS3_Msk                    (0x8UL)                   /*!< GPIOB STS: STS3 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS4_Pos                    (4UL)                     /*!< GPIOB STS: STS4 (Bit 4)                                     */
#define GPIOB_STS_STS4_Msk                    (0x10UL)                  /*!< GPIOB STS: STS4 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS5_Pos                    (5UL)                     /*!< GPIOB STS: STS5 (Bit 5)                                     */
#define GPIOB_STS_STS5_Msk                    (0x20UL)                  /*!< GPIOB STS: STS5 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS6_Pos                    (6UL)                     /*!< GPIOB STS: STS6 (Bit 6)                                     */
#define GPIOB_STS_STS6_Msk                    (0x40UL)                  /*!< GPIOB STS: STS6 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS7_Pos                    (7UL)                     /*!< GPIOB STS: STS7 (Bit 7)                                     */
#define GPIOB_STS_STS7_Msk                    (0x80UL)                  /*!< GPIOB STS: STS7 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS8_Pos                    (8UL)                     /*!< GPIOB STS: STS8 (Bit 8)                                     */
#define GPIOB_STS_STS8_Msk                    (0x100UL)                 /*!< GPIOB STS: STS8 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS9_Pos                    (9UL)                     /*!< GPIOB STS: STS9 (Bit 9)                                     */
#define GPIOB_STS_STS9_Msk                    (0x200UL)                 /*!< GPIOB STS: STS9 (Bitfield-Mask: 0x01)                       */
#define GPIOB_STS_STS10_Pos                   (10UL)                    /*!< GPIOB STS: STS10 (Bit 10)                                   */
#define GPIOB_STS_STS10_Msk                   (0x400UL)                 /*!< GPIOB STS: STS10 (Bitfield-Mask: 0x01)                      */
#define GPIOB_STS_STS11_Pos                   (11UL)                    /*!< GPIOB STS: STS11 (Bit 11)                                   */
#define GPIOB_STS_STS11_Msk                   (0x800UL)                 /*!< GPIOB STS: STS11 (Bitfield-Mask: 0x01)                      */
#define GPIOB_STS_STS12_Pos                   (12UL)                    /*!< GPIOB STS: STS12 (Bit 12)                                   */
#define GPIOB_STS_STS12_Msk                   (0x1000UL)                /*!< GPIOB STS: STS12 (Bitfield-Mask: 0x01)                      */
#define GPIOB_STS_STS13_Pos                   (13UL)                    /*!< GPIOB STS: STS13 (Bit 13)                                   */
#define GPIOB_STS_STS13_Msk                   (0x2000UL)                /*!< GPIOB STS: STS13 (Bitfield-Mask: 0x01)                      */
#define GPIOB_STS_STS14_Pos                   (14UL)                    /*!< GPIOB STS: STS14 (Bit 14)                                   */
#define GPIOB_STS_STS14_Msk                   (0x4000UL)                /*!< GPIOB STS: STS14 (Bitfield-Mask: 0x01)                      */
#define GPIOB_STS_STS15_Pos                   (15UL)                    /*!< GPIOB STS: STS15 (Bit 15)                                   */
#define GPIOB_STS_STS15_Msk                   (0x8000UL)                /*!< GPIOB STS: STS15 (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================         struct 'GPIOC' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  GPIOC_OEN  --------------------------------- */
#define GPIOC_OEN_OEN0_Pos                    (0UL)                     /*!< GPIOC OEN: OEN0 (Bit 0)                                     */
#define GPIOC_OEN_OEN0_Msk                    (0x1UL)                   /*!< GPIOC OEN: OEN0 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN1_Pos                    (1UL)                     /*!< GPIOC OEN: OEN1 (Bit 1)                                     */
#define GPIOC_OEN_OEN1_Msk                    (0x2UL)                   /*!< GPIOC OEN: OEN1 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN2_Pos                    (2UL)                     /*!< GPIOC OEN: OEN2 (Bit 2)                                     */
#define GPIOC_OEN_OEN2_Msk                    (0x4UL)                   /*!< GPIOC OEN: OEN2 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN3_Pos                    (3UL)                     /*!< GPIOC OEN: OEN3 (Bit 3)                                     */
#define GPIOC_OEN_OEN3_Msk                    (0x8UL)                   /*!< GPIOC OEN: OEN3 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN4_Pos                    (4UL)                     /*!< GPIOC OEN: OEN4 (Bit 4)                                     */
#define GPIOC_OEN_OEN4_Msk                    (0x10UL)                  /*!< GPIOC OEN: OEN4 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN5_Pos                    (5UL)                     /*!< GPIOC OEN: OEN5 (Bit 5)                                     */
#define GPIOC_OEN_OEN5_Msk                    (0x20UL)                  /*!< GPIOC OEN: OEN5 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN6_Pos                    (6UL)                     /*!< GPIOC OEN: OEN6 (Bit 6)                                     */
#define GPIOC_OEN_OEN6_Msk                    (0x40UL)                  /*!< GPIOC OEN: OEN6 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN7_Pos                    (7UL)                     /*!< GPIOC OEN: OEN7 (Bit 7)                                     */
#define GPIOC_OEN_OEN7_Msk                    (0x80UL)                  /*!< GPIOC OEN: OEN7 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN8_Pos                    (8UL)                     /*!< GPIOC OEN: OEN8 (Bit 8)                                     */
#define GPIOC_OEN_OEN8_Msk                    (0x100UL)                 /*!< GPIOC OEN: OEN8 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN9_Pos                    (9UL)                     /*!< GPIOC OEN: OEN9 (Bit 9)                                     */
#define GPIOC_OEN_OEN9_Msk                    (0x200UL)                 /*!< GPIOC OEN: OEN9 (Bitfield-Mask: 0x01)                       */
#define GPIOC_OEN_OEN10_Pos                   (10UL)                    /*!< GPIOC OEN: OEN10 (Bit 10)                                   */
#define GPIOC_OEN_OEN10_Msk                   (0x400UL)                 /*!< GPIOC OEN: OEN10 (Bitfield-Mask: 0x01)                      */
#define GPIOC_OEN_OEN11_Pos                   (11UL)                    /*!< GPIOC OEN: OEN11 (Bit 11)                                   */
#define GPIOC_OEN_OEN11_Msk                   (0x800UL)                 /*!< GPIOC OEN: OEN11 (Bitfield-Mask: 0x01)                      */
#define GPIOC_OEN_OEN12_Pos                   (12UL)                    /*!< GPIOC OEN: OEN12 (Bit 12)                                   */
#define GPIOC_OEN_OEN12_Msk                   (0x1000UL)                /*!< GPIOC OEN: OEN12 (Bitfield-Mask: 0x01)                      */
#define GPIOC_OEN_OEN13_Pos                   (13UL)                    /*!< GPIOC OEN: OEN13 (Bit 13)                                   */
#define GPIOC_OEN_OEN13_Msk                   (0x2000UL)                /*!< GPIOC OEN: OEN13 (Bitfield-Mask: 0x01)                      */
#define GPIOC_OEN_OEN14_Pos                   (14UL)                    /*!< GPIOC OEN: OEN14 (Bit 14)                                   */
#define GPIOC_OEN_OEN14_Msk                   (0x4000UL)                /*!< GPIOC OEN: OEN14 (Bitfield-Mask: 0x01)                      */
#define GPIOC_OEN_OEN15_Pos                   (15UL)                    /*!< GPIOC OEN: OEN15 (Bit 15)                                   */
#define GPIOC_OEN_OEN15_Msk                   (0x8000UL)                /*!< GPIOC OEN: OEN15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOC_IE  ---------------------------------- */
#define GPIOC_IE_IE0_Pos                      (0UL)                     /*!< GPIOC IE: IE0 (Bit 0)                                       */
#define GPIOC_IE_IE0_Msk                      (0x1UL)                   /*!< GPIOC IE: IE0 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE1_Pos                      (1UL)                     /*!< GPIOC IE: IE1 (Bit 1)                                       */
#define GPIOC_IE_IE1_Msk                      (0x2UL)                   /*!< GPIOC IE: IE1 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE2_Pos                      (2UL)                     /*!< GPIOC IE: IE2 (Bit 2)                                       */
#define GPIOC_IE_IE2_Msk                      (0x4UL)                   /*!< GPIOC IE: IE2 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE3_Pos                      (3UL)                     /*!< GPIOC IE: IE3 (Bit 3)                                       */
#define GPIOC_IE_IE3_Msk                      (0x8UL)                   /*!< GPIOC IE: IE3 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE4_Pos                      (4UL)                     /*!< GPIOC IE: IE4 (Bit 4)                                       */
#define GPIOC_IE_IE4_Msk                      (0x10UL)                  /*!< GPIOC IE: IE4 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE5_Pos                      (5UL)                     /*!< GPIOC IE: IE5 (Bit 5)                                       */
#define GPIOC_IE_IE5_Msk                      (0x20UL)                  /*!< GPIOC IE: IE5 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE6_Pos                      (6UL)                     /*!< GPIOC IE: IE6 (Bit 6)                                       */
#define GPIOC_IE_IE6_Msk                      (0x40UL)                  /*!< GPIOC IE: IE6 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE7_Pos                      (7UL)                     /*!< GPIOC IE: IE7 (Bit 7)                                       */
#define GPIOC_IE_IE7_Msk                      (0x80UL)                  /*!< GPIOC IE: IE7 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE8_Pos                      (8UL)                     /*!< GPIOC IE: IE8 (Bit 8)                                       */
#define GPIOC_IE_IE8_Msk                      (0x100UL)                 /*!< GPIOC IE: IE8 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE9_Pos                      (9UL)                     /*!< GPIOC IE: IE9 (Bit 9)                                       */
#define GPIOC_IE_IE9_Msk                      (0x200UL)                 /*!< GPIOC IE: IE9 (Bitfield-Mask: 0x01)                         */
#define GPIOC_IE_IE10_Pos                     (10UL)                    /*!< GPIOC IE: IE10 (Bit 10)                                     */
#define GPIOC_IE_IE10_Msk                     (0x400UL)                 /*!< GPIOC IE: IE10 (Bitfield-Mask: 0x01)                        */
#define GPIOC_IE_IE11_Pos                     (11UL)                    /*!< GPIOC IE: IE11 (Bit 11)                                     */
#define GPIOC_IE_IE11_Msk                     (0x800UL)                 /*!< GPIOC IE: IE11 (Bitfield-Mask: 0x01)                        */
#define GPIOC_IE_IE12_Pos                     (12UL)                    /*!< GPIOC IE: IE12 (Bit 12)                                     */
#define GPIOC_IE_IE12_Msk                     (0x1000UL)                /*!< GPIOC IE: IE12 (Bitfield-Mask: 0x01)                        */
#define GPIOC_IE_IE13_Pos                     (13UL)                    /*!< GPIOC IE: IE13 (Bit 13)                                     */
#define GPIOC_IE_IE13_Msk                     (0x2000UL)                /*!< GPIOC IE: IE13 (Bitfield-Mask: 0x01)                        */
#define GPIOC_IE_IE14_Pos                     (14UL)                    /*!< GPIOC IE: IE14 (Bit 14)                                     */
#define GPIOC_IE_IE14_Msk                     (0x4000UL)                /*!< GPIOC IE: IE14 (Bitfield-Mask: 0x01)                        */
#define GPIOC_IE_IE15_Pos                     (15UL)                    /*!< GPIOC IE: IE15 (Bit 15)                                     */
#define GPIOC_IE_IE15_Msk                     (0x8000UL)                /*!< GPIOC IE: IE15 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  GPIOC_DAT  --------------------------------- */
#define GPIOC_DAT_DAT0_Pos                    (0UL)                     /*!< GPIOC DAT: DAT0 (Bit 0)                                     */
#define GPIOC_DAT_DAT0_Msk                    (0x1UL)                   /*!< GPIOC DAT: DAT0 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT1_Pos                    (1UL)                     /*!< GPIOC DAT: DAT1 (Bit 1)                                     */
#define GPIOC_DAT_DAT1_Msk                    (0x2UL)                   /*!< GPIOC DAT: DAT1 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT2_Pos                    (2UL)                     /*!< GPIOC DAT: DAT2 (Bit 2)                                     */
#define GPIOC_DAT_DAT2_Msk                    (0x4UL)                   /*!< GPIOC DAT: DAT2 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT3_Pos                    (3UL)                     /*!< GPIOC DAT: DAT3 (Bit 3)                                     */
#define GPIOC_DAT_DAT3_Msk                    (0x8UL)                   /*!< GPIOC DAT: DAT3 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT4_Pos                    (4UL)                     /*!< GPIOC DAT: DAT4 (Bit 4)                                     */
#define GPIOC_DAT_DAT4_Msk                    (0x10UL)                  /*!< GPIOC DAT: DAT4 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT5_Pos                    (5UL)                     /*!< GPIOC DAT: DAT5 (Bit 5)                                     */
#define GPIOC_DAT_DAT5_Msk                    (0x20UL)                  /*!< GPIOC DAT: DAT5 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT6_Pos                    (6UL)                     /*!< GPIOC DAT: DAT6 (Bit 6)                                     */
#define GPIOC_DAT_DAT6_Msk                    (0x40UL)                  /*!< GPIOC DAT: DAT6 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT7_Pos                    (7UL)                     /*!< GPIOC DAT: DAT7 (Bit 7)                                     */
#define GPIOC_DAT_DAT7_Msk                    (0x80UL)                  /*!< GPIOC DAT: DAT7 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT8_Pos                    (8UL)                     /*!< GPIOC DAT: DAT8 (Bit 8)                                     */
#define GPIOC_DAT_DAT8_Msk                    (0x100UL)                 /*!< GPIOC DAT: DAT8 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT9_Pos                    (9UL)                     /*!< GPIOC DAT: DAT9 (Bit 9)                                     */
#define GPIOC_DAT_DAT9_Msk                    (0x200UL)                 /*!< GPIOC DAT: DAT9 (Bitfield-Mask: 0x01)                       */
#define GPIOC_DAT_DAT10_Pos                   (10UL)                    /*!< GPIOC DAT: DAT10 (Bit 10)                                   */
#define GPIOC_DAT_DAT10_Msk                   (0x400UL)                 /*!< GPIOC DAT: DAT10 (Bitfield-Mask: 0x01)                      */
#define GPIOC_DAT_DAT11_Pos                   (11UL)                    /*!< GPIOC DAT: DAT11 (Bit 11)                                   */
#define GPIOC_DAT_DAT11_Msk                   (0x800UL)                 /*!< GPIOC DAT: DAT11 (Bitfield-Mask: 0x01)                      */
#define GPIOC_DAT_DAT12_Pos                   (12UL)                    /*!< GPIOC DAT: DAT12 (Bit 12)                                   */
#define GPIOC_DAT_DAT12_Msk                   (0x1000UL)                /*!< GPIOC DAT: DAT12 (Bitfield-Mask: 0x01)                      */
#define GPIOC_DAT_DAT13_Pos                   (13UL)                    /*!< GPIOC DAT: DAT13 (Bit 13)                                   */
#define GPIOC_DAT_DAT13_Msk                   (0x2000UL)                /*!< GPIOC DAT: DAT13 (Bitfield-Mask: 0x01)                      */
#define GPIOC_DAT_DAT14_Pos                   (14UL)                    /*!< GPIOC DAT: DAT14 (Bit 14)                                   */
#define GPIOC_DAT_DAT14_Msk                   (0x4000UL)                /*!< GPIOC DAT: DAT14 (Bitfield-Mask: 0x01)                      */
#define GPIOC_DAT_DAT15_Pos                   (15UL)                    /*!< GPIOC DAT: DAT15 (Bit 15)                                   */
#define GPIOC_DAT_DAT15_Msk                   (0x8000UL)                /*!< GPIOC DAT: DAT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOC_ATT  --------------------------------- */
#define GPIOC_ATT_ATT0_Pos                    (0UL)                     /*!< GPIOC ATT: ATT0 (Bit 0)                                     */
#define GPIOC_ATT_ATT0_Msk                    (0x1UL)                   /*!< GPIOC ATT: ATT0 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT1_Pos                    (1UL)                     /*!< GPIOC ATT: ATT1 (Bit 1)                                     */
#define GPIOC_ATT_ATT1_Msk                    (0x2UL)                   /*!< GPIOC ATT: ATT1 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT2_Pos                    (2UL)                     /*!< GPIOC ATT: ATT2 (Bit 2)                                     */
#define GPIOC_ATT_ATT2_Msk                    (0x4UL)                   /*!< GPIOC ATT: ATT2 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT3_Pos                    (3UL)                     /*!< GPIOC ATT: ATT3 (Bit 3)                                     */
#define GPIOC_ATT_ATT3_Msk                    (0x8UL)                   /*!< GPIOC ATT: ATT3 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT4_Pos                    (4UL)                     /*!< GPIOC ATT: ATT4 (Bit 4)                                     */
#define GPIOC_ATT_ATT4_Msk                    (0x10UL)                  /*!< GPIOC ATT: ATT4 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT5_Pos                    (5UL)                     /*!< GPIOC ATT: ATT5 (Bit 5)                                     */
#define GPIOC_ATT_ATT5_Msk                    (0x20UL)                  /*!< GPIOC ATT: ATT5 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT6_Pos                    (6UL)                     /*!< GPIOC ATT: ATT6 (Bit 6)                                     */
#define GPIOC_ATT_ATT6_Msk                    (0x40UL)                  /*!< GPIOC ATT: ATT6 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT7_Pos                    (7UL)                     /*!< GPIOC ATT: ATT7 (Bit 7)                                     */
#define GPIOC_ATT_ATT7_Msk                    (0x80UL)                  /*!< GPIOC ATT: ATT7 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT8_Pos                    (8UL)                     /*!< GPIOC ATT: ATT8 (Bit 8)                                     */
#define GPIOC_ATT_ATT8_Msk                    (0x100UL)                 /*!< GPIOC ATT: ATT8 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT9_Pos                    (9UL)                     /*!< GPIOC ATT: ATT9 (Bit 9)                                     */
#define GPIOC_ATT_ATT9_Msk                    (0x200UL)                 /*!< GPIOC ATT: ATT9 (Bitfield-Mask: 0x01)                       */
#define GPIOC_ATT_ATT10_Pos                   (10UL)                    /*!< GPIOC ATT: ATT10 (Bit 10)                                   */
#define GPIOC_ATT_ATT10_Msk                   (0x400UL)                 /*!< GPIOC ATT: ATT10 (Bitfield-Mask: 0x01)                      */
#define GPIOC_ATT_ATT11_Pos                   (11UL)                    /*!< GPIOC ATT: ATT11 (Bit 11)                                   */
#define GPIOC_ATT_ATT11_Msk                   (0x800UL)                 /*!< GPIOC ATT: ATT11 (Bitfield-Mask: 0x01)                      */
#define GPIOC_ATT_ATT12_Pos                   (12UL)                    /*!< GPIOC ATT: ATT12 (Bit 12)                                   */
#define GPIOC_ATT_ATT12_Msk                   (0x1000UL)                /*!< GPIOC ATT: ATT12 (Bitfield-Mask: 0x01)                      */
#define GPIOC_ATT_ATT13_Pos                   (13UL)                    /*!< GPIOC ATT: ATT13 (Bit 13)                                   */
#define GPIOC_ATT_ATT13_Msk                   (0x2000UL)                /*!< GPIOC ATT: ATT13 (Bitfield-Mask: 0x01)                      */
#define GPIOC_ATT_ATT14_Pos                   (14UL)                    /*!< GPIOC ATT: ATT14 (Bit 14)                                   */
#define GPIOC_ATT_ATT14_Msk                   (0x4000UL)                /*!< GPIOC ATT: ATT14 (Bitfield-Mask: 0x01)                      */
#define GPIOC_ATT_ATT15_Pos                   (15UL)                    /*!< GPIOC ATT: ATT15 (Bit 15)                                   */
#define GPIOC_ATT_ATT15_Msk                   (0x8000UL)                /*!< GPIOC ATT: ATT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOC_STS  --------------------------------- */
#define GPIOC_STS_STS0_Pos                    (0UL)                     /*!< GPIOC STS: STS0 (Bit 0)                                     */
#define GPIOC_STS_STS0_Msk                    (0x1UL)                   /*!< GPIOC STS: STS0 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS1_Pos                    (1UL)                     /*!< GPIOC STS: STS1 (Bit 1)                                     */
#define GPIOC_STS_STS1_Msk                    (0x2UL)                   /*!< GPIOC STS: STS1 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS2_Pos                    (2UL)                     /*!< GPIOC STS: STS2 (Bit 2)                                     */
#define GPIOC_STS_STS2_Msk                    (0x4UL)                   /*!< GPIOC STS: STS2 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS3_Pos                    (3UL)                     /*!< GPIOC STS: STS3 (Bit 3)                                     */
#define GPIOC_STS_STS3_Msk                    (0x8UL)                   /*!< GPIOC STS: STS3 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS4_Pos                    (4UL)                     /*!< GPIOC STS: STS4 (Bit 4)                                     */
#define GPIOC_STS_STS4_Msk                    (0x10UL)                  /*!< GPIOC STS: STS4 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS5_Pos                    (5UL)                     /*!< GPIOC STS: STS5 (Bit 5)                                     */
#define GPIOC_STS_STS5_Msk                    (0x20UL)                  /*!< GPIOC STS: STS5 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS6_Pos                    (6UL)                     /*!< GPIOC STS: STS6 (Bit 6)                                     */
#define GPIOC_STS_STS6_Msk                    (0x40UL)                  /*!< GPIOC STS: STS6 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS7_Pos                    (7UL)                     /*!< GPIOC STS: STS7 (Bit 7)                                     */
#define GPIOC_STS_STS7_Msk                    (0x80UL)                  /*!< GPIOC STS: STS7 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS8_Pos                    (8UL)                     /*!< GPIOC STS: STS8 (Bit 8)                                     */
#define GPIOC_STS_STS8_Msk                    (0x100UL)                 /*!< GPIOC STS: STS8 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS9_Pos                    (9UL)                     /*!< GPIOC STS: STS9 (Bit 9)                                     */
#define GPIOC_STS_STS9_Msk                    (0x200UL)                 /*!< GPIOC STS: STS9 (Bitfield-Mask: 0x01)                       */
#define GPIOC_STS_STS10_Pos                   (10UL)                    /*!< GPIOC STS: STS10 (Bit 10)                                   */
#define GPIOC_STS_STS10_Msk                   (0x400UL)                 /*!< GPIOC STS: STS10 (Bitfield-Mask: 0x01)                      */
#define GPIOC_STS_STS11_Pos                   (11UL)                    /*!< GPIOC STS: STS11 (Bit 11)                                   */
#define GPIOC_STS_STS11_Msk                   (0x800UL)                 /*!< GPIOC STS: STS11 (Bitfield-Mask: 0x01)                      */
#define GPIOC_STS_STS12_Pos                   (12UL)                    /*!< GPIOC STS: STS12 (Bit 12)                                   */
#define GPIOC_STS_STS12_Msk                   (0x1000UL)                /*!< GPIOC STS: STS12 (Bitfield-Mask: 0x01)                      */
#define GPIOC_STS_STS13_Pos                   (13UL)                    /*!< GPIOC STS: STS13 (Bit 13)                                   */
#define GPIOC_STS_STS13_Msk                   (0x2000UL)                /*!< GPIOC STS: STS13 (Bitfield-Mask: 0x01)                      */
#define GPIOC_STS_STS14_Pos                   (14UL)                    /*!< GPIOC STS: STS14 (Bit 14)                                   */
#define GPIOC_STS_STS14_Msk                   (0x4000UL)                /*!< GPIOC STS: STS14 (Bitfield-Mask: 0x01)                      */
#define GPIOC_STS_STS15_Pos                   (15UL)                    /*!< GPIOC STS: STS15 (Bit 15)                                   */
#define GPIOC_STS_STS15_Msk                   (0x8000UL)                /*!< GPIOC STS: STS15 (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================         struct 'GPIOD' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  GPIOD_OEN  --------------------------------- */
#define GPIOD_OEN_OEN0_Pos                    (0UL)                     /*!< GPIOD OEN: OEN0 (Bit 0)                                     */
#define GPIOD_OEN_OEN0_Msk                    (0x1UL)                   /*!< GPIOD OEN: OEN0 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN1_Pos                    (1UL)                     /*!< GPIOD OEN: OEN1 (Bit 1)                                     */
#define GPIOD_OEN_OEN1_Msk                    (0x2UL)                   /*!< GPIOD OEN: OEN1 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN2_Pos                    (2UL)                     /*!< GPIOD OEN: OEN2 (Bit 2)                                     */
#define GPIOD_OEN_OEN2_Msk                    (0x4UL)                   /*!< GPIOD OEN: OEN2 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN3_Pos                    (3UL)                     /*!< GPIOD OEN: OEN3 (Bit 3)                                     */
#define GPIOD_OEN_OEN3_Msk                    (0x8UL)                   /*!< GPIOD OEN: OEN3 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN4_Pos                    (4UL)                     /*!< GPIOD OEN: OEN4 (Bit 4)                                     */
#define GPIOD_OEN_OEN4_Msk                    (0x10UL)                  /*!< GPIOD OEN: OEN4 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN5_Pos                    (5UL)                     /*!< GPIOD OEN: OEN5 (Bit 5)                                     */
#define GPIOD_OEN_OEN5_Msk                    (0x20UL)                  /*!< GPIOD OEN: OEN5 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN6_Pos                    (6UL)                     /*!< GPIOD OEN: OEN6 (Bit 6)                                     */
#define GPIOD_OEN_OEN6_Msk                    (0x40UL)                  /*!< GPIOD OEN: OEN6 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN7_Pos                    (7UL)                     /*!< GPIOD OEN: OEN7 (Bit 7)                                     */
#define GPIOD_OEN_OEN7_Msk                    (0x80UL)                  /*!< GPIOD OEN: OEN7 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN8_Pos                    (8UL)                     /*!< GPIOD OEN: OEN8 (Bit 8)                                     */
#define GPIOD_OEN_OEN8_Msk                    (0x100UL)                 /*!< GPIOD OEN: OEN8 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN9_Pos                    (9UL)                     /*!< GPIOD OEN: OEN9 (Bit 9)                                     */
#define GPIOD_OEN_OEN9_Msk                    (0x200UL)                 /*!< GPIOD OEN: OEN9 (Bitfield-Mask: 0x01)                       */
#define GPIOD_OEN_OEN10_Pos                   (10UL)                    /*!< GPIOD OEN: OEN10 (Bit 10)                                   */
#define GPIOD_OEN_OEN10_Msk                   (0x400UL)                 /*!< GPIOD OEN: OEN10 (Bitfield-Mask: 0x01)                      */
#define GPIOD_OEN_OEN11_Pos                   (11UL)                    /*!< GPIOD OEN: OEN11 (Bit 11)                                   */
#define GPIOD_OEN_OEN11_Msk                   (0x800UL)                 /*!< GPIOD OEN: OEN11 (Bitfield-Mask: 0x01)                      */
#define GPIOD_OEN_OEN12_Pos                   (12UL)                    /*!< GPIOD OEN: OEN12 (Bit 12)                                   */
#define GPIOD_OEN_OEN12_Msk                   (0x1000UL)                /*!< GPIOD OEN: OEN12 (Bitfield-Mask: 0x01)                      */
#define GPIOD_OEN_OEN13_Pos                   (13UL)                    /*!< GPIOD OEN: OEN13 (Bit 13)                                   */
#define GPIOD_OEN_OEN13_Msk                   (0x2000UL)                /*!< GPIOD OEN: OEN13 (Bitfield-Mask: 0x01)                      */
#define GPIOD_OEN_OEN14_Pos                   (14UL)                    /*!< GPIOD OEN: OEN14 (Bit 14)                                   */
#define GPIOD_OEN_OEN14_Msk                   (0x4000UL)                /*!< GPIOD OEN: OEN14 (Bitfield-Mask: 0x01)                      */
#define GPIOD_OEN_OEN15_Pos                   (15UL)                    /*!< GPIOD OEN: OEN15 (Bit 15)                                   */
#define GPIOD_OEN_OEN15_Msk                   (0x8000UL)                /*!< GPIOD OEN: OEN15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOD_IE  ---------------------------------- */
#define GPIOD_IE_IE0_Pos                      (0UL)                     /*!< GPIOD IE: IE0 (Bit 0)                                       */
#define GPIOD_IE_IE0_Msk                      (0x1UL)                   /*!< GPIOD IE: IE0 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE1_Pos                      (1UL)                     /*!< GPIOD IE: IE1 (Bit 1)                                       */
#define GPIOD_IE_IE1_Msk                      (0x2UL)                   /*!< GPIOD IE: IE1 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE2_Pos                      (2UL)                     /*!< GPIOD IE: IE2 (Bit 2)                                       */
#define GPIOD_IE_IE2_Msk                      (0x4UL)                   /*!< GPIOD IE: IE2 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE3_Pos                      (3UL)                     /*!< GPIOD IE: IE3 (Bit 3)                                       */
#define GPIOD_IE_IE3_Msk                      (0x8UL)                   /*!< GPIOD IE: IE3 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE4_Pos                      (4UL)                     /*!< GPIOD IE: IE4 (Bit 4)                                       */
#define GPIOD_IE_IE4_Msk                      (0x10UL)                  /*!< GPIOD IE: IE4 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE5_Pos                      (5UL)                     /*!< GPIOD IE: IE5 (Bit 5)                                       */
#define GPIOD_IE_IE5_Msk                      (0x20UL)                  /*!< GPIOD IE: IE5 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE6_Pos                      (6UL)                     /*!< GPIOD IE: IE6 (Bit 6)                                       */
#define GPIOD_IE_IE6_Msk                      (0x40UL)                  /*!< GPIOD IE: IE6 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE7_Pos                      (7UL)                     /*!< GPIOD IE: IE7 (Bit 7)                                       */
#define GPIOD_IE_IE7_Msk                      (0x80UL)                  /*!< GPIOD IE: IE7 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE8_Pos                      (8UL)                     /*!< GPIOD IE: IE8 (Bit 8)                                       */
#define GPIOD_IE_IE8_Msk                      (0x100UL)                 /*!< GPIOD IE: IE8 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE9_Pos                      (9UL)                     /*!< GPIOD IE: IE9 (Bit 9)                                       */
#define GPIOD_IE_IE9_Msk                      (0x200UL)                 /*!< GPIOD IE: IE9 (Bitfield-Mask: 0x01)                         */
#define GPIOD_IE_IE10_Pos                     (10UL)                    /*!< GPIOD IE: IE10 (Bit 10)                                     */
#define GPIOD_IE_IE10_Msk                     (0x400UL)                 /*!< GPIOD IE: IE10 (Bitfield-Mask: 0x01)                        */
#define GPIOD_IE_IE11_Pos                     (11UL)                    /*!< GPIOD IE: IE11 (Bit 11)                                     */
#define GPIOD_IE_IE11_Msk                     (0x800UL)                 /*!< GPIOD IE: IE11 (Bitfield-Mask: 0x01)                        */
#define GPIOD_IE_IE12_Pos                     (12UL)                    /*!< GPIOD IE: IE12 (Bit 12)                                     */
#define GPIOD_IE_IE12_Msk                     (0x1000UL)                /*!< GPIOD IE: IE12 (Bitfield-Mask: 0x01)                        */
#define GPIOD_IE_IE13_Pos                     (13UL)                    /*!< GPIOD IE: IE13 (Bit 13)                                     */
#define GPIOD_IE_IE13_Msk                     (0x2000UL)                /*!< GPIOD IE: IE13 (Bitfield-Mask: 0x01)                        */
#define GPIOD_IE_IE14_Pos                     (14UL)                    /*!< GPIOD IE: IE14 (Bit 14)                                     */
#define GPIOD_IE_IE14_Msk                     (0x4000UL)                /*!< GPIOD IE: IE14 (Bitfield-Mask: 0x01)                        */
#define GPIOD_IE_IE15_Pos                     (15UL)                    /*!< GPIOD IE: IE15 (Bit 15)                                     */
#define GPIOD_IE_IE15_Msk                     (0x8000UL)                /*!< GPIOD IE: IE15 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  GPIOD_DAT  --------------------------------- */
#define GPIOD_DAT_DAT0_Pos                    (0UL)                     /*!< GPIOD DAT: DAT0 (Bit 0)                                     */
#define GPIOD_DAT_DAT0_Msk                    (0x1UL)                   /*!< GPIOD DAT: DAT0 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT1_Pos                    (1UL)                     /*!< GPIOD DAT: DAT1 (Bit 1)                                     */
#define GPIOD_DAT_DAT1_Msk                    (0x2UL)                   /*!< GPIOD DAT: DAT1 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT2_Pos                    (2UL)                     /*!< GPIOD DAT: DAT2 (Bit 2)                                     */
#define GPIOD_DAT_DAT2_Msk                    (0x4UL)                   /*!< GPIOD DAT: DAT2 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT3_Pos                    (3UL)                     /*!< GPIOD DAT: DAT3 (Bit 3)                                     */
#define GPIOD_DAT_DAT3_Msk                    (0x8UL)                   /*!< GPIOD DAT: DAT3 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT4_Pos                    (4UL)                     /*!< GPIOD DAT: DAT4 (Bit 4)                                     */
#define GPIOD_DAT_DAT4_Msk                    (0x10UL)                  /*!< GPIOD DAT: DAT4 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT5_Pos                    (5UL)                     /*!< GPIOD DAT: DAT5 (Bit 5)                                     */
#define GPIOD_DAT_DAT5_Msk                    (0x20UL)                  /*!< GPIOD DAT: DAT5 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT6_Pos                    (6UL)                     /*!< GPIOD DAT: DAT6 (Bit 6)                                     */
#define GPIOD_DAT_DAT6_Msk                    (0x40UL)                  /*!< GPIOD DAT: DAT6 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT7_Pos                    (7UL)                     /*!< GPIOD DAT: DAT7 (Bit 7)                                     */
#define GPIOD_DAT_DAT7_Msk                    (0x80UL)                  /*!< GPIOD DAT: DAT7 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT8_Pos                    (8UL)                     /*!< GPIOD DAT: DAT8 (Bit 8)                                     */
#define GPIOD_DAT_DAT8_Msk                    (0x100UL)                 /*!< GPIOD DAT: DAT8 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT9_Pos                    (9UL)                     /*!< GPIOD DAT: DAT9 (Bit 9)                                     */
#define GPIOD_DAT_DAT9_Msk                    (0x200UL)                 /*!< GPIOD DAT: DAT9 (Bitfield-Mask: 0x01)                       */
#define GPIOD_DAT_DAT10_Pos                   (10UL)                    /*!< GPIOD DAT: DAT10 (Bit 10)                                   */
#define GPIOD_DAT_DAT10_Msk                   (0x400UL)                 /*!< GPIOD DAT: DAT10 (Bitfield-Mask: 0x01)                      */
#define GPIOD_DAT_DAT11_Pos                   (11UL)                    /*!< GPIOD DAT: DAT11 (Bit 11)                                   */
#define GPIOD_DAT_DAT11_Msk                   (0x800UL)                 /*!< GPIOD DAT: DAT11 (Bitfield-Mask: 0x01)                      */
#define GPIOD_DAT_DAT12_Pos                   (12UL)                    /*!< GPIOD DAT: DAT12 (Bit 12)                                   */
#define GPIOD_DAT_DAT12_Msk                   (0x1000UL)                /*!< GPIOD DAT: DAT12 (Bitfield-Mask: 0x01)                      */
#define GPIOD_DAT_DAT13_Pos                   (13UL)                    /*!< GPIOD DAT: DAT13 (Bit 13)                                   */
#define GPIOD_DAT_DAT13_Msk                   (0x2000UL)                /*!< GPIOD DAT: DAT13 (Bitfield-Mask: 0x01)                      */
#define GPIOD_DAT_DAT14_Pos                   (14UL)                    /*!< GPIOD DAT: DAT14 (Bit 14)                                   */
#define GPIOD_DAT_DAT14_Msk                   (0x4000UL)                /*!< GPIOD DAT: DAT14 (Bitfield-Mask: 0x01)                      */
#define GPIOD_DAT_DAT15_Pos                   (15UL)                    /*!< GPIOD DAT: DAT15 (Bit 15)                                   */
#define GPIOD_DAT_DAT15_Msk                   (0x8000UL)                /*!< GPIOD DAT: DAT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOD_ATT  --------------------------------- */
#define GPIOD_ATT_ATT0_Pos                    (0UL)                     /*!< GPIOD ATT: ATT0 (Bit 0)                                     */
#define GPIOD_ATT_ATT0_Msk                    (0x1UL)                   /*!< GPIOD ATT: ATT0 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT1_Pos                    (1UL)                     /*!< GPIOD ATT: ATT1 (Bit 1)                                     */
#define GPIOD_ATT_ATT1_Msk                    (0x2UL)                   /*!< GPIOD ATT: ATT1 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT2_Pos                    (2UL)                     /*!< GPIOD ATT: ATT2 (Bit 2)                                     */
#define GPIOD_ATT_ATT2_Msk                    (0x4UL)                   /*!< GPIOD ATT: ATT2 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT3_Pos                    (3UL)                     /*!< GPIOD ATT: ATT3 (Bit 3)                                     */
#define GPIOD_ATT_ATT3_Msk                    (0x8UL)                   /*!< GPIOD ATT: ATT3 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT4_Pos                    (4UL)                     /*!< GPIOD ATT: ATT4 (Bit 4)                                     */
#define GPIOD_ATT_ATT4_Msk                    (0x10UL)                  /*!< GPIOD ATT: ATT4 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT5_Pos                    (5UL)                     /*!< GPIOD ATT: ATT5 (Bit 5)                                     */
#define GPIOD_ATT_ATT5_Msk                    (0x20UL)                  /*!< GPIOD ATT: ATT5 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT6_Pos                    (6UL)                     /*!< GPIOD ATT: ATT6 (Bit 6)                                     */
#define GPIOD_ATT_ATT6_Msk                    (0x40UL)                  /*!< GPIOD ATT: ATT6 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT7_Pos                    (7UL)                     /*!< GPIOD ATT: ATT7 (Bit 7)                                     */
#define GPIOD_ATT_ATT7_Msk                    (0x80UL)                  /*!< GPIOD ATT: ATT7 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT8_Pos                    (8UL)                     /*!< GPIOD ATT: ATT8 (Bit 8)                                     */
#define GPIOD_ATT_ATT8_Msk                    (0x100UL)                 /*!< GPIOD ATT: ATT8 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT9_Pos                    (9UL)                     /*!< GPIOD ATT: ATT9 (Bit 9)                                     */
#define GPIOD_ATT_ATT9_Msk                    (0x200UL)                 /*!< GPIOD ATT: ATT9 (Bitfield-Mask: 0x01)                       */
#define GPIOD_ATT_ATT10_Pos                   (10UL)                    /*!< GPIOD ATT: ATT10 (Bit 10)                                   */
#define GPIOD_ATT_ATT10_Msk                   (0x400UL)                 /*!< GPIOD ATT: ATT10 (Bitfield-Mask: 0x01)                      */
#define GPIOD_ATT_ATT11_Pos                   (11UL)                    /*!< GPIOD ATT: ATT11 (Bit 11)                                   */
#define GPIOD_ATT_ATT11_Msk                   (0x800UL)                 /*!< GPIOD ATT: ATT11 (Bitfield-Mask: 0x01)                      */
#define GPIOD_ATT_ATT12_Pos                   (12UL)                    /*!< GPIOD ATT: ATT12 (Bit 12)                                   */
#define GPIOD_ATT_ATT12_Msk                   (0x1000UL)                /*!< GPIOD ATT: ATT12 (Bitfield-Mask: 0x01)                      */
#define GPIOD_ATT_ATT13_Pos                   (13UL)                    /*!< GPIOD ATT: ATT13 (Bit 13)                                   */
#define GPIOD_ATT_ATT13_Msk                   (0x2000UL)                /*!< GPIOD ATT: ATT13 (Bitfield-Mask: 0x01)                      */
#define GPIOD_ATT_ATT14_Pos                   (14UL)                    /*!< GPIOD ATT: ATT14 (Bit 14)                                   */
#define GPIOD_ATT_ATT14_Msk                   (0x4000UL)                /*!< GPIOD ATT: ATT14 (Bitfield-Mask: 0x01)                      */
#define GPIOD_ATT_ATT15_Pos                   (15UL)                    /*!< GPIOD ATT: ATT15 (Bit 15)                                   */
#define GPIOD_ATT_ATT15_Msk                   (0x8000UL)                /*!< GPIOD ATT: ATT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOD_STS  --------------------------------- */
#define GPIOD_STS_STS0_Pos                    (0UL)                     /*!< GPIOD STS: STS0 (Bit 0)                                     */
#define GPIOD_STS_STS0_Msk                    (0x1UL)                   /*!< GPIOD STS: STS0 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS1_Pos                    (1UL)                     /*!< GPIOD STS: STS1 (Bit 1)                                     */
#define GPIOD_STS_STS1_Msk                    (0x2UL)                   /*!< GPIOD STS: STS1 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS2_Pos                    (2UL)                     /*!< GPIOD STS: STS2 (Bit 2)                                     */
#define GPIOD_STS_STS2_Msk                    (0x4UL)                   /*!< GPIOD STS: STS2 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS3_Pos                    (3UL)                     /*!< GPIOD STS: STS3 (Bit 3)                                     */
#define GPIOD_STS_STS3_Msk                    (0x8UL)                   /*!< GPIOD STS: STS3 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS4_Pos                    (4UL)                     /*!< GPIOD STS: STS4 (Bit 4)                                     */
#define GPIOD_STS_STS4_Msk                    (0x10UL)                  /*!< GPIOD STS: STS4 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS5_Pos                    (5UL)                     /*!< GPIOD STS: STS5 (Bit 5)                                     */
#define GPIOD_STS_STS5_Msk                    (0x20UL)                  /*!< GPIOD STS: STS5 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS6_Pos                    (6UL)                     /*!< GPIOD STS: STS6 (Bit 6)                                     */
#define GPIOD_STS_STS6_Msk                    (0x40UL)                  /*!< GPIOD STS: STS6 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS7_Pos                    (7UL)                     /*!< GPIOD STS: STS7 (Bit 7)                                     */
#define GPIOD_STS_STS7_Msk                    (0x80UL)                  /*!< GPIOD STS: STS7 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS8_Pos                    (8UL)                     /*!< GPIOD STS: STS8 (Bit 8)                                     */
#define GPIOD_STS_STS8_Msk                    (0x100UL)                 /*!< GPIOD STS: STS8 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS9_Pos                    (9UL)                     /*!< GPIOD STS: STS9 (Bit 9)                                     */
#define GPIOD_STS_STS9_Msk                    (0x200UL)                 /*!< GPIOD STS: STS9 (Bitfield-Mask: 0x01)                       */
#define GPIOD_STS_STS10_Pos                   (10UL)                    /*!< GPIOD STS: STS10 (Bit 10)                                   */
#define GPIOD_STS_STS10_Msk                   (0x400UL)                 /*!< GPIOD STS: STS10 (Bitfield-Mask: 0x01)                      */
#define GPIOD_STS_STS11_Pos                   (11UL)                    /*!< GPIOD STS: STS11 (Bit 11)                                   */
#define GPIOD_STS_STS11_Msk                   (0x800UL)                 /*!< GPIOD STS: STS11 (Bitfield-Mask: 0x01)                      */
#define GPIOD_STS_STS12_Pos                   (12UL)                    /*!< GPIOD STS: STS12 (Bit 12)                                   */
#define GPIOD_STS_STS12_Msk                   (0x1000UL)                /*!< GPIOD STS: STS12 (Bitfield-Mask: 0x01)                      */
#define GPIOD_STS_STS13_Pos                   (13UL)                    /*!< GPIOD STS: STS13 (Bit 13)                                   */
#define GPIOD_STS_STS13_Msk                   (0x2000UL)                /*!< GPIOD STS: STS13 (Bitfield-Mask: 0x01)                      */
#define GPIOD_STS_STS14_Pos                   (14UL)                    /*!< GPIOD STS: STS14 (Bit 14)                                   */
#define GPIOD_STS_STS14_Msk                   (0x4000UL)                /*!< GPIOD STS: STS14 (Bitfield-Mask: 0x01)                      */
#define GPIOD_STS_STS15_Pos                   (15UL)                    /*!< GPIOD STS: STS15 (Bit 15)                                   */
#define GPIOD_STS_STS15_Msk                   (0x8000UL)                /*!< GPIOD STS: STS15 (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================         struct 'GPIOE' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  GPIOE_OEN  --------------------------------- */
#define GPIOE_OEN_OEN0_Pos                    (0UL)                     /*!< GPIOE OEN: OEN0 (Bit 0)                                     */
#define GPIOE_OEN_OEN0_Msk                    (0x1UL)                   /*!< GPIOE OEN: OEN0 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN1_Pos                    (1UL)                     /*!< GPIOE OEN: OEN1 (Bit 1)                                     */
#define GPIOE_OEN_OEN1_Msk                    (0x2UL)                   /*!< GPIOE OEN: OEN1 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN2_Pos                    (2UL)                     /*!< GPIOE OEN: OEN2 (Bit 2)                                     */
#define GPIOE_OEN_OEN2_Msk                    (0x4UL)                   /*!< GPIOE OEN: OEN2 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN3_Pos                    (3UL)                     /*!< GPIOE OEN: OEN3 (Bit 3)                                     */
#define GPIOE_OEN_OEN3_Msk                    (0x8UL)                   /*!< GPIOE OEN: OEN3 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN4_Pos                    (4UL)                     /*!< GPIOE OEN: OEN4 (Bit 4)                                     */
#define GPIOE_OEN_OEN4_Msk                    (0x10UL)                  /*!< GPIOE OEN: OEN4 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN5_Pos                    (5UL)                     /*!< GPIOE OEN: OEN5 (Bit 5)                                     */
#define GPIOE_OEN_OEN5_Msk                    (0x20UL)                  /*!< GPIOE OEN: OEN5 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN6_Pos                    (6UL)                     /*!< GPIOE OEN: OEN6 (Bit 6)                                     */
#define GPIOE_OEN_OEN6_Msk                    (0x40UL)                  /*!< GPIOE OEN: OEN6 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN7_Pos                    (7UL)                     /*!< GPIOE OEN: OEN7 (Bit 7)                                     */
#define GPIOE_OEN_OEN7_Msk                    (0x80UL)                  /*!< GPIOE OEN: OEN7 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN8_Pos                    (8UL)                     /*!< GPIOE OEN: OEN8 (Bit 8)                                     */
#define GPIOE_OEN_OEN8_Msk                    (0x100UL)                 /*!< GPIOE OEN: OEN8 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN9_Pos                    (9UL)                     /*!< GPIOE OEN: OEN9 (Bit 9)                                     */
#define GPIOE_OEN_OEN9_Msk                    (0x200UL)                 /*!< GPIOE OEN: OEN9 (Bitfield-Mask: 0x01)                       */
#define GPIOE_OEN_OEN10_Pos                   (10UL)                    /*!< GPIOE OEN: OEN10 (Bit 10)                                   */
#define GPIOE_OEN_OEN10_Msk                   (0x400UL)                 /*!< GPIOE OEN: OEN10 (Bitfield-Mask: 0x01)                      */
#define GPIOE_OEN_OEN11_Pos                   (11UL)                    /*!< GPIOE OEN: OEN11 (Bit 11)                                   */
#define GPIOE_OEN_OEN11_Msk                   (0x800UL)                 /*!< GPIOE OEN: OEN11 (Bitfield-Mask: 0x01)                      */
#define GPIOE_OEN_OEN12_Pos                   (12UL)                    /*!< GPIOE OEN: OEN12 (Bit 12)                                   */
#define GPIOE_OEN_OEN12_Msk                   (0x1000UL)                /*!< GPIOE OEN: OEN12 (Bitfield-Mask: 0x01)                      */
#define GPIOE_OEN_OEN13_Pos                   (13UL)                    /*!< GPIOE OEN: OEN13 (Bit 13)                                   */
#define GPIOE_OEN_OEN13_Msk                   (0x2000UL)                /*!< GPIOE OEN: OEN13 (Bitfield-Mask: 0x01)                      */
#define GPIOE_OEN_OEN14_Pos                   (14UL)                    /*!< GPIOE OEN: OEN14 (Bit 14)                                   */
#define GPIOE_OEN_OEN14_Msk                   (0x4000UL)                /*!< GPIOE OEN: OEN14 (Bitfield-Mask: 0x01)                      */
#define GPIOE_OEN_OEN15_Pos                   (15UL)                    /*!< GPIOE OEN: OEN15 (Bit 15)                                   */
#define GPIOE_OEN_OEN15_Msk                   (0x8000UL)                /*!< GPIOE OEN: OEN15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOE_IE  ---------------------------------- */
#define GPIOE_IE_IE0_Pos                      (0UL)                     /*!< GPIOE IE: IE0 (Bit 0)                                       */
#define GPIOE_IE_IE0_Msk                      (0x1UL)                   /*!< GPIOE IE: IE0 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE1_Pos                      (1UL)                     /*!< GPIOE IE: IE1 (Bit 1)                                       */
#define GPIOE_IE_IE1_Msk                      (0x2UL)                   /*!< GPIOE IE: IE1 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE2_Pos                      (2UL)                     /*!< GPIOE IE: IE2 (Bit 2)                                       */
#define GPIOE_IE_IE2_Msk                      (0x4UL)                   /*!< GPIOE IE: IE2 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE3_Pos                      (3UL)                     /*!< GPIOE IE: IE3 (Bit 3)                                       */
#define GPIOE_IE_IE3_Msk                      (0x8UL)                   /*!< GPIOE IE: IE3 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE4_Pos                      (4UL)                     /*!< GPIOE IE: IE4 (Bit 4)                                       */
#define GPIOE_IE_IE4_Msk                      (0x10UL)                  /*!< GPIOE IE: IE4 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE5_Pos                      (5UL)                     /*!< GPIOE IE: IE5 (Bit 5)                                       */
#define GPIOE_IE_IE5_Msk                      (0x20UL)                  /*!< GPIOE IE: IE5 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE6_Pos                      (6UL)                     /*!< GPIOE IE: IE6 (Bit 6)                                       */
#define GPIOE_IE_IE6_Msk                      (0x40UL)                  /*!< GPIOE IE: IE6 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE7_Pos                      (7UL)                     /*!< GPIOE IE: IE7 (Bit 7)                                       */
#define GPIOE_IE_IE7_Msk                      (0x80UL)                  /*!< GPIOE IE: IE7 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE8_Pos                      (8UL)                     /*!< GPIOE IE: IE8 (Bit 8)                                       */
#define GPIOE_IE_IE8_Msk                      (0x100UL)                 /*!< GPIOE IE: IE8 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE9_Pos                      (9UL)                     /*!< GPIOE IE: IE9 (Bit 9)                                       */
#define GPIOE_IE_IE9_Msk                      (0x200UL)                 /*!< GPIOE IE: IE9 (Bitfield-Mask: 0x01)                         */
#define GPIOE_IE_IE10_Pos                     (10UL)                    /*!< GPIOE IE: IE10 (Bit 10)                                     */
#define GPIOE_IE_IE10_Msk                     (0x400UL)                 /*!< GPIOE IE: IE10 (Bitfield-Mask: 0x01)                        */
#define GPIOE_IE_IE11_Pos                     (11UL)                    /*!< GPIOE IE: IE11 (Bit 11)                                     */
#define GPIOE_IE_IE11_Msk                     (0x800UL)                 /*!< GPIOE IE: IE11 (Bitfield-Mask: 0x01)                        */
#define GPIOE_IE_IE12_Pos                     (12UL)                    /*!< GPIOE IE: IE12 (Bit 12)                                     */
#define GPIOE_IE_IE12_Msk                     (0x1000UL)                /*!< GPIOE IE: IE12 (Bitfield-Mask: 0x01)                        */
#define GPIOE_IE_IE13_Pos                     (13UL)                    /*!< GPIOE IE: IE13 (Bit 13)                                     */
#define GPIOE_IE_IE13_Msk                     (0x2000UL)                /*!< GPIOE IE: IE13 (Bitfield-Mask: 0x01)                        */
#define GPIOE_IE_IE14_Pos                     (14UL)                    /*!< GPIOE IE: IE14 (Bit 14)                                     */
#define GPIOE_IE_IE14_Msk                     (0x4000UL)                /*!< GPIOE IE: IE14 (Bitfield-Mask: 0x01)                        */
#define GPIOE_IE_IE15_Pos                     (15UL)                    /*!< GPIOE IE: IE15 (Bit 15)                                     */
#define GPIOE_IE_IE15_Msk                     (0x8000UL)                /*!< GPIOE IE: IE15 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  GPIOE_DAT  --------------------------------- */
#define GPIOE_DAT_DAT0_Pos                    (0UL)                     /*!< GPIOE DAT: DAT0 (Bit 0)                                     */
#define GPIOE_DAT_DAT0_Msk                    (0x1UL)                   /*!< GPIOE DAT: DAT0 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT1_Pos                    (1UL)                     /*!< GPIOE DAT: DAT1 (Bit 1)                                     */
#define GPIOE_DAT_DAT1_Msk                    (0x2UL)                   /*!< GPIOE DAT: DAT1 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT2_Pos                    (2UL)                     /*!< GPIOE DAT: DAT2 (Bit 2)                                     */
#define GPIOE_DAT_DAT2_Msk                    (0x4UL)                   /*!< GPIOE DAT: DAT2 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT3_Pos                    (3UL)                     /*!< GPIOE DAT: DAT3 (Bit 3)                                     */
#define GPIOE_DAT_DAT3_Msk                    (0x8UL)                   /*!< GPIOE DAT: DAT3 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT4_Pos                    (4UL)                     /*!< GPIOE DAT: DAT4 (Bit 4)                                     */
#define GPIOE_DAT_DAT4_Msk                    (0x10UL)                  /*!< GPIOE DAT: DAT4 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT5_Pos                    (5UL)                     /*!< GPIOE DAT: DAT5 (Bit 5)                                     */
#define GPIOE_DAT_DAT5_Msk                    (0x20UL)                  /*!< GPIOE DAT: DAT5 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT6_Pos                    (6UL)                     /*!< GPIOE DAT: DAT6 (Bit 6)                                     */
#define GPIOE_DAT_DAT6_Msk                    (0x40UL)                  /*!< GPIOE DAT: DAT6 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT7_Pos                    (7UL)                     /*!< GPIOE DAT: DAT7 (Bit 7)                                     */
#define GPIOE_DAT_DAT7_Msk                    (0x80UL)                  /*!< GPIOE DAT: DAT7 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT8_Pos                    (8UL)                     /*!< GPIOE DAT: DAT8 (Bit 8)                                     */
#define GPIOE_DAT_DAT8_Msk                    (0x100UL)                 /*!< GPIOE DAT: DAT8 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT9_Pos                    (9UL)                     /*!< GPIOE DAT: DAT9 (Bit 9)                                     */
#define GPIOE_DAT_DAT9_Msk                    (0x200UL)                 /*!< GPIOE DAT: DAT9 (Bitfield-Mask: 0x01)                       */
#define GPIOE_DAT_DAT10_Pos                   (10UL)                    /*!< GPIOE DAT: DAT10 (Bit 10)                                   */
#define GPIOE_DAT_DAT10_Msk                   (0x400UL)                 /*!< GPIOE DAT: DAT10 (Bitfield-Mask: 0x01)                      */
#define GPIOE_DAT_DAT11_Pos                   (11UL)                    /*!< GPIOE DAT: DAT11 (Bit 11)                                   */
#define GPIOE_DAT_DAT11_Msk                   (0x800UL)                 /*!< GPIOE DAT: DAT11 (Bitfield-Mask: 0x01)                      */
#define GPIOE_DAT_DAT12_Pos                   (12UL)                    /*!< GPIOE DAT: DAT12 (Bit 12)                                   */
#define GPIOE_DAT_DAT12_Msk                   (0x1000UL)                /*!< GPIOE DAT: DAT12 (Bitfield-Mask: 0x01)                      */
#define GPIOE_DAT_DAT13_Pos                   (13UL)                    /*!< GPIOE DAT: DAT13 (Bit 13)                                   */
#define GPIOE_DAT_DAT13_Msk                   (0x2000UL)                /*!< GPIOE DAT: DAT13 (Bitfield-Mask: 0x01)                      */
#define GPIOE_DAT_DAT14_Pos                   (14UL)                    /*!< GPIOE DAT: DAT14 (Bit 14)                                   */
#define GPIOE_DAT_DAT14_Msk                   (0x4000UL)                /*!< GPIOE DAT: DAT14 (Bitfield-Mask: 0x01)                      */
#define GPIOE_DAT_DAT15_Pos                   (15UL)                    /*!< GPIOE DAT: DAT15 (Bit 15)                                   */
#define GPIOE_DAT_DAT15_Msk                   (0x8000UL)                /*!< GPIOE DAT: DAT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOE_ATT  --------------------------------- */
#define GPIOE_ATT_ATT0_Pos                    (0UL)                     /*!< GPIOE ATT: ATT0 (Bit 0)                                     */
#define GPIOE_ATT_ATT0_Msk                    (0x1UL)                   /*!< GPIOE ATT: ATT0 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT1_Pos                    (1UL)                     /*!< GPIOE ATT: ATT1 (Bit 1)                                     */
#define GPIOE_ATT_ATT1_Msk                    (0x2UL)                   /*!< GPIOE ATT: ATT1 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT2_Pos                    (2UL)                     /*!< GPIOE ATT: ATT2 (Bit 2)                                     */
#define GPIOE_ATT_ATT2_Msk                    (0x4UL)                   /*!< GPIOE ATT: ATT2 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT3_Pos                    (3UL)                     /*!< GPIOE ATT: ATT3 (Bit 3)                                     */
#define GPIOE_ATT_ATT3_Msk                    (0x8UL)                   /*!< GPIOE ATT: ATT3 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT4_Pos                    (4UL)                     /*!< GPIOE ATT: ATT4 (Bit 4)                                     */
#define GPIOE_ATT_ATT4_Msk                    (0x10UL)                  /*!< GPIOE ATT: ATT4 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT5_Pos                    (5UL)                     /*!< GPIOE ATT: ATT5 (Bit 5)                                     */
#define GPIOE_ATT_ATT5_Msk                    (0x20UL)                  /*!< GPIOE ATT: ATT5 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT6_Pos                    (6UL)                     /*!< GPIOE ATT: ATT6 (Bit 6)                                     */
#define GPIOE_ATT_ATT6_Msk                    (0x40UL)                  /*!< GPIOE ATT: ATT6 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT7_Pos                    (7UL)                     /*!< GPIOE ATT: ATT7 (Bit 7)                                     */
#define GPIOE_ATT_ATT7_Msk                    (0x80UL)                  /*!< GPIOE ATT: ATT7 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT8_Pos                    (8UL)                     /*!< GPIOE ATT: ATT8 (Bit 8)                                     */
#define GPIOE_ATT_ATT8_Msk                    (0x100UL)                 /*!< GPIOE ATT: ATT8 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT9_Pos                    (9UL)                     /*!< GPIOE ATT: ATT9 (Bit 9)                                     */
#define GPIOE_ATT_ATT9_Msk                    (0x200UL)                 /*!< GPIOE ATT: ATT9 (Bitfield-Mask: 0x01)                       */
#define GPIOE_ATT_ATT10_Pos                   (10UL)                    /*!< GPIOE ATT: ATT10 (Bit 10)                                   */
#define GPIOE_ATT_ATT10_Msk                   (0x400UL)                 /*!< GPIOE ATT: ATT10 (Bitfield-Mask: 0x01)                      */
#define GPIOE_ATT_ATT11_Pos                   (11UL)                    /*!< GPIOE ATT: ATT11 (Bit 11)                                   */
#define GPIOE_ATT_ATT11_Msk                   (0x800UL)                 /*!< GPIOE ATT: ATT11 (Bitfield-Mask: 0x01)                      */
#define GPIOE_ATT_ATT12_Pos                   (12UL)                    /*!< GPIOE ATT: ATT12 (Bit 12)                                   */
#define GPIOE_ATT_ATT12_Msk                   (0x1000UL)                /*!< GPIOE ATT: ATT12 (Bitfield-Mask: 0x01)                      */
#define GPIOE_ATT_ATT13_Pos                   (13UL)                    /*!< GPIOE ATT: ATT13 (Bit 13)                                   */
#define GPIOE_ATT_ATT13_Msk                   (0x2000UL)                /*!< GPIOE ATT: ATT13 (Bitfield-Mask: 0x01)                      */
#define GPIOE_ATT_ATT14_Pos                   (14UL)                    /*!< GPIOE ATT: ATT14 (Bit 14)                                   */
#define GPIOE_ATT_ATT14_Msk                   (0x4000UL)                /*!< GPIOE ATT: ATT14 (Bitfield-Mask: 0x01)                      */
#define GPIOE_ATT_ATT15_Pos                   (15UL)                    /*!< GPIOE ATT: ATT15 (Bit 15)                                   */
#define GPIOE_ATT_ATT15_Msk                   (0x8000UL)                /*!< GPIOE ATT: ATT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOE_STS  --------------------------------- */
#define GPIOE_STS_STS0_Pos                    (0UL)                     /*!< GPIOE STS: STS0 (Bit 0)                                     */
#define GPIOE_STS_STS0_Msk                    (0x1UL)                   /*!< GPIOE STS: STS0 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS1_Pos                    (1UL)                     /*!< GPIOE STS: STS1 (Bit 1)                                     */
#define GPIOE_STS_STS1_Msk                    (0x2UL)                   /*!< GPIOE STS: STS1 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS2_Pos                    (2UL)                     /*!< GPIOE STS: STS2 (Bit 2)                                     */
#define GPIOE_STS_STS2_Msk                    (0x4UL)                   /*!< GPIOE STS: STS2 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS3_Pos                    (3UL)                     /*!< GPIOE STS: STS3 (Bit 3)                                     */
#define GPIOE_STS_STS3_Msk                    (0x8UL)                   /*!< GPIOE STS: STS3 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS4_Pos                    (4UL)                     /*!< GPIOE STS: STS4 (Bit 4)                                     */
#define GPIOE_STS_STS4_Msk                    (0x10UL)                  /*!< GPIOE STS: STS4 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS5_Pos                    (5UL)                     /*!< GPIOE STS: STS5 (Bit 5)                                     */
#define GPIOE_STS_STS5_Msk                    (0x20UL)                  /*!< GPIOE STS: STS5 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS6_Pos                    (6UL)                     /*!< GPIOE STS: STS6 (Bit 6)                                     */
#define GPIOE_STS_STS6_Msk                    (0x40UL)                  /*!< GPIOE STS: STS6 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS7_Pos                    (7UL)                     /*!< GPIOE STS: STS7 (Bit 7)                                     */
#define GPIOE_STS_STS7_Msk                    (0x80UL)                  /*!< GPIOE STS: STS7 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS8_Pos                    (8UL)                     /*!< GPIOE STS: STS8 (Bit 8)                                     */
#define GPIOE_STS_STS8_Msk                    (0x100UL)                 /*!< GPIOE STS: STS8 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS9_Pos                    (9UL)                     /*!< GPIOE STS: STS9 (Bit 9)                                     */
#define GPIOE_STS_STS9_Msk                    (0x200UL)                 /*!< GPIOE STS: STS9 (Bitfield-Mask: 0x01)                       */
#define GPIOE_STS_STS10_Pos                   (10UL)                    /*!< GPIOE STS: STS10 (Bit 10)                                   */
#define GPIOE_STS_STS10_Msk                   (0x400UL)                 /*!< GPIOE STS: STS10 (Bitfield-Mask: 0x01)                      */
#define GPIOE_STS_STS11_Pos                   (11UL)                    /*!< GPIOE STS: STS11 (Bit 11)                                   */
#define GPIOE_STS_STS11_Msk                   (0x800UL)                 /*!< GPIOE STS: STS11 (Bitfield-Mask: 0x01)                      */
#define GPIOE_STS_STS12_Pos                   (12UL)                    /*!< GPIOE STS: STS12 (Bit 12)                                   */
#define GPIOE_STS_STS12_Msk                   (0x1000UL)                /*!< GPIOE STS: STS12 (Bitfield-Mask: 0x01)                      */
#define GPIOE_STS_STS13_Pos                   (13UL)                    /*!< GPIOE STS: STS13 (Bit 13)                                   */
#define GPIOE_STS_STS13_Msk                   (0x2000UL)                /*!< GPIOE STS: STS13 (Bitfield-Mask: 0x01)                      */
#define GPIOE_STS_STS14_Pos                   (14UL)                    /*!< GPIOE STS: STS14 (Bit 14)                                   */
#define GPIOE_STS_STS14_Msk                   (0x4000UL)                /*!< GPIOE STS: STS14 (Bitfield-Mask: 0x01)                      */
#define GPIOE_STS_STS15_Pos                   (15UL)                    /*!< GPIOE STS: STS15 (Bit 15)                                   */
#define GPIOE_STS_STS15_Msk                   (0x8000UL)                /*!< GPIOE STS: STS15 (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================         struct 'GPIOF' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  GPIOF_OEN  --------------------------------- */
#define GPIOF_OEN_OEN0_Pos                    (0UL)                     /*!< GPIOF OEN: OEN0 (Bit 0)                                     */
#define GPIOF_OEN_OEN0_Msk                    (0x1UL)                   /*!< GPIOF OEN: OEN0 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN1_Pos                    (1UL)                     /*!< GPIOF OEN: OEN1 (Bit 1)                                     */
#define GPIOF_OEN_OEN1_Msk                    (0x2UL)                   /*!< GPIOF OEN: OEN1 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN2_Pos                    (2UL)                     /*!< GPIOF OEN: OEN2 (Bit 2)                                     */
#define GPIOF_OEN_OEN2_Msk                    (0x4UL)                   /*!< GPIOF OEN: OEN2 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN3_Pos                    (3UL)                     /*!< GPIOF OEN: OEN3 (Bit 3)                                     */
#define GPIOF_OEN_OEN3_Msk                    (0x8UL)                   /*!< GPIOF OEN: OEN3 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN4_Pos                    (4UL)                     /*!< GPIOF OEN: OEN4 (Bit 4)                                     */
#define GPIOF_OEN_OEN4_Msk                    (0x10UL)                  /*!< GPIOF OEN: OEN4 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN5_Pos                    (5UL)                     /*!< GPIOF OEN: OEN5 (Bit 5)                                     */
#define GPIOF_OEN_OEN5_Msk                    (0x20UL)                  /*!< GPIOF OEN: OEN5 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN6_Pos                    (6UL)                     /*!< GPIOF OEN: OEN6 (Bit 6)                                     */
#define GPIOF_OEN_OEN6_Msk                    (0x40UL)                  /*!< GPIOF OEN: OEN6 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN7_Pos                    (7UL)                     /*!< GPIOF OEN: OEN7 (Bit 7)                                     */
#define GPIOF_OEN_OEN7_Msk                    (0x80UL)                  /*!< GPIOF OEN: OEN7 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN8_Pos                    (8UL)                     /*!< GPIOF OEN: OEN8 (Bit 8)                                     */
#define GPIOF_OEN_OEN8_Msk                    (0x100UL)                 /*!< GPIOF OEN: OEN8 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN9_Pos                    (9UL)                     /*!< GPIOF OEN: OEN9 (Bit 9)                                     */
#define GPIOF_OEN_OEN9_Msk                    (0x200UL)                 /*!< GPIOF OEN: OEN9 (Bitfield-Mask: 0x01)                       */
#define GPIOF_OEN_OEN10_Pos                   (10UL)                    /*!< GPIOF OEN: OEN10 (Bit 10)                                   */
#define GPIOF_OEN_OEN10_Msk                   (0x400UL)                 /*!< GPIOF OEN: OEN10 (Bitfield-Mask: 0x01)                      */
#define GPIOF_OEN_OEN11_Pos                   (11UL)                    /*!< GPIOF OEN: OEN11 (Bit 11)                                   */
#define GPIOF_OEN_OEN11_Msk                   (0x800UL)                 /*!< GPIOF OEN: OEN11 (Bitfield-Mask: 0x01)                      */
#define GPIOF_OEN_OEN12_Pos                   (12UL)                    /*!< GPIOF OEN: OEN12 (Bit 12)                                   */
#define GPIOF_OEN_OEN12_Msk                   (0x1000UL)                /*!< GPIOF OEN: OEN12 (Bitfield-Mask: 0x01)                      */
#define GPIOF_OEN_OEN13_Pos                   (13UL)                    /*!< GPIOF OEN: OEN13 (Bit 13)                                   */
#define GPIOF_OEN_OEN13_Msk                   (0x2000UL)                /*!< GPIOF OEN: OEN13 (Bitfield-Mask: 0x01)                      */
#define GPIOF_OEN_OEN14_Pos                   (14UL)                    /*!< GPIOF OEN: OEN14 (Bit 14)                                   */
#define GPIOF_OEN_OEN14_Msk                   (0x4000UL)                /*!< GPIOF OEN: OEN14 (Bitfield-Mask: 0x01)                      */
#define GPIOF_OEN_OEN15_Pos                   (15UL)                    /*!< GPIOF OEN: OEN15 (Bit 15)                                   */
#define GPIOF_OEN_OEN15_Msk                   (0x8000UL)                /*!< GPIOF OEN: OEN15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOF_IE  ---------------------------------- */
#define GPIOF_IE_IE0_Pos                      (0UL)                     /*!< GPIOF IE: IE0 (Bit 0)                                       */
#define GPIOF_IE_IE0_Msk                      (0x1UL)                   /*!< GPIOF IE: IE0 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE1_Pos                      (1UL)                     /*!< GPIOF IE: IE1 (Bit 1)                                       */
#define GPIOF_IE_IE1_Msk                      (0x2UL)                   /*!< GPIOF IE: IE1 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE2_Pos                      (2UL)                     /*!< GPIOF IE: IE2 (Bit 2)                                       */
#define GPIOF_IE_IE2_Msk                      (0x4UL)                   /*!< GPIOF IE: IE2 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE3_Pos                      (3UL)                     /*!< GPIOF IE: IE3 (Bit 3)                                       */
#define GPIOF_IE_IE3_Msk                      (0x8UL)                   /*!< GPIOF IE: IE3 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE4_Pos                      (4UL)                     /*!< GPIOF IE: IE4 (Bit 4)                                       */
#define GPIOF_IE_IE4_Msk                      (0x10UL)                  /*!< GPIOF IE: IE4 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE5_Pos                      (5UL)                     /*!< GPIOF IE: IE5 (Bit 5)                                       */
#define GPIOF_IE_IE5_Msk                      (0x20UL)                  /*!< GPIOF IE: IE5 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE6_Pos                      (6UL)                     /*!< GPIOF IE: IE6 (Bit 6)                                       */
#define GPIOF_IE_IE6_Msk                      (0x40UL)                  /*!< GPIOF IE: IE6 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE7_Pos                      (7UL)                     /*!< GPIOF IE: IE7 (Bit 7)                                       */
#define GPIOF_IE_IE7_Msk                      (0x80UL)                  /*!< GPIOF IE: IE7 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE8_Pos                      (8UL)                     /*!< GPIOF IE: IE8 (Bit 8)                                       */
#define GPIOF_IE_IE8_Msk                      (0x100UL)                 /*!< GPIOF IE: IE8 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE9_Pos                      (9UL)                     /*!< GPIOF IE: IE9 (Bit 9)                                       */
#define GPIOF_IE_IE9_Msk                      (0x200UL)                 /*!< GPIOF IE: IE9 (Bitfield-Mask: 0x01)                         */
#define GPIOF_IE_IE10_Pos                     (10UL)                    /*!< GPIOF IE: IE10 (Bit 10)                                     */
#define GPIOF_IE_IE10_Msk                     (0x400UL)                 /*!< GPIOF IE: IE10 (Bitfield-Mask: 0x01)                        */
#define GPIOF_IE_IE11_Pos                     (11UL)                    /*!< GPIOF IE: IE11 (Bit 11)                                     */
#define GPIOF_IE_IE11_Msk                     (0x800UL)                 /*!< GPIOF IE: IE11 (Bitfield-Mask: 0x01)                        */
#define GPIOF_IE_IE12_Pos                     (12UL)                    /*!< GPIOF IE: IE12 (Bit 12)                                     */
#define GPIOF_IE_IE12_Msk                     (0x1000UL)                /*!< GPIOF IE: IE12 (Bitfield-Mask: 0x01)                        */
#define GPIOF_IE_IE13_Pos                     (13UL)                    /*!< GPIOF IE: IE13 (Bit 13)                                     */
#define GPIOF_IE_IE13_Msk                     (0x2000UL)                /*!< GPIOF IE: IE13 (Bitfield-Mask: 0x01)                        */
#define GPIOF_IE_IE14_Pos                     (14UL)                    /*!< GPIOF IE: IE14 (Bit 14)                                     */
#define GPIOF_IE_IE14_Msk                     (0x4000UL)                /*!< GPIOF IE: IE14 (Bitfield-Mask: 0x01)                        */
#define GPIOF_IE_IE15_Pos                     (15UL)                    /*!< GPIOF IE: IE15 (Bit 15)                                     */
#define GPIOF_IE_IE15_Msk                     (0x8000UL)                /*!< GPIOF IE: IE15 (Bitfield-Mask: 0x01)                        */

/* ----------------------------------  GPIOF_DAT  --------------------------------- */
#define GPIOF_DAT_DAT0_Pos                    (0UL)                     /*!< GPIOF DAT: DAT0 (Bit 0)                                     */
#define GPIOF_DAT_DAT0_Msk                    (0x1UL)                   /*!< GPIOF DAT: DAT0 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT1_Pos                    (1UL)                     /*!< GPIOF DAT: DAT1 (Bit 1)                                     */
#define GPIOF_DAT_DAT1_Msk                    (0x2UL)                   /*!< GPIOF DAT: DAT1 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT2_Pos                    (2UL)                     /*!< GPIOF DAT: DAT2 (Bit 2)                                     */
#define GPIOF_DAT_DAT2_Msk                    (0x4UL)                   /*!< GPIOF DAT: DAT2 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT3_Pos                    (3UL)                     /*!< GPIOF DAT: DAT3 (Bit 3)                                     */
#define GPIOF_DAT_DAT3_Msk                    (0x8UL)                   /*!< GPIOF DAT: DAT3 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT4_Pos                    (4UL)                     /*!< GPIOF DAT: DAT4 (Bit 4)                                     */
#define GPIOF_DAT_DAT4_Msk                    (0x10UL)                  /*!< GPIOF DAT: DAT4 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT5_Pos                    (5UL)                     /*!< GPIOF DAT: DAT5 (Bit 5)                                     */
#define GPIOF_DAT_DAT5_Msk                    (0x20UL)                  /*!< GPIOF DAT: DAT5 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT6_Pos                    (6UL)                     /*!< GPIOF DAT: DAT6 (Bit 6)                                     */
#define GPIOF_DAT_DAT6_Msk                    (0x40UL)                  /*!< GPIOF DAT: DAT6 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT7_Pos                    (7UL)                     /*!< GPIOF DAT: DAT7 (Bit 7)                                     */
#define GPIOF_DAT_DAT7_Msk                    (0x80UL)                  /*!< GPIOF DAT: DAT7 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT8_Pos                    (8UL)                     /*!< GPIOF DAT: DAT8 (Bit 8)                                     */
#define GPIOF_DAT_DAT8_Msk                    (0x100UL)                 /*!< GPIOF DAT: DAT8 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT9_Pos                    (9UL)                     /*!< GPIOF DAT: DAT9 (Bit 9)                                     */
#define GPIOF_DAT_DAT9_Msk                    (0x200UL)                 /*!< GPIOF DAT: DAT9 (Bitfield-Mask: 0x01)                       */
#define GPIOF_DAT_DAT10_Pos                   (10UL)                    /*!< GPIOF DAT: DAT10 (Bit 10)                                   */
#define GPIOF_DAT_DAT10_Msk                   (0x400UL)                 /*!< GPIOF DAT: DAT10 (Bitfield-Mask: 0x01)                      */
#define GPIOF_DAT_DAT11_Pos                   (11UL)                    /*!< GPIOF DAT: DAT11 (Bit 11)                                   */
#define GPIOF_DAT_DAT11_Msk                   (0x800UL)                 /*!< GPIOF DAT: DAT11 (Bitfield-Mask: 0x01)                      */
#define GPIOF_DAT_DAT12_Pos                   (12UL)                    /*!< GPIOF DAT: DAT12 (Bit 12)                                   */
#define GPIOF_DAT_DAT12_Msk                   (0x1000UL)                /*!< GPIOF DAT: DAT12 (Bitfield-Mask: 0x01)                      */
#define GPIOF_DAT_DAT13_Pos                   (13UL)                    /*!< GPIOF DAT: DAT13 (Bit 13)                                   */
#define GPIOF_DAT_DAT13_Msk                   (0x2000UL)                /*!< GPIOF DAT: DAT13 (Bitfield-Mask: 0x01)                      */
#define GPIOF_DAT_DAT14_Pos                   (14UL)                    /*!< GPIOF DAT: DAT14 (Bit 14)                                   */
#define GPIOF_DAT_DAT14_Msk                   (0x4000UL)                /*!< GPIOF DAT: DAT14 (Bitfield-Mask: 0x01)                      */
#define GPIOF_DAT_DAT15_Pos                   (15UL)                    /*!< GPIOF DAT: DAT15 (Bit 15)                                   */
#define GPIOF_DAT_DAT15_Msk                   (0x8000UL)                /*!< GPIOF DAT: DAT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOF_ATT  --------------------------------- */
#define GPIOF_ATT_ATT0_Pos                    (0UL)                     /*!< GPIOF ATT: ATT0 (Bit 0)                                     */
#define GPIOF_ATT_ATT0_Msk                    (0x1UL)                   /*!< GPIOF ATT: ATT0 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT1_Pos                    (1UL)                     /*!< GPIOF ATT: ATT1 (Bit 1)                                     */
#define GPIOF_ATT_ATT1_Msk                    (0x2UL)                   /*!< GPIOF ATT: ATT1 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT2_Pos                    (2UL)                     /*!< GPIOF ATT: ATT2 (Bit 2)                                     */
#define GPIOF_ATT_ATT2_Msk                    (0x4UL)                   /*!< GPIOF ATT: ATT2 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT3_Pos                    (3UL)                     /*!< GPIOF ATT: ATT3 (Bit 3)                                     */
#define GPIOF_ATT_ATT3_Msk                    (0x8UL)                   /*!< GPIOF ATT: ATT3 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT4_Pos                    (4UL)                     /*!< GPIOF ATT: ATT4 (Bit 4)                                     */
#define GPIOF_ATT_ATT4_Msk                    (0x10UL)                  /*!< GPIOF ATT: ATT4 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT5_Pos                    (5UL)                     /*!< GPIOF ATT: ATT5 (Bit 5)                                     */
#define GPIOF_ATT_ATT5_Msk                    (0x20UL)                  /*!< GPIOF ATT: ATT5 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT6_Pos                    (6UL)                     /*!< GPIOF ATT: ATT6 (Bit 6)                                     */
#define GPIOF_ATT_ATT6_Msk                    (0x40UL)                  /*!< GPIOF ATT: ATT6 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT7_Pos                    (7UL)                     /*!< GPIOF ATT: ATT7 (Bit 7)                                     */
#define GPIOF_ATT_ATT7_Msk                    (0x80UL)                  /*!< GPIOF ATT: ATT7 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT8_Pos                    (8UL)                     /*!< GPIOF ATT: ATT8 (Bit 8)                                     */
#define GPIOF_ATT_ATT8_Msk                    (0x100UL)                 /*!< GPIOF ATT: ATT8 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT9_Pos                    (9UL)                     /*!< GPIOF ATT: ATT9 (Bit 9)                                     */
#define GPIOF_ATT_ATT9_Msk                    (0x200UL)                 /*!< GPIOF ATT: ATT9 (Bitfield-Mask: 0x01)                       */
#define GPIOF_ATT_ATT10_Pos                   (10UL)                    /*!< GPIOF ATT: ATT10 (Bit 10)                                   */
#define GPIOF_ATT_ATT10_Msk                   (0x400UL)                 /*!< GPIOF ATT: ATT10 (Bitfield-Mask: 0x01)                      */
#define GPIOF_ATT_ATT11_Pos                   (11UL)                    /*!< GPIOF ATT: ATT11 (Bit 11)                                   */
#define GPIOF_ATT_ATT11_Msk                   (0x800UL)                 /*!< GPIOF ATT: ATT11 (Bitfield-Mask: 0x01)                      */
#define GPIOF_ATT_ATT12_Pos                   (12UL)                    /*!< GPIOF ATT: ATT12 (Bit 12)                                   */
#define GPIOF_ATT_ATT12_Msk                   (0x1000UL)                /*!< GPIOF ATT: ATT12 (Bitfield-Mask: 0x01)                      */
#define GPIOF_ATT_ATT13_Pos                   (13UL)                    /*!< GPIOF ATT: ATT13 (Bit 13)                                   */
#define GPIOF_ATT_ATT13_Msk                   (0x2000UL)                /*!< GPIOF ATT: ATT13 (Bitfield-Mask: 0x01)                      */
#define GPIOF_ATT_ATT14_Pos                   (14UL)                    /*!< GPIOF ATT: ATT14 (Bit 14)                                   */
#define GPIOF_ATT_ATT14_Msk                   (0x4000UL)                /*!< GPIOF ATT: ATT14 (Bitfield-Mask: 0x01)                      */
#define GPIOF_ATT_ATT15_Pos                   (15UL)                    /*!< GPIOF ATT: ATT15 (Bit 15)                                   */
#define GPIOF_ATT_ATT15_Msk                   (0x8000UL)                /*!< GPIOF ATT: ATT15 (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  GPIOF_STS  --------------------------------- */
#define GPIOF_STS_STS0_Pos                    (0UL)                     /*!< GPIOF STS: STS0 (Bit 0)                                     */
#define GPIOF_STS_STS0_Msk                    (0x1UL)                   /*!< GPIOF STS: STS0 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS1_Pos                    (1UL)                     /*!< GPIOF STS: STS1 (Bit 1)                                     */
#define GPIOF_STS_STS1_Msk                    (0x2UL)                   /*!< GPIOF STS: STS1 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS2_Pos                    (2UL)                     /*!< GPIOF STS: STS2 (Bit 2)                                     */
#define GPIOF_STS_STS2_Msk                    (0x4UL)                   /*!< GPIOF STS: STS2 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS3_Pos                    (3UL)                     /*!< GPIOF STS: STS3 (Bit 3)                                     */
#define GPIOF_STS_STS3_Msk                    (0x8UL)                   /*!< GPIOF STS: STS3 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS4_Pos                    (4UL)                     /*!< GPIOF STS: STS4 (Bit 4)                                     */
#define GPIOF_STS_STS4_Msk                    (0x10UL)                  /*!< GPIOF STS: STS4 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS5_Pos                    (5UL)                     /*!< GPIOF STS: STS5 (Bit 5)                                     */
#define GPIOF_STS_STS5_Msk                    (0x20UL)                  /*!< GPIOF STS: STS5 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS6_Pos                    (6UL)                     /*!< GPIOF STS: STS6 (Bit 6)                                     */
#define GPIOF_STS_STS6_Msk                    (0x40UL)                  /*!< GPIOF STS: STS6 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS7_Pos                    (7UL)                     /*!< GPIOF STS: STS7 (Bit 7)                                     */
#define GPIOF_STS_STS7_Msk                    (0x80UL)                  /*!< GPIOF STS: STS7 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS8_Pos                    (8UL)                     /*!< GPIOF STS: STS8 (Bit 8)                                     */
#define GPIOF_STS_STS8_Msk                    (0x100UL)                 /*!< GPIOF STS: STS8 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS9_Pos                    (9UL)                     /*!< GPIOF STS: STS9 (Bit 9)                                     */
#define GPIOF_STS_STS9_Msk                    (0x200UL)                 /*!< GPIOF STS: STS9 (Bitfield-Mask: 0x01)                       */
#define GPIOF_STS_STS10_Pos                   (10UL)                    /*!< GPIOF STS: STS10 (Bit 10)                                   */
#define GPIOF_STS_STS10_Msk                   (0x400UL)                 /*!< GPIOF STS: STS10 (Bitfield-Mask: 0x01)                      */
#define GPIOF_STS_STS11_Pos                   (11UL)                    /*!< GPIOF STS: STS11 (Bit 11)                                   */
#define GPIOF_STS_STS11_Msk                   (0x800UL)                 /*!< GPIOF STS: STS11 (Bitfield-Mask: 0x01)                      */
#define GPIOF_STS_STS12_Pos                   (12UL)                    /*!< GPIOF STS: STS12 (Bit 12)                                   */
#define GPIOF_STS_STS12_Msk                   (0x1000UL)                /*!< GPIOF STS: STS12 (Bitfield-Mask: 0x01)                      */
#define GPIOF_STS_STS13_Pos                   (13UL)                    /*!< GPIOF STS: STS13 (Bit 13)                                   */
#define GPIOF_STS_STS13_Msk                   (0x2000UL)                /*!< GPIOF STS: STS13 (Bitfield-Mask: 0x01)                      */
#define GPIOF_STS_STS14_Pos                   (14UL)                    /*!< GPIOF STS: STS14 (Bit 14)                                   */
#define GPIOF_STS_STS14_Msk                   (0x4000UL)                /*!< GPIOF STS: STS14 (Bitfield-Mask: 0x01)                      */
#define GPIOF_STS_STS15_Pos                   (15UL)                    /*!< GPIOF STS: STS15 (Bit 15)                                   */
#define GPIOF_STS_STS15_Msk                   (0x8000UL)                /*!< GPIOF STS: STS15 (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================        struct 'GPIOSEL' Position & Mask        ================ */
/* ================================================================================ */


/* -------------------------------  GPIOSEL_IOB_SEL  ------------------------------ */
#define GPIOSEL_IOB_SEL_IOB_SEL1_Pos          (1UL)                     /*!< GPIOSEL IOB_SEL: IOB_SEL1 (Bit 1)                           */
#define GPIOSEL_IOB_SEL_IOB_SEL1_Msk          (0x2UL)                   /*!< GPIOSEL IOB_SEL: IOB_SEL1 (Bitfield-Mask: 0x01)             */
#define GPIOSEL_IOB_SEL_IOB_SEL2_Pos          (2UL)                     /*!< GPIOSEL IOB_SEL: IOB_SEL2 (Bit 2)                           */
#define GPIOSEL_IOB_SEL_IOB_SEL2_Msk          (0x4UL)                   /*!< GPIOSEL IOB_SEL: IOB_SEL2 (Bitfield-Mask: 0x01)             */
#define GPIOSEL_IOB_SEL_IOB_SEL6_Pos          (6UL)                     /*!< GPIOSEL IOB_SEL: IOB_SEL6 (Bit 6)                           */
#define GPIOSEL_IOB_SEL_IOB_SEL6_Msk          (0x40UL)                  /*!< GPIOSEL IOB_SEL: IOB_SEL6 (Bitfield-Mask: 0x01)             */

/* -------------------------------  GPIOSEL_IOE_SEL  ------------------------------ */
#define GPIOSEL_IOE_SEL_IOE_SEL7_Pos          (7UL)                     /*!< GPIOSEL IOE_SEL: IOE_SEL7 (Bit 7)                           */
#define GPIOSEL_IOE_SEL_IOE_SEL7_Msk          (0x80UL)                  /*!< GPIOSEL IOE_SEL: IOE_SEL7 (Bitfield-Mask: 0x01)             */

/* -------------------------------  GPIOSEL_IO_MISC  ------------------------------ */
#define GPIOSEL_IO_MISC_PLLHDIV_Pos           (0UL)                     /*!< GPIOSEL IO_MISC: PLLHDIV (Bit 0)                            */
#define GPIOSEL_IO_MISC_PLLHDIV_Msk           (0x7UL)                   /*!< GPIOSEL IO_MISC: PLLHDIV (Bitfield-Mask: 0x07)              */
#define GPIOSEL_IO_MISC_I2CIOC_Pos            (5UL)                     /*!< GPIOSEL IO_MISC: I2CIOC (Bit 5)                             */
#define GPIOSEL_IO_MISC_I2CIOC_Msk            (0x20UL)                  /*!< GPIOSEL IO_MISC: I2CIOC (Bitfield-Mask: 0x01)               */


/* ================================================================================ */
/* ================          struct 'I2C' Position & Mask          ================ */
/* ================================================================================ */


/* ----------------------------------  I2C_DATA  ---------------------------------- */
#define I2C_DATA_DATA_Pos                     (0UL)                     /*!< I2C DATA: DATA (Bit 0)                                      */
#define I2C_DATA_DATA_Msk                     (0xffUL)                  /*!< I2C DATA: DATA (Bitfield-Mask: 0xff)                        */

/* ----------------------------------  I2C_ADDR  ---------------------------------- */
#define I2C_ADDR_GC_Pos                       (0UL)                     /*!< I2C ADDR: GC (Bit 0)                                        */
#define I2C_ADDR_GC_Msk                       (0x1UL)                   /*!< I2C ADDR: GC (Bitfield-Mask: 0x01)                          */
#define I2C_ADDR_SLA_Pos                      (1UL)                     /*!< I2C ADDR: SLA (Bit 1)                                       */
#define I2C_ADDR_SLA_Msk                      (0xfeUL)                  /*!< I2C ADDR: SLA (Bitfield-Mask: 0x7f)                         */

/* ----------------------------------  I2C_CTRL  ---------------------------------- */
#define I2C_CTRL_CR0_Pos                      (0UL)                     /*!< I2C CTRL: CR0 (Bit 0)                                       */
#define I2C_CTRL_CR0_Msk                      (0x1UL)                   /*!< I2C CTRL: CR0 (Bitfield-Mask: 0x01)                         */
#define I2C_CTRL_CR1_Pos                      (1UL)                     /*!< I2C CTRL: CR1 (Bit 1)                                       */
#define I2C_CTRL_CR1_Msk                      (0x2UL)                   /*!< I2C CTRL: CR1 (Bitfield-Mask: 0x01)                         */
#define I2C_CTRL_AA_Pos                       (2UL)                     /*!< I2C CTRL: AA (Bit 2)                                        */
#define I2C_CTRL_AA_Msk                       (0x4UL)                   /*!< I2C CTRL: AA (Bitfield-Mask: 0x01)                          */
#define I2C_CTRL_SI_Pos                       (3UL)                     /*!< I2C CTRL: SI (Bit 3)                                        */
#define I2C_CTRL_SI_Msk                       (0x8UL)                   /*!< I2C CTRL: SI (Bitfield-Mask: 0x01)                          */
#define I2C_CTRL_STO_Pos                      (4UL)                     /*!< I2C CTRL: STO (Bit 4)                                       */
#define I2C_CTRL_STO_Msk                      (0x10UL)                  /*!< I2C CTRL: STO (Bitfield-Mask: 0x01)                         */
#define I2C_CTRL_STA_Pos                      (5UL)                     /*!< I2C CTRL: STA (Bit 5)                                       */
#define I2C_CTRL_STA_Msk                      (0x20UL)                  /*!< I2C CTRL: STA (Bitfield-Mask: 0x01)                         */
#define I2C_CTRL_EN_Pos                       (6UL)                     /*!< I2C CTRL: EN (Bit 6)                                        */
#define I2C_CTRL_EN_Msk                       (0x40UL)                  /*!< I2C CTRL: EN (Bitfield-Mask: 0x01)                          */
#define I2C_CTRL_CR2_Pos                      (7UL)                     /*!< I2C CTRL: CR2 (Bit 7)                                       */
#define I2C_CTRL_CR2_Msk                      (0x80UL)                  /*!< I2C CTRL: CR2 (Bitfield-Mask: 0x01)                         */

/* -----------------------------------  I2C_STS  ---------------------------------- */
#define I2C_STS_STS_Pos                       (3UL)                     /*!< I2C STS: STS (Bit 3)                                        */
#define I2C_STS_STS_Msk                       (0xf8UL)                  /*!< I2C STS: STS (Bitfield-Mask: 0x1f)                          */

/* ----------------------------------  I2C_CTRL2  --------------------------------- */
#define I2C_CTRL2_INTEN_Pos                   (0UL)                     /*!< I2C CTRL2: INTEN (Bit 0)                                    */
#define I2C_CTRL2_INTEN_Msk                   (0x1UL)                   /*!< I2C CTRL2: INTEN (Bitfield-Mask: 0x01)                      */


/* ================================================================================ */
/* ================         Group 'ISO7816' Position & Mask        ================ */
/* ================================================================================ */


/* ------------------------------  ISO7816_BAUDDIVL  ------------------------------ */
#define ISO7816_BAUDDIVL_BAUDDIVL_Pos         (0UL)                     /*!< ISO7816 BAUDDIVL: BAUDDIVL (Bit 0)                          */
#define ISO7816_BAUDDIVL_BAUDDIVL_Msk         (0xffUL)                  /*!< ISO7816 BAUDDIVL: BAUDDIVL (Bitfield-Mask: 0xff)            */

/* ------------------------------  ISO7816_BAUDDIVH  ------------------------------ */
#define ISO7816_BAUDDIVH_BAUDDIVH_Pos         (0UL)                     /*!< ISO7816 BAUDDIVH: BAUDDIVH (Bit 0)                          */
#define ISO7816_BAUDDIVH_BAUDDIVH_Msk         (0xffUL)                  /*!< ISO7816 BAUDDIVH: BAUDDIVH (Bitfield-Mask: 0xff)            */

/* --------------------------------  ISO7816_DATA  -------------------------------- */
#define ISO7816_DATA_DATA_Pos                 (0UL)                     /*!< ISO7816 DATA: DATA (Bit 0)                                  */
#define ISO7816_DATA_DATA_Msk                 (0xffUL)                  /*!< ISO7816 DATA: DATA (Bitfield-Mask: 0xff)                    */

/* --------------------------------  ISO7816_INFO  -------------------------------- */
#define ISO7816_INFO_RCACK_Pos                (0UL)                     /*!< ISO7816 INFO: RCACK (Bit 0)                                 */
#define ISO7816_INFO_RCACK_Msk                (0x1UL)                   /*!< ISO7816 INFO: RCACK (Bitfield-Mask: 0x01)                   */
#define ISO7816_INFO_CHKSUM_Pos               (1UL)                     /*!< ISO7816 INFO: CHKSUM (Bit 1)                                */
#define ISO7816_INFO_CHKSUM_Msk               (0x2UL)                   /*!< ISO7816 INFO: CHKSUM (Bitfield-Mask: 0x01)                  */
#define ISO7816_INFO_RCERR_Pos                (2UL)                     /*!< ISO7816 INFO: RCERR (Bit 2)                                 */
#define ISO7816_INFO_RCERR_Msk                (0x4UL)                   /*!< ISO7816 INFO: RCERR (Bitfield-Mask: 0x01)                   */
#define ISO7816_INFO_SDERR_Pos                (3UL)                     /*!< ISO7816 INFO: SDERR (Bit 3)                                 */
#define ISO7816_INFO_SDERR_Msk                (0x8UL)                   /*!< ISO7816 INFO: SDERR (Bitfield-Mask: 0x01)                   */
#define ISO7816_INFO_LSB_Pos                  (4UL)                     /*!< ISO7816 INFO: LSB (Bit 4)                                   */
#define ISO7816_INFO_LSB_Msk                  (0x10UL)                  /*!< ISO7816 INFO: LSB (Bitfield-Mask: 0x01)                     */
#define ISO7816_INFO_RCIF_Pos                 (5UL)                     /*!< ISO7816 INFO: RCIF (Bit 5)                                  */
#define ISO7816_INFO_RCIF_Msk                 (0x20UL)                  /*!< ISO7816 INFO: RCIF (Bitfield-Mask: 0x01)                    */
#define ISO7816_INFO_SDIF_Pos                 (6UL)                     /*!< ISO7816 INFO: SDIF (Bit 6)                                  */
#define ISO7816_INFO_SDIF_Msk                 (0x40UL)                  /*!< ISO7816 INFO: SDIF (Bitfield-Mask: 0x01)                    */
#define ISO7816_INFO_OVIF_Pos                 (7UL)                     /*!< ISO7816 INFO: OVIF (Bit 7)                                  */
#define ISO7816_INFO_OVIF_Msk                 (0x80UL)                  /*!< ISO7816 INFO: OVIF (Bitfield-Mask: 0x01)                    */

/* ---------------------------------  ISO7816_CFG  -------------------------------- */
#define ISO7816_CFG_EN_Pos                    (0UL)                     /*!< ISO7816 CFG: EN (Bit 0)                                     */
#define ISO7816_CFG_EN_Msk                    (0x1UL)                   /*!< ISO7816 CFG: EN (Bitfield-Mask: 0x01)                       */
#define ISO7816_CFG_CHKP_Pos                  (1UL)                     /*!< ISO7816 CFG: CHKP (Bit 1)                                   */
#define ISO7816_CFG_CHKP_Msk                  (0x2UL)                   /*!< ISO7816 CFG: CHKP (Bitfield-Mask: 0x01)                     */
#define ISO7816_CFG_AUTORC_Pos                (2UL)                     /*!< ISO7816 CFG: AUTORC (Bit 2)                                 */
#define ISO7816_CFG_AUTORC_Msk                (0x4UL)                   /*!< ISO7816 CFG: AUTORC (Bitfield-Mask: 0x01)                   */
#define ISO7816_CFG_AUTOSD_Pos                (3UL)                     /*!< ISO7816 CFG: AUTOSD (Bit 3)                                 */
#define ISO7816_CFG_AUTOSD_Msk                (0x8UL)                   /*!< ISO7816 CFG: AUTOSD (Bitfield-Mask: 0x01)                   */
#define ISO7816_CFG_ACKLEN_Pos                (4UL)                     /*!< ISO7816 CFG: ACKLEN (Bit 4)                                 */
#define ISO7816_CFG_ACKLEN_Msk                (0x10UL)                  /*!< ISO7816 CFG: ACKLEN (Bitfield-Mask: 0x01)                   */
#define ISO7816_CFG_RCIE_Pos                  (5UL)                     /*!< ISO7816 CFG: RCIE (Bit 5)                                   */
#define ISO7816_CFG_RCIE_Msk                  (0x20UL)                  /*!< ISO7816 CFG: RCIE (Bitfield-Mask: 0x01)                     */
#define ISO7816_CFG_SDIE_Pos                  (6UL)                     /*!< ISO7816 CFG: SDIE (Bit 6)                                   */
#define ISO7816_CFG_SDIE_Msk                  (0x40UL)                  /*!< ISO7816 CFG: SDIE (Bitfield-Mask: 0x01)                     */
#define ISO7816_CFG_OVIE_Pos                  (7UL)                     /*!< ISO7816 CFG: OVIE (Bit 7)                                   */
#define ISO7816_CFG_OVIE_Msk                  (0x80UL)                  /*!< ISO7816 CFG: OVIE (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  ISO7816_CLK  -------------------------------- */
#define ISO7816_CLK_CLKDIV_Pos                (0UL)                     /*!< ISO7816 CLK: CLKDIV (Bit 0)                                 */
#define ISO7816_CLK_CLKDIV_Msk                (0x7fUL)                  /*!< ISO7816 CLK: CLKDIV (Bitfield-Mask: 0x7f)                   */
#define ISO7816_CLK_CLKEN_Pos                 (7UL)                     /*!< ISO7816 CLK: CLKEN (Bit 7)                                  */
#define ISO7816_CLK_CLKEN_Msk                 (0x80UL)                  /*!< ISO7816 CLK: CLKEN (Bitfield-Mask: 0x01)                    */


/* ================================================================================ */
/* ================        struct 'ISO78160' Position & Mask       ================ */
/* ================================================================================ */


/* ------------------------------  ISO78160_BAUDDIVL  ----------------------------- */
#define ISO78160_BAUDDIVL_BAUDDIVL_Pos        (0UL)                     /*!< ISO78160 BAUDDIVL: BAUDDIVL (Bit 0)                         */
#define ISO78160_BAUDDIVL_BAUDDIVL_Msk        (0xffUL)                  /*!< ISO78160 BAUDDIVL: BAUDDIVL (Bitfield-Mask: 0xff)           */

/* ------------------------------  ISO78160_BAUDDIVH  ----------------------------- */
#define ISO78160_BAUDDIVH_BAUDDIVH_Pos        (0UL)                     /*!< ISO78160 BAUDDIVH: BAUDDIVH (Bit 0)                         */
#define ISO78160_BAUDDIVH_BAUDDIVH_Msk        (0xffUL)                  /*!< ISO78160 BAUDDIVH: BAUDDIVH (Bitfield-Mask: 0xff)           */

/* --------------------------------  ISO78160_DATA  ------------------------------- */
#define ISO78160_DATA_DATA_Pos                (0UL)                     /*!< ISO78160 DATA: DATA (Bit 0)                                 */
#define ISO78160_DATA_DATA_Msk                (0xffUL)                  /*!< ISO78160 DATA: DATA (Bitfield-Mask: 0xff)                   */

/* --------------------------------  ISO78160_INFO  ------------------------------- */
#define ISO78160_INFO_RCACK_Pos               (0UL)                     /*!< ISO78160 INFO: RCACK (Bit 0)                                */
#define ISO78160_INFO_RCACK_Msk               (0x1UL)                   /*!< ISO78160 INFO: RCACK (Bitfield-Mask: 0x01)                  */
#define ISO78160_INFO_CHKSUM_Pos              (1UL)                     /*!< ISO78160 INFO: CHKSUM (Bit 1)                               */
#define ISO78160_INFO_CHKSUM_Msk              (0x2UL)                   /*!< ISO78160 INFO: CHKSUM (Bitfield-Mask: 0x01)                 */
#define ISO78160_INFO_RCERR_Pos               (2UL)                     /*!< ISO78160 INFO: RCERR (Bit 2)                                */
#define ISO78160_INFO_RCERR_Msk               (0x4UL)                   /*!< ISO78160 INFO: RCERR (Bitfield-Mask: 0x01)                  */
#define ISO78160_INFO_SDERR_Pos               (3UL)                     /*!< ISO78160 INFO: SDERR (Bit 3)                                */
#define ISO78160_INFO_SDERR_Msk               (0x8UL)                   /*!< ISO78160 INFO: SDERR (Bitfield-Mask: 0x01)                  */
#define ISO78160_INFO_LSB_Pos                 (4UL)                     /*!< ISO78160 INFO: LSB (Bit 4)                                  */
#define ISO78160_INFO_LSB_Msk                 (0x10UL)                  /*!< ISO78160 INFO: LSB (Bitfield-Mask: 0x01)                    */
#define ISO78160_INFO_RCIF_Pos                (5UL)                     /*!< ISO78160 INFO: RCIF (Bit 5)                                 */
#define ISO78160_INFO_RCIF_Msk                (0x20UL)                  /*!< ISO78160 INFO: RCIF (Bitfield-Mask: 0x01)                   */
#define ISO78160_INFO_SDIF_Pos                (6UL)                     /*!< ISO78160 INFO: SDIF (Bit 6)                                 */
#define ISO78160_INFO_SDIF_Msk                (0x40UL)                  /*!< ISO78160 INFO: SDIF (Bitfield-Mask: 0x01)                   */
#define ISO78160_INFO_OVIF_Pos                (7UL)                     /*!< ISO78160 INFO: OVIF (Bit 7)                                 */
#define ISO78160_INFO_OVIF_Msk                (0x80UL)                  /*!< ISO78160 INFO: OVIF (Bitfield-Mask: 0x01)                   */

/* --------------------------------  ISO78160_CFG  -------------------------------- */
#define ISO78160_CFG_EN_Pos                   (0UL)                     /*!< ISO78160 CFG: EN (Bit 0)                                    */
#define ISO78160_CFG_EN_Msk                   (0x1UL)                   /*!< ISO78160 CFG: EN (Bitfield-Mask: 0x01)                      */
#define ISO78160_CFG_CHKP_Pos                 (1UL)                     /*!< ISO78160 CFG: CHKP (Bit 1)                                  */
#define ISO78160_CFG_CHKP_Msk                 (0x2UL)                   /*!< ISO78160 CFG: CHKP (Bitfield-Mask: 0x01)                    */
#define ISO78160_CFG_AUTORC_Pos               (2UL)                     /*!< ISO78160 CFG: AUTORC (Bit 2)                                */
#define ISO78160_CFG_AUTORC_Msk               (0x4UL)                   /*!< ISO78160 CFG: AUTORC (Bitfield-Mask: 0x01)                  */
#define ISO78160_CFG_AUTOSD_Pos               (3UL)                     /*!< ISO78160 CFG: AUTOSD (Bit 3)                                */
#define ISO78160_CFG_AUTOSD_Msk               (0x8UL)                   /*!< ISO78160 CFG: AUTOSD (Bitfield-Mask: 0x01)                  */
#define ISO78160_CFG_ACKLEN_Pos               (4UL)                     /*!< ISO78160 CFG: ACKLEN (Bit 4)                                */
#define ISO78160_CFG_ACKLEN_Msk               (0x10UL)                  /*!< ISO78160 CFG: ACKLEN (Bitfield-Mask: 0x01)                  */
#define ISO78160_CFG_RCIE_Pos                 (5UL)                     /*!< ISO78160 CFG: RCIE (Bit 5)                                  */
#define ISO78160_CFG_RCIE_Msk                 (0x20UL)                  /*!< ISO78160 CFG: RCIE (Bitfield-Mask: 0x01)                    */
#define ISO78160_CFG_SDIE_Pos                 (6UL)                     /*!< ISO78160 CFG: SDIE (Bit 6)                                  */
#define ISO78160_CFG_SDIE_Msk                 (0x40UL)                  /*!< ISO78160 CFG: SDIE (Bitfield-Mask: 0x01)                    */
#define ISO78160_CFG_OVIE_Pos                 (7UL)                     /*!< ISO78160 CFG: OVIE (Bit 7)                                  */
#define ISO78160_CFG_OVIE_Msk                 (0x80UL)                  /*!< ISO78160 CFG: OVIE (Bitfield-Mask: 0x01)                    */

/* --------------------------------  ISO78160_CLK  -------------------------------- */
#define ISO78160_CLK_CLKDIV_Pos               (0UL)                     /*!< ISO78160 CLK: CLKDIV (Bit 0)                                */
#define ISO78160_CLK_CLKDIV_Msk               (0x7fUL)                  /*!< ISO78160 CLK: CLKDIV (Bitfield-Mask: 0x7f)                  */
#define ISO78160_CLK_CLKEN_Pos                (7UL)                     /*!< ISO78160 CLK: CLKEN (Bit 7)                                 */
#define ISO78160_CLK_CLKEN_Msk                (0x80UL)                  /*!< ISO78160 CLK: CLKEN (Bitfield-Mask: 0x01)                   */


/* ================================================================================ */
/* ================        struct 'ISO78161' Position & Mask       ================ */
/* ================================================================================ */


/* ------------------------------  ISO78161_BAUDDIVL  ----------------------------- */
#define ISO78161_BAUDDIVL_BAUDDIVL_Pos        (0UL)                     /*!< ISO78161 BAUDDIVL: BAUDDIVL (Bit 0)                         */
#define ISO78161_BAUDDIVL_BAUDDIVL_Msk        (0xffUL)                  /*!< ISO78161 BAUDDIVL: BAUDDIVL (Bitfield-Mask: 0xff)           */

/* ------------------------------  ISO78161_BAUDDIVH  ----------------------------- */
#define ISO78161_BAUDDIVH_BAUDDIVH_Pos        (0UL)                     /*!< ISO78161 BAUDDIVH: BAUDDIVH (Bit 0)                         */
#define ISO78161_BAUDDIVH_BAUDDIVH_Msk        (0xffUL)                  /*!< ISO78161 BAUDDIVH: BAUDDIVH (Bitfield-Mask: 0xff)           */

/* --------------------------------  ISO78161_DATA  ------------------------------- */
#define ISO78161_DATA_DATA_Pos                (0UL)                     /*!< ISO78161 DATA: DATA (Bit 0)                                 */
#define ISO78161_DATA_DATA_Msk                (0xffUL)                  /*!< ISO78161 DATA: DATA (Bitfield-Mask: 0xff)                   */

/* --------------------------------  ISO78161_INFO  ------------------------------- */
#define ISO78161_INFO_RCACK_Pos               (0UL)                     /*!< ISO78161 INFO: RCACK (Bit 0)                                */
#define ISO78161_INFO_RCACK_Msk               (0x1UL)                   /*!< ISO78161 INFO: RCACK (Bitfield-Mask: 0x01)                  */
#define ISO78161_INFO_CHKSUM_Pos              (1UL)                     /*!< ISO78161 INFO: CHKSUM (Bit 1)                               */
#define ISO78161_INFO_CHKSUM_Msk              (0x2UL)                   /*!< ISO78161 INFO: CHKSUM (Bitfield-Mask: 0x01)                 */
#define ISO78161_INFO_RCERR_Pos               (2UL)                     /*!< ISO78161 INFO: RCERR (Bit 2)                                */
#define ISO78161_INFO_RCERR_Msk               (0x4UL)                   /*!< ISO78161 INFO: RCERR (Bitfield-Mask: 0x01)                  */
#define ISO78161_INFO_SDERR_Pos               (3UL)                     /*!< ISO78161 INFO: SDERR (Bit 3)                                */
#define ISO78161_INFO_SDERR_Msk               (0x8UL)                   /*!< ISO78161 INFO: SDERR (Bitfield-Mask: 0x01)                  */
#define ISO78161_INFO_LSB_Pos                 (4UL)                     /*!< ISO78161 INFO: LSB (Bit 4)                                  */
#define ISO78161_INFO_LSB_Msk                 (0x10UL)                  /*!< ISO78161 INFO: LSB (Bitfield-Mask: 0x01)                    */
#define ISO78161_INFO_RCIF_Pos                (5UL)                     /*!< ISO78161 INFO: RCIF (Bit 5)                                 */
#define ISO78161_INFO_RCIF_Msk                (0x20UL)                  /*!< ISO78161 INFO: RCIF (Bitfield-Mask: 0x01)                   */
#define ISO78161_INFO_SDIF_Pos                (6UL)                     /*!< ISO78161 INFO: SDIF (Bit 6)                                 */
#define ISO78161_INFO_SDIF_Msk                (0x40UL)                  /*!< ISO78161 INFO: SDIF (Bitfield-Mask: 0x01)                   */
#define ISO78161_INFO_OVIF_Pos                (7UL)                     /*!< ISO78161 INFO: OVIF (Bit 7)                                 */
#define ISO78161_INFO_OVIF_Msk                (0x80UL)                  /*!< ISO78161 INFO: OVIF (Bitfield-Mask: 0x01)                   */

/* --------------------------------  ISO78161_CFG  -------------------------------- */
#define ISO78161_CFG_EN_Pos                   (0UL)                     /*!< ISO78161 CFG: EN (Bit 0)                                    */
#define ISO78161_CFG_EN_Msk                   (0x1UL)                   /*!< ISO78161 CFG: EN (Bitfield-Mask: 0x01)                      */
#define ISO78161_CFG_CHKP_Pos                 (1UL)                     /*!< ISO78161 CFG: CHKP (Bit 1)                                  */
#define ISO78161_CFG_CHKP_Msk                 (0x2UL)                   /*!< ISO78161 CFG: CHKP (Bitfield-Mask: 0x01)                    */
#define ISO78161_CFG_AUTORC_Pos               (2UL)                     /*!< ISO78161 CFG: AUTORC (Bit 2)                                */
#define ISO78161_CFG_AUTORC_Msk               (0x4UL)                   /*!< ISO78161 CFG: AUTORC (Bitfield-Mask: 0x01)                  */
#define ISO78161_CFG_AUTOSD_Pos               (3UL)                     /*!< ISO78161 CFG: AUTOSD (Bit 3)                                */
#define ISO78161_CFG_AUTOSD_Msk               (0x8UL)                   /*!< ISO78161 CFG: AUTOSD (Bitfield-Mask: 0x01)                  */
#define ISO78161_CFG_ACKLEN_Pos               (4UL)                     /*!< ISO78161 CFG: ACKLEN (Bit 4)                                */
#define ISO78161_CFG_ACKLEN_Msk               (0x10UL)                  /*!< ISO78161 CFG: ACKLEN (Bitfield-Mask: 0x01)                  */
#define ISO78161_CFG_RCIE_Pos                 (5UL)                     /*!< ISO78161 CFG: RCIE (Bit 5)                                  */
#define ISO78161_CFG_RCIE_Msk                 (0x20UL)                  /*!< ISO78161 CFG: RCIE (Bitfield-Mask: 0x01)                    */
#define ISO78161_CFG_SDIE_Pos                 (6UL)                     /*!< ISO78161 CFG: SDIE (Bit 6)                                  */
#define ISO78161_CFG_SDIE_Msk                 (0x40UL)                  /*!< ISO78161 CFG: SDIE (Bitfield-Mask: 0x01)                    */
#define ISO78161_CFG_OVIE_Pos                 (7UL)                     /*!< ISO78161 CFG: OVIE (Bit 7)                                  */
#define ISO78161_CFG_OVIE_Msk                 (0x80UL)                  /*!< ISO78161 CFG: OVIE (Bitfield-Mask: 0x01)                    */

/* --------------------------------  ISO78161_CLK  -------------------------------- */
#define ISO78161_CLK_CLKDIV_Pos               (0UL)                     /*!< ISO78161 CLK: CLKDIV (Bit 0)                                */
#define ISO78161_CLK_CLKDIV_Msk               (0x7fUL)                  /*!< ISO78161 CLK: CLKDIV (Bitfield-Mask: 0x7f)                  */
#define ISO78161_CLK_CLKEN_Pos                (7UL)                     /*!< ISO78161 CLK: CLKEN (Bit 7)                                 */
#define ISO78161_CLK_CLKEN_Msk                (0x80UL)                  /*!< ISO78161 CLK: CLKEN (Bitfield-Mask: 0x01)                   */


/* ================================================================================ */
/* ================          struct 'LCD' Position & Mask          ================ */
/* ================================================================================ */


/* -----------------------------------  LCD_FB  ----------------------------------- */
#define LCD_FB_DATAx_Pos                      (0UL)                     /*!< LCD FB: DATAx (Bit 0)                                       */
#define LCD_FB_DATAx_Msk                      (0xffffffffUL)            /*!< LCD FB: DATAx (Bitfield-Mask: 0xffffffff)                   */

/* ----------------------------------  LCD_CTRL  ---------------------------------- */
#define LCD_CTRL_FRQ_Pos                      (0UL)                     /*!< LCD CTRL: FRQ (Bit 0)                                       */
#define LCD_CTRL_FRQ_Msk                      (0x3UL)                   /*!< LCD CTRL: FRQ (Bitfield-Mask: 0x03)                         */
#define LCD_CTRL_DRV_Pos                      (2UL)                     /*!< LCD CTRL: DRV (Bit 2)                                       */
#define LCD_CTRL_DRV_Msk                      (0xcUL)                   /*!< LCD CTRL: DRV (Bitfield-Mask: 0x03)                         */
#define LCD_CTRL_TYPE_Pos                     (4UL)                     /*!< LCD CTRL: TYPE (Bit 4)                                      */
#define LCD_CTRL_TYPE_Msk                     (0x30UL)                  /*!< LCD CTRL: TYPE (Bitfield-Mask: 0x03)                        */
#define LCD_CTRL_EN_Pos                       (7UL)                     /*!< LCD CTRL: EN (Bit 7)                                        */
#define LCD_CTRL_EN_Msk                       (0x80UL)                  /*!< LCD CTRL: EN (Bitfield-Mask: 0x01)                          */

/* ----------------------------------  LCD_CTRL2  --------------------------------- */
#define LCD_CTRL2_BKFILL_Pos                  (4UL)                     /*!< LCD CTRL2: BKFILL (Bit 4)                                   */
#define LCD_CTRL2_BKFILL_Msk                  (0x10UL)                  /*!< LCD CTRL2: BKFILL (Bitfield-Mask: 0x01)                     */
#define LCD_CTRL2_FBMODE_Pos                  (6UL)                     /*!< LCD CTRL2: FBMODE (Bit 6)                                   */
#define LCD_CTRL2_FBMODE_Msk                  (0xc0UL)                  /*!< LCD CTRL2: FBMODE (Bitfield-Mask: 0x03)                     */
#define LCD_CTRL2_SWPR_Pos                    (8UL)                     /*!< LCD CTRL2: SWPR (Bit 8)                                     */
#define LCD_CTRL2_SWPR_Msk                    (0xff00UL)                /*!< LCD CTRL2: SWPR (Bitfield-Mask: 0xff)                       */

/* --------------------------------  LCD_SEGCTRL0  -------------------------------- */
#define LCD_SEGCTRL0_SEGCTRL_Pos              (0UL)                     /*!< LCD SEGCTRL0: SEGCTRL (Bit 0)                               */
#define LCD_SEGCTRL0_SEGCTRL_Msk              (0xffffffffUL)            /*!< LCD SEGCTRL0: SEGCTRL (Bitfield-Mask: 0xffffffff)           */

/* --------------------------------  LCD_SEGCTRL1  -------------------------------- */
#define LCD_SEGCTRL1_SEGCTRL_Pos              (0UL)                     /*!< LCD SEGCTRL1: SEGCTRL (Bit 0)                               */
#define LCD_SEGCTRL1_SEGCTRL_Msk              (0xffffffffUL)            /*!< LCD SEGCTRL1: SEGCTRL (Bitfield-Mask: 0xffffffff)           */

/* --------------------------------  LCD_SEGCTRL2  -------------------------------- */
#define LCD_SEGCTRL2_SEGCTRL_Pos              (0UL)                     /*!< LCD SEGCTRL2: SEGCTRL (Bit 0)                               */
#define LCD_SEGCTRL2_SEGCTRL_Msk              (0xffffUL)                /*!< LCD SEGCTRL2: SEGCTRL (Bitfield-Mask: 0xffff)               */


/* ================================================================================ */
/* ================          struct 'MISC' Position & Mask         ================ */
/* ================================================================================ */


/* --------------------------------  MISC_SRAMINT  -------------------------------- */
#define MISC_SRAMINT_PERR_Pos                 (0UL)                     /*!< MISC SRAMINT: PERR (Bit 0)                                  */
#define MISC_SRAMINT_PERR_Msk                 (0x1UL)                   /*!< MISC SRAMINT: PERR (Bitfield-Mask: 0x01)                    */
#define MISC_SRAMINT_HIAC_Pos                 (2UL)                     /*!< MISC SRAMINT: HIAC (Bit 2)                                  */
#define MISC_SRAMINT_HIAC_Msk                 (0x4UL)                   /*!< MISC SRAMINT: HIAC (Bitfield-Mask: 0x01)                    */
#define MISC_SRAMINT_PIAC_Pos                 (3UL)                     /*!< MISC SRAMINT: PIAC (Bit 3)                                  */
#define MISC_SRAMINT_PIAC_Msk                 (0x8UL)                   /*!< MISC SRAMINT: PIAC (Bitfield-Mask: 0x01)                    */
#define MISC_SRAMINT_LOCKUP_Pos               (4UL)                     /*!< MISC SRAMINT: LOCKUP (Bit 4)                                */
#define MISC_SRAMINT_LOCKUP_Msk               (0x10UL)                  /*!< MISC SRAMINT: LOCKUP (Bitfield-Mask: 0x01)                  */

/* --------------------------------  MISC_SRAMINIT  ------------------------------- */
#define MISC_SRAMINIT_PEN_Pos                 (0UL)                     /*!< MISC SRAMINIT: PEN (Bit 0)                                  */
#define MISC_SRAMINIT_PEN_Msk                 (0x1UL)                   /*!< MISC SRAMINIT: PEN (Bitfield-Mask: 0x01)                    */
#define MISC_SRAMINIT_PERRIE_Pos              (1UL)                     /*!< MISC SRAMINIT: PERRIE (Bit 1)                               */
#define MISC_SRAMINIT_PERRIE_Msk              (0x2UL)                   /*!< MISC SRAMINIT: PERRIE (Bitfield-Mask: 0x01)                 */
#define MISC_SRAMINIT_INIT_Pos                (2UL)                     /*!< MISC SRAMINIT: INIT (Bit 2)                                 */
#define MISC_SRAMINIT_INIT_Msk                (0x4UL)                   /*!< MISC SRAMINIT: INIT (Bitfield-Mask: 0x01)                   */
#define MISC_SRAMINIT_HIACIE_Pos              (5UL)                     /*!< MISC SRAMINIT: HIACIE (Bit 5)                               */
#define MISC_SRAMINIT_HIACIE_Msk              (0x20UL)                  /*!< MISC SRAMINIT: HIACIE (Bitfield-Mask: 0x01)                 */
#define MISC_SRAMINIT_PIACIE_Pos              (6UL)                     /*!< MISC SRAMINIT: PIACIE (Bit 6)                               */
#define MISC_SRAMINIT_PIACIE_Msk              (0x40UL)                  /*!< MISC SRAMINIT: PIACIE (Bitfield-Mask: 0x01)                 */
#define MISC_SRAMINIT_LOCKIE_Pos              (7UL)                     /*!< MISC SRAMINIT: LOCKIE (Bit 7)                               */
#define MISC_SRAMINIT_LOCKIE_Msk              (0x80UL)                  /*!< MISC SRAMINIT: LOCKIE (Bitfield-Mask: 0x01)                 */

/* ---------------------------------  MISC_PARERR  -------------------------------- */
#define MISC_PARERR_PEADDR_Pos                (0UL)                     /*!< MISC PARERR: PEADDR (Bit 0)                                 */
#define MISC_PARERR_PEADDR_Msk                (0xfffUL)                 /*!< MISC PARERR: PEADDR (Bitfield-Mask: 0xfff)                  */

/* ----------------------------------  MISC_IREN  --------------------------------- */
#define MISC_IREN_IREN_Pos                    (0UL)                     /*!< MISC IREN: IREN (Bit 0)                                     */
#define MISC_IREN_IREN_Msk                    (0x3fUL)                  /*!< MISC IREN: IREN (Bitfield-Mask: 0x3f)                       */

/* ---------------------------------  MISC_DUTYL  --------------------------------- */
#define MISC_DUTYL_DUTYL_Pos                  (0UL)                     /*!< MISC DUTYL: DUTYL (Bit 0)                                   */
#define MISC_DUTYL_DUTYL_Msk                  (0xffffUL)                /*!< MISC DUTYL: DUTYL (Bitfield-Mask: 0xffff)                   */

/* ---------------------------------  MISC_DUTYH  --------------------------------- */
#define MISC_DUTYH_DUTYH_Pos                  (0UL)                     /*!< MISC DUTYH: DUTYH (Bit 0)                                   */
#define MISC_DUTYH_DUTYH_Msk                  (0xffffUL)                /*!< MISC DUTYH: DUTYH (Bitfield-Mask: 0xffff)                   */

/* ---------------------------------  MISC_IRQLAT  -------------------------------- */
#define MISC_IRQLAT_IRQLAT_Pos                (0UL)                     /*!< MISC IRQLAT: IRQLAT (Bit 0)                                 */
#define MISC_IRQLAT_IRQLAT_Msk                (0xffUL)                  /*!< MISC IRQLAT: IRQLAT (Bitfield-Mask: 0xff)                   */
#define MISC_IRQLAT_LOCKRESET_Pos             (8UL)                     /*!< MISC IRQLAT: LOCKRESET (Bit 8)                              */
#define MISC_IRQLAT_LOCKRESET_Msk             (0x100UL)                 /*!< MISC IRQLAT: LOCKRESET (Bitfield-Mask: 0x01)                */
#define MISC_IRQLAT_NOHARDFAULT_Pos           (9UL)                     /*!< MISC IRQLAT: NOHARDFAULT (Bit 9)                            */
#define MISC_IRQLAT_NOHARDFAULT_Msk           (0x200UL)                 /*!< MISC IRQLAT: NOHARDFAULT (Bitfield-Mask: 0x01)              */


/* ================================================================================ */
/* ================         struct 'MISC2' Position & Mask         ================ */
/* ================================================================================ */


/* --------------------------------  MISC2_FLASHWC  ------------------------------- */
#define MISC2_FLASHWC_CYCLE_1US_Pos           (8UL)                     /*!< MISC2 FLASHWC: CYCLE_1US (Bit 8)                            */
#define MISC2_FLASHWC_CYCLE_1US_Msk           (0x3f00UL)                /*!< MISC2 FLASHWC: CYCLE_1US (Bitfield-Mask: 0x3f)              */

/* --------------------------------  MISC2_CLKSEL  -------------------------------- */
#define MISC2_CLKSEL_CLKSEL_Pos               (0UL)                     /*!< MISC2 CLKSEL: CLKSEL (Bit 0)                                */
#define MISC2_CLKSEL_CLKSEL_Msk               (0x7UL)                   /*!< MISC2 CLKSEL: CLKSEL (Bitfield-Mask: 0x07)                  */

/* --------------------------------  MISC2_CLKDIVH  ------------------------------- */
#define MISC2_CLKDIVH_CLKDIVH_Pos             (0UL)                     /*!< MISC2 CLKDIVH: CLKDIVH (Bit 0)                              */
#define MISC2_CLKDIVH_CLKDIVH_Msk             (0xffUL)                  /*!< MISC2 CLKDIVH: CLKDIVH (Bitfield-Mask: 0xff)                */

/* --------------------------------  MISC2_CLKDIVP  ------------------------------- */
#define MISC2_CLKDIVP_CLKDIVP_Pos             (0UL)                     /*!< MISC2 CLKDIVP: CLKDIVP (Bit 0)                              */
#define MISC2_CLKDIVP_CLKDIVP_Msk             (0xffUL)                  /*!< MISC2 CLKDIVP: CLKDIVP (Bitfield-Mask: 0xff)                */

/* --------------------------------  MISC2_HCLKEN  -------------------------------- */
#define MISC2_HCLKEN_ArbiterBusMatrix_CLKEN_Pos (1UL)                   /*!< MISC2 HCLKEN: ArbiterBusMatrix_CLKEN (Bit 1)                */
#define MISC2_HCLKEN_ArbiterBusMatrix_CLKEN_Msk (0x2UL)                 /*!< MISC2 HCLKEN: ArbiterBusMatrix_CLKEN (Bitfield-Mask: 0x01)  */
#define MISC2_HCLKEN_FLASH_CLKEN_Pos          (2UL)                     /*!< MISC2 HCLKEN: FLASH_CLKEN (Bit 2)                           */
#define MISC2_HCLKEN_FLASH_CLKEN_Msk          (0x4UL)                   /*!< MISC2 HCLKEN: FLASH_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_HCLKEN_SRAM_CLKEN_Pos           (3UL)                     /*!< MISC2 HCLKEN: SRAM_CLKEN (Bit 3)                            */
#define MISC2_HCLKEN_SRAM_CLKEN_Msk           (0x8UL)                   /*!< MISC2 HCLKEN: SRAM_CLKEN (Bitfield-Mask: 0x01)              */
#define MISC2_HCLKEN_DMA_CLKEN_Pos            (4UL)                     /*!< MISC2 HCLKEN: DMA_CLKEN (Bit 4)                             */
#define MISC2_HCLKEN_DMA_CLKEN_Msk            (0x10UL)                  /*!< MISC2 HCLKEN: DMA_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_HCLKEN_GPIO_CLKEN_Pos           (5UL)                     /*!< MISC2 HCLKEN: GPIO_CLKEN (Bit 5)                            */
#define MISC2_HCLKEN_GPIO_CLKEN_Msk           (0x20UL)                  /*!< MISC2 HCLKEN: GPIO_CLKEN (Bitfield-Mask: 0x01)              */
#define MISC2_HCLKEN_LCD_CLKEN_Pos            (6UL)                     /*!< MISC2 HCLKEN: LCD_CLKEN (Bit 6)                             */
#define MISC2_HCLKEN_LCD_CLKEN_Msk            (0x40UL)                  /*!< MISC2 HCLKEN: LCD_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_HCLKEN_CRYPT_CLKEN_Pos          (8UL)                     /*!< MISC2 HCLKEN: CRYPT_CLKEN (Bit 8)                           */
#define MISC2_HCLKEN_CRYPT_CLKEN_Msk          (0x100UL)                 /*!< MISC2 HCLKEN: CRYPT_CLKEN (Bitfield-Mask: 0x01)             */

/* --------------------------------  MISC2_PCLKEN  -------------------------------- */
#define MISC2_PCLKEN_AHB2APB_Bridge_CLKEN_Pos (0UL)                     /*!< MISC2 PCLKEN: AHB2APB_Bridge_CLKEN (Bit 0)                  */
#define MISC2_PCLKEN_AHB2APB_Bridge_CLKEN_Msk (0x1UL)                   /*!< MISC2 PCLKEN: AHB2APB_Bridge_CLKEN (Bitfield-Mask: 0x01)    */
#define MISC2_PCLKEN_DMA_CLKEN_Pos            (1UL)                     /*!< MISC2 PCLKEN: DMA_CLKEN (Bit 1)                             */
#define MISC2_PCLKEN_DMA_CLKEN_Msk            (0x2UL)                   /*!< MISC2 PCLKEN: DMA_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_PCLKEN_I2C_CLKEN_Pos            (2UL)                     /*!< MISC2 PCLKEN: I2C_CLKEN (Bit 2)                             */
#define MISC2_PCLKEN_I2C_CLKEN_Msk            (0x4UL)                   /*!< MISC2 PCLKEN: I2C_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_PCLKEN_SPI1_CLKEN_Pos           (3UL)                     /*!< MISC2 PCLKEN: SPI1_CLKEN (Bit 3)                            */
#define MISC2_PCLKEN_SPI1_CLKEN_Msk           (0x8UL)                   /*!< MISC2 PCLKEN: SPI1_CLKEN (Bitfield-Mask: 0x01)              */
#define MISC2_PCLKEN_UART0_CLKEN_Pos          (4UL)                     /*!< MISC2 PCLKEN: UART0_CLKEN (Bit 4)                           */
#define MISC2_PCLKEN_UART0_CLKEN_Msk          (0x10UL)                  /*!< MISC2 PCLKEN: UART0_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_UART1_CLKEN_Pos          (5UL)                     /*!< MISC2 PCLKEN: UART1_CLKEN (Bit 5)                           */
#define MISC2_PCLKEN_UART1_CLKEN_Msk          (0x20UL)                  /*!< MISC2 PCLKEN: UART1_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_UART2_CLKEN_Pos          (6UL)                     /*!< MISC2 PCLKEN: UART2_CLKEN (Bit 6)                           */
#define MISC2_PCLKEN_UART2_CLKEN_Msk          (0x40UL)                  /*!< MISC2 PCLKEN: UART2_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_UART3_CLKEN_Pos          (7UL)                     /*!< MISC2 PCLKEN: UART3_CLKEN (Bit 7)                           */
#define MISC2_PCLKEN_UART3_CLKEN_Msk          (0x80UL)                  /*!< MISC2 PCLKEN: UART3_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_UART4_CLKEN_Pos          (8UL)                     /*!< MISC2 PCLKEN: UART4_CLKEN (Bit 8)                           */
#define MISC2_PCLKEN_UART4_CLKEN_Msk          (0x100UL)                 /*!< MISC2 PCLKEN: UART4_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_UART5_CLKEN_Pos          (9UL)                     /*!< MISC2 PCLKEN: UART5_CLKEN (Bit 9)                           */
#define MISC2_PCLKEN_UART5_CLKEN_Msk          (0x200UL)                 /*!< MISC2 PCLKEN: UART5_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_ISO78160_CLKEN_Pos       (10UL)                    /*!< MISC2 PCLKEN: ISO78160_CLKEN (Bit 10)                       */
#define MISC2_PCLKEN_ISO78160_CLKEN_Msk       (0x400UL)                 /*!< MISC2 PCLKEN: ISO78160_CLKEN (Bitfield-Mask: 0x01)          */
#define MISC2_PCLKEN_ISO78161_CLKEN_Pos       (11UL)                    /*!< MISC2 PCLKEN: ISO78161_CLKEN (Bit 11)                       */
#define MISC2_PCLKEN_ISO78161_CLKEN_Msk       (0x800UL)                 /*!< MISC2 PCLKEN: ISO78161_CLKEN (Bitfield-Mask: 0x01)          */
#define MISC2_PCLKEN_Timer_CLKEN_Pos          (12UL)                    /*!< MISC2 PCLKEN: Timer_CLKEN (Bit 12)                          */
#define MISC2_PCLKEN_Timer_CLKEN_Msk          (0x1000UL)                /*!< MISC2 PCLKEN: Timer_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_MISC_CLKEN_Pos           (13UL)                    /*!< MISC2 PCLKEN: MISC_CLKEN (Bit 13)                           */
#define MISC2_PCLKEN_MISC_CLKEN_Msk           (0x2000UL)                /*!< MISC2 PCLKEN: MISC_CLKEN (Bitfield-Mask: 0x01)              */
#define MISC2_PCLKEN_MISC2_CLKEN_Pos          (14UL)                    /*!< MISC2 PCLKEN: MISC2_CLKEN (Bit 14)                          */
#define MISC2_PCLKEN_MISC2_CLKEN_Msk          (0x4000UL)                /*!< MISC2 PCLKEN: MISC2_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_PMU_CLKEN_Pos            (15UL)                    /*!< MISC2 PCLKEN: PMU_CLKEN (Bit 15)                            */
#define MISC2_PCLKEN_PMU_CLKEN_Msk            (0x8000UL)                /*!< MISC2 PCLKEN: PMU_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_PCLKEN_RTC_CLKEN_Pos            (16UL)                    /*!< MISC2 PCLKEN: RTC_CLKEN (Bit 16)                            */
#define MISC2_PCLKEN_RTC_CLKEN_Msk            (0x10000UL)               /*!< MISC2 PCLKEN: RTC_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_PCLKEN_ANA_CLKEN_Pos            (17UL)                    /*!< MISC2 PCLKEN: ANA_CLKEN (Bit 17)                            */
#define MISC2_PCLKEN_ANA_CLKEN_Msk            (0x20000UL)               /*!< MISC2 PCLKEN: ANA_CLKEN (Bitfield-Mask: 0x01)               */
#define MISC2_PCLKEN_U32K0_CLKEN_Pos          (18UL)                    /*!< MISC2 PCLKEN: U32K0_CLKEN (Bit 18)                          */
#define MISC2_PCLKEN_U32K0_CLKEN_Msk          (0x40000UL)               /*!< MISC2 PCLKEN: U32K0_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_U32K1_CLKEN_Pos          (19UL)                    /*!< MISC2 PCLKEN: U32K1_CLKEN (Bit 19)                          */
#define MISC2_PCLKEN_U32K1_CLKEN_Msk          (0x80000UL)               /*!< MISC2 PCLKEN: U32K1_CLKEN (Bitfield-Mask: 0x01)             */
#define MISC2_PCLKEN_SPI2_CLKEN_Pos           (21UL)                    /*!< MISC2 PCLKEN: SPI2_CLKEN (Bit 21)                           */
#define MISC2_PCLKEN_SPI2_CLKEN_Msk           (0x200000UL)              /*!< MISC2 PCLKEN: SPI2_CLKEN (Bitfield-Mask: 0x01)              */


/* ================================================================================ */
/* ================          struct 'PMU' Position & Mask          ================ */
/* ================================================================================ */


/* --------------------------------  PMU_DSLEEPEN  -------------------------------- */
#define PMU_DSLEEPEN_WKU_Pos                  (31UL)                    /*!< PMU DSLEEPEN: WKU (Bit 31)                                  */
#define PMU_DSLEEPEN_WKU_Msk                  (0x80000000UL)            /*!< PMU DSLEEPEN: WKU (Bitfield-Mask: 0x01)                     */

/* -------------------------------  PMU_DSLEEPPASS  ------------------------------- */
#define PMU_DSLEEPPASS_UNLOCK_Pos             (0UL)                     /*!< PMU DSLEEPPASS: UNLOCK (Bit 0)                              */
#define PMU_DSLEEPPASS_UNLOCK_Msk             (0x1UL)                   /*!< PMU DSLEEPPASS: UNLOCK (Bitfield-Mask: 0x01)                */

/* ---------------------------------  PMU_CONTROL  -------------------------------- */
#define PMU_CONTROL_INT_IOA_EN_Pos            (0UL)                     /*!< PMU CONTROL: INT_IOA_EN (Bit 0)                             */
#define PMU_CONTROL_INT_IOA_EN_Msk            (0x1UL)                   /*!< PMU CONTROL: INT_IOA_EN (Bitfield-Mask: 0x01)               */
#define PMU_CONTROL_RTCCLK_SEL_Pos            (1UL)                     /*!< PMU CONTROL: RTCCLK_SEL (Bit 1)                             */
#define PMU_CONTROL_RTCCLK_SEL_Msk            (0x2UL)                   /*!< PMU CONTROL: RTCCLK_SEL (Bitfield-Mask: 0x01)               */
#define PMU_CONTROL_INT_32K_EN_Pos            (2UL)                     /*!< PMU CONTROL: INT_32K_EN (Bit 2)                             */
#define PMU_CONTROL_INT_32K_EN_Msk            (0x4UL)                   /*!< PMU CONTROL: INT_32K_EN (Bitfield-Mask: 0x01)               */
#define PMU_CONTROL_INT_6M_EN_Pos             (3UL)                     /*!< PMU CONTROL: INT_6M_EN (Bit 3)                              */
#define PMU_CONTROL_INT_6M_EN_Msk             (0x8UL)                   /*!< PMU CONTROL: INT_6M_EN (Bitfield-Mask: 0x01)                */
#define PMU_CONTROL_PLLH_SEL_Pos              (4UL)                     /*!< PMU CONTROL: PLLH_SEL (Bit 4)                               */
#define PMU_CONTROL_PLLH_SEL_Msk              (0x10UL)                  /*!< PMU CONTROL: PLLH_SEL (Bitfield-Mask: 0x01)                 */
#define PMU_CONTROL_PLLL_SEL_Pos              (5UL)                     /*!< PMU CONTROL: PLLL_SEL (Bit 5)                               */
#define PMU_CONTROL_PLLL_SEL_Msk              (0x20UL)                  /*!< PMU CONTROL: PLLL_SEL (Bitfield-Mask: 0x01)                 */
#define PMU_CONTROL_PWUPCYC_Pos               (8UL)                     /*!< PMU CONTROL: PWUPCYC (Bit 8)                                */
#define PMU_CONTROL_PWUPCYC_Msk               (0xff00UL)                /*!< PMU CONTROL: PWUPCYC (Bitfield-Mask: 0xff)                  */

/* -----------------------------------  PMU_STS  ---------------------------------- */
#define PMU_STS_INT_32K_Pos                   (0UL)                     /*!< PMU STS: INT_32K (Bit 0)                                    */
#define PMU_STS_INT_32K_Msk                   (0x1UL)                   /*!< PMU STS: INT_32K (Bitfield-Mask: 0x01)                      */
#define PMU_STS_INT_6M_Pos                    (1UL)                     /*!< PMU STS: INT_6M (Bit 1)                                     */
#define PMU_STS_INT_6M_Msk                    (0x2UL)                   /*!< PMU STS: INT_6M (Bitfield-Mask: 0x01)                       */
#define PMU_STS_EXIST_32K_Pos                 (2UL)                     /*!< PMU STS: EXIST_32K (Bit 2)                                  */
#define PMU_STS_EXIST_32K_Msk                 (0x4UL)                   /*!< PMU STS: EXIST_32K (Bitfield-Mask: 0x01)                    */
#define PMU_STS_EXIST_6M_Pos                  (3UL)                     /*!< PMU STS: EXIST_6M (Bit 3)                                   */
#define PMU_STS_EXIST_6M_Msk                  (0x8UL)                   /*!< PMU STS: EXIST_6M (Bitfield-Mask: 0x01)                     */
#define PMU_STS_EXTRST_Pos                    (4UL)                     /*!< PMU STS: EXTRST (Bit 4)                                     */
#define PMU_STS_EXTRST_Msk                    (0x10UL)                  /*!< PMU STS: EXTRST (Bitfield-Mask: 0x01)                       */
#define PMU_STS_PORST_Pos                     (5UL)                     /*!< PMU STS: PORST (Bit 5)                                      */
#define PMU_STS_PORST_Msk                     (0x20UL)                  /*!< PMU STS: PORST (Bitfield-Mask: 0x01)                        */
#define PMU_STS_DPORST_Pos                    (6UL)                     /*!< PMU STS: DPORST (Bit 6)                                     */
#define PMU_STS_DPORST_Msk                    (0x40UL)                  /*!< PMU STS: DPORST (Bitfield-Mask: 0x01)                       */
#define PMU_STS_MODE_Pos                      (24UL)                    /*!< PMU STS: MODE (Bit 24)                                      */
#define PMU_STS_MODE_Msk                      (0x1000000UL)             /*!< PMU STS: MODE (Bitfield-Mask: 0x01)                         */

/* ---------------------------------  PMU_WDTPASS  -------------------------------- */
#define PMU_WDTPASS_UNLOCK_Pos                (0UL)                     /*!< PMU WDTPASS: UNLOCK (Bit 0)                                 */
#define PMU_WDTPASS_UNLOCK_Msk                (0x1UL)                   /*!< PMU WDTPASS: UNLOCK (Bitfield-Mask: 0x01)                   */

/* ----------------------------------  PMU_WDTEN  --------------------------------- */
#define PMU_WDTEN_WDTEN_Pos                   (0UL)                     /*!< PMU WDTEN: WDTEN (Bit 0)                                    */
#define PMU_WDTEN_WDTEN_Msk                   (0x1UL)                   /*!< PMU WDTEN: WDTEN (Bitfield-Mask: 0x01)                      */
#define PMU_WDTEN_WDTSEL_Pos                  (2UL)                     /*!< PMU WDTEN: WDTSEL (Bit 2)                                   */
#define PMU_WDTEN_WDTSEL_Msk                  (0xcUL)                   /*!< PMU WDTEN: WDTSEL (Bitfield-Mask: 0x03)                     */

/* ---------------------------------  PMU_WDTCLR  --------------------------------- */
#define PMU_WDTCLR_WDTCNT_Pos                 (0UL)                     /*!< PMU WDTCLR: WDTCNT (Bit 0)                                  */
#define PMU_WDTCLR_WDTCNT_Msk                 (0xffffUL)                /*!< PMU WDTCLR: WDTCNT (Bitfield-Mask: 0xffff)                  */

/* -----------------------------------  PMU_RAM  ---------------------------------- */
#define PMU_RAM_RAMx_Pos                      (0UL)                     /*!< PMU RAM: RAMx (Bit 0)                                       */
#define PMU_RAM_RAMx_Msk                      (0xffffffffUL)            /*!< PMU RAM: RAMx (Bitfield-Mask: 0xffffffff)                   */


/* ================================================================================ */
/* ================           Group 'PWM' Position & Mask          ================ */
/* ================================================================================ */


/* -----------------------------------  PWM_CTL  ---------------------------------- */
#define PWM_CTL_IFG_Pos                       (0UL)                     /*!< PWM CTL: IFG (Bit 0)                                        */
#define PWM_CTL_IFG_Msk                       (0x1UL)                   /*!< PWM CTL: IFG (Bitfield-Mask: 0x01)                          */
#define PWM_CTL_IE_Pos                        (1UL)                     /*!< PWM CTL: IE (Bit 1)                                         */
#define PWM_CTL_IE_Msk                        (0x2UL)                   /*!< PWM CTL: IE (Bitfield-Mask: 0x01)                           */
#define PWM_CTL_CLR_Pos                       (2UL)                     /*!< PWM CTL: CLR (Bit 2)                                        */
#define PWM_CTL_CLR_Msk                       (0x4UL)                   /*!< PWM CTL: CLR (Bitfield-Mask: 0x01)                          */
#define PWM_CTL_TSEL_Pos                      (3UL)                     /*!< PWM CTL: TSEL (Bit 3)                                       */
#define PWM_CTL_TSEL_Msk                      (0x8UL)                   /*!< PWM CTL: TSEL (Bitfield-Mask: 0x01)                         */
#define PWM_CTL_MC_Pos                        (4UL)                     /*!< PWM CTL: MC (Bit 4)                                         */
#define PWM_CTL_MC_Msk                        (0x30UL)                  /*!< PWM CTL: MC (Bitfield-Mask: 0x03)                           */
#define PWM_CTL_ID_Pos                        (6UL)                     /*!< PWM CTL: ID (Bit 6)                                         */
#define PWM_CTL_ID_Msk                        (0xc0UL)                  /*!< PWM CTL: ID (Bitfield-Mask: 0x03)                           */

/* -----------------------------------  PWM_TAR  ---------------------------------- */
#define PWM_TAR_TAR_Pos                       (0UL)                     /*!< PWM TAR: TAR (Bit 0)                                        */
#define PWM_TAR_TAR_Msk                       (0xffffUL)                /*!< PWM TAR: TAR (Bitfield-Mask: 0xffff)                        */

/* ----------------------------------  PWM_CCTL0  --------------------------------- */
#define PWM_CCTL0_CCIFG_Pos                   (0UL)                     /*!< PWM CCTL0: CCIFG (Bit 0)                                    */
#define PWM_CCTL0_CCIFG_Msk                   (0x1UL)                   /*!< PWM CCTL0: CCIFG (Bitfield-Mask: 0x01)                      */
#define PWM_CCTL0_OUT_Pos                     (2UL)                     /*!< PWM CCTL0: OUT (Bit 2)                                      */
#define PWM_CCTL0_OUT_Msk                     (0x4UL)                   /*!< PWM CCTL0: OUT (Bitfield-Mask: 0x01)                        */
#define PWM_CCTL0_CCIE_Pos                    (4UL)                     /*!< PWM CCTL0: CCIE (Bit 4)                                     */
#define PWM_CCTL0_CCIE_Msk                    (0x10UL)                  /*!< PWM CCTL0: CCIE (Bitfield-Mask: 0x01)                       */
#define PWM_CCTL0_OUTMOD_Pos                  (5UL)                     /*!< PWM CCTL0: OUTMOD (Bit 5)                                   */
#define PWM_CCTL0_OUTMOD_Msk                  (0xe0UL)                  /*!< PWM CCTL0: OUTMOD (Bitfield-Mask: 0x07)                     */
#define PWM_CCTL0_OUTEN_Pos                   (9UL)                     /*!< PWM CCTL0: OUTEN (Bit 9)                                    */
#define PWM_CCTL0_OUTEN_Msk                   (0x200UL)                 /*!< PWM CCTL0: OUTEN (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  PWM_CCTL1  --------------------------------- */
#define PWM_CCTL1_CCIFG_Pos                   (0UL)                     /*!< PWM CCTL1: CCIFG (Bit 0)                                    */
#define PWM_CCTL1_CCIFG_Msk                   (0x1UL)                   /*!< PWM CCTL1: CCIFG (Bitfield-Mask: 0x01)                      */
#define PWM_CCTL1_OUT_Pos                     (2UL)                     /*!< PWM CCTL1: OUT (Bit 2)                                      */
#define PWM_CCTL1_OUT_Msk                     (0x4UL)                   /*!< PWM CCTL1: OUT (Bitfield-Mask: 0x01)                        */
#define PWM_CCTL1_CCIE_Pos                    (4UL)                     /*!< PWM CCTL1: CCIE (Bit 4)                                     */
#define PWM_CCTL1_CCIE_Msk                    (0x10UL)                  /*!< PWM CCTL1: CCIE (Bitfield-Mask: 0x01)                       */
#define PWM_CCTL1_OUTMOD_Pos                  (5UL)                     /*!< PWM CCTL1: OUTMOD (Bit 5)                                   */
#define PWM_CCTL1_OUTMOD_Msk                  (0xe0UL)                  /*!< PWM CCTL1: OUTMOD (Bitfield-Mask: 0x07)                     */
#define PWM_CCTL1_OUTEN_Pos                   (9UL)                     /*!< PWM CCTL1: OUTEN (Bit 9)                                    */
#define PWM_CCTL1_OUTEN_Msk                   (0x200UL)                 /*!< PWM CCTL1: OUTEN (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  PWM_CCTL2  --------------------------------- */
#define PWM_CCTL2_CCIFG_Pos                   (0UL)                     /*!< PWM CCTL2: CCIFG (Bit 0)                                    */
#define PWM_CCTL2_CCIFG_Msk                   (0x1UL)                   /*!< PWM CCTL2: CCIFG (Bitfield-Mask: 0x01)                      */
#define PWM_CCTL2_OUT_Pos                     (2UL)                     /*!< PWM CCTL2: OUT (Bit 2)                                      */
#define PWM_CCTL2_OUT_Msk                     (0x4UL)                   /*!< PWM CCTL2: OUT (Bitfield-Mask: 0x01)                        */
#define PWM_CCTL2_CCIE_Pos                    (4UL)                     /*!< PWM CCTL2: CCIE (Bit 4)                                     */
#define PWM_CCTL2_CCIE_Msk                    (0x10UL)                  /*!< PWM CCTL2: CCIE (Bitfield-Mask: 0x01)                       */
#define PWM_CCTL2_OUTMOD_Pos                  (5UL)                     /*!< PWM CCTL2: OUTMOD (Bit 5)                                   */
#define PWM_CCTL2_OUTMOD_Msk                  (0xe0UL)                  /*!< PWM CCTL2: OUTMOD (Bitfield-Mask: 0x07)                     */
#define PWM_CCTL2_OUTEN_Pos                   (9UL)                     /*!< PWM CCTL2: OUTEN (Bit 9)                                    */
#define PWM_CCTL2_OUTEN_Msk                   (0x200UL)                 /*!< PWM CCTL2: OUTEN (Bitfield-Mask: 0x01)                      */

/* ----------------------------------  PWM_CCR0  ---------------------------------- */
#define PWM_CCR0_CCRx_Pos                     (0UL)                     /*!< PWM CCR0: CCRx (Bit 0)                                      */
#define PWM_CCR0_CCRx_Msk                     (0xffffUL)                /*!< PWM CCR0: CCRx (Bitfield-Mask: 0xffff)                      */

/* ----------------------------------  PWM_CCR1  ---------------------------------- */
#define PWM_CCR1_CCRx_Pos                     (0UL)                     /*!< PWM CCR1: CCRx (Bit 0)                                      */
#define PWM_CCR1_CCRx_Msk                     (0xffffUL)                /*!< PWM CCR1: CCRx (Bitfield-Mask: 0xffff)                      */

/* ----------------------------------  PWM_CCR2  ---------------------------------- */
#define PWM_CCR2_CCRx_Pos                     (0UL)                     /*!< PWM CCR2: CCRx (Bit 0)                                      */
#define PWM_CCR2_CCRx_Msk                     (0xffffUL)                /*!< PWM CCR2: CCRx (Bitfield-Mask: 0xffff)                      */


/* ================================================================================ */
/* ================          struct 'PWM0' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  PWM0_CTL  ---------------------------------- */
#define PWM0_CTL_IFG_Pos                      (0UL)                     /*!< PWM0 CTL: IFG (Bit 0)                                       */
#define PWM0_CTL_IFG_Msk                      (0x1UL)                   /*!< PWM0 CTL: IFG (Bitfield-Mask: 0x01)                         */
#define PWM0_CTL_IE_Pos                       (1UL)                     /*!< PWM0 CTL: IE (Bit 1)                                        */
#define PWM0_CTL_IE_Msk                       (0x2UL)                   /*!< PWM0 CTL: IE (Bitfield-Mask: 0x01)                          */
#define PWM0_CTL_CLR_Pos                      (2UL)                     /*!< PWM0 CTL: CLR (Bit 2)                                       */
#define PWM0_CTL_CLR_Msk                      (0x4UL)                   /*!< PWM0 CTL: CLR (Bitfield-Mask: 0x01)                         */
#define PWM0_CTL_TSEL_Pos                     (3UL)                     /*!< PWM0 CTL: TSEL (Bit 3)                                      */
#define PWM0_CTL_TSEL_Msk                     (0x8UL)                   /*!< PWM0 CTL: TSEL (Bitfield-Mask: 0x01)                        */
#define PWM0_CTL_MC_Pos                       (4UL)                     /*!< PWM0 CTL: MC (Bit 4)                                        */
#define PWM0_CTL_MC_Msk                       (0x30UL)                  /*!< PWM0 CTL: MC (Bitfield-Mask: 0x03)                          */
#define PWM0_CTL_ID_Pos                       (6UL)                     /*!< PWM0 CTL: ID (Bit 6)                                        */
#define PWM0_CTL_ID_Msk                       (0xc0UL)                  /*!< PWM0 CTL: ID (Bitfield-Mask: 0x03)                          */

/* ----------------------------------  PWM0_TAR  ---------------------------------- */
#define PWM0_TAR_TAR_Pos                      (0UL)                     /*!< PWM0 TAR: TAR (Bit 0)                                       */
#define PWM0_TAR_TAR_Msk                      (0xffffUL)                /*!< PWM0 TAR: TAR (Bitfield-Mask: 0xffff)                       */

/* ---------------------------------  PWM0_CCTL0  --------------------------------- */
#define PWM0_CCTL0_CCIFG_Pos                  (0UL)                     /*!< PWM0 CCTL0: CCIFG (Bit 0)                                   */
#define PWM0_CCTL0_CCIFG_Msk                  (0x1UL)                   /*!< PWM0 CCTL0: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM0_CCTL0_OUT_Pos                    (2UL)                     /*!< PWM0 CCTL0: OUT (Bit 2)                                     */
#define PWM0_CCTL0_OUT_Msk                    (0x4UL)                   /*!< PWM0 CCTL0: OUT (Bitfield-Mask: 0x01)                       */
#define PWM0_CCTL0_CCIE_Pos                   (4UL)                     /*!< PWM0 CCTL0: CCIE (Bit 4)                                    */
#define PWM0_CCTL0_CCIE_Msk                   (0x10UL)                  /*!< PWM0 CCTL0: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM0_CCTL0_OUTMOD_Pos                 (5UL)                     /*!< PWM0 CCTL0: OUTMOD (Bit 5)                                  */
#define PWM0_CCTL0_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM0 CCTL0: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM0_CCTL0_OUTEN_Pos                  (9UL)                     /*!< PWM0 CCTL0: OUTEN (Bit 9)                                   */
#define PWM0_CCTL0_OUTEN_Msk                  (0x200UL)                 /*!< PWM0 CCTL0: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM0_CCTL1  --------------------------------- */
#define PWM0_CCTL1_CCIFG_Pos                  (0UL)                     /*!< PWM0 CCTL1: CCIFG (Bit 0)                                   */
#define PWM0_CCTL1_CCIFG_Msk                  (0x1UL)                   /*!< PWM0 CCTL1: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM0_CCTL1_OUT_Pos                    (2UL)                     /*!< PWM0 CCTL1: OUT (Bit 2)                                     */
#define PWM0_CCTL1_OUT_Msk                    (0x4UL)                   /*!< PWM0 CCTL1: OUT (Bitfield-Mask: 0x01)                       */
#define PWM0_CCTL1_CCIE_Pos                   (4UL)                     /*!< PWM0 CCTL1: CCIE (Bit 4)                                    */
#define PWM0_CCTL1_CCIE_Msk                   (0x10UL)                  /*!< PWM0 CCTL1: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM0_CCTL1_OUTMOD_Pos                 (5UL)                     /*!< PWM0 CCTL1: OUTMOD (Bit 5)                                  */
#define PWM0_CCTL1_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM0 CCTL1: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM0_CCTL1_OUTEN_Pos                  (9UL)                     /*!< PWM0 CCTL1: OUTEN (Bit 9)                                   */
#define PWM0_CCTL1_OUTEN_Msk                  (0x200UL)                 /*!< PWM0 CCTL1: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM0_CCTL2  --------------------------------- */
#define PWM0_CCTL2_CCIFG_Pos                  (0UL)                     /*!< PWM0 CCTL2: CCIFG (Bit 0)                                   */
#define PWM0_CCTL2_CCIFG_Msk                  (0x1UL)                   /*!< PWM0 CCTL2: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM0_CCTL2_OUT_Pos                    (2UL)                     /*!< PWM0 CCTL2: OUT (Bit 2)                                     */
#define PWM0_CCTL2_OUT_Msk                    (0x4UL)                   /*!< PWM0 CCTL2: OUT (Bitfield-Mask: 0x01)                       */
#define PWM0_CCTL2_CCIE_Pos                   (4UL)                     /*!< PWM0 CCTL2: CCIE (Bit 4)                                    */
#define PWM0_CCTL2_CCIE_Msk                   (0x10UL)                  /*!< PWM0 CCTL2: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM0_CCTL2_OUTMOD_Pos                 (5UL)                     /*!< PWM0 CCTL2: OUTMOD (Bit 5)                                  */
#define PWM0_CCTL2_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM0 CCTL2: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM0_CCTL2_OUTEN_Pos                  (9UL)                     /*!< PWM0 CCTL2: OUTEN (Bit 9)                                   */
#define PWM0_CCTL2_OUTEN_Msk                  (0x200UL)                 /*!< PWM0 CCTL2: OUTEN (Bitfield-Mask: 0x01)                     */

/* ----------------------------------  PWM0_CCR0  --------------------------------- */
#define PWM0_CCR0_CCRx_Pos                    (0UL)                     /*!< PWM0 CCR0: CCRx (Bit 0)                                     */
#define PWM0_CCR0_CCRx_Msk                    (0xffffUL)                /*!< PWM0 CCR0: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM0_CCR1  --------------------------------- */
#define PWM0_CCR1_CCRx_Pos                    (0UL)                     /*!< PWM0 CCR1: CCRx (Bit 0)                                     */
#define PWM0_CCR1_CCRx_Msk                    (0xffffUL)                /*!< PWM0 CCR1: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM0_CCR2  --------------------------------- */
#define PWM0_CCR2_CCRx_Pos                    (0UL)                     /*!< PWM0 CCR2: CCRx (Bit 0)                                     */
#define PWM0_CCR2_CCRx_Msk                    (0xffffUL)                /*!< PWM0 CCR2: CCRx (Bitfield-Mask: 0xffff)                     */


/* ================================================================================ */
/* ================          struct 'PWM1' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  PWM1_CTL  ---------------------------------- */
#define PWM1_CTL_IFG_Pos                      (0UL)                     /*!< PWM1 CTL: IFG (Bit 0)                                       */
#define PWM1_CTL_IFG_Msk                      (0x1UL)                   /*!< PWM1 CTL: IFG (Bitfield-Mask: 0x01)                         */
#define PWM1_CTL_IE_Pos                       (1UL)                     /*!< PWM1 CTL: IE (Bit 1)                                        */
#define PWM1_CTL_IE_Msk                       (0x2UL)                   /*!< PWM1 CTL: IE (Bitfield-Mask: 0x01)                          */
#define PWM1_CTL_CLR_Pos                      (2UL)                     /*!< PWM1 CTL: CLR (Bit 2)                                       */
#define PWM1_CTL_CLR_Msk                      (0x4UL)                   /*!< PWM1 CTL: CLR (Bitfield-Mask: 0x01)                         */
#define PWM1_CTL_TSEL_Pos                     (3UL)                     /*!< PWM1 CTL: TSEL (Bit 3)                                      */
#define PWM1_CTL_TSEL_Msk                     (0x8UL)                   /*!< PWM1 CTL: TSEL (Bitfield-Mask: 0x01)                        */
#define PWM1_CTL_MC_Pos                       (4UL)                     /*!< PWM1 CTL: MC (Bit 4)                                        */
#define PWM1_CTL_MC_Msk                       (0x30UL)                  /*!< PWM1 CTL: MC (Bitfield-Mask: 0x03)                          */
#define PWM1_CTL_ID_Pos                       (6UL)                     /*!< PWM1 CTL: ID (Bit 6)                                        */
#define PWM1_CTL_ID_Msk                       (0xc0UL)                  /*!< PWM1 CTL: ID (Bitfield-Mask: 0x03)                          */

/* ----------------------------------  PWM1_TAR  ---------------------------------- */
#define PWM1_TAR_TAR_Pos                      (0UL)                     /*!< PWM1 TAR: TAR (Bit 0)                                       */
#define PWM1_TAR_TAR_Msk                      (0xffffUL)                /*!< PWM1 TAR: TAR (Bitfield-Mask: 0xffff)                       */

/* ---------------------------------  PWM1_CCTL0  --------------------------------- */
#define PWM1_CCTL0_CCIFG_Pos                  (0UL)                     /*!< PWM1 CCTL0: CCIFG (Bit 0)                                   */
#define PWM1_CCTL0_CCIFG_Msk                  (0x1UL)                   /*!< PWM1 CCTL0: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM1_CCTL0_OUT_Pos                    (2UL)                     /*!< PWM1 CCTL0: OUT (Bit 2)                                     */
#define PWM1_CCTL0_OUT_Msk                    (0x4UL)                   /*!< PWM1 CCTL0: OUT (Bitfield-Mask: 0x01)                       */
#define PWM1_CCTL0_CCIE_Pos                   (4UL)                     /*!< PWM1 CCTL0: CCIE (Bit 4)                                    */
#define PWM1_CCTL0_CCIE_Msk                   (0x10UL)                  /*!< PWM1 CCTL0: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM1_CCTL0_OUTMOD_Pos                 (5UL)                     /*!< PWM1 CCTL0: OUTMOD (Bit 5)                                  */
#define PWM1_CCTL0_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM1 CCTL0: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM1_CCTL0_OUTEN_Pos                  (9UL)                     /*!< PWM1 CCTL0: OUTEN (Bit 9)                                   */
#define PWM1_CCTL0_OUTEN_Msk                  (0x200UL)                 /*!< PWM1 CCTL0: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM1_CCTL1  --------------------------------- */
#define PWM1_CCTL1_CCIFG_Pos                  (0UL)                     /*!< PWM1 CCTL1: CCIFG (Bit 0)                                   */
#define PWM1_CCTL1_CCIFG_Msk                  (0x1UL)                   /*!< PWM1 CCTL1: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM1_CCTL1_OUT_Pos                    (2UL)                     /*!< PWM1 CCTL1: OUT (Bit 2)                                     */
#define PWM1_CCTL1_OUT_Msk                    (0x4UL)                   /*!< PWM1 CCTL1: OUT (Bitfield-Mask: 0x01)                       */
#define PWM1_CCTL1_CCIE_Pos                   (4UL)                     /*!< PWM1 CCTL1: CCIE (Bit 4)                                    */
#define PWM1_CCTL1_CCIE_Msk                   (0x10UL)                  /*!< PWM1 CCTL1: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM1_CCTL1_OUTMOD_Pos                 (5UL)                     /*!< PWM1 CCTL1: OUTMOD (Bit 5)                                  */
#define PWM1_CCTL1_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM1 CCTL1: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM1_CCTL1_OUTEN_Pos                  (9UL)                     /*!< PWM1 CCTL1: OUTEN (Bit 9)                                   */
#define PWM1_CCTL1_OUTEN_Msk                  (0x200UL)                 /*!< PWM1 CCTL1: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM1_CCTL2  --------------------------------- */
#define PWM1_CCTL2_CCIFG_Pos                  (0UL)                     /*!< PWM1 CCTL2: CCIFG (Bit 0)                                   */
#define PWM1_CCTL2_CCIFG_Msk                  (0x1UL)                   /*!< PWM1 CCTL2: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM1_CCTL2_OUT_Pos                    (2UL)                     /*!< PWM1 CCTL2: OUT (Bit 2)                                     */
#define PWM1_CCTL2_OUT_Msk                    (0x4UL)                   /*!< PWM1 CCTL2: OUT (Bitfield-Mask: 0x01)                       */
#define PWM1_CCTL2_CCIE_Pos                   (4UL)                     /*!< PWM1 CCTL2: CCIE (Bit 4)                                    */
#define PWM1_CCTL2_CCIE_Msk                   (0x10UL)                  /*!< PWM1 CCTL2: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM1_CCTL2_OUTMOD_Pos                 (5UL)                     /*!< PWM1 CCTL2: OUTMOD (Bit 5)                                  */
#define PWM1_CCTL2_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM1 CCTL2: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM1_CCTL2_OUTEN_Pos                  (9UL)                     /*!< PWM1 CCTL2: OUTEN (Bit 9)                                   */
#define PWM1_CCTL2_OUTEN_Msk                  (0x200UL)                 /*!< PWM1 CCTL2: OUTEN (Bitfield-Mask: 0x01)                     */

/* ----------------------------------  PWM1_CCR0  --------------------------------- */
#define PWM1_CCR0_CCRx_Pos                    (0UL)                     /*!< PWM1 CCR0: CCRx (Bit 0)                                     */
#define PWM1_CCR0_CCRx_Msk                    (0xffffUL)                /*!< PWM1 CCR0: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM1_CCR1  --------------------------------- */
#define PWM1_CCR1_CCRx_Pos                    (0UL)                     /*!< PWM1 CCR1: CCRx (Bit 0)                                     */
#define PWM1_CCR1_CCRx_Msk                    (0xffffUL)                /*!< PWM1 CCR1: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM1_CCR2  --------------------------------- */
#define PWM1_CCR2_CCRx_Pos                    (0UL)                     /*!< PWM1 CCR2: CCRx (Bit 0)                                     */
#define PWM1_CCR2_CCRx_Msk                    (0xffffUL)                /*!< PWM1 CCR2: CCRx (Bitfield-Mask: 0xffff)                     */


/* ================================================================================ */
/* ================          struct 'PWM2' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  PWM2_CTL  ---------------------------------- */
#define PWM2_CTL_IFG_Pos                      (0UL)                     /*!< PWM2 CTL: IFG (Bit 0)                                       */
#define PWM2_CTL_IFG_Msk                      (0x1UL)                   /*!< PWM2 CTL: IFG (Bitfield-Mask: 0x01)                         */
#define PWM2_CTL_IE_Pos                       (1UL)                     /*!< PWM2 CTL: IE (Bit 1)                                        */
#define PWM2_CTL_IE_Msk                       (0x2UL)                   /*!< PWM2 CTL: IE (Bitfield-Mask: 0x01)                          */
#define PWM2_CTL_CLR_Pos                      (2UL)                     /*!< PWM2 CTL: CLR (Bit 2)                                       */
#define PWM2_CTL_CLR_Msk                      (0x4UL)                   /*!< PWM2 CTL: CLR (Bitfield-Mask: 0x01)                         */
#define PWM2_CTL_TSEL_Pos                     (3UL)                     /*!< PWM2 CTL: TSEL (Bit 3)                                      */
#define PWM2_CTL_TSEL_Msk                     (0x8UL)                   /*!< PWM2 CTL: TSEL (Bitfield-Mask: 0x01)                        */
#define PWM2_CTL_MC_Pos                       (4UL)                     /*!< PWM2 CTL: MC (Bit 4)                                        */
#define PWM2_CTL_MC_Msk                       (0x30UL)                  /*!< PWM2 CTL: MC (Bitfield-Mask: 0x03)                          */
#define PWM2_CTL_ID_Pos                       (6UL)                     /*!< PWM2 CTL: ID (Bit 6)                                        */
#define PWM2_CTL_ID_Msk                       (0xc0UL)                  /*!< PWM2 CTL: ID (Bitfield-Mask: 0x03)                          */

/* ----------------------------------  PWM2_TAR  ---------------------------------- */
#define PWM2_TAR_TAR_Pos                      (0UL)                     /*!< PWM2 TAR: TAR (Bit 0)                                       */
#define PWM2_TAR_TAR_Msk                      (0xffffUL)                /*!< PWM2 TAR: TAR (Bitfield-Mask: 0xffff)                       */

/* ---------------------------------  PWM2_CCTL0  --------------------------------- */
#define PWM2_CCTL0_CCIFG_Pos                  (0UL)                     /*!< PWM2 CCTL0: CCIFG (Bit 0)                                   */
#define PWM2_CCTL0_CCIFG_Msk                  (0x1UL)                   /*!< PWM2 CCTL0: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM2_CCTL0_OUT_Pos                    (2UL)                     /*!< PWM2 CCTL0: OUT (Bit 2)                                     */
#define PWM2_CCTL0_OUT_Msk                    (0x4UL)                   /*!< PWM2 CCTL0: OUT (Bitfield-Mask: 0x01)                       */
#define PWM2_CCTL0_CCIE_Pos                   (4UL)                     /*!< PWM2 CCTL0: CCIE (Bit 4)                                    */
#define PWM2_CCTL0_CCIE_Msk                   (0x10UL)                  /*!< PWM2 CCTL0: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM2_CCTL0_OUTMOD_Pos                 (5UL)                     /*!< PWM2 CCTL0: OUTMOD (Bit 5)                                  */
#define PWM2_CCTL0_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM2 CCTL0: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM2_CCTL0_OUTEN_Pos                  (9UL)                     /*!< PWM2 CCTL0: OUTEN (Bit 9)                                   */
#define PWM2_CCTL0_OUTEN_Msk                  (0x200UL)                 /*!< PWM2 CCTL0: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM2_CCTL1  --------------------------------- */
#define PWM2_CCTL1_CCIFG_Pos                  (0UL)                     /*!< PWM2 CCTL1: CCIFG (Bit 0)                                   */
#define PWM2_CCTL1_CCIFG_Msk                  (0x1UL)                   /*!< PWM2 CCTL1: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM2_CCTL1_OUT_Pos                    (2UL)                     /*!< PWM2 CCTL1: OUT (Bit 2)                                     */
#define PWM2_CCTL1_OUT_Msk                    (0x4UL)                   /*!< PWM2 CCTL1: OUT (Bitfield-Mask: 0x01)                       */
#define PWM2_CCTL1_CCIE_Pos                   (4UL)                     /*!< PWM2 CCTL1: CCIE (Bit 4)                                    */
#define PWM2_CCTL1_CCIE_Msk                   (0x10UL)                  /*!< PWM2 CCTL1: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM2_CCTL1_OUTMOD_Pos                 (5UL)                     /*!< PWM2 CCTL1: OUTMOD (Bit 5)                                  */
#define PWM2_CCTL1_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM2 CCTL1: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM2_CCTL1_OUTEN_Pos                  (9UL)                     /*!< PWM2 CCTL1: OUTEN (Bit 9)                                   */
#define PWM2_CCTL1_OUTEN_Msk                  (0x200UL)                 /*!< PWM2 CCTL1: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM2_CCTL2  --------------------------------- */
#define PWM2_CCTL2_CCIFG_Pos                  (0UL)                     /*!< PWM2 CCTL2: CCIFG (Bit 0)                                   */
#define PWM2_CCTL2_CCIFG_Msk                  (0x1UL)                   /*!< PWM2 CCTL2: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM2_CCTL2_OUT_Pos                    (2UL)                     /*!< PWM2 CCTL2: OUT (Bit 2)                                     */
#define PWM2_CCTL2_OUT_Msk                    (0x4UL)                   /*!< PWM2 CCTL2: OUT (Bitfield-Mask: 0x01)                       */
#define PWM2_CCTL2_CCIE_Pos                   (4UL)                     /*!< PWM2 CCTL2: CCIE (Bit 4)                                    */
#define PWM2_CCTL2_CCIE_Msk                   (0x10UL)                  /*!< PWM2 CCTL2: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM2_CCTL2_OUTMOD_Pos                 (5UL)                     /*!< PWM2 CCTL2: OUTMOD (Bit 5)                                  */
#define PWM2_CCTL2_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM2 CCTL2: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM2_CCTL2_OUTEN_Pos                  (9UL)                     /*!< PWM2 CCTL2: OUTEN (Bit 9)                                   */
#define PWM2_CCTL2_OUTEN_Msk                  (0x200UL)                 /*!< PWM2 CCTL2: OUTEN (Bitfield-Mask: 0x01)                     */

/* ----------------------------------  PWM2_CCR0  --------------------------------- */
#define PWM2_CCR0_CCRx_Pos                    (0UL)                     /*!< PWM2 CCR0: CCRx (Bit 0)                                     */
#define PWM2_CCR0_CCRx_Msk                    (0xffffUL)                /*!< PWM2 CCR0: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM2_CCR1  --------------------------------- */
#define PWM2_CCR1_CCRx_Pos                    (0UL)                     /*!< PWM2 CCR1: CCRx (Bit 0)                                     */
#define PWM2_CCR1_CCRx_Msk                    (0xffffUL)                /*!< PWM2 CCR1: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM2_CCR2  --------------------------------- */
#define PWM2_CCR2_CCRx_Pos                    (0UL)                     /*!< PWM2 CCR2: CCRx (Bit 0)                                     */
#define PWM2_CCR2_CCRx_Msk                    (0xffffUL)                /*!< PWM2 CCR2: CCRx (Bitfield-Mask: 0xffff)                     */


/* ================================================================================ */
/* ================          struct 'PWM3' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  PWM3_CTL  ---------------------------------- */
#define PWM3_CTL_IFG_Pos                      (0UL)                     /*!< PWM3 CTL: IFG (Bit 0)                                       */
#define PWM3_CTL_IFG_Msk                      (0x1UL)                   /*!< PWM3 CTL: IFG (Bitfield-Mask: 0x01)                         */
#define PWM3_CTL_IE_Pos                       (1UL)                     /*!< PWM3 CTL: IE (Bit 1)                                        */
#define PWM3_CTL_IE_Msk                       (0x2UL)                   /*!< PWM3 CTL: IE (Bitfield-Mask: 0x01)                          */
#define PWM3_CTL_CLR_Pos                      (2UL)                     /*!< PWM3 CTL: CLR (Bit 2)                                       */
#define PWM3_CTL_CLR_Msk                      (0x4UL)                   /*!< PWM3 CTL: CLR (Bitfield-Mask: 0x01)                         */
#define PWM3_CTL_TSEL_Pos                     (3UL)                     /*!< PWM3 CTL: TSEL (Bit 3)                                      */
#define PWM3_CTL_TSEL_Msk                     (0x8UL)                   /*!< PWM3 CTL: TSEL (Bitfield-Mask: 0x01)                        */
#define PWM3_CTL_MC_Pos                       (4UL)                     /*!< PWM3 CTL: MC (Bit 4)                                        */
#define PWM3_CTL_MC_Msk                       (0x30UL)                  /*!< PWM3 CTL: MC (Bitfield-Mask: 0x03)                          */
#define PWM3_CTL_ID_Pos                       (6UL)                     /*!< PWM3 CTL: ID (Bit 6)                                        */
#define PWM3_CTL_ID_Msk                       (0xc0UL)                  /*!< PWM3 CTL: ID (Bitfield-Mask: 0x03)                          */

/* ----------------------------------  PWM3_TAR  ---------------------------------- */
#define PWM3_TAR_TAR_Pos                      (0UL)                     /*!< PWM3 TAR: TAR (Bit 0)                                       */
#define PWM3_TAR_TAR_Msk                      (0xffffUL)                /*!< PWM3 TAR: TAR (Bitfield-Mask: 0xffff)                       */

/* ---------------------------------  PWM3_CCTL0  --------------------------------- */
#define PWM3_CCTL0_CCIFG_Pos                  (0UL)                     /*!< PWM3 CCTL0: CCIFG (Bit 0)                                   */
#define PWM3_CCTL0_CCIFG_Msk                  (0x1UL)                   /*!< PWM3 CCTL0: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM3_CCTL0_OUT_Pos                    (2UL)                     /*!< PWM3 CCTL0: OUT (Bit 2)                                     */
#define PWM3_CCTL0_OUT_Msk                    (0x4UL)                   /*!< PWM3 CCTL0: OUT (Bitfield-Mask: 0x01)                       */
#define PWM3_CCTL0_CCIE_Pos                   (4UL)                     /*!< PWM3 CCTL0: CCIE (Bit 4)                                    */
#define PWM3_CCTL0_CCIE_Msk                   (0x10UL)                  /*!< PWM3 CCTL0: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM3_CCTL0_OUTMOD_Pos                 (5UL)                     /*!< PWM3 CCTL0: OUTMOD (Bit 5)                                  */
#define PWM3_CCTL0_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM3 CCTL0: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM3_CCTL0_OUTEN_Pos                  (9UL)                     /*!< PWM3 CCTL0: OUTEN (Bit 9)                                   */
#define PWM3_CCTL0_OUTEN_Msk                  (0x200UL)                 /*!< PWM3 CCTL0: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM3_CCTL1  --------------------------------- */
#define PWM3_CCTL1_CCIFG_Pos                  (0UL)                     /*!< PWM3 CCTL1: CCIFG (Bit 0)                                   */
#define PWM3_CCTL1_CCIFG_Msk                  (0x1UL)                   /*!< PWM3 CCTL1: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM3_CCTL1_OUT_Pos                    (2UL)                     /*!< PWM3 CCTL1: OUT (Bit 2)                                     */
#define PWM3_CCTL1_OUT_Msk                    (0x4UL)                   /*!< PWM3 CCTL1: OUT (Bitfield-Mask: 0x01)                       */
#define PWM3_CCTL1_CCIE_Pos                   (4UL)                     /*!< PWM3 CCTL1: CCIE (Bit 4)                                    */
#define PWM3_CCTL1_CCIE_Msk                   (0x10UL)                  /*!< PWM3 CCTL1: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM3_CCTL1_OUTMOD_Pos                 (5UL)                     /*!< PWM3 CCTL1: OUTMOD (Bit 5)                                  */
#define PWM3_CCTL1_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM3 CCTL1: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM3_CCTL1_OUTEN_Pos                  (9UL)                     /*!< PWM3 CCTL1: OUTEN (Bit 9)                                   */
#define PWM3_CCTL1_OUTEN_Msk                  (0x200UL)                 /*!< PWM3 CCTL1: OUTEN (Bitfield-Mask: 0x01)                     */

/* ---------------------------------  PWM3_CCTL2  --------------------------------- */
#define PWM3_CCTL2_CCIFG_Pos                  (0UL)                     /*!< PWM3 CCTL2: CCIFG (Bit 0)                                   */
#define PWM3_CCTL2_CCIFG_Msk                  (0x1UL)                   /*!< PWM3 CCTL2: CCIFG (Bitfield-Mask: 0x01)                     */
#define PWM3_CCTL2_OUT_Pos                    (2UL)                     /*!< PWM3 CCTL2: OUT (Bit 2)                                     */
#define PWM3_CCTL2_OUT_Msk                    (0x4UL)                   /*!< PWM3 CCTL2: OUT (Bitfield-Mask: 0x01)                       */
#define PWM3_CCTL2_CCIE_Pos                   (4UL)                     /*!< PWM3 CCTL2: CCIE (Bit 4)                                    */
#define PWM3_CCTL2_CCIE_Msk                   (0x10UL)                  /*!< PWM3 CCTL2: CCIE (Bitfield-Mask: 0x01)                      */
#define PWM3_CCTL2_OUTMOD_Pos                 (5UL)                     /*!< PWM3 CCTL2: OUTMOD (Bit 5)                                  */
#define PWM3_CCTL2_OUTMOD_Msk                 (0xe0UL)                  /*!< PWM3 CCTL2: OUTMOD (Bitfield-Mask: 0x07)                    */
#define PWM3_CCTL2_OUTEN_Pos                  (9UL)                     /*!< PWM3 CCTL2: OUTEN (Bit 9)                                   */
#define PWM3_CCTL2_OUTEN_Msk                  (0x200UL)                 /*!< PWM3 CCTL2: OUTEN (Bitfield-Mask: 0x01)                     */

/* ----------------------------------  PWM3_CCR0  --------------------------------- */
#define PWM3_CCR0_CCRx_Pos                    (0UL)                     /*!< PWM3 CCR0: CCRx (Bit 0)                                     */
#define PWM3_CCR0_CCRx_Msk                    (0xffffUL)                /*!< PWM3 CCR0: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM3_CCR1  --------------------------------- */
#define PWM3_CCR1_CCRx_Pos                    (0UL)                     /*!< PWM3 CCR1: CCRx (Bit 0)                                     */
#define PWM3_CCR1_CCRx_Msk                    (0xffffUL)                /*!< PWM3 CCR1: CCRx (Bitfield-Mask: 0xffff)                     */

/* ----------------------------------  PWM3_CCR2  --------------------------------- */
#define PWM3_CCR2_CCRx_Pos                    (0UL)                     /*!< PWM3 CCR2: CCRx (Bit 0)                                     */
#define PWM3_CCR2_CCRx_Msk                    (0xffffUL)                /*!< PWM3 CCR2: CCRx (Bitfield-Mask: 0xffff)                     */


/* ================================================================================ */
/* ================         Group 'PWMOSEL' Position & Mask        ================ */
/* ================================================================================ */


/* --------------------------------  PWMOSEL_O_SEL  ------------------------------- */
#define PWMOSEL_O_SEL_O_SEL0_Pos              (0UL)                     /*!< PWMOSEL O_SEL: O_SEL0 (Bit 0)                               */
#define PWMOSEL_O_SEL_O_SEL0_Msk              (0xfUL)                   /*!< PWMOSEL O_SEL: O_SEL0 (Bitfield-Mask: 0x0f)                 */
#define PWMOSEL_O_SEL_O_SEL1_Pos              (4UL)                     /*!< PWMOSEL O_SEL: O_SEL1 (Bit 4)                               */
#define PWMOSEL_O_SEL_O_SEL1_Msk              (0xf0UL)                  /*!< PWMOSEL O_SEL: O_SEL1 (Bitfield-Mask: 0x0f)                 */
#define PWMOSEL_O_SEL_O_SEL2_Pos              (8UL)                     /*!< PWMOSEL O_SEL: O_SEL2 (Bit 8)                               */
#define PWMOSEL_O_SEL_O_SEL2_Msk              (0xf00UL)                 /*!< PWMOSEL O_SEL: O_SEL2 (Bitfield-Mask: 0x0f)                 */
#define PWMOSEL_O_SEL_O_SEL3_Pos              (12UL)                    /*!< PWMOSEL O_SEL: O_SEL3 (Bit 12)                              */
#define PWMOSEL_O_SEL_O_SEL3_Msk              (0xf000UL)                /*!< PWMOSEL O_SEL: O_SEL3 (Bitfield-Mask: 0x0f)                 */


/* ================================================================================ */
/* ================        struct 'PWMOSEL' Position & Mask        ================ */
/* ================================================================================ */


/* --------------------------------  PWMOSEL_O_SEL  ------------------------------- */
#define PWMOSEL_O_SEL_O_SEL0_Pos              (0UL)                     /*!< PWMOSEL O_SEL: O_SEL0 (Bit 0)                               */
#define PWMOSEL_O_SEL_O_SEL0_Msk              (0xfUL)                   /*!< PWMOSEL O_SEL: O_SEL0 (Bitfield-Mask: 0x0f)                 */
#define PWMOSEL_O_SEL_O_SEL1_Pos              (4UL)                     /*!< PWMOSEL O_SEL: O_SEL1 (Bit 4)                               */
#define PWMOSEL_O_SEL_O_SEL1_Msk              (0xf0UL)                  /*!< PWMOSEL O_SEL: O_SEL1 (Bitfield-Mask: 0x0f)                 */
#define PWMOSEL_O_SEL_O_SEL2_Pos              (8UL)                     /*!< PWMOSEL O_SEL: O_SEL2 (Bit 8)                               */
#define PWMOSEL_O_SEL_O_SEL2_Msk              (0xf00UL)                 /*!< PWMOSEL O_SEL: O_SEL2 (Bitfield-Mask: 0x0f)                 */
#define PWMOSEL_O_SEL_O_SEL3_Pos              (12UL)                    /*!< PWMOSEL O_SEL: O_SEL3 (Bit 12)                              */
#define PWMOSEL_O_SEL_O_SEL3_Msk              (0xf000UL)                /*!< PWMOSEL O_SEL: O_SEL3 (Bitfield-Mask: 0x0f)                 */


/* ================================================================================ */
/* ================          struct 'RTC' Position & Mask          ================ */
/* ================================================================================ */


/* -----------------------------------  RTC_SEC  ---------------------------------- */
#define RTC_SEC_SEC_Pos                       (0UL)                     /*!< RTC SEC: SEC (Bit 0)                                        */
#define RTC_SEC_SEC_Msk                       (0x7fUL)                  /*!< RTC SEC: SEC (Bitfield-Mask: 0x7f)                          */

/* -----------------------------------  RTC_MIN  ---------------------------------- */
#define RTC_MIN_MIN_Pos                       (0UL)                     /*!< RTC MIN: MIN (Bit 0)                                        */
#define RTC_MIN_MIN_Msk                       (0x7fUL)                  /*!< RTC MIN: MIN (Bitfield-Mask: 0x7f)                          */

/* ----------------------------------  RTC_HOUR  ---------------------------------- */
#define RTC_HOUR_HOUR_Pos                     (0UL)                     /*!< RTC HOUR: HOUR (Bit 0)                                      */
#define RTC_HOUR_HOUR_Msk                     (0x3fUL)                  /*!< RTC HOUR: HOUR (Bitfield-Mask: 0x3f)                        */

/* -----------------------------------  RTC_DAY  ---------------------------------- */
#define RTC_DAY_DAY_Pos                       (0UL)                     /*!< RTC DAY: DAY (Bit 0)                                        */
#define RTC_DAY_DAY_Msk                       (0x3fUL)                  /*!< RTC DAY: DAY (Bitfield-Mask: 0x3f)                          */

/* ----------------------------------  RTC_WEEK  ---------------------------------- */
#define RTC_WEEK_WEEK_Pos                     (0UL)                     /*!< RTC WEEK: WEEK (Bit 0)                                      */
#define RTC_WEEK_WEEK_Msk                     (0x7UL)                   /*!< RTC WEEK: WEEK (Bitfield-Mask: 0x07)                        */

/* -----------------------------------  RTC_MON  ---------------------------------- */
#define RTC_MON_MON_Pos                       (0UL)                     /*!< RTC MON: MON (Bit 0)                                        */
#define RTC_MON_MON_Msk                       (0x1fUL)                  /*!< RTC MON: MON (Bitfield-Mask: 0x1f)                          */

/* ----------------------------------  RTC_YEAR  ---------------------------------- */
#define RTC_YEAR_YEAR_Pos                     (0UL)                     /*!< RTC YEAR: YEAR (Bit 0)                                      */
#define RTC_YEAR_YEAR_Msk                     (0xffUL)                  /*!< RTC YEAR: YEAR (Bitfield-Mask: 0xff)                        */

/* ---------------------------------  RTC_WKUSEC  --------------------------------- */
#define RTC_WKUSEC_WKUSEC_Pos                 (0UL)                     /*!< RTC WKUSEC: WKUSEC (Bit 0)                                  */
#define RTC_WKUSEC_WKUSEC_Msk                 (0x3fUL)                  /*!< RTC WKUSEC: WKUSEC (Bitfield-Mask: 0x3f)                    */

/* ---------------------------------  RTC_WKUMIN  --------------------------------- */
#define RTC_WKUMIN_WKUMIN_Pos                 (0UL)                     /*!< RTC WKUMIN: WKUMIN (Bit 0)                                  */
#define RTC_WKUMIN_WKUMIN_Msk                 (0x3fUL)                  /*!< RTC WKUMIN: WKUMIN (Bitfield-Mask: 0x3f)                    */

/* ---------------------------------  RTC_WKUHOUR  -------------------------------- */
#define RTC_WKUHOUR_WKUHOUR_Pos               (0UL)                     /*!< RTC WKUHOUR: WKUHOUR (Bit 0)                                */
#define RTC_WKUHOUR_WKUHOUR_Msk               (0x1fUL)                  /*!< RTC WKUHOUR: WKUHOUR (Bitfield-Mask: 0x1f)                  */

/* ---------------------------------  RTC_WKUCNT  --------------------------------- */
#define RTC_WKUCNT_WKUCNT_Pos                 (0UL)                     /*!< RTC WKUCNT: WKUCNT (Bit 0)                                  */
#define RTC_WKUCNT_WKUCNT_Msk                 (0xffffffUL)              /*!< RTC WKUCNT: WKUCNT (Bitfield-Mask: 0xffffff)                */
#define RTC_WKUCNT_CNTSEL_Pos                 (24UL)                    /*!< RTC WKUCNT: CNTSEL (Bit 24)                                 */
#define RTC_WKUCNT_CNTSEL_Msk                 (0x3000000UL)             /*!< RTC WKUCNT: CNTSEL (Bitfield-Mask: 0x03)                    */

/* -----------------------------------  RTC_CAL  ---------------------------------- */
#define RTC_CAL_CAL_Pos                       (0UL)                     /*!< RTC CAL: CAL (Bit 0)                                        */
#define RTC_CAL_CAL_Msk                       (0x3fffUL)                /*!< RTC CAL: CAL (Bitfield-Mask: 0x3fff)                        */

/* -----------------------------------  RTC_DIV  ---------------------------------- */
#define RTC_DIV_RTCDIV_Pos                    (0UL)                     /*!< RTC DIV: RTCDIV (Bit 0)                                     */
#define RTC_DIV_RTCDIV_Msk                    (0x3ffffffUL)             /*!< RTC DIV: RTCDIV (Bitfield-Mask: 0x3ffffff)                  */

/* -----------------------------------  RTC_CTL  ---------------------------------- */
#define RTC_CTL_RTCPLLOE_Pos                  (2UL)                     /*!< RTC CTL: RTCPLLOE (Bit 2)                                   */
#define RTC_CTL_RTCPLLOE_Msk                  (0x4UL)                   /*!< RTC CTL: RTCPLLOE (Bitfield-Mask: 0x01)                     */

/* -----------------------------------  RTC_PWD  ---------------------------------- */
#define RTC_PWD_PWDEN_Pos                     (0UL)                     /*!< RTC PWD: PWDEN (Bit 0)                                      */
#define RTC_PWD_PWDEN_Msk                     (0x1UL)                   /*!< RTC PWD: PWDEN (Bitfield-Mask: 0x01)                        */

/* -----------------------------------  RTC_CE  ----------------------------------- */
#define RTC_CE_CE_Pos                         (0UL)                     /*!< RTC CE: CE (Bit 0)                                          */
#define RTC_CE_CE_Msk                         (0x1UL)                   /*!< RTC CE: CE (Bitfield-Mask: 0x01)                            */
#define RTC_CE_BSY_Pos                        (1UL)                     /*!< RTC CE: BSY (Bit 1)                                         */
#define RTC_CE_BSY_Msk                        (0x2UL)                   /*!< RTC CE: BSY (Bitfield-Mask: 0x01)                           */

/* ----------------------------------  RTC_LOAD  ---------------------------------- */
#define RTC_LOAD_LOAD_Pos                     (0UL)                     /*!< RTC LOAD: LOAD (Bit 0)                                      */
#define RTC_LOAD_LOAD_Msk                     (0xffffffffUL)            /*!< RTC LOAD: LOAD (Bitfield-Mask: 0xffffffff)                  */

/* ---------------------------------  RTC_INTSTS  --------------------------------- */
#define RTC_INTSTS_INTSTS1_Pos                (1UL)                     /*!< RTC INTSTS: INTSTS1 (Bit 1)                                 */
#define RTC_INTSTS_INTSTS1_Msk                (0x2UL)                   /*!< RTC INTSTS: INTSTS1 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS2_Pos                (2UL)                     /*!< RTC INTSTS: INTSTS2 (Bit 2)                                 */
#define RTC_INTSTS_INTSTS2_Msk                (0x4UL)                   /*!< RTC INTSTS: INTSTS2 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS3_Pos                (3UL)                     /*!< RTC INTSTS: INTSTS3 (Bit 3)                                 */
#define RTC_INTSTS_INTSTS3_Msk                (0x8UL)                   /*!< RTC INTSTS: INTSTS3 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS4_Pos                (4UL)                     /*!< RTC INTSTS: INTSTS4 (Bit 4)                                 */
#define RTC_INTSTS_INTSTS4_Msk                (0x10UL)                  /*!< RTC INTSTS: INTSTS4 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS5_Pos                (5UL)                     /*!< RTC INTSTS: INTSTS5 (Bit 5)                                 */
#define RTC_INTSTS_INTSTS5_Msk                (0x20UL)                  /*!< RTC INTSTS: INTSTS5 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS6_Pos                (6UL)                     /*!< RTC INTSTS: INTSTS6 (Bit 6)                                 */
#define RTC_INTSTS_INTSTS6_Msk                (0x40UL)                  /*!< RTC INTSTS: INTSTS6 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS7_Pos                (7UL)                     /*!< RTC INTSTS: INTSTS7 (Bit 7)                                 */
#define RTC_INTSTS_INTSTS7_Msk                (0x80UL)                  /*!< RTC INTSTS: INTSTS7 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_INTSTS8_Pos                (8UL)                     /*!< RTC INTSTS: INTSTS8 (Bit 8)                                 */
#define RTC_INTSTS_INTSTS8_Msk                (0x100UL)                 /*!< RTC INTSTS: INTSTS8 (Bitfield-Mask: 0x01)                   */
#define RTC_INTSTS_ACBSY_Pos                  (9UL)                     /*!< RTC INTSTS: ACBSY (Bit 9)                                   */
#define RTC_INTSTS_ACBSY_Msk                  (0x200UL)                 /*!< RTC INTSTS: ACBSY (Bitfield-Mask: 0x01)                     */

/* ----------------------------------  RTC_INTEN  --------------------------------- */
#define RTC_INTEN_INTEN1_Pos                  (1UL)                     /*!< RTC INTEN: INTEN1 (Bit 1)                                   */
#define RTC_INTEN_INTEN1_Msk                  (0x2UL)                   /*!< RTC INTEN: INTEN1 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTEN2_Pos                  (2UL)                     /*!< RTC INTEN: INTEN2 (Bit 2)                                   */
#define RTC_INTEN_INTEN2_Msk                  (0x4UL)                   /*!< RTC INTEN: INTEN2 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTRN3_Pos                  (3UL)                     /*!< RTC INTEN: INTRN3 (Bit 3)                                   */
#define RTC_INTEN_INTRN3_Msk                  (0x8UL)                   /*!< RTC INTEN: INTRN3 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTEN4_Pos                  (4UL)                     /*!< RTC INTEN: INTEN4 (Bit 4)                                   */
#define RTC_INTEN_INTEN4_Msk                  (0x10UL)                  /*!< RTC INTEN: INTEN4 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTEN5_Pos                  (5UL)                     /*!< RTC INTEN: INTEN5 (Bit 5)                                   */
#define RTC_INTEN_INTEN5_Msk                  (0x20UL)                  /*!< RTC INTEN: INTEN5 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTEN6_Pos                  (6UL)                     /*!< RTC INTEN: INTEN6 (Bit 6)                                   */
#define RTC_INTEN_INTEN6_Msk                  (0x40UL)                  /*!< RTC INTEN: INTEN6 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTEN7_Pos                  (7UL)                     /*!< RTC INTEN: INTEN7 (Bit 7)                                   */
#define RTC_INTEN_INTEN7_Msk                  (0x80UL)                  /*!< RTC INTEN: INTEN7 (Bitfield-Mask: 0x01)                     */
#define RTC_INTEN_INTEN8_Pos                  (8UL)                     /*!< RTC INTEN: INTEN8 (Bit 8)                                   */
#define RTC_INTEN_INTEN8_Msk                  (0x100UL)                 /*!< RTC INTEN: INTEN8 (Bitfield-Mask: 0x01)                     */

/* ----------------------------------  RTC_PSCA  ---------------------------------- */
#define RTC_PSCA_PSCA_Pos                     (0UL)                     /*!< RTC PSCA: PSCA (Bit 0)                                      */
#define RTC_PSCA_PSCA_Msk                     (0x3UL)                   /*!< RTC PSCA: PSCA (Bitfield-Mask: 0x03)                        */

/* ---------------------------------  RTC_ACCTRL  --------------------------------- */
#define RTC_ACCTRL_ADCEN_Pos                  (0UL)                     /*!< RTC ACCTRL: ADCEN (Bit 0)                                   */
#define RTC_ACCTRL_ADCEN_Msk                  (0x1UL)                   /*!< RTC ACCTRL: ADCEN (Bitfield-Mask: 0x01)                     */
#define RTC_ACCTRL_MANU_Pos                   (1UL)                     /*!< RTC ACCTRL: MANU (Bit 1)                                    */
#define RTC_ACCTRL_MANU_Msk                   (0x2UL)                   /*!< RTC ACCTRL: MANU (Bitfield-Mask: 0x01)                      */
#define RTC_ACCTRL_ADCSEL_Pos                 (3UL)                     /*!< RTC ACCTRL: ADCSEL (Bit 3)                                  */
#define RTC_ACCTRL_ADCSEL_Msk                 (0x8UL)                   /*!< RTC ACCTRL: ADCSEL (Bitfield-Mask: 0x01)                    */
#define RTC_ACCTRL_ACCLK_Pos                  (4UL)                     /*!< RTC ACCTRL: ACCLK (Bit 4)                                   */
#define RTC_ACCTRL_ACCLK_Msk                  (0x30UL)                  /*!< RTC ACCTRL: ACCLK (Bitfield-Mask: 0x03)                     */
#define RTC_ACCTRL_ACDEL_Pos                  (6UL)                     /*!< RTC ACCTRL: ACDEL (Bit 6)                                   */
#define RTC_ACCTRL_ACDEL_Msk                  (0xc0UL)                  /*!< RTC ACCTRL: ACDEL (Bitfield-Mask: 0x03)                     */
#define RTC_ACCTRL_ACPER_Pos                  (8UL)                     /*!< RTC ACCTRL: ACPER (Bit 8)                                   */
#define RTC_ACCTRL_ACPER_Msk                  (0x3f00UL)                /*!< RTC ACCTRL: ACPER (Bitfield-Mask: 0x3f)                     */

/* ----------------------------------  RTC_ACTI  ---------------------------------- */
#define RTC_ACTI_ACTI_Pos                     (0UL)                     /*!< RTC ACTI: ACTI (Bit 0)                                      */
#define RTC_ACTI_ACTI_Msk                     (0xffffUL)                /*!< RTC ACTI: ACTI (Bitfield-Mask: 0xffff)                      */

/* ---------------------------------  RTC_ACF200  --------------------------------- */
#define RTC_ACF200_F200_Pos                   (0UL)                     /*!< RTC ACF200: F200 (Bit 0)                                    */
#define RTC_ACF200_F200_Msk                   (0x3ffffffUL)             /*!< RTC ACF200: F200 (Bitfield-Mask: 0x3ffffff)                 */

/* ---------------------------------  RTC_ACADCW  --------------------------------- */
#define RTC_ACADCW_ADCW_Pos                   (0UL)                     /*!< RTC ACADCW: ADCW (Bit 0)                                    */
#define RTC_ACADCW_ADCW_Msk                   (0xffffUL)                /*!< RTC ACADCW: ADCW (Bitfield-Mask: 0xffff)                    */

/* ----------------------------------  RTC_ACP0  ---------------------------------- */
#define RTC_ACP0_Px_Pos                       (0UL)                     /*!< RTC ACP0: Px (Bit 0)                                        */
#define RTC_ACP0_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP0: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP1  ---------------------------------- */
#define RTC_ACP1_Px_Pos                       (0UL)                     /*!< RTC ACP1: Px (Bit 0)                                        */
#define RTC_ACP1_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP1: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP2  ---------------------------------- */
#define RTC_ACP2_Px_Pos                       (0UL)                     /*!< RTC ACP2: Px (Bit 0)                                        */
#define RTC_ACP2_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP2: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP3  ---------------------------------- */
#define RTC_ACP3_Px_Pos                       (0UL)                     /*!< RTC ACP3: Px (Bit 0)                                        */
#define RTC_ACP3_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP3: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP4  ---------------------------------- */
#define RTC_ACP4_Px_Pos                       (0UL)                     /*!< RTC ACP4: Px (Bit 0)                                        */
#define RTC_ACP4_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP4: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP5  ---------------------------------- */
#define RTC_ACP5_Px_Pos                       (0UL)                     /*!< RTC ACP5: Px (Bit 0)                                        */
#define RTC_ACP5_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP5: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP6  ---------------------------------- */
#define RTC_ACP6_Px_Pos                       (0UL)                     /*!< RTC ACP6: Px (Bit 0)                                        */
#define RTC_ACP6_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP6: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACP7  ---------------------------------- */
#define RTC_ACP7_Px_Pos                       (0UL)                     /*!< RTC ACP7: Px (Bit 0)                                        */
#define RTC_ACP7_Px_Msk                       (0xffffffffUL)            /*!< RTC ACP7: Px (Bitfield-Mask: 0xffffffff)                    */

/* ----------------------------------  RTC_ACK1  ---------------------------------- */
#define RTC_ACK1_Kx_Pos                       (0UL)                     /*!< RTC ACK1: Kx (Bit 0)                                        */
#define RTC_ACK1_Kx_Msk                       (0xffffUL)                /*!< RTC ACK1: Kx (Bitfield-Mask: 0xffff)                        */

/* ----------------------------------  RTC_ACK2  ---------------------------------- */
#define RTC_ACK2_Kx_Pos                       (0UL)                     /*!< RTC ACK2: Kx (Bit 0)                                        */
#define RTC_ACK2_Kx_Msk                       (0xffffUL)                /*!< RTC ACK2: Kx (Bitfield-Mask: 0xffff)                        */

/* ----------------------------------  RTC_ACK3  ---------------------------------- */
#define RTC_ACK3_Kx_Pos                       (0UL)                     /*!< RTC ACK3: Kx (Bit 0)                                        */
#define RTC_ACK3_Kx_Msk                       (0xffffUL)                /*!< RTC ACK3: Kx (Bitfield-Mask: 0xffff)                        */

/* ----------------------------------  RTC_ACK4  ---------------------------------- */
#define RTC_ACK4_Kx_Pos                       (0UL)                     /*!< RTC ACK4: Kx (Bit 0)                                        */
#define RTC_ACK4_Kx_Msk                       (0xffffUL)                /*!< RTC ACK4: Kx (Bitfield-Mask: 0xffff)                        */

/* ----------------------------------  RTC_ACK5  ---------------------------------- */
#define RTC_ACK5_Kx_Pos                       (0UL)                     /*!< RTC ACK5: Kx (Bit 0)                                        */
#define RTC_ACK5_Kx_Msk                       (0xffffUL)                /*!< RTC ACK5: Kx (Bitfield-Mask: 0xffff)                        */

/* ---------------------------------  RTC_ACTEMP  --------------------------------- */
#define RTC_ACTEMP_TEMP_Pos                   (0UL)                     /*!< RTC ACTEMP: TEMP (Bit 0)                                    */
#define RTC_ACTEMP_TEMP_Msk                   (0xffffUL)                /*!< RTC ACTEMP: TEMP (Bitfield-Mask: 0xffff)                    */

/* ----------------------------------  RTC_ACPPM  --------------------------------- */
#define RTC_ACPPM_PPM_Pos                     (0UL)                     /*!< RTC ACPPM: PPM (Bit 0)                                      */
#define RTC_ACPPM_PPM_Msk                     (0xffffUL)                /*!< RTC ACPPM: PPM (Bitfield-Mask: 0xffff)                      */

/* ---------------------------------  RTC_WKUCNTR  -------------------------------- */
#define RTC_WKUCNTR_WKUCNTR_Pos               (0UL)                     /*!< RTC WKUCNTR: WKUCNTR (Bit 0)                                */
#define RTC_WKUCNTR_WKUCNTR_Msk               (0xffffffUL)              /*!< RTC WKUCNTR: WKUCNTR (Bitfield-Mask: 0xffffff)              */

/* ---------------------------------  RTC_ACKTEMP  -------------------------------- */
#define RTC_ACKTEMP_KTEMP1_Pos                (0UL)                     /*!< RTC ACKTEMP: KTEMP1 (Bit 0)                                 */
#define RTC_ACKTEMP_KTEMP1_Msk                (0xffUL)                  /*!< RTC ACKTEMP: KTEMP1 (Bitfield-Mask: 0xff)                   */
#define RTC_ACKTEMP_KTEMP2_Pos                (8UL)                     /*!< RTC ACKTEMP: KTEMP2 (Bit 8)                                 */
#define RTC_ACKTEMP_KTEMP2_Msk                (0xff00UL)                /*!< RTC ACKTEMP: KTEMP2 (Bitfield-Mask: 0xff)                   */
#define RTC_ACKTEMP_KTEMP3_Pos                (16UL)                    /*!< RTC ACKTEMP: KTEMP3 (Bit 16)                                */
#define RTC_ACKTEMP_KTEMP3_Msk                (0xff0000UL)              /*!< RTC ACKTEMP: KTEMP3 (Bitfield-Mask: 0xff)                   */
#define RTC_ACKTEMP_KTEMP4_Pos                (24UL)                    /*!< RTC ACKTEMP: KTEMP4 (Bit 24)                                */
#define RTC_ACKTEMP_KTEMP4_Msk                (0xff000000UL)            /*!< RTC ACKTEMP: KTEMP4 (Bitfield-Mask: 0xff)                   */


/* ================================================================================ */
/* ================           Group 'SPI' Position & Mask          ================ */
/* ================================================================================ */


/* ----------------------------------  SPI_CTRL  ---------------------------------- */
#define SPI_CTRL_SCKSEL_Pos                   (0UL)                     /*!< SPI CTRL: SCKSEL (Bit 0)                                    */
#define SPI_CTRL_SCKSEL_Msk                   (0x7UL)                   /*!< SPI CTRL: SCKSEL (Bitfield-Mask: 0x07)                      */
#define SPI_CTRL_SCKPOL_Pos                   (4UL)                     /*!< SPI CTRL: SCKPOL (Bit 4)                                    */
#define SPI_CTRL_SCKPOL_Msk                   (0x10UL)                  /*!< SPI CTRL: SCKPOL (Bitfield-Mask: 0x01)                      */
#define SPI_CTRL_SCKPHA_Pos                   (5UL)                     /*!< SPI CTRL: SCKPHA (Bit 5)                                    */
#define SPI_CTRL_SCKPHA_Msk                   (0x20UL)                  /*!< SPI CTRL: SCKPHA (Bitfield-Mask: 0x01)                      */
#define SPI_CTRL_MOD_Pos                      (8UL)                     /*!< SPI CTRL: MOD (Bit 8)                                       */
#define SPI_CTRL_MOD_Msk                      (0x100UL)                 /*!< SPI CTRL: MOD (Bitfield-Mask: 0x01)                         */
#define SPI_CTRL_SWAP_Pos                     (9UL)                     /*!< SPI CTRL: SWAP (Bit 9)                                      */
#define SPI_CTRL_SWAP_Msk                     (0x200UL)                 /*!< SPI CTRL: SWAP (Bitfield-Mask: 0x01)                        */
#define SPI_CTRL_CSGPIO_Pos                   (10UL)                    /*!< SPI CTRL: CSGPIO (Bit 10)                                   */
#define SPI_CTRL_CSGPIO_Msk                   (0x400UL)                 /*!< SPI CTRL: CSGPIO (Bitfield-Mask: 0x01)                      */
#define SPI_CTRL_SPIRST_Pos                   (11UL)                    /*!< SPI CTRL: SPIRST (Bit 11)                                   */
#define SPI_CTRL_SPIRST_Msk                   (0x800UL)                 /*!< SPI CTRL: SPIRST (Bitfield-Mask: 0x01)                      */
#define SPI_CTRL_SPIEN_Pos                    (15UL)                    /*!< SPI CTRL: SPIEN (Bit 15)                                    */
#define SPI_CTRL_SPIEN_Msk                    (0x8000UL)                /*!< SPI CTRL: SPIEN (Bitfield-Mask: 0x01)                       */

/* ----------------------------------  SPI_TXSTS  --------------------------------- */
#define SPI_TXSTS_TXFFLAG_Pos                 (0UL)                     /*!< SPI TXSTS: TXFFLAG (Bit 0)                                  */
#define SPI_TXSTS_TXFFLAG_Msk                 (0x7UL)                   /*!< SPI TXSTS: TXFFLAG (Bitfield-Mask: 0x07)                    */
#define SPI_TXSTS_TXFLEV_Pos                  (4UL)                     /*!< SPI TXSTS: TXFLEV (Bit 4)                                   */
#define SPI_TXSTS_TXFLEV_Msk                  (0x70UL)                  /*!< SPI TXSTS: TXFLEV (Bitfield-Mask: 0x07)                     */
#define SPI_TXSTS_TXFUR_Pos                   (8UL)                     /*!< SPI TXSTS: TXFUR (Bit 8)                                    */
#define SPI_TXSTS_TXFUR_Msk                   (0x100UL)                 /*!< SPI TXSTS: TXFUR (Bitfield-Mask: 0x01)                      */
#define SPI_TXSTS_TXEMPTY_Pos                 (9UL)                     /*!< SPI TXSTS: TXEMPTY (Bit 9)                                  */
#define SPI_TXSTS_TXEMPTY_Msk                 (0x200UL)                 /*!< SPI TXSTS: TXEMPTY (Bitfield-Mask: 0x01)                    */
#define SPI_TXSTS_SPITXIEN_Pos                (14UL)                    /*!< SPI TXSTS: SPITXIEN (Bit 14)                                */
#define SPI_TXSTS_SPITXIEN_Msk                (0x4000UL)                /*!< SPI TXSTS: SPITXIEN (Bitfield-Mask: 0x01)                   */
#define SPI_TXSTS_SPITXIF_Pos                 (15UL)                    /*!< SPI TXSTS: SPITXIF (Bit 15)                                 */
#define SPI_TXSTS_SPITXIF_Msk                 (0x8000UL)                /*!< SPI TXSTS: SPITXIF (Bitfield-Mask: 0x01)                    */

/* ----------------------------------  SPI_TXDAT  --------------------------------- */
#define SPI_TXDAT_SPITXD_Pos                  (0UL)                     /*!< SPI TXDAT: SPITXD (Bit 0)                                   */
#define SPI_TXDAT_SPITXD_Msk                  (0xffUL)                  /*!< SPI TXDAT: SPITXD (Bitfield-Mask: 0xff)                     */

/* ----------------------------------  SPI_RXSTS  --------------------------------- */
#define SPI_RXSTS_RXFFLAG_Pos                 (0UL)                     /*!< SPI RXSTS: RXFFLAG (Bit 0)                                  */
#define SPI_RXSTS_RXFFLAG_Msk                 (0x7UL)                   /*!< SPI RXSTS: RXFFLAG (Bitfield-Mask: 0x07)                    */
#define SPI_RXSTS_RXFLEV_Pos                  (4UL)                     /*!< SPI RXSTS: RXFLEV (Bit 4)                                   */
#define SPI_RXSTS_RXFLEV_Msk                  (0x70UL)                  /*!< SPI RXSTS: RXFLEV (Bitfield-Mask: 0x07)                     */
#define SPI_RXSTS_RXFOV_Pos                   (8UL)                     /*!< SPI RXSTS: RXFOV (Bit 8)                                    */
#define SPI_RXSTS_RXFOV_Msk                   (0x100UL)                 /*!< SPI RXSTS: RXFOV (Bitfield-Mask: 0x01)                      */
#define SPI_RXSTS_RXFULL_Pos                  (9UL)                     /*!< SPI RXSTS: RXFULL (Bit 9)                                   */
#define SPI_RXSTS_RXFULL_Msk                  (0x200UL)                 /*!< SPI RXSTS: RXFULL (Bitfield-Mask: 0x01)                     */
#define SPI_RXSTS_SPIRXIEN_Pos                (14UL)                    /*!< SPI RXSTS: SPIRXIEN (Bit 14)                                */
#define SPI_RXSTS_SPIRXIEN_Msk                (0x4000UL)                /*!< SPI RXSTS: SPIRXIEN (Bitfield-Mask: 0x01)                   */
#define SPI_RXSTS_SPIRXIF_Pos                 (15UL)                    /*!< SPI RXSTS: SPIRXIF (Bit 15)                                 */
#define SPI_RXSTS_SPIRXIF_Msk                 (0x8000UL)                /*!< SPI RXSTS: SPIRXIF (Bitfield-Mask: 0x01)                    */

/* ----------------------------------  SPI_RXDAT  --------------------------------- */
#define SPI_RXDAT_SPIRXD_Pos                  (0UL)                     /*!< SPI RXDAT: SPIRXD (Bit 0)                                   */
#define SPI_RXDAT_SPIRXD_Msk                  (0xffUL)                  /*!< SPI RXDAT: SPIRXD (Bitfield-Mask: 0xff)                     */

/* ----------------------------------  SPI_MISC  ---------------------------------- */
#define SPI_MISC_TFE_Pos                      (0UL)                     /*!< SPI MISC: TFE (Bit 0)                                       */
#define SPI_MISC_TFE_Msk                      (0x1UL)                   /*!< SPI MISC: TFE (Bitfield-Mask: 0x01)                         */
#define SPI_MISC_TNF_Pos                      (1UL)                     /*!< SPI MISC: TNF (Bit 1)                                       */
#define SPI_MISC_TNF_Msk                      (0x2UL)                   /*!< SPI MISC: TNF (Bitfield-Mask: 0x01)                         */
#define SPI_MISC_RNE_Pos                      (2UL)                     /*!< SPI MISC: RNE (Bit 2)                                       */
#define SPI_MISC_RNE_Msk                      (0x4UL)                   /*!< SPI MISC: RNE (Bitfield-Mask: 0x01)                         */
#define SPI_MISC_RFF_Pos                      (3UL)                     /*!< SPI MISC: RFF (Bit 3)                                       */
#define SPI_MISC_RFF_Msk                      (0x8UL)                   /*!< SPI MISC: RFF (Bitfield-Mask: 0x01)                         */
#define SPI_MISC_BSY_Pos                      (4UL)                     /*!< SPI MISC: BSY (Bit 4)                                       */
#define SPI_MISC_BSY_Msk                      (0x10UL)                  /*!< SPI MISC: BSY (Bitfield-Mask: 0x01)                         */
#define SPI_MISC_SMART_Pos                    (8UL)                     /*!< SPI MISC: SMART (Bit 8)                                     */
#define SPI_MISC_SMART_Msk                    (0x100UL)                 /*!< SPI MISC: SMART (Bitfield-Mask: 0x01)                       */
#define SPI_MISC_OVER_Pos                     (9UL)                     /*!< SPI MISC: OVER (Bit 9)                                      */
#define SPI_MISC_OVER_Msk                     (0x200UL)                 /*!< SPI MISC: OVER (Bitfield-Mask: 0x01)                        */


/* ================================================================================ */
/* ================          struct 'SPI1' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  SPI1_CTRL  --------------------------------- */
#define SPI1_CTRL_SCKSEL_Pos                  (0UL)                     /*!< SPI1 CTRL: SCKSEL (Bit 0)                                   */
#define SPI1_CTRL_SCKSEL_Msk                  (0x7UL)                   /*!< SPI1 CTRL: SCKSEL (Bitfield-Mask: 0x07)                     */
#define SPI1_CTRL_SCKPOL_Pos                  (4UL)                     /*!< SPI1 CTRL: SCKPOL (Bit 4)                                   */
#define SPI1_CTRL_SCKPOL_Msk                  (0x10UL)                  /*!< SPI1 CTRL: SCKPOL (Bitfield-Mask: 0x01)                     */
#define SPI1_CTRL_SCKPHA_Pos                  (5UL)                     /*!< SPI1 CTRL: SCKPHA (Bit 5)                                   */
#define SPI1_CTRL_SCKPHA_Msk                  (0x20UL)                  /*!< SPI1 CTRL: SCKPHA (Bitfield-Mask: 0x01)                     */
#define SPI1_CTRL_MOD_Pos                     (8UL)                     /*!< SPI1 CTRL: MOD (Bit 8)                                      */
#define SPI1_CTRL_MOD_Msk                     (0x100UL)                 /*!< SPI1 CTRL: MOD (Bitfield-Mask: 0x01)                        */
#define SPI1_CTRL_SWAP_Pos                    (9UL)                     /*!< SPI1 CTRL: SWAP (Bit 9)                                     */
#define SPI1_CTRL_SWAP_Msk                    (0x200UL)                 /*!< SPI1 CTRL: SWAP (Bitfield-Mask: 0x01)                       */
#define SPI1_CTRL_CSGPIO_Pos                  (10UL)                    /*!< SPI1 CTRL: CSGPIO (Bit 10)                                  */
#define SPI1_CTRL_CSGPIO_Msk                  (0x400UL)                 /*!< SPI1 CTRL: CSGPIO (Bitfield-Mask: 0x01)                     */
#define SPI1_CTRL_SPIRST_Pos                  (11UL)                    /*!< SPI1 CTRL: SPIRST (Bit 11)                                  */
#define SPI1_CTRL_SPIRST_Msk                  (0x800UL)                 /*!< SPI1 CTRL: SPIRST (Bitfield-Mask: 0x01)                     */
#define SPI1_CTRL_SPIEN_Pos                   (15UL)                    /*!< SPI1 CTRL: SPIEN (Bit 15)                                   */
#define SPI1_CTRL_SPIEN_Msk                   (0x8000UL)                /*!< SPI1 CTRL: SPIEN (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  SPI1_TXSTS  --------------------------------- */
#define SPI1_TXSTS_TXFFLAG_Pos                (0UL)                     /*!< SPI1 TXSTS: TXFFLAG (Bit 0)                                 */
#define SPI1_TXSTS_TXFFLAG_Msk                (0x7UL)                   /*!< SPI1 TXSTS: TXFFLAG (Bitfield-Mask: 0x07)                   */
#define SPI1_TXSTS_TXFLEV_Pos                 (4UL)                     /*!< SPI1 TXSTS: TXFLEV (Bit 4)                                  */
#define SPI1_TXSTS_TXFLEV_Msk                 (0x70UL)                  /*!< SPI1 TXSTS: TXFLEV (Bitfield-Mask: 0x07)                    */
#define SPI1_TXSTS_TXFUR_Pos                  (8UL)                     /*!< SPI1 TXSTS: TXFUR (Bit 8)                                   */
#define SPI1_TXSTS_TXFUR_Msk                  (0x100UL)                 /*!< SPI1 TXSTS: TXFUR (Bitfield-Mask: 0x01)                     */
#define SPI1_TXSTS_TXEMPTY_Pos                (9UL)                     /*!< SPI1 TXSTS: TXEMPTY (Bit 9)                                 */
#define SPI1_TXSTS_TXEMPTY_Msk                (0x200UL)                 /*!< SPI1 TXSTS: TXEMPTY (Bitfield-Mask: 0x01)                   */
#define SPI1_TXSTS_SPITXIEN_Pos               (14UL)                    /*!< SPI1 TXSTS: SPITXIEN (Bit 14)                               */
#define SPI1_TXSTS_SPITXIEN_Msk               (0x4000UL)                /*!< SPI1 TXSTS: SPITXIEN (Bitfield-Mask: 0x01)                  */
#define SPI1_TXSTS_SPITXIF_Pos                (15UL)                    /*!< SPI1 TXSTS: SPITXIF (Bit 15)                                */
#define SPI1_TXSTS_SPITXIF_Msk                (0x8000UL)                /*!< SPI1 TXSTS: SPITXIF (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  SPI1_TXDAT  --------------------------------- */
#define SPI1_TXDAT_SPITXD_Pos                 (0UL)                     /*!< SPI1 TXDAT: SPITXD (Bit 0)                                  */
#define SPI1_TXDAT_SPITXD_Msk                 (0xffUL)                  /*!< SPI1 TXDAT: SPITXD (Bitfield-Mask: 0xff)                    */

/* ---------------------------------  SPI1_RXSTS  --------------------------------- */
#define SPI1_RXSTS_RXFFLAG_Pos                (0UL)                     /*!< SPI1 RXSTS: RXFFLAG (Bit 0)                                 */
#define SPI1_RXSTS_RXFFLAG_Msk                (0x7UL)                   /*!< SPI1 RXSTS: RXFFLAG (Bitfield-Mask: 0x07)                   */
#define SPI1_RXSTS_RXFLEV_Pos                 (4UL)                     /*!< SPI1 RXSTS: RXFLEV (Bit 4)                                  */
#define SPI1_RXSTS_RXFLEV_Msk                 (0x70UL)                  /*!< SPI1 RXSTS: RXFLEV (Bitfield-Mask: 0x07)                    */
#define SPI1_RXSTS_RXFOV_Pos                  (8UL)                     /*!< SPI1 RXSTS: RXFOV (Bit 8)                                   */
#define SPI1_RXSTS_RXFOV_Msk                  (0x100UL)                 /*!< SPI1 RXSTS: RXFOV (Bitfield-Mask: 0x01)                     */
#define SPI1_RXSTS_RXFULL_Pos                 (9UL)                     /*!< SPI1 RXSTS: RXFULL (Bit 9)                                  */
#define SPI1_RXSTS_RXFULL_Msk                 (0x200UL)                 /*!< SPI1 RXSTS: RXFULL (Bitfield-Mask: 0x01)                    */
#define SPI1_RXSTS_SPIRXIEN_Pos               (14UL)                    /*!< SPI1 RXSTS: SPIRXIEN (Bit 14)                               */
#define SPI1_RXSTS_SPIRXIEN_Msk               (0x4000UL)                /*!< SPI1 RXSTS: SPIRXIEN (Bitfield-Mask: 0x01)                  */
#define SPI1_RXSTS_SPIRXIF_Pos                (15UL)                    /*!< SPI1 RXSTS: SPIRXIF (Bit 15)                                */
#define SPI1_RXSTS_SPIRXIF_Msk                (0x8000UL)                /*!< SPI1 RXSTS: SPIRXIF (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  SPI1_RXDAT  --------------------------------- */
#define SPI1_RXDAT_SPIRXD_Pos                 (0UL)                     /*!< SPI1 RXDAT: SPIRXD (Bit 0)                                  */
#define SPI1_RXDAT_SPIRXD_Msk                 (0xffUL)                  /*!< SPI1 RXDAT: SPIRXD (Bitfield-Mask: 0xff)                    */

/* ----------------------------------  SPI1_MISC  --------------------------------- */
#define SPI1_MISC_TFE_Pos                     (0UL)                     /*!< SPI1 MISC: TFE (Bit 0)                                      */
#define SPI1_MISC_TFE_Msk                     (0x1UL)                   /*!< SPI1 MISC: TFE (Bitfield-Mask: 0x01)                        */
#define SPI1_MISC_TNF_Pos                     (1UL)                     /*!< SPI1 MISC: TNF (Bit 1)                                      */
#define SPI1_MISC_TNF_Msk                     (0x2UL)                   /*!< SPI1 MISC: TNF (Bitfield-Mask: 0x01)                        */
#define SPI1_MISC_RNE_Pos                     (2UL)                     /*!< SPI1 MISC: RNE (Bit 2)                                      */
#define SPI1_MISC_RNE_Msk                     (0x4UL)                   /*!< SPI1 MISC: RNE (Bitfield-Mask: 0x01)                        */
#define SPI1_MISC_RFF_Pos                     (3UL)                     /*!< SPI1 MISC: RFF (Bit 3)                                      */
#define SPI1_MISC_RFF_Msk                     (0x8UL)                   /*!< SPI1 MISC: RFF (Bitfield-Mask: 0x01)                        */
#define SPI1_MISC_BSY_Pos                     (4UL)                     /*!< SPI1 MISC: BSY (Bit 4)                                      */
#define SPI1_MISC_BSY_Msk                     (0x10UL)                  /*!< SPI1 MISC: BSY (Bitfield-Mask: 0x01)                        */
#define SPI1_MISC_SMART_Pos                   (8UL)                     /*!< SPI1 MISC: SMART (Bit 8)                                    */
#define SPI1_MISC_SMART_Msk                   (0x100UL)                 /*!< SPI1 MISC: SMART (Bitfield-Mask: 0x01)                      */
#define SPI1_MISC_OVER_Pos                    (9UL)                     /*!< SPI1 MISC: OVER (Bit 9)                                     */
#define SPI1_MISC_OVER_Msk                    (0x200UL)                 /*!< SPI1 MISC: OVER (Bitfield-Mask: 0x01)                       */


/* ================================================================================ */
/* ================          struct 'SPI2' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  SPI2_CTRL  --------------------------------- */
#define SPI2_CTRL_SCKSEL_Pos                  (0UL)                     /*!< SPI2 CTRL: SCKSEL (Bit 0)                                   */
#define SPI2_CTRL_SCKSEL_Msk                  (0x7UL)                   /*!< SPI2 CTRL: SCKSEL (Bitfield-Mask: 0x07)                     */
#define SPI2_CTRL_SCKPOL_Pos                  (4UL)                     /*!< SPI2 CTRL: SCKPOL (Bit 4)                                   */
#define SPI2_CTRL_SCKPOL_Msk                  (0x10UL)                  /*!< SPI2 CTRL: SCKPOL (Bitfield-Mask: 0x01)                     */
#define SPI2_CTRL_SCKPHA_Pos                  (5UL)                     /*!< SPI2 CTRL: SCKPHA (Bit 5)                                   */
#define SPI2_CTRL_SCKPHA_Msk                  (0x20UL)                  /*!< SPI2 CTRL: SCKPHA (Bitfield-Mask: 0x01)                     */
#define SPI2_CTRL_MOD_Pos                     (8UL)                     /*!< SPI2 CTRL: MOD (Bit 8)                                      */
#define SPI2_CTRL_MOD_Msk                     (0x100UL)                 /*!< SPI2 CTRL: MOD (Bitfield-Mask: 0x01)                        */
#define SPI2_CTRL_SWAP_Pos                    (9UL)                     /*!< SPI2 CTRL: SWAP (Bit 9)                                     */
#define SPI2_CTRL_SWAP_Msk                    (0x200UL)                 /*!< SPI2 CTRL: SWAP (Bitfield-Mask: 0x01)                       */
#define SPI2_CTRL_CSGPIO_Pos                  (10UL)                    /*!< SPI2 CTRL: CSGPIO (Bit 10)                                  */
#define SPI2_CTRL_CSGPIO_Msk                  (0x400UL)                 /*!< SPI2 CTRL: CSGPIO (Bitfield-Mask: 0x01)                     */
#define SPI2_CTRL_SPIRST_Pos                  (11UL)                    /*!< SPI2 CTRL: SPIRST (Bit 11)                                  */
#define SPI2_CTRL_SPIRST_Msk                  (0x800UL)                 /*!< SPI2 CTRL: SPIRST (Bitfield-Mask: 0x01)                     */
#define SPI2_CTRL_SPIEN_Pos                   (15UL)                    /*!< SPI2 CTRL: SPIEN (Bit 15)                                   */
#define SPI2_CTRL_SPIEN_Msk                   (0x8000UL)                /*!< SPI2 CTRL: SPIEN (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  SPI2_TXSTS  --------------------------------- */
#define SPI2_TXSTS_TXFFLAG_Pos                (0UL)                     /*!< SPI2 TXSTS: TXFFLAG (Bit 0)                                 */
#define SPI2_TXSTS_TXFFLAG_Msk                (0x7UL)                   /*!< SPI2 TXSTS: TXFFLAG (Bitfield-Mask: 0x07)                   */
#define SPI2_TXSTS_TXFLEV_Pos                 (4UL)                     /*!< SPI2 TXSTS: TXFLEV (Bit 4)                                  */
#define SPI2_TXSTS_TXFLEV_Msk                 (0x70UL)                  /*!< SPI2 TXSTS: TXFLEV (Bitfield-Mask: 0x07)                    */
#define SPI2_TXSTS_TXFUR_Pos                  (8UL)                     /*!< SPI2 TXSTS: TXFUR (Bit 8)                                   */
#define SPI2_TXSTS_TXFUR_Msk                  (0x100UL)                 /*!< SPI2 TXSTS: TXFUR (Bitfield-Mask: 0x01)                     */
#define SPI2_TXSTS_TXEMPTY_Pos                (9UL)                     /*!< SPI2 TXSTS: TXEMPTY (Bit 9)                                 */
#define SPI2_TXSTS_TXEMPTY_Msk                (0x200UL)                 /*!< SPI2 TXSTS: TXEMPTY (Bitfield-Mask: 0x01)                   */
#define SPI2_TXSTS_SPITXIEN_Pos               (14UL)                    /*!< SPI2 TXSTS: SPITXIEN (Bit 14)                               */
#define SPI2_TXSTS_SPITXIEN_Msk               (0x4000UL)                /*!< SPI2 TXSTS: SPITXIEN (Bitfield-Mask: 0x01)                  */
#define SPI2_TXSTS_SPITXIF_Pos                (15UL)                    /*!< SPI2 TXSTS: SPITXIF (Bit 15)                                */
#define SPI2_TXSTS_SPITXIF_Msk                (0x8000UL)                /*!< SPI2 TXSTS: SPITXIF (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  SPI2_TXDAT  --------------------------------- */
#define SPI2_TXDAT_SPITXD_Pos                 (0UL)                     /*!< SPI2 TXDAT: SPITXD (Bit 0)                                  */
#define SPI2_TXDAT_SPITXD_Msk                 (0xffUL)                  /*!< SPI2 TXDAT: SPITXD (Bitfield-Mask: 0xff)                    */

/* ---------------------------------  SPI2_RXSTS  --------------------------------- */
#define SPI2_RXSTS_RXFFLAG_Pos                (0UL)                     /*!< SPI2 RXSTS: RXFFLAG (Bit 0)                                 */
#define SPI2_RXSTS_RXFFLAG_Msk                (0x7UL)                   /*!< SPI2 RXSTS: RXFFLAG (Bitfield-Mask: 0x07)                   */
#define SPI2_RXSTS_RXFLEV_Pos                 (4UL)                     /*!< SPI2 RXSTS: RXFLEV (Bit 4)                                  */
#define SPI2_RXSTS_RXFLEV_Msk                 (0x70UL)                  /*!< SPI2 RXSTS: RXFLEV (Bitfield-Mask: 0x07)                    */
#define SPI2_RXSTS_RXFOV_Pos                  (8UL)                     /*!< SPI2 RXSTS: RXFOV (Bit 8)                                   */
#define SPI2_RXSTS_RXFOV_Msk                  (0x100UL)                 /*!< SPI2 RXSTS: RXFOV (Bitfield-Mask: 0x01)                     */
#define SPI2_RXSTS_RXFULL_Pos                 (9UL)                     /*!< SPI2 RXSTS: RXFULL (Bit 9)                                  */
#define SPI2_RXSTS_RXFULL_Msk                 (0x200UL)                 /*!< SPI2 RXSTS: RXFULL (Bitfield-Mask: 0x01)                    */
#define SPI2_RXSTS_SPIRXIEN_Pos               (14UL)                    /*!< SPI2 RXSTS: SPIRXIEN (Bit 14)                               */
#define SPI2_RXSTS_SPIRXIEN_Msk               (0x4000UL)                /*!< SPI2 RXSTS: SPIRXIEN (Bitfield-Mask: 0x01)                  */
#define SPI2_RXSTS_SPIRXIF_Pos                (15UL)                    /*!< SPI2 RXSTS: SPIRXIF (Bit 15)                                */
#define SPI2_RXSTS_SPIRXIF_Msk                (0x8000UL)                /*!< SPI2 RXSTS: SPIRXIF (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  SPI2_RXDAT  --------------------------------- */
#define SPI2_RXDAT_SPIRXD_Pos                 (0UL)                     /*!< SPI2 RXDAT: SPIRXD (Bit 0)                                  */
#define SPI2_RXDAT_SPIRXD_Msk                 (0xffUL)                  /*!< SPI2 RXDAT: SPIRXD (Bitfield-Mask: 0xff)                    */

/* ----------------------------------  SPI2_MISC  --------------------------------- */
#define SPI2_MISC_TFE_Pos                     (0UL)                     /*!< SPI2 MISC: TFE (Bit 0)                                      */
#define SPI2_MISC_TFE_Msk                     (0x1UL)                   /*!< SPI2 MISC: TFE (Bitfield-Mask: 0x01)                        */
#define SPI2_MISC_TNF_Pos                     (1UL)                     /*!< SPI2 MISC: TNF (Bit 1)                                      */
#define SPI2_MISC_TNF_Msk                     (0x2UL)                   /*!< SPI2 MISC: TNF (Bitfield-Mask: 0x01)                        */
#define SPI2_MISC_RNE_Pos                     (2UL)                     /*!< SPI2 MISC: RNE (Bit 2)                                      */
#define SPI2_MISC_RNE_Msk                     (0x4UL)                   /*!< SPI2 MISC: RNE (Bitfield-Mask: 0x01)                        */
#define SPI2_MISC_RFF_Pos                     (3UL)                     /*!< SPI2 MISC: RFF (Bit 3)                                      */
#define SPI2_MISC_RFF_Msk                     (0x8UL)                   /*!< SPI2 MISC: RFF (Bitfield-Mask: 0x01)                        */
#define SPI2_MISC_BSY_Pos                     (4UL)                     /*!< SPI2 MISC: BSY (Bit 4)                                      */
#define SPI2_MISC_BSY_Msk                     (0x10UL)                  /*!< SPI2 MISC: BSY (Bitfield-Mask: 0x01)                        */
#define SPI2_MISC_SMART_Pos                   (8UL)                     /*!< SPI2 MISC: SMART (Bit 8)                                    */
#define SPI2_MISC_SMART_Msk                   (0x100UL)                 /*!< SPI2 MISC: SMART (Bitfield-Mask: 0x01)                      */
#define SPI2_MISC_OVER_Pos                    (9UL)                     /*!< SPI2 MISC: OVER (Bit 9)                                     */
#define SPI2_MISC_OVER_Msk                    (0x200UL)                 /*!< SPI2 MISC: OVER (Bitfield-Mask: 0x01)                       */


/* ================================================================================ */
/* ================           Group 'TMR' Position & Mask          ================ */
/* ================================================================================ */


/* ----------------------------------  TMR_CTRL  ---------------------------------- */
#define TMR_CTRL_EN_Pos                       (0UL)                     /*!< TMR CTRL: EN (Bit 0)                                        */
#define TMR_CTRL_EN_Msk                       (0x1UL)                   /*!< TMR CTRL: EN (Bitfield-Mask: 0x01)                          */
#define TMR_CTRL_EXTEN_Pos                    (1UL)                     /*!< TMR CTRL: EXTEN (Bit 1)                                     */
#define TMR_CTRL_EXTEN_Msk                    (0x2UL)                   /*!< TMR CTRL: EXTEN (Bitfield-Mask: 0x01)                       */
#define TMR_CTRL_EXTCLK_Pos                   (2UL)                     /*!< TMR CTRL: EXTCLK (Bit 2)                                    */
#define TMR_CTRL_EXTCLK_Msk                   (0x4UL)                   /*!< TMR CTRL: EXTCLK (Bitfield-Mask: 0x01)                      */
#define TMR_CTRL_INTEN_Pos                    (3UL)                     /*!< TMR CTRL: INTEN (Bit 3)                                     */
#define TMR_CTRL_INTEN_Msk                    (0x8UL)                   /*!< TMR CTRL: INTEN (Bitfield-Mask: 0x01)                       */

/* ----------------------------------  TMR_VALUE  --------------------------------- */
#define TMR_VALUE_VALUE_Pos                   (0UL)                     /*!< TMR VALUE: VALUE (Bit 0)                                    */
#define TMR_VALUE_VALUE_Msk                   (0xffffffffUL)            /*!< TMR VALUE: VALUE (Bitfield-Mask: 0xffffffff)                */

/* ---------------------------------  TMR_RELOAD  --------------------------------- */
#define TMR_RELOAD_RELOAD_Pos                 (0UL)                     /*!< TMR RELOAD: RELOAD (Bit 0)                                  */
#define TMR_RELOAD_RELOAD_Msk                 (0xffffffffUL)            /*!< TMR RELOAD: RELOAD (Bitfield-Mask: 0xffffffff)              */

/* -----------------------------------  TMR_INT  ---------------------------------- */
#define TMR_INT_INT_Pos                       (0UL)                     /*!< TMR INT: INT (Bit 0)                                        */
#define TMR_INT_INT_Msk                       (0x1UL)                   /*!< TMR INT: INT (Bitfield-Mask: 0x01)                          */


/* ================================================================================ */
/* ================          struct 'TMR0' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  TMR0_CTRL  --------------------------------- */
#define TMR0_CTRL_EN_Pos                      (0UL)                     /*!< TMR0 CTRL: EN (Bit 0)                                       */
#define TMR0_CTRL_EN_Msk                      (0x1UL)                   /*!< TMR0 CTRL: EN (Bitfield-Mask: 0x01)                         */
#define TMR0_CTRL_EXTEN_Pos                   (1UL)                     /*!< TMR0 CTRL: EXTEN (Bit 1)                                    */
#define TMR0_CTRL_EXTEN_Msk                   (0x2UL)                   /*!< TMR0 CTRL: EXTEN (Bitfield-Mask: 0x01)                      */
#define TMR0_CTRL_EXTCLK_Pos                  (2UL)                     /*!< TMR0 CTRL: EXTCLK (Bit 2)                                   */
#define TMR0_CTRL_EXTCLK_Msk                  (0x4UL)                   /*!< TMR0 CTRL: EXTCLK (Bitfield-Mask: 0x01)                     */
#define TMR0_CTRL_INTEN_Pos                   (3UL)                     /*!< TMR0 CTRL: INTEN (Bit 3)                                    */
#define TMR0_CTRL_INTEN_Msk                   (0x8UL)                   /*!< TMR0 CTRL: INTEN (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  TMR0_VALUE  --------------------------------- */
#define TMR0_VALUE_VALUE_Pos                  (0UL)                     /*!< TMR0 VALUE: VALUE (Bit 0)                                   */
#define TMR0_VALUE_VALUE_Msk                  (0xffffffffUL)            /*!< TMR0 VALUE: VALUE (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  TMR0_RELOAD  -------------------------------- */
#define TMR0_RELOAD_RELOAD_Pos                (0UL)                     /*!< TMR0 RELOAD: RELOAD (Bit 0)                                 */
#define TMR0_RELOAD_RELOAD_Msk                (0xffffffffUL)            /*!< TMR0 RELOAD: RELOAD (Bitfield-Mask: 0xffffffff)             */

/* ----------------------------------  TMR0_INT  ---------------------------------- */
#define TMR0_INT_INT_Pos                      (0UL)                     /*!< TMR0 INT: INT (Bit 0)                                       */
#define TMR0_INT_INT_Msk                      (0x1UL)                   /*!< TMR0 INT: INT (Bitfield-Mask: 0x01)                         */


/* ================================================================================ */
/* ================          struct 'TMR1' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  TMR1_CTRL  --------------------------------- */
#define TMR1_CTRL_EN_Pos                      (0UL)                     /*!< TMR1 CTRL: EN (Bit 0)                                       */
#define TMR1_CTRL_EN_Msk                      (0x1UL)                   /*!< TMR1 CTRL: EN (Bitfield-Mask: 0x01)                         */
#define TMR1_CTRL_EXTEN_Pos                   (1UL)                     /*!< TMR1 CTRL: EXTEN (Bit 1)                                    */
#define TMR1_CTRL_EXTEN_Msk                   (0x2UL)                   /*!< TMR1 CTRL: EXTEN (Bitfield-Mask: 0x01)                      */
#define TMR1_CTRL_EXTCLK_Pos                  (2UL)                     /*!< TMR1 CTRL: EXTCLK (Bit 2)                                   */
#define TMR1_CTRL_EXTCLK_Msk                  (0x4UL)                   /*!< TMR1 CTRL: EXTCLK (Bitfield-Mask: 0x01)                     */
#define TMR1_CTRL_INTEN_Pos                   (3UL)                     /*!< TMR1 CTRL: INTEN (Bit 3)                                    */
#define TMR1_CTRL_INTEN_Msk                   (0x8UL)                   /*!< TMR1 CTRL: INTEN (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  TMR1_VALUE  --------------------------------- */
#define TMR1_VALUE_VALUE_Pos                  (0UL)                     /*!< TMR1 VALUE: VALUE (Bit 0)                                   */
#define TMR1_VALUE_VALUE_Msk                  (0xffffffffUL)            /*!< TMR1 VALUE: VALUE (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  TMR1_RELOAD  -------------------------------- */
#define TMR1_RELOAD_RELOAD_Pos                (0UL)                     /*!< TMR1 RELOAD: RELOAD (Bit 0)                                 */
#define TMR1_RELOAD_RELOAD_Msk                (0xffffffffUL)            /*!< TMR1 RELOAD: RELOAD (Bitfield-Mask: 0xffffffff)             */

/* ----------------------------------  TMR1_INT  ---------------------------------- */
#define TMR1_INT_INT_Pos                      (0UL)                     /*!< TMR1 INT: INT (Bit 0)                                       */
#define TMR1_INT_INT_Msk                      (0x1UL)                   /*!< TMR1 INT: INT (Bitfield-Mask: 0x01)                         */


/* ================================================================================ */
/* ================          struct 'TMR2' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  TMR2_CTRL  --------------------------------- */
#define TMR2_CTRL_EN_Pos                      (0UL)                     /*!< TMR2 CTRL: EN (Bit 0)                                       */
#define TMR2_CTRL_EN_Msk                      (0x1UL)                   /*!< TMR2 CTRL: EN (Bitfield-Mask: 0x01)                         */
#define TMR2_CTRL_EXTEN_Pos                   (1UL)                     /*!< TMR2 CTRL: EXTEN (Bit 1)                                    */
#define TMR2_CTRL_EXTEN_Msk                   (0x2UL)                   /*!< TMR2 CTRL: EXTEN (Bitfield-Mask: 0x01)                      */
#define TMR2_CTRL_EXTCLK_Pos                  (2UL)                     /*!< TMR2 CTRL: EXTCLK (Bit 2)                                   */
#define TMR2_CTRL_EXTCLK_Msk                  (0x4UL)                   /*!< TMR2 CTRL: EXTCLK (Bitfield-Mask: 0x01)                     */
#define TMR2_CTRL_INTEN_Pos                   (3UL)                     /*!< TMR2 CTRL: INTEN (Bit 3)                                    */
#define TMR2_CTRL_INTEN_Msk                   (0x8UL)                   /*!< TMR2 CTRL: INTEN (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  TMR2_VALUE  --------------------------------- */
#define TMR2_VALUE_VALUE_Pos                  (0UL)                     /*!< TMR2 VALUE: VALUE (Bit 0)                                   */
#define TMR2_VALUE_VALUE_Msk                  (0xffffffffUL)            /*!< TMR2 VALUE: VALUE (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  TMR2_RELOAD  -------------------------------- */
#define TMR2_RELOAD_RELOAD_Pos                (0UL)                     /*!< TMR2 RELOAD: RELOAD (Bit 0)                                 */
#define TMR2_RELOAD_RELOAD_Msk                (0xffffffffUL)            /*!< TMR2 RELOAD: RELOAD (Bitfield-Mask: 0xffffffff)             */

/* ----------------------------------  TMR2_INT  ---------------------------------- */
#define TMR2_INT_INT_Pos                      (0UL)                     /*!< TMR2 INT: INT (Bit 0)                                       */
#define TMR2_INT_INT_Msk                      (0x1UL)                   /*!< TMR2 INT: INT (Bitfield-Mask: 0x01)                         */


/* ================================================================================ */
/* ================          struct 'TMR3' Position & Mask         ================ */
/* ================================================================================ */


/* ----------------------------------  TMR3_CTRL  --------------------------------- */
#define TMR3_CTRL_EN_Pos                      (0UL)                     /*!< TMR3 CTRL: EN (Bit 0)                                       */
#define TMR3_CTRL_EN_Msk                      (0x1UL)                   /*!< TMR3 CTRL: EN (Bitfield-Mask: 0x01)                         */
#define TMR3_CTRL_EXTEN_Pos                   (1UL)                     /*!< TMR3 CTRL: EXTEN (Bit 1)                                    */
#define TMR3_CTRL_EXTEN_Msk                   (0x2UL)                   /*!< TMR3 CTRL: EXTEN (Bitfield-Mask: 0x01)                      */
#define TMR3_CTRL_EXTCLK_Pos                  (2UL)                     /*!< TMR3 CTRL: EXTCLK (Bit 2)                                   */
#define TMR3_CTRL_EXTCLK_Msk                  (0x4UL)                   /*!< TMR3 CTRL: EXTCLK (Bitfield-Mask: 0x01)                     */
#define TMR3_CTRL_INTEN_Pos                   (3UL)                     /*!< TMR3 CTRL: INTEN (Bit 3)                                    */
#define TMR3_CTRL_INTEN_Msk                   (0x8UL)                   /*!< TMR3 CTRL: INTEN (Bitfield-Mask: 0x01)                      */

/* ---------------------------------  TMR3_VALUE  --------------------------------- */
#define TMR3_VALUE_VALUE_Pos                  (0UL)                     /*!< TMR3 VALUE: VALUE (Bit 0)                                   */
#define TMR3_VALUE_VALUE_Msk                  (0xffffffffUL)            /*!< TMR3 VALUE: VALUE (Bitfield-Mask: 0xffffffff)               */

/* ---------------------------------  TMR3_RELOAD  -------------------------------- */
#define TMR3_RELOAD_RELOAD_Pos                (0UL)                     /*!< TMR3 RELOAD: RELOAD (Bit 0)                                 */
#define TMR3_RELOAD_RELOAD_Msk                (0xffffffffUL)            /*!< TMR3 RELOAD: RELOAD (Bitfield-Mask: 0xffffffff)             */

/* ----------------------------------  TMR3_INT  ---------------------------------- */
#define TMR3_INT_INT_Pos                      (0UL)                     /*!< TMR3 INT: INT (Bit 0)                                       */
#define TMR3_INT_INT_Msk                      (0x1UL)                   /*!< TMR3 INT: INT (Bitfield-Mask: 0x01)                         */


/* ================================================================================ */
/* ================          Group 'UART' Position & Mask          ================ */
/* ================================================================================ */


/* ----------------------------------  UART_DATA  --------------------------------- */
#define UART_DATA_DATA_Pos                    (0UL)                     /*!< UART DATA: DATA (Bit 0)                                     */
#define UART_DATA_DATA_Msk                    (0xffUL)                  /*!< UART DATA: DATA (Bitfield-Mask: 0xff)                       */

/* ---------------------------------  UART_STATE  --------------------------------- */
#define UART_STATE_RXFULL_Pos                 (1UL)                     /*!< UART STATE: RXFULL (Bit 1)                                  */
#define UART_STATE_RXFULL_Msk                 (0x2UL)                   /*!< UART STATE: RXFULL (Bitfield-Mask: 0x01)                    */
#define UART_STATE_TXOV_Pos                   (2UL)                     /*!< UART STATE: TXOV (Bit 2)                                    */
#define UART_STATE_TXOV_Msk                   (0x4UL)                   /*!< UART STATE: TXOV (Bitfield-Mask: 0x01)                      */
#define UART_STATE_RXOV_Pos                   (3UL)                     /*!< UART STATE: RXOV (Bit 3)                                    */
#define UART_STATE_RXOV_Msk                   (0x8UL)                   /*!< UART STATE: RXOV (Bitfield-Mask: 0x01)                      */
#define UART_STATE_RXPE_Pos                   (4UL)                     /*!< UART STATE: RXPE (Bit 4)                                    */
#define UART_STATE_RXPE_Msk                   (0x10UL)                  /*!< UART STATE: RXPE (Bitfield-Mask: 0x01)                      */
#define UART_STATE_TXDONE_Pos                 (5UL)                     /*!< UART STATE: TXDONE (Bit 5)                                  */
#define UART_STATE_TXDONE_Msk                 (0x20UL)                  /*!< UART STATE: TXDONE (Bitfield-Mask: 0x01)                    */
#define UART_STATE_RXPSTS_Pos                 (6UL)                     /*!< UART STATE: RXPSTS (Bit 6)                                  */
#define UART_STATE_RXPSTS_Msk                 (0x40UL)                  /*!< UART STATE: RXPSTS (Bitfield-Mask: 0x01)                    */

/* ----------------------------------  UART_CTRL  --------------------------------- */
#define UART_CTRL_TXEN_Pos                    (0UL)                     /*!< UART CTRL: TXEN (Bit 0)                                     */
#define UART_CTRL_TXEN_Msk                    (0x1UL)                   /*!< UART CTRL: TXEN (Bitfield-Mask: 0x01)                       */
#define UART_CTRL_RXEN_Pos                    (1UL)                     /*!< UART CTRL: RXEN (Bit 1)                                     */
#define UART_CTRL_RXEN_Msk                    (0x2UL)                   /*!< UART CTRL: RXEN (Bitfield-Mask: 0x01)                       */
#define UART_CTRL_RXIE_Pos                    (3UL)                     /*!< UART CTRL: RXIE (Bit 3)                                     */
#define UART_CTRL_RXIE_Msk                    (0x8UL)                   /*!< UART CTRL: RXIE (Bitfield-Mask: 0x01)                       */
#define UART_CTRL_TXOVIE_Pos                  (4UL)                     /*!< UART CTRL: TXOVIE (Bit 4)                                   */
#define UART_CTRL_TXOVIE_Msk                  (0x10UL)                  /*!< UART CTRL: TXOVIE (Bitfield-Mask: 0x01)                     */
#define UART_CTRL_RXOVIE_Pos                  (5UL)                     /*!< UART CTRL: RXOVIE (Bit 5)                                   */
#define UART_CTRL_RXOVIE_Msk                  (0x20UL)                  /*!< UART CTRL: RXOVIE (Bitfield-Mask: 0x01)                     */
#define UART_CTRL_RXPEIE_Pos                  (7UL)                     /*!< UART CTRL: RXPEIE (Bit 7)                                   */
#define UART_CTRL_RXPEIE_Msk                  (0x80UL)                  /*!< UART CTRL: RXPEIE (Bitfield-Mask: 0x01)                     */
#define UART_CTRL_TXDONEIE_Pos                (8UL)                     /*!< UART CTRL: TXDONEIE (Bit 8)                                 */
#define UART_CTRL_TXDONEIE_Msk                (0x100UL)                 /*!< UART CTRL: TXDONEIE (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART_INTSTS  -------------------------------- */
#define UART_INTSTS_RXIF_Pos                  (1UL)                     /*!< UART INTSTS: RXIF (Bit 1)                                   */
#define UART_INTSTS_RXIF_Msk                  (0x2UL)                   /*!< UART INTSTS: RXIF (Bitfield-Mask: 0x01)                     */
#define UART_INTSTS_TXOVIF_Pos                (2UL)                     /*!< UART INTSTS: TXOVIF (Bit 2)                                 */
#define UART_INTSTS_TXOVIF_Msk                (0x4UL)                   /*!< UART INTSTS: TXOVIF (Bitfield-Mask: 0x01)                   */
#define UART_INTSTS_RXOVIF_Pos                (3UL)                     /*!< UART INTSTS: RXOVIF (Bit 3)                                 */
#define UART_INTSTS_RXOVIF_Msk                (0x8UL)                   /*!< UART INTSTS: RXOVIF (Bitfield-Mask: 0x01)                   */
#define UART_INTSTS_RXPEIF_Pos                (4UL)                     /*!< UART INTSTS: RXPEIF (Bit 4)                                 */
#define UART_INTSTS_RXPEIF_Msk                (0x10UL)                  /*!< UART INTSTS: RXPEIF (Bitfield-Mask: 0x01)                   */
#define UART_INTSTS_TXDONEIF_Pos              (5UL)                     /*!< UART INTSTS: TXDONEIF (Bit 5)                               */
#define UART_INTSTS_TXDONEIF_Msk              (0x20UL)                  /*!< UART INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                 */

/* --------------------------------  UART_BAUDDIV  -------------------------------- */
#define UART_BAUDDIV_BAUDDIV_Pos              (0UL)                     /*!< UART BAUDDIV: BAUDDIV (Bit 0)                               */
#define UART_BAUDDIV_BAUDDIV_Msk              (0xfffffUL)               /*!< UART BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)              */

/* ---------------------------------  UART_CTRL2  --------------------------------- */
#define UART_CTRL2_MSB_Pos                    (0UL)                     /*!< UART CTRL2: MSB (Bit 0)                                     */
#define UART_CTRL2_MSB_Msk                    (0x1UL)                   /*!< UART CTRL2: MSB (Bitfield-Mask: 0x01)                       */
#define UART_CTRL2_MODE_Pos                   (1UL)                     /*!< UART CTRL2: MODE (Bit 1)                                    */
#define UART_CTRL2_MODE_Msk                   (0x2UL)                   /*!< UART CTRL2: MODE (Bitfield-Mask: 0x01)                      */
#define UART_CTRL2_PMODE_Pos                  (2UL)                     /*!< UART CTRL2: PMODE (Bit 2)                                   */
#define UART_CTRL2_PMODE_Msk                  (0xcUL)                   /*!< UART CTRL2: PMODE (Bitfield-Mask: 0x03)                     */


/* ================================================================================ */
/* ================         struct 'UART0' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  UART0_DATA  --------------------------------- */
#define UART0_DATA_DATA_Pos                   (0UL)                     /*!< UART0 DATA: DATA (Bit 0)                                    */
#define UART0_DATA_DATA_Msk                   (0xffUL)                  /*!< UART0 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  UART0_STATE  -------------------------------- */
#define UART0_STATE_RXFULL_Pos                (1UL)                     /*!< UART0 STATE: RXFULL (Bit 1)                                 */
#define UART0_STATE_RXFULL_Msk                (0x2UL)                   /*!< UART0 STATE: RXFULL (Bitfield-Mask: 0x01)                   */
#define UART0_STATE_TXOV_Pos                  (2UL)                     /*!< UART0 STATE: TXOV (Bit 2)                                   */
#define UART0_STATE_TXOV_Msk                  (0x4UL)                   /*!< UART0 STATE: TXOV (Bitfield-Mask: 0x01)                     */
#define UART0_STATE_RXOV_Pos                  (3UL)                     /*!< UART0 STATE: RXOV (Bit 3)                                   */
#define UART0_STATE_RXOV_Msk                  (0x8UL)                   /*!< UART0 STATE: RXOV (Bitfield-Mask: 0x01)                     */
#define UART0_STATE_RXPE_Pos                  (4UL)                     /*!< UART0 STATE: RXPE (Bit 4)                                   */
#define UART0_STATE_RXPE_Msk                  (0x10UL)                  /*!< UART0 STATE: RXPE (Bitfield-Mask: 0x01)                     */
#define UART0_STATE_TXDONE_Pos                (5UL)                     /*!< UART0 STATE: TXDONE (Bit 5)                                 */
#define UART0_STATE_TXDONE_Msk                (0x20UL)                  /*!< UART0 STATE: TXDONE (Bitfield-Mask: 0x01)                   */
#define UART0_STATE_RXPSTS_Pos                (6UL)                     /*!< UART0 STATE: RXPSTS (Bit 6)                                 */
#define UART0_STATE_RXPSTS_Msk                (0x40UL)                  /*!< UART0 STATE: RXPSTS (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART0_CTRL  --------------------------------- */
#define UART0_CTRL_TXEN_Pos                   (0UL)                     /*!< UART0 CTRL: TXEN (Bit 0)                                    */
#define UART0_CTRL_TXEN_Msk                   (0x1UL)                   /*!< UART0 CTRL: TXEN (Bitfield-Mask: 0x01)                      */
#define UART0_CTRL_RXEN_Pos                   (1UL)                     /*!< UART0 CTRL: RXEN (Bit 1)                                    */
#define UART0_CTRL_RXEN_Msk                   (0x2UL)                   /*!< UART0 CTRL: RXEN (Bitfield-Mask: 0x01)                      */
#define UART0_CTRL_RXIE_Pos                   (3UL)                     /*!< UART0 CTRL: RXIE (Bit 3)                                    */
#define UART0_CTRL_RXIE_Msk                   (0x8UL)                   /*!< UART0 CTRL: RXIE (Bitfield-Mask: 0x01)                      */
#define UART0_CTRL_TXOVIE_Pos                 (4UL)                     /*!< UART0 CTRL: TXOVIE (Bit 4)                                  */
#define UART0_CTRL_TXOVIE_Msk                 (0x10UL)                  /*!< UART0 CTRL: TXOVIE (Bitfield-Mask: 0x01)                    */
#define UART0_CTRL_RXOVIE_Pos                 (5UL)                     /*!< UART0 CTRL: RXOVIE (Bit 5)                                  */
#define UART0_CTRL_RXOVIE_Msk                 (0x20UL)                  /*!< UART0 CTRL: RXOVIE (Bitfield-Mask: 0x01)                    */
#define UART0_CTRL_RXPEIE_Pos                 (7UL)                     /*!< UART0 CTRL: RXPEIE (Bit 7)                                  */
#define UART0_CTRL_RXPEIE_Msk                 (0x80UL)                  /*!< UART0 CTRL: RXPEIE (Bitfield-Mask: 0x01)                    */
#define UART0_CTRL_TXDONEIE_Pos               (8UL)                     /*!< UART0 CTRL: TXDONEIE (Bit 8)                                */
#define UART0_CTRL_TXDONEIE_Msk               (0x100UL)                 /*!< UART0 CTRL: TXDONEIE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  UART0_INTSTS  -------------------------------- */
#define UART0_INTSTS_RXIF_Pos                 (1UL)                     /*!< UART0 INTSTS: RXIF (Bit 1)                                  */
#define UART0_INTSTS_RXIF_Msk                 (0x2UL)                   /*!< UART0 INTSTS: RXIF (Bitfield-Mask: 0x01)                    */
#define UART0_INTSTS_TXOVIF_Pos               (2UL)                     /*!< UART0 INTSTS: TXOVIF (Bit 2)                                */
#define UART0_INTSTS_TXOVIF_Msk               (0x4UL)                   /*!< UART0 INTSTS: TXOVIF (Bitfield-Mask: 0x01)                  */
#define UART0_INTSTS_RXOVIF_Pos               (3UL)                     /*!< UART0 INTSTS: RXOVIF (Bit 3)                                */
#define UART0_INTSTS_RXOVIF_Msk               (0x8UL)                   /*!< UART0 INTSTS: RXOVIF (Bitfield-Mask: 0x01)                  */
#define UART0_INTSTS_RXPEIF_Pos               (4UL)                     /*!< UART0 INTSTS: RXPEIF (Bit 4)                                */
#define UART0_INTSTS_RXPEIF_Msk               (0x10UL)                  /*!< UART0 INTSTS: RXPEIF (Bitfield-Mask: 0x01)                  */
#define UART0_INTSTS_TXDONEIF_Pos             (5UL)                     /*!< UART0 INTSTS: TXDONEIF (Bit 5)                              */
#define UART0_INTSTS_TXDONEIF_Msk             (0x20UL)                  /*!< UART0 INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                */

/* --------------------------------  UART0_BAUDDIV  ------------------------------- */
#define UART0_BAUDDIV_BAUDDIV_Pos             (0UL)                     /*!< UART0 BAUDDIV: BAUDDIV (Bit 0)                              */
#define UART0_BAUDDIV_BAUDDIV_Msk             (0xfffffUL)               /*!< UART0 BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)             */

/* ---------------------------------  UART0_CTRL2  -------------------------------- */
#define UART0_CTRL2_MSB_Pos                   (0UL)                     /*!< UART0 CTRL2: MSB (Bit 0)                                    */
#define UART0_CTRL2_MSB_Msk                   (0x1UL)                   /*!< UART0 CTRL2: MSB (Bitfield-Mask: 0x01)                      */
#define UART0_CTRL2_MODE_Pos                  (1UL)                     /*!< UART0 CTRL2: MODE (Bit 1)                                   */
#define UART0_CTRL2_MODE_Msk                  (0x2UL)                   /*!< UART0 CTRL2: MODE (Bitfield-Mask: 0x01)                     */
#define UART0_CTRL2_PMODE_Pos                 (2UL)                     /*!< UART0 CTRL2: PMODE (Bit 2)                                  */
#define UART0_CTRL2_PMODE_Msk                 (0xcUL)                   /*!< UART0 CTRL2: PMODE (Bitfield-Mask: 0x03)                    */


/* ================================================================================ */
/* ================         struct 'UART1' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  UART1_DATA  --------------------------------- */
#define UART1_DATA_DATA_Pos                   (0UL)                     /*!< UART1 DATA: DATA (Bit 0)                                    */
#define UART1_DATA_DATA_Msk                   (0xffUL)                  /*!< UART1 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  UART1_STATE  -------------------------------- */
#define UART1_STATE_RXFULL_Pos                (1UL)                     /*!< UART1 STATE: RXFULL (Bit 1)                                 */
#define UART1_STATE_RXFULL_Msk                (0x2UL)                   /*!< UART1 STATE: RXFULL (Bitfield-Mask: 0x01)                   */
#define UART1_STATE_TXOV_Pos                  (2UL)                     /*!< UART1 STATE: TXOV (Bit 2)                                   */
#define UART1_STATE_TXOV_Msk                  (0x4UL)                   /*!< UART1 STATE: TXOV (Bitfield-Mask: 0x01)                     */
#define UART1_STATE_RXOV_Pos                  (3UL)                     /*!< UART1 STATE: RXOV (Bit 3)                                   */
#define UART1_STATE_RXOV_Msk                  (0x8UL)                   /*!< UART1 STATE: RXOV (Bitfield-Mask: 0x01)                     */
#define UART1_STATE_RXPE_Pos                  (4UL)                     /*!< UART1 STATE: RXPE (Bit 4)                                   */
#define UART1_STATE_RXPE_Msk                  (0x10UL)                  /*!< UART1 STATE: RXPE (Bitfield-Mask: 0x01)                     */
#define UART1_STATE_TXDONE_Pos                (5UL)                     /*!< UART1 STATE: TXDONE (Bit 5)                                 */
#define UART1_STATE_TXDONE_Msk                (0x20UL)                  /*!< UART1 STATE: TXDONE (Bitfield-Mask: 0x01)                   */
#define UART1_STATE_RXPSTS_Pos                (6UL)                     /*!< UART1 STATE: RXPSTS (Bit 6)                                 */
#define UART1_STATE_RXPSTS_Msk                (0x40UL)                  /*!< UART1 STATE: RXPSTS (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART1_CTRL  --------------------------------- */
#define UART1_CTRL_TXEN_Pos                   (0UL)                     /*!< UART1 CTRL: TXEN (Bit 0)                                    */
#define UART1_CTRL_TXEN_Msk                   (0x1UL)                   /*!< UART1 CTRL: TXEN (Bitfield-Mask: 0x01)                      */
#define UART1_CTRL_RXEN_Pos                   (1UL)                     /*!< UART1 CTRL: RXEN (Bit 1)                                    */
#define UART1_CTRL_RXEN_Msk                   (0x2UL)                   /*!< UART1 CTRL: RXEN (Bitfield-Mask: 0x01)                      */
#define UART1_CTRL_RXIE_Pos                   (3UL)                     /*!< UART1 CTRL: RXIE (Bit 3)                                    */
#define UART1_CTRL_RXIE_Msk                   (0x8UL)                   /*!< UART1 CTRL: RXIE (Bitfield-Mask: 0x01)                      */
#define UART1_CTRL_TXOVIE_Pos                 (4UL)                     /*!< UART1 CTRL: TXOVIE (Bit 4)                                  */
#define UART1_CTRL_TXOVIE_Msk                 (0x10UL)                  /*!< UART1 CTRL: TXOVIE (Bitfield-Mask: 0x01)                    */
#define UART1_CTRL_RXOVIE_Pos                 (5UL)                     /*!< UART1 CTRL: RXOVIE (Bit 5)                                  */
#define UART1_CTRL_RXOVIE_Msk                 (0x20UL)                  /*!< UART1 CTRL: RXOVIE (Bitfield-Mask: 0x01)                    */
#define UART1_CTRL_RXPEIE_Pos                 (7UL)                     /*!< UART1 CTRL: RXPEIE (Bit 7)                                  */
#define UART1_CTRL_RXPEIE_Msk                 (0x80UL)                  /*!< UART1 CTRL: RXPEIE (Bitfield-Mask: 0x01)                    */
#define UART1_CTRL_TXDONEIE_Pos               (8UL)                     /*!< UART1 CTRL: TXDONEIE (Bit 8)                                */
#define UART1_CTRL_TXDONEIE_Msk               (0x100UL)                 /*!< UART1 CTRL: TXDONEIE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  UART1_INTSTS  -------------------------------- */
#define UART1_INTSTS_RXIF_Pos                 (1UL)                     /*!< UART1 INTSTS: RXIF (Bit 1)                                  */
#define UART1_INTSTS_RXIF_Msk                 (0x2UL)                   /*!< UART1 INTSTS: RXIF (Bitfield-Mask: 0x01)                    */
#define UART1_INTSTS_TXOVIF_Pos               (2UL)                     /*!< UART1 INTSTS: TXOVIF (Bit 2)                                */
#define UART1_INTSTS_TXOVIF_Msk               (0x4UL)                   /*!< UART1 INTSTS: TXOVIF (Bitfield-Mask: 0x01)                  */
#define UART1_INTSTS_RXOVIF_Pos               (3UL)                     /*!< UART1 INTSTS: RXOVIF (Bit 3)                                */
#define UART1_INTSTS_RXOVIF_Msk               (0x8UL)                   /*!< UART1 INTSTS: RXOVIF (Bitfield-Mask: 0x01)                  */
#define UART1_INTSTS_RXPEIF_Pos               (4UL)                     /*!< UART1 INTSTS: RXPEIF (Bit 4)                                */
#define UART1_INTSTS_RXPEIF_Msk               (0x10UL)                  /*!< UART1 INTSTS: RXPEIF (Bitfield-Mask: 0x01)                  */
#define UART1_INTSTS_TXDONEIF_Pos             (5UL)                     /*!< UART1 INTSTS: TXDONEIF (Bit 5)                              */
#define UART1_INTSTS_TXDONEIF_Msk             (0x20UL)                  /*!< UART1 INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                */

/* --------------------------------  UART1_BAUDDIV  ------------------------------- */
#define UART1_BAUDDIV_BAUDDIV_Pos             (0UL)                     /*!< UART1 BAUDDIV: BAUDDIV (Bit 0)                              */
#define UART1_BAUDDIV_BAUDDIV_Msk             (0xfffffUL)               /*!< UART1 BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)             */

/* ---------------------------------  UART1_CTRL2  -------------------------------- */
#define UART1_CTRL2_MSB_Pos                   (0UL)                     /*!< UART1 CTRL2: MSB (Bit 0)                                    */
#define UART1_CTRL2_MSB_Msk                   (0x1UL)                   /*!< UART1 CTRL2: MSB (Bitfield-Mask: 0x01)                      */
#define UART1_CTRL2_MODE_Pos                  (1UL)                     /*!< UART1 CTRL2: MODE (Bit 1)                                   */
#define UART1_CTRL2_MODE_Msk                  (0x2UL)                   /*!< UART1 CTRL2: MODE (Bitfield-Mask: 0x01)                     */
#define UART1_CTRL2_PMODE_Pos                 (2UL)                     /*!< UART1 CTRL2: PMODE (Bit 2)                                  */
#define UART1_CTRL2_PMODE_Msk                 (0xcUL)                   /*!< UART1 CTRL2: PMODE (Bitfield-Mask: 0x03)                    */


/* ================================================================================ */
/* ================         struct 'UART2' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  UART2_DATA  --------------------------------- */
#define UART2_DATA_DATA_Pos                   (0UL)                     /*!< UART2 DATA: DATA (Bit 0)                                    */
#define UART2_DATA_DATA_Msk                   (0xffUL)                  /*!< UART2 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  UART2_STATE  -------------------------------- */
#define UART2_STATE_RXFULL_Pos                (1UL)                     /*!< UART2 STATE: RXFULL (Bit 1)                                 */
#define UART2_STATE_RXFULL_Msk                (0x2UL)                   /*!< UART2 STATE: RXFULL (Bitfield-Mask: 0x01)                   */
#define UART2_STATE_TXOV_Pos                  (2UL)                     /*!< UART2 STATE: TXOV (Bit 2)                                   */
#define UART2_STATE_TXOV_Msk                  (0x4UL)                   /*!< UART2 STATE: TXOV (Bitfield-Mask: 0x01)                     */
#define UART2_STATE_RXOV_Pos                  (3UL)                     /*!< UART2 STATE: RXOV (Bit 3)                                   */
#define UART2_STATE_RXOV_Msk                  (0x8UL)                   /*!< UART2 STATE: RXOV (Bitfield-Mask: 0x01)                     */
#define UART2_STATE_RXPE_Pos                  (4UL)                     /*!< UART2 STATE: RXPE (Bit 4)                                   */
#define UART2_STATE_RXPE_Msk                  (0x10UL)                  /*!< UART2 STATE: RXPE (Bitfield-Mask: 0x01)                     */
#define UART2_STATE_TXDONE_Pos                (5UL)                     /*!< UART2 STATE: TXDONE (Bit 5)                                 */
#define UART2_STATE_TXDONE_Msk                (0x20UL)                  /*!< UART2 STATE: TXDONE (Bitfield-Mask: 0x01)                   */
#define UART2_STATE_RXPSTS_Pos                (6UL)                     /*!< UART2 STATE: RXPSTS (Bit 6)                                 */
#define UART2_STATE_RXPSTS_Msk                (0x40UL)                  /*!< UART2 STATE: RXPSTS (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART2_CTRL  --------------------------------- */
#define UART2_CTRL_TXEN_Pos                   (0UL)                     /*!< UART2 CTRL: TXEN (Bit 0)                                    */
#define UART2_CTRL_TXEN_Msk                   (0x1UL)                   /*!< UART2 CTRL: TXEN (Bitfield-Mask: 0x01)                      */
#define UART2_CTRL_RXEN_Pos                   (1UL)                     /*!< UART2 CTRL: RXEN (Bit 1)                                    */
#define UART2_CTRL_RXEN_Msk                   (0x2UL)                   /*!< UART2 CTRL: RXEN (Bitfield-Mask: 0x01)                      */
#define UART2_CTRL_RXIE_Pos                   (3UL)                     /*!< UART2 CTRL: RXIE (Bit 3)                                    */
#define UART2_CTRL_RXIE_Msk                   (0x8UL)                   /*!< UART2 CTRL: RXIE (Bitfield-Mask: 0x01)                      */
#define UART2_CTRL_TXOVIE_Pos                 (4UL)                     /*!< UART2 CTRL: TXOVIE (Bit 4)                                  */
#define UART2_CTRL_TXOVIE_Msk                 (0x10UL)                  /*!< UART2 CTRL: TXOVIE (Bitfield-Mask: 0x01)                    */
#define UART2_CTRL_RXOVIE_Pos                 (5UL)                     /*!< UART2 CTRL: RXOVIE (Bit 5)                                  */
#define UART2_CTRL_RXOVIE_Msk                 (0x20UL)                  /*!< UART2 CTRL: RXOVIE (Bitfield-Mask: 0x01)                    */
#define UART2_CTRL_RXPEIE_Pos                 (7UL)                     /*!< UART2 CTRL: RXPEIE (Bit 7)                                  */
#define UART2_CTRL_RXPEIE_Msk                 (0x80UL)                  /*!< UART2 CTRL: RXPEIE (Bitfield-Mask: 0x01)                    */
#define UART2_CTRL_TXDONEIE_Pos               (8UL)                     /*!< UART2 CTRL: TXDONEIE (Bit 8)                                */
#define UART2_CTRL_TXDONEIE_Msk               (0x100UL)                 /*!< UART2 CTRL: TXDONEIE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  UART2_INTSTS  -------------------------------- */
#define UART2_INTSTS_RXIF_Pos                 (1UL)                     /*!< UART2 INTSTS: RXIF (Bit 1)                                  */
#define UART2_INTSTS_RXIF_Msk                 (0x2UL)                   /*!< UART2 INTSTS: RXIF (Bitfield-Mask: 0x01)                    */
#define UART2_INTSTS_TXOVIF_Pos               (2UL)                     /*!< UART2 INTSTS: TXOVIF (Bit 2)                                */
#define UART2_INTSTS_TXOVIF_Msk               (0x4UL)                   /*!< UART2 INTSTS: TXOVIF (Bitfield-Mask: 0x01)                  */
#define UART2_INTSTS_RXOVIF_Pos               (3UL)                     /*!< UART2 INTSTS: RXOVIF (Bit 3)                                */
#define UART2_INTSTS_RXOVIF_Msk               (0x8UL)                   /*!< UART2 INTSTS: RXOVIF (Bitfield-Mask: 0x01)                  */
#define UART2_INTSTS_RXPEIF_Pos               (4UL)                     /*!< UART2 INTSTS: RXPEIF (Bit 4)                                */
#define UART2_INTSTS_RXPEIF_Msk               (0x10UL)                  /*!< UART2 INTSTS: RXPEIF (Bitfield-Mask: 0x01)                  */
#define UART2_INTSTS_TXDONEIF_Pos             (5UL)                     /*!< UART2 INTSTS: TXDONEIF (Bit 5)                              */
#define UART2_INTSTS_TXDONEIF_Msk             (0x20UL)                  /*!< UART2 INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                */

/* --------------------------------  UART2_BAUDDIV  ------------------------------- */
#define UART2_BAUDDIV_BAUDDIV_Pos             (0UL)                     /*!< UART2 BAUDDIV: BAUDDIV (Bit 0)                              */
#define UART2_BAUDDIV_BAUDDIV_Msk             (0xfffffUL)               /*!< UART2 BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)             */

/* ---------------------------------  UART2_CTRL2  -------------------------------- */
#define UART2_CTRL2_MSB_Pos                   (0UL)                     /*!< UART2 CTRL2: MSB (Bit 0)                                    */
#define UART2_CTRL2_MSB_Msk                   (0x1UL)                   /*!< UART2 CTRL2: MSB (Bitfield-Mask: 0x01)                      */
#define UART2_CTRL2_MODE_Pos                  (1UL)                     /*!< UART2 CTRL2: MODE (Bit 1)                                   */
#define UART2_CTRL2_MODE_Msk                  (0x2UL)                   /*!< UART2 CTRL2: MODE (Bitfield-Mask: 0x01)                     */
#define UART2_CTRL2_PMODE_Pos                 (2UL)                     /*!< UART2 CTRL2: PMODE (Bit 2)                                  */
#define UART2_CTRL2_PMODE_Msk                 (0xcUL)                   /*!< UART2 CTRL2: PMODE (Bitfield-Mask: 0x03)                    */


/* ================================================================================ */
/* ================         struct 'UART3' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  UART3_DATA  --------------------------------- */
#define UART3_DATA_DATA_Pos                   (0UL)                     /*!< UART3 DATA: DATA (Bit 0)                                    */
#define UART3_DATA_DATA_Msk                   (0xffUL)                  /*!< UART3 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  UART3_STATE  -------------------------------- */
#define UART3_STATE_RXFULL_Pos                (1UL)                     /*!< UART3 STATE: RXFULL (Bit 1)                                 */
#define UART3_STATE_RXFULL_Msk                (0x2UL)                   /*!< UART3 STATE: RXFULL (Bitfield-Mask: 0x01)                   */
#define UART3_STATE_TXOV_Pos                  (2UL)                     /*!< UART3 STATE: TXOV (Bit 2)                                   */
#define UART3_STATE_TXOV_Msk                  (0x4UL)                   /*!< UART3 STATE: TXOV (Bitfield-Mask: 0x01)                     */
#define UART3_STATE_RXOV_Pos                  (3UL)                     /*!< UART3 STATE: RXOV (Bit 3)                                   */
#define UART3_STATE_RXOV_Msk                  (0x8UL)                   /*!< UART3 STATE: RXOV (Bitfield-Mask: 0x01)                     */
#define UART3_STATE_RXPE_Pos                  (4UL)                     /*!< UART3 STATE: RXPE (Bit 4)                                   */
#define UART3_STATE_RXPE_Msk                  (0x10UL)                  /*!< UART3 STATE: RXPE (Bitfield-Mask: 0x01)                     */
#define UART3_STATE_TXDONE_Pos                (5UL)                     /*!< UART3 STATE: TXDONE (Bit 5)                                 */
#define UART3_STATE_TXDONE_Msk                (0x20UL)                  /*!< UART3 STATE: TXDONE (Bitfield-Mask: 0x01)                   */
#define UART3_STATE_RXPSTS_Pos                (6UL)                     /*!< UART3 STATE: RXPSTS (Bit 6)                                 */
#define UART3_STATE_RXPSTS_Msk                (0x40UL)                  /*!< UART3 STATE: RXPSTS (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART3_CTRL  --------------------------------- */
#define UART3_CTRL_TXEN_Pos                   (0UL)                     /*!< UART3 CTRL: TXEN (Bit 0)                                    */
#define UART3_CTRL_TXEN_Msk                   (0x1UL)                   /*!< UART3 CTRL: TXEN (Bitfield-Mask: 0x01)                      */
#define UART3_CTRL_RXEN_Pos                   (1UL)                     /*!< UART3 CTRL: RXEN (Bit 1)                                    */
#define UART3_CTRL_RXEN_Msk                   (0x2UL)                   /*!< UART3 CTRL: RXEN (Bitfield-Mask: 0x01)                      */
#define UART3_CTRL_RXIE_Pos                   (3UL)                     /*!< UART3 CTRL: RXIE (Bit 3)                                    */
#define UART3_CTRL_RXIE_Msk                   (0x8UL)                   /*!< UART3 CTRL: RXIE (Bitfield-Mask: 0x01)                      */
#define UART3_CTRL_TXOVIE_Pos                 (4UL)                     /*!< UART3 CTRL: TXOVIE (Bit 4)                                  */
#define UART3_CTRL_TXOVIE_Msk                 (0x10UL)                  /*!< UART3 CTRL: TXOVIE (Bitfield-Mask: 0x01)                    */
#define UART3_CTRL_RXOVIE_Pos                 (5UL)                     /*!< UART3 CTRL: RXOVIE (Bit 5)                                  */
#define UART3_CTRL_RXOVIE_Msk                 (0x20UL)                  /*!< UART3 CTRL: RXOVIE (Bitfield-Mask: 0x01)                    */
#define UART3_CTRL_RXPEIE_Pos                 (7UL)                     /*!< UART3 CTRL: RXPEIE (Bit 7)                                  */
#define UART3_CTRL_RXPEIE_Msk                 (0x80UL)                  /*!< UART3 CTRL: RXPEIE (Bitfield-Mask: 0x01)                    */
#define UART3_CTRL_TXDONEIE_Pos               (8UL)                     /*!< UART3 CTRL: TXDONEIE (Bit 8)                                */
#define UART3_CTRL_TXDONEIE_Msk               (0x100UL)                 /*!< UART3 CTRL: TXDONEIE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  UART3_INTSTS  -------------------------------- */
#define UART3_INTSTS_RXIF_Pos                 (1UL)                     /*!< UART3 INTSTS: RXIF (Bit 1)                                  */
#define UART3_INTSTS_RXIF_Msk                 (0x2UL)                   /*!< UART3 INTSTS: RXIF (Bitfield-Mask: 0x01)                    */
#define UART3_INTSTS_TXOVIF_Pos               (2UL)                     /*!< UART3 INTSTS: TXOVIF (Bit 2)                                */
#define UART3_INTSTS_TXOVIF_Msk               (0x4UL)                   /*!< UART3 INTSTS: TXOVIF (Bitfield-Mask: 0x01)                  */
#define UART3_INTSTS_RXOVIF_Pos               (3UL)                     /*!< UART3 INTSTS: RXOVIF (Bit 3)                                */
#define UART3_INTSTS_RXOVIF_Msk               (0x8UL)                   /*!< UART3 INTSTS: RXOVIF (Bitfield-Mask: 0x01)                  */
#define UART3_INTSTS_RXPEIF_Pos               (4UL)                     /*!< UART3 INTSTS: RXPEIF (Bit 4)                                */
#define UART3_INTSTS_RXPEIF_Msk               (0x10UL)                  /*!< UART3 INTSTS: RXPEIF (Bitfield-Mask: 0x01)                  */
#define UART3_INTSTS_TXDONEIF_Pos             (5UL)                     /*!< UART3 INTSTS: TXDONEIF (Bit 5)                              */
#define UART3_INTSTS_TXDONEIF_Msk             (0x20UL)                  /*!< UART3 INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                */

/* --------------------------------  UART3_BAUDDIV  ------------------------------- */
#define UART3_BAUDDIV_BAUDDIV_Pos             (0UL)                     /*!< UART3 BAUDDIV: BAUDDIV (Bit 0)                              */
#define UART3_BAUDDIV_BAUDDIV_Msk             (0xfffffUL)               /*!< UART3 BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)             */

/* ---------------------------------  UART3_CTRL2  -------------------------------- */
#define UART3_CTRL2_MSB_Pos                   (0UL)                     /*!< UART3 CTRL2: MSB (Bit 0)                                    */
#define UART3_CTRL2_MSB_Msk                   (0x1UL)                   /*!< UART3 CTRL2: MSB (Bitfield-Mask: 0x01)                      */
#define UART3_CTRL2_MODE_Pos                  (1UL)                     /*!< UART3 CTRL2: MODE (Bit 1)                                   */
#define UART3_CTRL2_MODE_Msk                  (0x2UL)                   /*!< UART3 CTRL2: MODE (Bitfield-Mask: 0x01)                     */
#define UART3_CTRL2_PMODE_Pos                 (2UL)                     /*!< UART3 CTRL2: PMODE (Bit 2)                                  */
#define UART3_CTRL2_PMODE_Msk                 (0xcUL)                   /*!< UART3 CTRL2: PMODE (Bitfield-Mask: 0x03)                    */


/* ================================================================================ */
/* ================         struct 'UART4' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  UART4_DATA  --------------------------------- */
#define UART4_DATA_DATA_Pos                   (0UL)                     /*!< UART4 DATA: DATA (Bit 0)                                    */
#define UART4_DATA_DATA_Msk                   (0xffUL)                  /*!< UART4 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  UART4_STATE  -------------------------------- */
#define UART4_STATE_RXFULL_Pos                (1UL)                     /*!< UART4 STATE: RXFULL (Bit 1)                                 */
#define UART4_STATE_RXFULL_Msk                (0x2UL)                   /*!< UART4 STATE: RXFULL (Bitfield-Mask: 0x01)                   */
#define UART4_STATE_TXOV_Pos                  (2UL)                     /*!< UART4 STATE: TXOV (Bit 2)                                   */
#define UART4_STATE_TXOV_Msk                  (0x4UL)                   /*!< UART4 STATE: TXOV (Bitfield-Mask: 0x01)                     */
#define UART4_STATE_RXOV_Pos                  (3UL)                     /*!< UART4 STATE: RXOV (Bit 3)                                   */
#define UART4_STATE_RXOV_Msk                  (0x8UL)                   /*!< UART4 STATE: RXOV (Bitfield-Mask: 0x01)                     */
#define UART4_STATE_RXPE_Pos                  (4UL)                     /*!< UART4 STATE: RXPE (Bit 4)                                   */
#define UART4_STATE_RXPE_Msk                  (0x10UL)                  /*!< UART4 STATE: RXPE (Bitfield-Mask: 0x01)                     */
#define UART4_STATE_TXDONE_Pos                (5UL)                     /*!< UART4 STATE: TXDONE (Bit 5)                                 */
#define UART4_STATE_TXDONE_Msk                (0x20UL)                  /*!< UART4 STATE: TXDONE (Bitfield-Mask: 0x01)                   */
#define UART4_STATE_RXPSTS_Pos                (6UL)                     /*!< UART4 STATE: RXPSTS (Bit 6)                                 */
#define UART4_STATE_RXPSTS_Msk                (0x40UL)                  /*!< UART4 STATE: RXPSTS (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART4_CTRL  --------------------------------- */
#define UART4_CTRL_TXEN_Pos                   (0UL)                     /*!< UART4 CTRL: TXEN (Bit 0)                                    */
#define UART4_CTRL_TXEN_Msk                   (0x1UL)                   /*!< UART4 CTRL: TXEN (Bitfield-Mask: 0x01)                      */
#define UART4_CTRL_RXEN_Pos                   (1UL)                     /*!< UART4 CTRL: RXEN (Bit 1)                                    */
#define UART4_CTRL_RXEN_Msk                   (0x2UL)                   /*!< UART4 CTRL: RXEN (Bitfield-Mask: 0x01)                      */
#define UART4_CTRL_RXIE_Pos                   (3UL)                     /*!< UART4 CTRL: RXIE (Bit 3)                                    */
#define UART4_CTRL_RXIE_Msk                   (0x8UL)                   /*!< UART4 CTRL: RXIE (Bitfield-Mask: 0x01)                      */
#define UART4_CTRL_TXOVIE_Pos                 (4UL)                     /*!< UART4 CTRL: TXOVIE (Bit 4)                                  */
#define UART4_CTRL_TXOVIE_Msk                 (0x10UL)                  /*!< UART4 CTRL: TXOVIE (Bitfield-Mask: 0x01)                    */
#define UART4_CTRL_RXOVIE_Pos                 (5UL)                     /*!< UART4 CTRL: RXOVIE (Bit 5)                                  */
#define UART4_CTRL_RXOVIE_Msk                 (0x20UL)                  /*!< UART4 CTRL: RXOVIE (Bitfield-Mask: 0x01)                    */
#define UART4_CTRL_RXPEIE_Pos                 (7UL)                     /*!< UART4 CTRL: RXPEIE (Bit 7)                                  */
#define UART4_CTRL_RXPEIE_Msk                 (0x80UL)                  /*!< UART4 CTRL: RXPEIE (Bitfield-Mask: 0x01)                    */
#define UART4_CTRL_TXDONEIE_Pos               (8UL)                     /*!< UART4 CTRL: TXDONEIE (Bit 8)                                */
#define UART4_CTRL_TXDONEIE_Msk               (0x100UL)                 /*!< UART4 CTRL: TXDONEIE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  UART4_INTSTS  -------------------------------- */
#define UART4_INTSTS_RXIF_Pos                 (1UL)                     /*!< UART4 INTSTS: RXIF (Bit 1)                                  */
#define UART4_INTSTS_RXIF_Msk                 (0x2UL)                   /*!< UART4 INTSTS: RXIF (Bitfield-Mask: 0x01)                    */
#define UART4_INTSTS_TXOVIF_Pos               (2UL)                     /*!< UART4 INTSTS: TXOVIF (Bit 2)                                */
#define UART4_INTSTS_TXOVIF_Msk               (0x4UL)                   /*!< UART4 INTSTS: TXOVIF (Bitfield-Mask: 0x01)                  */
#define UART4_INTSTS_RXOVIF_Pos               (3UL)                     /*!< UART4 INTSTS: RXOVIF (Bit 3)                                */
#define UART4_INTSTS_RXOVIF_Msk               (0x8UL)                   /*!< UART4 INTSTS: RXOVIF (Bitfield-Mask: 0x01)                  */
#define UART4_INTSTS_RXPEIF_Pos               (4UL)                     /*!< UART4 INTSTS: RXPEIF (Bit 4)                                */
#define UART4_INTSTS_RXPEIF_Msk               (0x10UL)                  /*!< UART4 INTSTS: RXPEIF (Bitfield-Mask: 0x01)                  */
#define UART4_INTSTS_TXDONEIF_Pos             (5UL)                     /*!< UART4 INTSTS: TXDONEIF (Bit 5)                              */
#define UART4_INTSTS_TXDONEIF_Msk             (0x20UL)                  /*!< UART4 INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                */

/* --------------------------------  UART4_BAUDDIV  ------------------------------- */
#define UART4_BAUDDIV_BAUDDIV_Pos             (0UL)                     /*!< UART4 BAUDDIV: BAUDDIV (Bit 0)                              */
#define UART4_BAUDDIV_BAUDDIV_Msk             (0xfffffUL)               /*!< UART4 BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)             */

/* ---------------------------------  UART4_CTRL2  -------------------------------- */
#define UART4_CTRL2_MSB_Pos                   (0UL)                     /*!< UART4 CTRL2: MSB (Bit 0)                                    */
#define UART4_CTRL2_MSB_Msk                   (0x1UL)                   /*!< UART4 CTRL2: MSB (Bitfield-Mask: 0x01)                      */
#define UART4_CTRL2_MODE_Pos                  (1UL)                     /*!< UART4 CTRL2: MODE (Bit 1)                                   */
#define UART4_CTRL2_MODE_Msk                  (0x2UL)                   /*!< UART4 CTRL2: MODE (Bitfield-Mask: 0x01)                     */
#define UART4_CTRL2_PMODE_Pos                 (2UL)                     /*!< UART4 CTRL2: PMODE (Bit 2)                                  */
#define UART4_CTRL2_PMODE_Msk                 (0xcUL)                   /*!< UART4 CTRL2: PMODE (Bitfield-Mask: 0x03)                    */


/* ================================================================================ */
/* ================         struct 'UART5' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  UART5_DATA  --------------------------------- */
#define UART5_DATA_DATA_Pos                   (0UL)                     /*!< UART5 DATA: DATA (Bit 0)                                    */
#define UART5_DATA_DATA_Msk                   (0xffUL)                  /*!< UART5 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ---------------------------------  UART5_STATE  -------------------------------- */
#define UART5_STATE_RXFULL_Pos                (1UL)                     /*!< UART5 STATE: RXFULL (Bit 1)                                 */
#define UART5_STATE_RXFULL_Msk                (0x2UL)                   /*!< UART5 STATE: RXFULL (Bitfield-Mask: 0x01)                   */
#define UART5_STATE_TXOV_Pos                  (2UL)                     /*!< UART5 STATE: TXOV (Bit 2)                                   */
#define UART5_STATE_TXOV_Msk                  (0x4UL)                   /*!< UART5 STATE: TXOV (Bitfield-Mask: 0x01)                     */
#define UART5_STATE_RXOV_Pos                  (3UL)                     /*!< UART5 STATE: RXOV (Bit 3)                                   */
#define UART5_STATE_RXOV_Msk                  (0x8UL)                   /*!< UART5 STATE: RXOV (Bitfield-Mask: 0x01)                     */
#define UART5_STATE_RXPE_Pos                  (4UL)                     /*!< UART5 STATE: RXPE (Bit 4)                                   */
#define UART5_STATE_RXPE_Msk                  (0x10UL)                  /*!< UART5 STATE: RXPE (Bitfield-Mask: 0x01)                     */
#define UART5_STATE_TXDONE_Pos                (5UL)                     /*!< UART5 STATE: TXDONE (Bit 5)                                 */
#define UART5_STATE_TXDONE_Msk                (0x20UL)                  /*!< UART5 STATE: TXDONE (Bitfield-Mask: 0x01)                   */
#define UART5_STATE_RXPSTS_Pos                (6UL)                     /*!< UART5 STATE: RXPSTS (Bit 6)                                 */
#define UART5_STATE_RXPSTS_Msk                (0x40UL)                  /*!< UART5 STATE: RXPSTS (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  UART5_CTRL  --------------------------------- */
#define UART5_CTRL_TXEN_Pos                   (0UL)                     /*!< UART5 CTRL: TXEN (Bit 0)                                    */
#define UART5_CTRL_TXEN_Msk                   (0x1UL)                   /*!< UART5 CTRL: TXEN (Bitfield-Mask: 0x01)                      */
#define UART5_CTRL_RXEN_Pos                   (1UL)                     /*!< UART5 CTRL: RXEN (Bit 1)                                    */
#define UART5_CTRL_RXEN_Msk                   (0x2UL)                   /*!< UART5 CTRL: RXEN (Bitfield-Mask: 0x01)                      */
#define UART5_CTRL_RXIE_Pos                   (3UL)                     /*!< UART5 CTRL: RXIE (Bit 3)                                    */
#define UART5_CTRL_RXIE_Msk                   (0x8UL)                   /*!< UART5 CTRL: RXIE (Bitfield-Mask: 0x01)                      */
#define UART5_CTRL_TXOVIE_Pos                 (4UL)                     /*!< UART5 CTRL: TXOVIE (Bit 4)                                  */
#define UART5_CTRL_TXOVIE_Msk                 (0x10UL)                  /*!< UART5 CTRL: TXOVIE (Bitfield-Mask: 0x01)                    */
#define UART5_CTRL_RXOVIE_Pos                 (5UL)                     /*!< UART5 CTRL: RXOVIE (Bit 5)                                  */
#define UART5_CTRL_RXOVIE_Msk                 (0x20UL)                  /*!< UART5 CTRL: RXOVIE (Bitfield-Mask: 0x01)                    */
#define UART5_CTRL_RXPEIE_Pos                 (7UL)                     /*!< UART5 CTRL: RXPEIE (Bit 7)                                  */
#define UART5_CTRL_RXPEIE_Msk                 (0x80UL)                  /*!< UART5 CTRL: RXPEIE (Bitfield-Mask: 0x01)                    */
#define UART5_CTRL_TXDONEIE_Pos               (8UL)                     /*!< UART5 CTRL: TXDONEIE (Bit 8)                                */
#define UART5_CTRL_TXDONEIE_Msk               (0x100UL)                 /*!< UART5 CTRL: TXDONEIE (Bitfield-Mask: 0x01)                  */

/* --------------------------------  UART5_INTSTS  -------------------------------- */
#define UART5_INTSTS_RXIF_Pos                 (1UL)                     /*!< UART5 INTSTS: RXIF (Bit 1)                                  */
#define UART5_INTSTS_RXIF_Msk                 (0x2UL)                   /*!< UART5 INTSTS: RXIF (Bitfield-Mask: 0x01)                    */
#define UART5_INTSTS_TXOVIF_Pos               (2UL)                     /*!< UART5 INTSTS: TXOVIF (Bit 2)                                */
#define UART5_INTSTS_TXOVIF_Msk               (0x4UL)                   /*!< UART5 INTSTS: TXOVIF (Bitfield-Mask: 0x01)                  */
#define UART5_INTSTS_RXOVIF_Pos               (3UL)                     /*!< UART5 INTSTS: RXOVIF (Bit 3)                                */
#define UART5_INTSTS_RXOVIF_Msk               (0x8UL)                   /*!< UART5 INTSTS: RXOVIF (Bitfield-Mask: 0x01)                  */
#define UART5_INTSTS_RXPEIF_Pos               (4UL)                     /*!< UART5 INTSTS: RXPEIF (Bit 4)                                */
#define UART5_INTSTS_RXPEIF_Msk               (0x10UL)                  /*!< UART5 INTSTS: RXPEIF (Bitfield-Mask: 0x01)                  */
#define UART5_INTSTS_TXDONEIF_Pos             (5UL)                     /*!< UART5 INTSTS: TXDONEIF (Bit 5)                              */
#define UART5_INTSTS_TXDONEIF_Msk             (0x20UL)                  /*!< UART5 INTSTS: TXDONEIF (Bitfield-Mask: 0x01)                */

/* --------------------------------  UART5_BAUDDIV  ------------------------------- */
#define UART5_BAUDDIV_BAUDDIV_Pos             (0UL)                     /*!< UART5 BAUDDIV: BAUDDIV (Bit 0)                              */
#define UART5_BAUDDIV_BAUDDIV_Msk             (0xfffffUL)               /*!< UART5 BAUDDIV: BAUDDIV (Bitfield-Mask: 0xfffff)             */

/* ---------------------------------  UART5_CTRL2  -------------------------------- */
#define UART5_CTRL2_MSB_Pos                   (0UL)                     /*!< UART5 CTRL2: MSB (Bit 0)                                    */
#define UART5_CTRL2_MSB_Msk                   (0x1UL)                   /*!< UART5 CTRL2: MSB (Bitfield-Mask: 0x01)                      */
#define UART5_CTRL2_MODE_Pos                  (1UL)                     /*!< UART5 CTRL2: MODE (Bit 1)                                   */
#define UART5_CTRL2_MODE_Msk                  (0x2UL)                   /*!< UART5 CTRL2: MODE (Bitfield-Mask: 0x01)                     */
#define UART5_CTRL2_PMODE_Pos                 (2UL)                     /*!< UART5 CTRL2: PMODE (Bit 2)                                  */
#define UART5_CTRL2_PMODE_Msk                 (0xcUL)                   /*!< UART5 CTRL2: PMODE (Bitfield-Mask: 0x03)                    */


/* ================================================================================ */
/* ================          Group 'U32K' Position & Mask          ================ */
/* ================================================================================ */


/* ---------------------------------  U32K_CTRL0  --------------------------------- */
#define U32K_CTRL0_EN_Pos                     (0UL)                     /*!< U32K CTRL0: EN (Bit 0)                                      */
#define U32K_CTRL0_EN_Msk                     (0x1UL)                   /*!< U32K CTRL0: EN (Bitfield-Mask: 0x01)                        */
#define U32K_CTRL0_ACOFF_Pos                  (1UL)                     /*!< U32K CTRL0: ACOFF (Bit 1)                                   */
#define U32K_CTRL0_ACOFF_Msk                  (0x2UL)                   /*!< U32K CTRL0: ACOFF (Bitfield-Mask: 0x01)                     */
#define U32K_CTRL0_MSB_Pos                    (2UL)                     /*!< U32K CTRL0: MSB (Bit 2)                                     */
#define U32K_CTRL0_MSB_Msk                    (0x4UL)                   /*!< U32K CTRL0: MSB (Bitfield-Mask: 0x01)                       */
#define U32K_CTRL0_MODE_Pos                   (3UL)                     /*!< U32K CTRL0: MODE (Bit 3)                                    */
#define U32K_CTRL0_MODE_Msk                   (0x8UL)                   /*!< U32K CTRL0: MODE (Bitfield-Mask: 0x01)                      */
#define U32K_CTRL0_PMODE_Pos                  (4UL)                     /*!< U32K CTRL0: PMODE (Bit 4)                                   */
#define U32K_CTRL0_PMODE_Msk                  (0x30UL)                  /*!< U32K CTRL0: PMODE (Bitfield-Mask: 0x03)                     */
#define U32K_CTRL0_DEBSEL_Pos                 (6UL)                     /*!< U32K CTRL0: DEBSEL (Bit 6)                                  */
#define U32K_CTRL0_DEBSEL_Msk                 (0xc0UL)                  /*!< U32K CTRL0: DEBSEL (Bitfield-Mask: 0x03)                    */
#define U32K_CTRL0_WKUMODE_Pos                (8UL)                     /*!< U32K CTRL0: WKUMODE (Bit 8)                                 */
#define U32K_CTRL0_WKUMODE_Msk                (0x100UL)                 /*!< U32K CTRL0: WKUMODE (Bitfield-Mask: 0x01)                   */

/* ---------------------------------  U32K_CTRL1  --------------------------------- */
#define U32K_CTRL1_RXIE_Pos                   (0UL)                     /*!< U32K CTRL1: RXIE (Bit 0)                                    */
#define U32K_CTRL1_RXIE_Msk                   (0x1UL)                   /*!< U32K CTRL1: RXIE (Bitfield-Mask: 0x01)                      */
#define U32K_CTRL1_RXPEIE_Pos                 (1UL)                     /*!< U32K CTRL1: RXPEIE (Bit 1)                                  */
#define U32K_CTRL1_RXPEIE_Msk                 (0x2UL)                   /*!< U32K CTRL1: RXPEIE (Bitfield-Mask: 0x01)                    */
#define U32K_CTRL1_RXOVIE_Pos                 (2UL)                     /*!< U32K CTRL1: RXOVIE (Bit 2)                                  */
#define U32K_CTRL1_RXOVIE_Msk                 (0x4UL)                   /*!< U32K CTRL1: RXOVIE (Bitfield-Mask: 0x01)                    */
#define U32K_CTRL1_RXSEL_Pos                  (4UL)                     /*!< U32K CTRL1: RXSEL (Bit 4)                                   */
#define U32K_CTRL1_RXSEL_Msk                  (0x30UL)                  /*!< U32K CTRL1: RXSEL (Bitfield-Mask: 0x03)                     */

/* ---------------------------------  U32K_PHASE  --------------------------------- */
#define U32K_PHASE_PHASE_Pos                  (0UL)                     /*!< U32K PHASE: PHASE (Bit 0)                                   */
#define U32K_PHASE_PHASE_Msk                  (0xffffUL)                /*!< U32K PHASE: PHASE (Bitfield-Mask: 0xffff)                   */

/* ----------------------------------  U32K_DATA  --------------------------------- */
#define U32K_DATA_DATA_Pos                    (0UL)                     /*!< U32K DATA: DATA (Bit 0)                                     */
#define U32K_DATA_DATA_Msk                    (0xffUL)                  /*!< U32K DATA: DATA (Bitfield-Mask: 0xff)                       */

/* ----------------------------------  U32K_STS  ---------------------------------- */
#define U32K_STS_RXIF_Pos                     (0UL)                     /*!< U32K STS: RXIF (Bit 0)                                      */
#define U32K_STS_RXIF_Msk                     (0x1UL)                   /*!< U32K STS: RXIF (Bitfield-Mask: 0x01)                        */
#define U32K_STS_RXPE_Pos                     (1UL)                     /*!< U32K STS: RXPE (Bit 1)                                      */
#define U32K_STS_RXPE_Msk                     (0x2UL)                   /*!< U32K STS: RXPE (Bitfield-Mask: 0x01)                        */
#define U32K_STS_RXOV_Pos                     (2UL)                     /*!< U32K STS: RXOV (Bit 2)                                      */
#define U32K_STS_RXOV_Msk                     (0x4UL)                   /*!< U32K STS: RXOV (Bitfield-Mask: 0x01)                        */


/* ================================================================================ */
/* ================         struct 'U32K0' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  U32K0_CTRL0  -------------------------------- */
#define U32K0_CTRL0_EN_Pos                    (0UL)                     /*!< U32K0 CTRL0: EN (Bit 0)                                     */
#define U32K0_CTRL0_EN_Msk                    (0x1UL)                   /*!< U32K0 CTRL0: EN (Bitfield-Mask: 0x01)                       */
#define U32K0_CTRL0_ACOFF_Pos                 (1UL)                     /*!< U32K0 CTRL0: ACOFF (Bit 1)                                  */
#define U32K0_CTRL0_ACOFF_Msk                 (0x2UL)                   /*!< U32K0 CTRL0: ACOFF (Bitfield-Mask: 0x01)                    */
#define U32K0_CTRL0_MSB_Pos                   (2UL)                     /*!< U32K0 CTRL0: MSB (Bit 2)                                    */
#define U32K0_CTRL0_MSB_Msk                   (0x4UL)                   /*!< U32K0 CTRL0: MSB (Bitfield-Mask: 0x01)                      */
#define U32K0_CTRL0_MODE_Pos                  (3UL)                     /*!< U32K0 CTRL0: MODE (Bit 3)                                   */
#define U32K0_CTRL0_MODE_Msk                  (0x8UL)                   /*!< U32K0 CTRL0: MODE (Bitfield-Mask: 0x01)                     */
#define U32K0_CTRL0_PMODE_Pos                 (4UL)                     /*!< U32K0 CTRL0: PMODE (Bit 4)                                  */
#define U32K0_CTRL0_PMODE_Msk                 (0x30UL)                  /*!< U32K0 CTRL0: PMODE (Bitfield-Mask: 0x03)                    */
#define U32K0_CTRL0_DEBSEL_Pos                (6UL)                     /*!< U32K0 CTRL0: DEBSEL (Bit 6)                                 */
#define U32K0_CTRL0_DEBSEL_Msk                (0xc0UL)                  /*!< U32K0 CTRL0: DEBSEL (Bitfield-Mask: 0x03)                   */
#define U32K0_CTRL0_WKUMODE_Pos               (8UL)                     /*!< U32K0 CTRL0: WKUMODE (Bit 8)                                */
#define U32K0_CTRL0_WKUMODE_Msk               (0x100UL)                 /*!< U32K0 CTRL0: WKUMODE (Bitfield-Mask: 0x01)                  */

/* ---------------------------------  U32K0_CTRL1  -------------------------------- */
#define U32K0_CTRL1_RXIE_Pos                  (0UL)                     /*!< U32K0 CTRL1: RXIE (Bit 0)                                   */
#define U32K0_CTRL1_RXIE_Msk                  (0x1UL)                   /*!< U32K0 CTRL1: RXIE (Bitfield-Mask: 0x01)                     */
#define U32K0_CTRL1_RXPEIE_Pos                (1UL)                     /*!< U32K0 CTRL1: RXPEIE (Bit 1)                                 */
#define U32K0_CTRL1_RXPEIE_Msk                (0x2UL)                   /*!< U32K0 CTRL1: RXPEIE (Bitfield-Mask: 0x01)                   */
#define U32K0_CTRL1_RXOVIE_Pos                (2UL)                     /*!< U32K0 CTRL1: RXOVIE (Bit 2)                                 */
#define U32K0_CTRL1_RXOVIE_Msk                (0x4UL)                   /*!< U32K0 CTRL1: RXOVIE (Bitfield-Mask: 0x01)                   */
#define U32K0_CTRL1_RXSEL_Pos                 (4UL)                     /*!< U32K0 CTRL1: RXSEL (Bit 4)                                  */
#define U32K0_CTRL1_RXSEL_Msk                 (0x30UL)                  /*!< U32K0 CTRL1: RXSEL (Bitfield-Mask: 0x03)                    */

/* ---------------------------------  U32K0_PHASE  -------------------------------- */
#define U32K0_PHASE_PHASE_Pos                 (0UL)                     /*!< U32K0 PHASE: PHASE (Bit 0)                                  */
#define U32K0_PHASE_PHASE_Msk                 (0xffffUL)                /*!< U32K0 PHASE: PHASE (Bitfield-Mask: 0xffff)                  */

/* ---------------------------------  U32K0_DATA  --------------------------------- */
#define U32K0_DATA_DATA_Pos                   (0UL)                     /*!< U32K0 DATA: DATA (Bit 0)                                    */
#define U32K0_DATA_DATA_Msk                   (0xffUL)                  /*!< U32K0 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ----------------------------------  U32K0_STS  --------------------------------- */
#define U32K0_STS_RXIF_Pos                    (0UL)                     /*!< U32K0 STS: RXIF (Bit 0)                                     */
#define U32K0_STS_RXIF_Msk                    (0x1UL)                   /*!< U32K0 STS: RXIF (Bitfield-Mask: 0x01)                       */
#define U32K0_STS_RXPE_Pos                    (1UL)                     /*!< U32K0 STS: RXPE (Bit 1)                                     */
#define U32K0_STS_RXPE_Msk                    (0x2UL)                   /*!< U32K0 STS: RXPE (Bitfield-Mask: 0x01)                       */
#define U32K0_STS_RXOV_Pos                    (2UL)                     /*!< U32K0 STS: RXOV (Bit 2)                                     */
#define U32K0_STS_RXOV_Msk                    (0x4UL)                   /*!< U32K0 STS: RXOV (Bitfield-Mask: 0x01)                       */


/* ================================================================================ */
/* ================         struct 'U32K1' Position & Mask         ================ */
/* ================================================================================ */


/* ---------------------------------  U32K1_CTRL0  -------------------------------- */
#define U32K1_CTRL0_EN_Pos                    (0UL)                     /*!< U32K1 CTRL0: EN (Bit 0)                                     */
#define U32K1_CTRL0_EN_Msk                    (0x1UL)                   /*!< U32K1 CTRL0: EN (Bitfield-Mask: 0x01)                       */
#define U32K1_CTRL0_ACOFF_Pos                 (1UL)                     /*!< U32K1 CTRL0: ACOFF (Bit 1)                                  */
#define U32K1_CTRL0_ACOFF_Msk                 (0x2UL)                   /*!< U32K1 CTRL0: ACOFF (Bitfield-Mask: 0x01)                    */
#define U32K1_CTRL0_MSB_Pos                   (2UL)                     /*!< U32K1 CTRL0: MSB (Bit 2)                                    */
#define U32K1_CTRL0_MSB_Msk                   (0x4UL)                   /*!< U32K1 CTRL0: MSB (Bitfield-Mask: 0x01)                      */
#define U32K1_CTRL0_MODE_Pos                  (3UL)                     /*!< U32K1 CTRL0: MODE (Bit 3)                                   */
#define U32K1_CTRL0_MODE_Msk                  (0x8UL)                   /*!< U32K1 CTRL0: MODE (Bitfield-Mask: 0x01)                     */
#define U32K1_CTRL0_PMODE_Pos                 (4UL)                     /*!< U32K1 CTRL0: PMODE (Bit 4)                                  */
#define U32K1_CTRL0_PMODE_Msk                 (0x30UL)                  /*!< U32K1 CTRL0: PMODE (Bitfield-Mask: 0x03)                    */
#define U32K1_CTRL0_DEBSEL_Pos                (6UL)                     /*!< U32K1 CTRL0: DEBSEL (Bit 6)                                 */
#define U32K1_CTRL0_DEBSEL_Msk                (0xc0UL)                  /*!< U32K1 CTRL0: DEBSEL (Bitfield-Mask: 0x03)                   */
#define U32K1_CTRL0_WKUMODE_Pos               (8UL)                     /*!< U32K1 CTRL0: WKUMODE (Bit 8)                                */
#define U32K1_CTRL0_WKUMODE_Msk               (0x100UL)                 /*!< U32K1 CTRL0: WKUMODE (Bitfield-Mask: 0x01)                  */

/* ---------------------------------  U32K1_CTRL1  -------------------------------- */
#define U32K1_CTRL1_RXIE_Pos                  (0UL)                     /*!< U32K1 CTRL1: RXIE (Bit 0)                                   */
#define U32K1_CTRL1_RXIE_Msk                  (0x1UL)                   /*!< U32K1 CTRL1: RXIE (Bitfield-Mask: 0x01)                     */
#define U32K1_CTRL1_RXPEIE_Pos                (1UL)                     /*!< U32K1 CTRL1: RXPEIE (Bit 1)                                 */
#define U32K1_CTRL1_RXPEIE_Msk                (0x2UL)                   /*!< U32K1 CTRL1: RXPEIE (Bitfield-Mask: 0x01)                   */
#define U32K1_CTRL1_RXOVIE_Pos                (2UL)                     /*!< U32K1 CTRL1: RXOVIE (Bit 2)                                 */
#define U32K1_CTRL1_RXOVIE_Msk                (0x4UL)                   /*!< U32K1 CTRL1: RXOVIE (Bitfield-Mask: 0x01)                   */
#define U32K1_CTRL1_RXSEL_Pos                 (4UL)                     /*!< U32K1 CTRL1: RXSEL (Bit 4)                                  */
#define U32K1_CTRL1_RXSEL_Msk                 (0x30UL)                  /*!< U32K1 CTRL1: RXSEL (Bitfield-Mask: 0x03)                    */

/* ---------------------------------  U32K1_PHASE  -------------------------------- */
#define U32K1_PHASE_PHASE_Pos                 (0UL)                     /*!< U32K1 PHASE: PHASE (Bit 0)                                  */
#define U32K1_PHASE_PHASE_Msk                 (0xffffUL)                /*!< U32K1 PHASE: PHASE (Bitfield-Mask: 0xffff)                  */

/* ---------------------------------  U32K1_DATA  --------------------------------- */
#define U32K1_DATA_DATA_Pos                   (0UL)                     /*!< U32K1 DATA: DATA (Bit 0)                                    */
#define U32K1_DATA_DATA_Msk                   (0xffUL)                  /*!< U32K1 DATA: DATA (Bitfield-Mask: 0xff)                      */

/* ----------------------------------  U32K1_STS  --------------------------------- */
#define U32K1_STS_RXIF_Pos                    (0UL)                     /*!< U32K1 STS: RXIF (Bit 0)                                     */
#define U32K1_STS_RXIF_Msk                    (0x1UL)                   /*!< U32K1 STS: RXIF (Bitfield-Mask: 0x01)                       */
#define U32K1_STS_RXPE_Pos                    (1UL)                     /*!< U32K1 STS: RXPE (Bit 1)                                     */
#define U32K1_STS_RXPE_Msk                    (0x2UL)                   /*!< U32K1 STS: RXPE (Bitfield-Mask: 0x01)                       */
#define U32K1_STS_RXOV_Pos                    (2UL)                     /*!< U32K1 STS: RXOV (Bit 2)                                     */
#define U32K1_STS_RXOV_Msk                    (0x4UL)                   /*!< U32K1 STS: RXOV (Bitfield-Mask: 0x01)                       */



/* ================================================================================ */
/* ================              Peripheral memory map             ================ */
/* ================================================================================ */

#define ANA_BASE                        0x40014200UL
#define CRYPT_BASE                      0x40006000UL
#define DMA_BASE                        0x40010000UL
#define FLASH_BASE                      0x000FFFB0UL
#define GPIOA_BASE                      0x40014010UL
#define GPIOB_BASE                      0x40000020UL
#define GPIOC_BASE                      0x40000040UL
#define GPIOD_BASE                      0x40000060UL
#define GPIOE_BASE                      0x40000080UL
#define GPIOF_BASE                      0x400000A0UL
#define GPIOSEL_BASE                    0x400000C0UL
#define I2C_BASE                        0x40010800UL
#define ISO78160_BASE                   0x40012000UL
#define ISO78161_BASE                   0x40012040UL
#define LCD_BASE                        0x40002000UL
#define MISC_BASE                       0x40013000UL
#define MISC2_BASE                      0x40013E00UL
#define PMU_BASE                        0x40014000UL
#define PWM0_BASE                       0x40012900UL
#define PWM1_BASE                       0x40012920UL
#define PWM2_BASE                       0x40012940UL
#define PWM3_BASE                       0x40012960UL
#define PWMOSEL_BASE                    0x400129F0UL
#define RTC_BASE                        0x40014800UL
#define SPI1_BASE                       0x40011000UL
#define SPI2_BASE                       0x40015800UL
#define TMR0_BASE                       0x40012800UL
#define TMR1_BASE                       0x40012820UL
#define TMR2_BASE                       0x40012840UL
#define TMR3_BASE                       0x40012860UL
#define UART0_BASE                      0x40011800UL
#define UART1_BASE                      0x40011820UL
#define UART2_BASE                      0x40011840UL
#define UART3_BASE                      0x40011860UL
#define UART4_BASE                      0x40011880UL
#define UART5_BASE                      0x400118A0UL
#define U32K0_BASE                      0x40014100UL
#define U32K1_BASE                      0x40014180UL


/* ================================================================================ */
/* ================             Peripheral declaration             ================ */
/* ================================================================================ */

#define ANA                             ((ANA_Type                *) ANA_BASE)
#define CRYPT                           ((CRYPT_Type              *) CRYPT_BASE)
#define DMA                             ((DMA_Type                *) DMA_BASE)
#define FLASH                           ((FLASH_Type              *) FLASH_BASE)
#define GPIOA                           ((GPIOA_Type              *) GPIOA_BASE)
#define GPIOB                           ((GPIO_Type               *) GPIOB_BASE)
#define GPIOC                           ((GPIO_Type               *) GPIOC_BASE)
#define GPIOD                           ((GPIO_Type               *) GPIOD_BASE)
#define GPIOE                           ((GPIO_Type               *) GPIOE_BASE)
#define GPIOF                           ((GPIO_Type               *) GPIOF_BASE)
#define GPIOSEL                         ((GPIOSEL_Type            *) GPIOSEL_BASE)
#define I2C                             ((I2C_Type                *) I2C_BASE)
#define ISO78160                        ((ISO7816_Type            *) ISO78160_BASE)
#define ISO78161                        ((ISO7816_Type            *) ISO78161_BASE)
#define LCD                             ((LCD_Type                *) LCD_BASE)
#define MISC                            ((MISC_Type               *) MISC_BASE)
#define MISC2                           ((MISC2_Type              *) MISC2_BASE)
#define PMU                             ((PMU_Type                *) PMU_BASE)
#define PWM0                            ((PWM_Type                *) PWM0_BASE)
#define PWM1                            ((PWM_Type                *) PWM1_BASE)
#define PWM2                            ((PWM_Type                *) PWM2_BASE)
#define PWM3                            ((PWM_Type                *) PWM3_BASE)
#define PWMOSEL                         ((PWMOSEL_Type            *) PWMOSEL_BASE)
#define RTC                             ((RTC_Type                *) RTC_BASE)
#define SPI1                            ((SPI_Type                *) SPI1_BASE)
#define SPI2                            ((SPI_Type                *) SPI2_BASE)
#define TMR0                            ((TMR_Type                *) TMR0_BASE)
#define TMR1                            ((TMR_Type                *) TMR1_BASE)
#define TMR2                            ((TMR_Type                *) TMR2_BASE)
#define TMR3                            ((TMR_Type                *) TMR3_BASE)
#define UART0                           ((UART_Type               *) UART0_BASE)
#define UART1                           ((UART_Type               *) UART1_BASE)
#define UART2                           ((UART_Type               *) UART2_BASE)
#define UART3                           ((UART_Type               *) UART3_BASE)
#define UART4                           ((UART_Type               *) UART4_BASE)
#define UART5                           ((UART_Type               *) UART5_BASE)
#define U32K0                           ((U32K_Type               *) U32K0_BASE)
#define U32K1                           ((U32K_Type               *) U32K1_BASE)


/** @} */ /* End of group Device_Peripheral_Registers */
/** @} */ /* End of group V85XX */
/** @} */ /* End of group Vango */

#ifdef __cplusplus
}
#endif


#endif  /* V85XX_H */

